@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.document;
 
 import java.io.InputStream;
@@ -352,7 +350,7 @@ public class DocFileServiceImpl implements DocFileService {
                     }
 
                     if (null != metaData) {
-                    	MDC.put(MDCEntries.FILENAME, metaData.getFileName());
+                        MDC.put(MDCEntries.FILENAME, metaData.getFileName());
                         // determine write protected state using the write permissions
                         final FileHelperService fileHelperService = fileHelperServiceFactory.create(session);
 
@@ -386,7 +384,8 @@ public class DocFileServiceImpl implements DocFileService {
                 streamInfo.setErrorCode(ErrorCode.LOADDOCUMENT_FAILED_ERROR);
             } finally {
                 closeFileAccess(fileAccess);
-            }
+                MDC.remove(MDCEntries.FILENAME);
+           }
         }
 
         LOG.trace("RT connection: TIME to get document stream = " + (System.currentTimeMillis() - time1) + "ms");
