@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -135,7 +135,9 @@ public class DocRequestJmsConsumer implements MessageListener, JmsMessageListene
         } catch (Exception e) {
         	log.error(e.getMessage(), e);
         } finally {
-        	MDC.clear();
+        	MDC.remove(MDCEntries.DOC_UID);
+			MDC.remove(MDCEntries.CLIENT_UID);
+			MDC.remove(MDCEntries.BACKEND_PART);
         }
     }
 }
