@@ -90,6 +90,21 @@ public class CTColorMapping {
     @XmlAttribute(required = true)
     protected STColorSchemeIndex folHlink;
 
+    public CTColorMapping() {
+        bg1 = STColorSchemeIndex.LT_1;
+        tx1 = STColorSchemeIndex.DK_1;
+        bg2 = STColorSchemeIndex.LT_2;
+        tx2 = STColorSchemeIndex.DK_2;
+        accent1 = STColorSchemeIndex.ACCENT_1;
+        accent2 = STColorSchemeIndex.ACCENT_2;
+        accent3 = STColorSchemeIndex.ACCENT_3;
+        accent4 = STColorSchemeIndex.ACCENT_4;
+        accent5 = STColorSchemeIndex.ACCENT_5;
+        accent6 = STColorSchemeIndex.ACCENT_6;
+        hlink = STColorSchemeIndex.HLINK;
+        folHlink = STColorSchemeIndex.FOL_HLINK;
+    }
+
     /**
      * Gets the value of the extLst property.
      * 
