@@ -29,8 +29,7 @@ import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlElements;
 import javax.xml.bind.annotation.XmlType;
-
-import org.docx4j.wml.ContentAccessor;
+import com.openexchange.office.filter.core.IContentAccessor;
 
 
 /**
@@ -56,7 +55,7 @@ import org.docx4j.wml.ContentAccessor;
 @XmlType(name = "CT_FillStyleList", propOrder = {
     "egFillProperties"
 })
-public class CTFillStyleList implements ContentAccessor {
+public class CTFillStyleList implements IContentAccessor {
 
     @XmlElements({
         @XmlElement(name = "grpFill", type = CTGroupFillProperties.class),
