@@ -21,10 +21,12 @@
 
 package org.docx4j.dml;
 
+import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlElement;
+import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -112,6 +114,7 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
      *     {@link CTNoFillProperties }
      *
      */
+    @Override
     public CTNoFillProperties getNoFill() {
         return noFill;
     }
@@ -124,6 +127,7 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
      *     {@link CTNoFillProperties }
      *
      */
+    @Override
     public void setNoFill(CTNoFillProperties value) {
         this.noFill = value;
     }
@@ -136,6 +140,7 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
      *     {@link CTSolidColorFillProperties }
      *
      */
+    @Override
     public CTSolidColorFillProperties getSolidFill() {
         return solidFill;
     }
@@ -148,6 +153,7 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
      *     {@link CTSolidColorFillProperties }
      *
      */
+    @Override
     public void setSolidFill(CTSolidColorFillProperties value) {
         this.solidFill = value;
     }
@@ -160,6 +166,7 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
      *     {@link CTGradientFillProperties }
      *
      */
+    @Override
     public CTGradientFillProperties getGradFill() {
         return gradFill;
     }
@@ -172,6 +179,7 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
      *     {@link CTGradientFillProperties }
      *
      */
+    @Override
     public void setGradFill(CTGradientFillProperties value) {
         this.gradFill = value;
     }
@@ -184,6 +192,7 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
      *     {@link CTBlipFillProperties }
      *
      */
+    @Override
     public CTBlipFillProperties getBlipFill() {
         return blipFill;
     }
@@ -196,6 +205,7 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
      *     {@link CTBlipFillProperties }
      *
      */
+    @Override
     public void setBlipFill(CTBlipFillProperties value) {
         this.blipFill = value;
     }
@@ -208,6 +218,7 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
      *     {@link CTPatternFillProperties }
      *
      */
+    @Override
     public CTPatternFillProperties getPattFill() {
         return pattFill;
     }
@@ -220,6 +231,7 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
      *     {@link CTPatternFillProperties }
      *
      */
+    @Override
     public void setPattFill(CTPatternFillProperties value) {
         this.pattFill = value;
     }
@@ -232,6 +244,7 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
      *     {@link CTGroupFillProperties }
      *
      */
+    @Override
     public CTGroupFillProperties getGrpFill() {
         return grpFill;
     }
@@ -244,6 +257,7 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
      *     {@link CTGroupFillProperties }
      *
      */
+    @Override
     public void setGrpFill(CTGroupFillProperties value) {
         this.grpFill = value;
     }
@@ -367,4 +381,29 @@ public class CTGroupShapeProperties implements IFillProperties, ITransform2DAcce
     public void setBwMode(STBlackWhiteMode value) {
         this.bwMode = value;
     }
+
+    @XmlTransient
+    private Object parent;
+
+    @Override
+    public Object getParent() {
+        return this.parent;
+    }
+
+    @Override
+    public void setParent(Object parent) {
+        this.parent = parent;
+    }
+
+    /**
+     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
+     * 
+     * @param parent
+     *     The parent object in the object tree.
+     * @param unmarshaller
+     *     The unmarshaller that generated the instance.
+     */
+    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
+        setParent(parent);
+    }
 }
