@@ -21,9 +21,11 @@
 
 package org.docx4j.dml;
 
+import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
+import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -306,6 +308,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     {@link CTNoFillProperties }
      *     
      */
+    @Override
     public CTNoFillProperties getNoFill() {
         return noFill;
     }
@@ -318,6 +321,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     {@link CTNoFillProperties }
      *     
      */
+    @Override
     public void setNoFill(CTNoFillProperties value) {
         this.noFill = value;
     }
@@ -330,6 +334,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     {@link CTSolidColorFillProperties }
      *     
      */
+    @Override
     public CTSolidColorFillProperties getSolidFill() {
         return solidFill;
     }
@@ -342,6 +347,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     {@link CTSolidColorFillProperties }
      *     
      */
+    @Override
     public void setSolidFill(CTSolidColorFillProperties value) {
         this.solidFill = value;
     }
@@ -354,6 +360,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     {@link CTGradientFillProperties }
      *     
      */
+    @Override
     public CTGradientFillProperties getGradFill() {
         return gradFill;
     }
@@ -366,6 +373,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     {@link CTGradientFillProperties }
      *     
      */
+    @Override
     public void setGradFill(CTGradientFillProperties value) {
         this.gradFill = value;
     }
@@ -378,6 +386,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     {@link CTBlipFillProperties }
      *     
      */
+    @Override
     public CTBlipFillProperties getBlipFill() {
         return blipFill;
     }
@@ -390,6 +399,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     {@link CTBlipFillProperties }
      *     
      */
+    @Override
     public void setBlipFill(CTBlipFillProperties value) {
         this.blipFill = value;
     }
@@ -402,6 +412,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     {@link CTPatternFillProperties }
      *     
      */
+    @Override
     public CTPatternFillProperties getPattFill() {
         return pattFill;
     }
@@ -414,6 +425,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     {@link CTPatternFillProperties }
      *     
      */
+    @Override
     public void setPattFill(CTPatternFillProperties value) {
         this.pattFill = value;
     }
@@ -426,6 +438,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     {@link CTGroupFillProperties }
      *     
      */
+    @Override
     public CTGroupFillProperties getGrpFill() {
         return grpFill;
     }
@@ -438,6 +451,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     {@link CTGroupFillProperties }
      *     
      */
+    @Override
     public void setGrpFill(CTGroupFillProperties value) {
         this.grpFill = value;
     }
@@ -573,9 +587,8 @@ public class CTTableCellProperties implements IFillProperties {
     public STTextVerticalType getVert() {
         if (vert == null) {
             return STTextVerticalType.HORZ;
-        } else {
-            return vert;
         }
+        return vert;
     }
 
     /**
@@ -599,11 +612,7 @@ public class CTTableCellProperties implements IFillProperties {
      *     
      */
     public STTextAnchoringType getAnchor() {
-        if (anchor == null) {
-            return STTextAnchoringType.T;
-        } else {
-            return anchor;
-        }
+        return anchor;
     }
 
     /**
@@ -629,9 +638,8 @@ public class CTTableCellProperties implements IFillProperties {
     public boolean isAnchorCtr() {
         if (anchorCtr == null) {
             return false;
-        } else {
-            return anchorCtr;
         }
+        return anchorCtr;
     }
 
     /**
@@ -657,9 +665,8 @@ public class CTTableCellProperties implements IFillProperties {
     public STTextHorzOverflowType getHorzOverflow() {
         if (horzOverflow == null) {
             return STTextHorzOverflowType.CLIP;
-        } else {
-            return horzOverflow;
         }
+        return horzOverflow;
     }
 
     /**
@@ -674,4 +681,29 @@ public class CTTableCellProperties implements IFillProperties {
         this.horzOverflow = value;
     }
 
+
+    @XmlTransient
+    private Object parent;
+
+    @Override
+    public Object getParent() {
+        return this.parent;
+    }
+
+    @Override
+    public void setParent(Object parent) {
+        this.parent = parent;
+    }
+
+    /**
+     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
+     * 
+     * @param parent
+     *     The parent object in the object tree.
+     * @param unmarshaller
+     *     The unmarshaller that generated the instance.
+     */
+    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
+        setParent(parent);
+    }
 }
