@@ -27,9 +27,9 @@ import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
-import org.docx4j.IndexedNodeList;
-import org.docx4j.wml.ContentAccessor;
+import com.openexchange.office.filter.core.IContentAccessor;
+import com.openexchange.office.filter.core.DLList;
+import com.openexchange.office.filter.core.component.Child;
 
 
 /**
@@ -58,10 +58,10 @@ import org.docx4j.wml.ContentAccessor;
     "tc",
     "extLst"
 })
-public class CTTableRow implements ContentAccessor, Child {
+public class CTTableRow implements IContentAccessor, Child {
 
     @XmlElement(name="tc", type = CTTableCell.class)
-    protected IndexedNodeList<Object> tc;
+    protected DLList<Object> tc;
     protected CTOfficeArtExtensionList extLst;
     @XmlAttribute(required = true)
     protected long h;
@@ -90,9 +90,9 @@ public class CTTableRow implements ContentAccessor, Child {
      * 
      * 
      */
-    public IndexedNodeList<Object> getContent() {
+    public DLList<Object> getContent() {
         if (tc == null) {
-            tc = new IndexedNodeList<Object>();
+            tc = new DLList<Object>();
         }
         return tc;
     }
