@@ -98,11 +98,11 @@ public class CTAreaChart extends NoBarDirChart {
     }
 
     @Override
-    public void setStacking(String stacking) {
+    public void setStacking(String stacking, String defaultStacking) {
         if(grouping==null) {
             grouping = new CTGrouping();
         }
-        grouping.setVal(STGrouping.fromValue(stacking));
+        grouping.setVal(STGrouping.fromValue(stacking, defaultStacking));
     }
 
     /**
