@@ -131,11 +131,11 @@ public class CTBarChart implements IListSer {
     }
 
     @Override
-    public void setStacking(String stacking) {
+    public void setStacking(String stacking, String defaultStacking) {
         if(grouping==null) {
             grouping = new CTBarGrouping();
         }
-        grouping.setVal(STBarGrouping.fromValue(stacking));
+        grouping.setVal(STBarGrouping.fromValue(stacking, defaultStacking));
     }
 
 
