@@ -5,7 +5,7 @@ import java.util.List;
 /**
  * Set/Get the content for Bubble and scatter graphic  */
 
-public interface ISerContentXY extends ISerContent {
+public interface ISerContentXY extends ISerErrorBarListContent {
 
     public List<CTDPt> getDPt();
 
@@ -14,5 +14,4 @@ public interface ISerContentXY extends ISerContent {
 
     public List<CTTrendline> getTrendline();
 
-    public List<CTErrBars> getErrBars();
 }
