@@ -25,7 +25,7 @@ import javax.xml.bind.JAXBElement;
 import javax.xml.bind.annotation.XmlElementDecl;
 import javax.xml.bind.annotation.XmlRegistry;
 import javax.xml.namespace.QName;
-import org.docx4j.dml.chart.chartStyle.CTChartColor;
+
 import org.docx4j.dml.chartDrawing.CTDrawing;
 
 
@@ -49,7 +49,6 @@ public class ObjectFactory {
     private final static QName _Chart_QNAME = new QName("http://schemas.openxmlformats.org/drawingml/2006/chart", "chart");
     private final static QName _UserShapes_QNAME = new QName("http://schemas.openxmlformats.org/drawingml/2006/chart", "userShapes");
     private final static QName _ChartSpace_QNAME = new QName("http://schemas.openxmlformats.org/drawingml/2006/chart", "chartSpace");
-    private final static QName _ChartColor_QNAME = new QName("http://schemas.microsoft.com/office/drawing/2012/chartStyle", "colorStyle");
 
     /**
      * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.docx4j.dml.chart
@@ -1164,13 +1163,4 @@ public class ObjectFactory {
     public JAXBElement<CTChartSpace> createChartSpace(CTChartSpace value) {
         return new JAXBElement<CTChartSpace>(_ChartSpace_QNAME, CTChartSpace.class, null, value);
     }
-
-    /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link CTChartColor }{@code >}}
-     *
-     */
-    @XmlElementDecl(namespace = "http://schemas.microsoft.com/office/drawing/2012/chartStyle", name = "colorStyle")
-    public JAXBElement<CTChartColor> createChartColor(CTChartColor value) {
-        return new JAXBElement<CTChartColor>(_ChartColor_QNAME, CTChartColor.class, null, value);
-    }
 }
