@@ -85,6 +85,11 @@ public class CTPicture implements ITransform2DAccessor, IPicture {
     	return spPr.getXfrm(forceCreate);
     }
 
+    @Override
+    public void removeXfrm() {
+        spPr.removeXfrm();
+    }
+
     /**
      * Gets the value of the blipFill property.
      * 
@@ -93,7 +98,10 @@ public class CTPicture implements ITransform2DAccessor, IPicture {
      *     {@link CTBlipFillProperties }
      *     
      */
-    public CTBlipFillProperties getBlipFill() {
+    public CTBlipFillProperties getBlipFill(boolean forceCreate) {
+    	if(blipFill==null&&forceCreate) {
+    		blipFill = new CTBlipFillProperties();
+    	}
         return blipFill;
     }
 
