@@ -22,12 +22,13 @@
 package org.docx4j.dml.chartDrawing;
 
 import javax.xml.bind.Marshaller;
+import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlElement;
+import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-
 import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.CTNonVisualDrawingShapeProps;
 import org.docx4j.dml.CTShapeProperties;
@@ -91,6 +92,7 @@ public class CTShape implements ITransform2DAccessor, IShape {
     @XmlAttribute
     protected Boolean fPublished;
 
+    @Override
     public CTTransform2D getXfrm(boolean forceCreate) {
     	return spPr.getXfrm(forceCreate);
     }
@@ -132,6 +134,7 @@ public class CTShape implements ITransform2DAccessor, IShape {
      *     {@link CTShapeProperties }
      *     
      */
+    @Override
     public CTShapeProperties getSpPr() {
         return spPr;
     }
@@ -144,6 +147,7 @@ public class CTShape implements ITransform2DAccessor, IShape {
      *     {@link CTShapeProperties }
      *     
      */
+    @Override
     public void setSpPr(CTShapeProperties value) {
         this.spPr = value;
     }
@@ -156,6 +160,7 @@ public class CTShape implements ITransform2DAccessor, IShape {
      *     {@link CTShapeStyle }
      *     
      */
+    @Override
     public CTShapeStyle getStyle(boolean forceCreate) {
     	if(style==null&&forceCreate) {
     		style = new CTShapeStyle();
@@ -171,6 +176,7 @@ public class CTShape implements ITransform2DAccessor, IShape {
      *     {@link CTShapeStyle }
      *     
      */
+    @Override
     public void setStyle(CTShapeStyle value) {
         this.style = value;
     }
@@ -258,9 +264,8 @@ public class CTShape implements ITransform2DAccessor, IShape {
     public boolean isFLocksText() {
         if (fLocksText == null) {
             return true;
-        } else {
-            return fLocksText;
         }
+        return fLocksText;
     }
 
     /**
@@ -286,9 +291,8 @@ public class CTShape implements ITransform2DAccessor, IShape {
     public boolean isFPublished() {
         if (fPublished == null) {
             return false;
-        } else {
-            return fPublished;
         }
+        return fPublished;
     }
 
     /**
@@ -371,4 +375,30 @@ public class CTShape implements ITransform2DAccessor, IShape {
 		}
 		txBody.setBodyPr(textBodyProperties);
  	}
+
+
+    @XmlTransient
+    private Object parent;
+
+    @Override
+    public Object getParent() {
+        return this.parent;
+    }
+
+    @Override
+    public void setParent(Object parent) {
+        this.parent = parent;
+    }
+
+    /**
+     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
+     * 
+     * @param parent
+     *     The parent object in the object tree.
+     * @param unmarshaller
+     *     The unmarshaller that generated the instance.
+     */
+    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
+        setParent(parent);
+    }
 }
