@@ -29,8 +29,6 @@ import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
-import org.docx4j.IndexedNodeList;
 import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.CTNonVisualGraphicFrameProperties;
 import org.docx4j.dml.CTTransform2D;
@@ -38,7 +36,9 @@ import org.docx4j.dml.Graphic;
 import org.docx4j.dml.INonVisualDrawingPropertyAccess;
 import org.docx4j.dml.INonVisualDrawingShapePropertyAccess;
 import org.docx4j.dml.ITransform2DAccessor;
-import org.docx4j.wml.ContentAccessor;
+import com.openexchange.office.filter.core.IContentAccessor;
+import com.openexchange.office.filter.core.DLList;
+import com.openexchange.office.filter.core.component.Child;
 
 /**
  * <p>Java class for CT_GraphicalObjectFrame complex type.
@@ -70,7 +70,7 @@ import org.docx4j.wml.ContentAccessor;
     "graphic"
 })
 @XmlRootElement(name="graphicFrame")
-public class CTGraphicalObjectFrame implements Child, ContentAccessor, ITransform2DAccessor, INonVisualDrawingPropertyAccess, INonVisualDrawingShapePropertyAccess {
+public class CTGraphicalObjectFrame implements Child, IContentAccessor, ITransform2DAccessor, INonVisualDrawingPropertyAccess, INonVisualDrawingShapePropertyAccess {
 
     @XmlElement(required = true)
     protected CTGraphicalObjectFrameNonVisual nvGraphicFramePr;
@@ -86,7 +86,7 @@ public class CTGraphicalObjectFrame implements Child, ContentAccessor, ITransfor
     private Object parent;
 
     @Override
-    public IndexedNodeList<Object> getContent() {
+    public DLList<Object> getContent() {
         return null;
     }
 
