@@ -30,7 +30,6 @@ import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.IndexedNodeList;
 import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.CTNonVisualDrawingShapeProps;
 import org.docx4j.dml.CTShapeProperties;
@@ -42,7 +41,8 @@ import org.docx4j.dml.CTTransform2D;
 import org.docx4j.dml.IShape;
 import org.docx4j.dml.ITransform2DAccessor;
 import org.docx4j.jaxb.Context;
-import org.docx4j.wml.ContentAccessor;
+import com.openexchange.office.filter.core.IContentAccessor;
+import com.openexchange.office.filter.core.DLList;
 
 /**
  * <p>Java class for CT_Shape complex type.
@@ -78,7 +78,7 @@ import org.docx4j.wml.ContentAccessor;
     "txBody"
 })
 @XmlRootElement(name="sp")
-public class CTShape implements ContentAccessor, ITransform2DAccessor, IShape {
+public class CTShape implements IContentAccessor, ITransform2DAccessor, IShape {
 
     @XmlElement(required = true)
     protected CTShapeNonVisual nvSpPr;
@@ -106,7 +106,7 @@ public class CTShape implements ContentAccessor, ITransform2DAccessor, IShape {
     }
 
     @Override
-    public IndexedNodeList<Object> getContent() {
+    public DLList<Object> getContent() {
         if (txBody==null) {
             txBody = new CTTextBody();
             txBody.setBodyPr(new CTTextBodyProperties());
