@@ -1,11 +1,12 @@
 package org.docx4j.dml.spreadsheetdrawing;
 
 import org.docx4j.mce.AlternateContent;
+import com.openexchange.office.filter.core.IContentAccessor;
 
 /**
  * Get the drawing/graphic from a generic anchor.
  */
-public interface ICellAnchor {
+public interface ICellAnchor extends IContentAccessor {
 
     public CTShape getSp();
     public void setSp(CTShape value);
