@@ -27,10 +27,10 @@ import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.ValidationEventHandler;
 import javax.xml.stream.XMLInputFactory;
 import org.docx4j.dml.CTCustomGeometry2D;
-import org.docx4j.dml.STShapeType;
 import org.docx4j.openpackaging.packages.OpcPackage;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import com.openexchange.office.filter.core.STShapeType;
 
 final public class Context {
 
