@@ -29,7 +29,6 @@ import javax.xml.bind.annotation.XmlElementRef;
 import javax.xml.bind.annotation.XmlElementRefs;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
 import org.docx4j.wml.CTBookmark;
 import org.docx4j.wml.CTMarkup;
 import org.docx4j.wml.CTMarkupRange;
@@ -44,6 +43,7 @@ import org.docx4j.wml.RunDel;
 import org.docx4j.wml.RunIns;
 import org.docx4j.wml.RunMoveFrom;
 import org.docx4j.wml.RunMoveTo;
+import com.openexchange.office.filter.core.component.Child;
 
 
 /**
