@@ -441,6 +441,7 @@ public class ContentTypeManager  {
             return new ChartExPart(partName);
 		} else if (contentType.startsWith("application/vnd.openxmlformats-officedocument.presentationml")
             || ContentTypes.PRESENTATIONML_MAIN_MACROENABLED.equals(contentType)
+            || ContentTypes.PRESENTATIONML_TEMPLATE_MACROENABLED.equals(contentType)
             || ContentTypes.PRESENTATIONML_SLIDESHOW.equals(contentType)
             || ContentTypes.PRESENTATIONML_SLIDESHOW_MACROENABLED.equals(contentType)) {
 
@@ -493,6 +494,7 @@ public class ContentTypeManager  {
 
         if (contentType.equals(ContentTypes.PRESENTATIONML_MAIN)
             || contentType.equals(ContentTypes.PRESENTATIONML_TEMPLATE)
+            || contentType.equals(ContentTypes.PRESENTATIONML_TEMPLATE_MACROENABLED)
             || contentType.equals(ContentTypes.PRESENTATIONML_MAIN_MACROENABLED)
             || contentType.equals(ContentTypes.PRESENTATIONML_SLIDESHOW)
             || contentType.equals(ContentTypes.PRESENTATIONML_SLIDESHOW_MACROENABLED)) {
@@ -950,6 +952,7 @@ public class ContentTypeManager  {
             case ContentTypes.PRESENTATIONML_MAIN:
             case ContentTypes.PRESENTATIONML_MAIN_MACROENABLED:
             case ContentTypes.PRESENTATIONML_TEMPLATE:
+            case ContentTypes.PRESENTATIONML_TEMPLATE_MACROENABLED:
             case ContentTypes.PRESENTATIONML_SLIDESHOW:
             case ContentTypes.PRESENTATIONML_SLIDESHOW_MACROENABLED:
 
