@@ -125,7 +125,7 @@ public class ContentTypes {
 
     // PartName="/word/commentsEx.xml"
     public final static String WORDPROCESSINGML_COMMENTS_EX = "application/vnd.openxmlformats-officedocument.wordprocessingml.commentsExtended+xml";
-    
+
 	// PartName="/word/endnotes.xml"
 	public final static String WORDPROCESSINGML_ENDNOTES = "application/vnd.openxmlformats-officedocument.wordprocessingml.endnotes+xml";
 	// PartName="/word/fontTable.xml"
@@ -193,6 +193,11 @@ public class ContentTypes {
 	// .potx |
 	public final static String PRESENTATIONML_TEMPLATE =
 		"application/vnd.openxmlformats-officedocument.presentationml.template.main+xml";
+
+	// .ptom
+	public final static String PRESENTATIONML_TEMPLATE_MACROENABLED =
+	    "application/vnd.ms-powerpoint.template.macroEnabled.main+xml";
+
 	// .ppsx |
 	public final static String PRESENTATIONML_SLIDESHOW =
 		"application/vnd.openxmlformats-officedocument.presentationml.slideshow.main+xml";
