@@ -417,24 +417,15 @@ public class Load3 {
 //					is = partStore.loadPart( resolvedPartUri);
 //					((BinaryPart)part).setBinaryData(is);
 
-				} else if (part instanceof org.docx4j.openpackaging.parts.XmlPart ) {
+				} else if (part instanceof org.docx4j.openpackaging.parts.XmlPart) {
 
-					is = partStore.loadPart( resolvedPartUri);
-
-//					try {
-						((XmlPart)part).setDocument(is);
-
-					// Experimental 22/6/2011; don't fall back to binary (which we used to)
-
-//					} catch (Docx4JException d) {
-//						// This isn't an XML part after all,
-//						// even though ContentTypeManager detected it as such
-//						// So get it as a binary part
-//						part = getBinaryPart(partByteArrays, ctm, resolvedPartUri);
-//						log.warn("Could not parse as XML, so using BinaryPart for "
-//								+ resolvedPartUri);
-//						((BinaryPart)part).setBinaryData(is);
-//					}
+					is = partStore.loadPart(resolvedPartUri);
+					if(is == null) {
+					    part = null;
+					}
+					else {
+	                    ((XmlPart)part).setDocument(is);
+					}
 
 				} else {
 					// Shouldn't happen, since ContentTypeManagerImpl should
