@@ -165,7 +165,7 @@ public class Save {
                 final ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
                 ((SerializationPart<?>)part).marshal(outputStream);
 
-                // searching and collecting each "rId                
+                // searching and collecting each "rId
                 final byte[] out = outputStream.toByteArray();
                 final byte[] pattern = {'"', 'r', 'I', 'd'};
                 final Set<String> ids = CharMatcher.findAllMatches(out, pattern, '"', 3);
@@ -173,8 +173,10 @@ public class Save {
                 // now each rId used within our part is kept within ids
                 for(int i = 0; i<relationshipList.size();i++) {
                     final Relationship relShip = relationshipList.get(i);
-                    if(checkRelations.contains(relShip.getType())&&!ids.contains(relShip.getId())) {
-                        relationshipList.remove(i--);
+                    if(relShip.getId()!=null && relShip.getId().startsWith("rId")) {
+                        if(checkRelations.contains(relShip.getType())&&!ids.contains(relShip.getId())) {
+                            relationshipList.remove(i--);
+                        }
                     }
                 }
                 return outputStream;
