@@ -25,10 +25,11 @@ import java.io.IOException;
 import javax.xml.bind.JAXBException;
 import org.docx4j.dml.diagram.CTColorTransform;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
+import org.docx4j.openpackaging.parts.JaxbXmlPart;
 import org.docx4j.openpackaging.parts.PartName;
 import org.docx4j.openpackaging.parts.relationships.Namespaces;
 
-public final class DiagramColorsPart extends JaxbDmlPart<CTColorTransform> {
+public final class DiagramColorsPart extends JaxbXmlPart<CTColorTransform> {
 	// <xsd:element name="colorsDef" type="CT_ColorTransform">
 
 	public DiagramColorsPart(PartName partName) throws InvalidFormatException {
@@ -43,7 +44,6 @@ public final class DiagramColorsPart extends JaxbDmlPart<CTColorTransform> {
 	}
 
 	public void init() {
-
 		// Used if this Part is added to [Content_Types].xml
 		setContentType(new  org.docx4j.openpackaging.contenttype.ContentType(
 				org.docx4j.openpackaging.contenttype.ContentTypes.DRAWINGML_DIAGRAM_COLORS));
