@@ -20,11 +20,9 @@
 
 package org.docx4j.openpackaging.parts.DrawingML;
 
-import javax.xml.bind.JAXBElement;
-
 import org.docx4j.dml.CTBaseStylesOverride;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
-import org.docx4j.openpackaging.parts.JaxbXmlPartXPathAware;
+import org.docx4j.openpackaging.parts.JaxbXmlPart;
 import org.docx4j.openpackaging.parts.PartName;
 import org.docx4j.openpackaging.parts.relationships.Namespaces;
 
@@ -38,7 +36,7 @@ import org.docx4j.openpackaging.parts.relationships.Namespaces;
  *    org.docx4j.dml.CTBaseStylesOverride bso = of.createCTBaseStylesOverride();
  *    JAXBElement<CTBaseStylesOverride> themeOverride = of.createThemeOverride(bso);
  */
-public final class ThemeOverridePart extends JaxbXmlPartXPathAware<JAXBElement<CTBaseStylesOverride>> {
+public final class ThemeOverridePart extends JaxbXmlPart<CTBaseStylesOverride> {
 
 	public ThemeOverridePart(PartName partName) throws InvalidFormatException {
 		super(partName);
