@@ -22,7 +22,6 @@ package org.docx4j.openpackaging.parts;
 
 import java.util.HashMap;
 import java.util.Map;
-
 import org.docx4j.dml.FontCollection;
 import org.docx4j.dml.FontCollection.Font;
 import org.docx4j.dml.TextFont;
@@ -37,7 +36,7 @@ import org.slf4j.LoggerFactory;
 
 
 
-public final class ThemePart extends JaxbXmlPartXPathAware<Theme> {
+public final class ThemePart extends JaxbXmlPart<Theme> {
 	
 	private static Logger log = LoggerFactory.getLogger(ThemePart.class);		
 	
@@ -70,7 +69,7 @@ public final class ThemePart extends JaxbXmlPartXPathAware<Theme> {
     
     public org.docx4j.dml.BaseStyles.FontScheme getFontScheme() {
     	if (fontScheme == null) { // ie we haven't done this already
-			org.docx4j.dml.Theme theme = (org.docx4j.dml.Theme) this
+			org.docx4j.dml.Theme theme = this
 					.getJaxbElement();
 			if (theme.getThemeElements() != null
 					&& theme.getThemeElements().getFontScheme() != null) {
@@ -122,10 +121,10 @@ public final class ThemePart extends JaxbXmlPartXPathAware<Theme> {
     	
     	if (majorFontCollectionInitialised) return majorFontCollection;
     	
-		if (this.getContents().getThemeElements()!=null
-				&& this.getContents().getThemeElements().getFontScheme()!=null) {
+		if (this.getJaxbElement().getThemeElements()!=null
+				&& this.getJaxbElement().getThemeElements().getFontScheme()!=null) {
 			
-			majorFontCollection = this.getContents().getThemeElements().getFontScheme().getMajorFont();
+			majorFontCollection = this.getJaxbElement().getThemeElements().getFontScheme().getMajorFont();
 		}
 		majorFontCollectionInitialised = true;
 		return majorFontCollection;
@@ -137,10 +136,10 @@ public final class ThemePart extends JaxbXmlPartXPathAware<Theme> {
     	
     	if (minorFontCollectionInitialised) return minorFontCollection;
     	
-		if (this.getContents().getThemeElements()!=null
-				&& this.getContents().getThemeElements().getFontScheme()!=null) {
+		if (this.getJaxbElement().getThemeElements()!=null
+				&& this.getJaxbElement().getThemeElements().getFontScheme()!=null) {
 			
-			minorFontCollection = this.getContents().getThemeElements().getFontScheme().getMinorFont();
+			minorFontCollection = this.getJaxbElement().getThemeElements().getFontScheme().getMinorFont();
 		}
 		minorFontCollectionInitialised = true;
 		return minorFontCollection;
