@@ -63,12 +63,12 @@ public final class CommentsPart extends JaxbXmlPart<Comments> implements IConten
     	return this.getJaxbElement().getContent();
     }
 
-    public void mergeParaIdToUserId() {
+    public void mergeParaIdToComment() {
         final Comments comments = getJaxbElement();
         for(Comment comment:comments.getComments()) {
-            final Integer paraId = comment.getParaId();
+            final Integer paraId = comment.getParaIdFromParagraph();
             if(paraId!=null) {
-                comment.setUserId(paraId & 0xffff);
+                comment.setParaId(paraId);
             }
         }
     }
