@@ -28,11 +28,11 @@ import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.parts.JaxbXmlPart;
 import org.docx4j.openpackaging.parts.PartName;
 import org.docx4j.openpackaging.parts.relationships.Namespaces;
-import org.docx4j.wml.ContentAccessor;
 import org.docx4j.wml.FldChar;
 import org.docx4j.wml.Hdr;
+import com.openexchange.office.filter.core.IContentAccessor;
 
-public final class HeaderPart extends JaxbXmlPart<Hdr> implements ContentAccessor {
+public final class HeaderPart extends JaxbXmlPart<Hdr> implements IContentAccessor {
 
 	public HeaderPart(PartName partName) throws InvalidFormatException {
 		super(partName);		
