@@ -47,7 +47,6 @@
  * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-
 package org.docx4j.openpackaging.parts.relationships;
 
 import java.net.URI;
@@ -55,10 +54,7 @@ import java.net.URISyntaxException;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
-
 import javax.xml.bind.JAXBException;
-import javax.xml.bind.Unmarshaller;
-
 import org.docx4j.XmlUtils;
 import org.docx4j.jaxb.Context;
 import org.docx4j.jaxb.NamespacePrefixMapperUtils;
@@ -66,7 +62,6 @@ import org.docx4j.openpackaging.Base;
 import org.docx4j.openpackaging.URIHelper;
 import org.docx4j.openpackaging.contenttype.ContentTypeManager;
 import org.docx4j.openpackaging.contenttype.ContentTypes;
-import org.docx4j.openpackaging.exceptions.Docx4JException;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.exceptions.InvalidOperationException;
 import org.docx4j.openpackaging.packages.OpcPackage;
@@ -79,7 +74,6 @@ import org.docx4j.relationships.Relationships;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-
 /**
  * Represents a Relationship Part, which contains the relationships for a
  * given PackagePart or the Package.
@@ -206,9 +200,13 @@ public final class RelationshipsPart extends JaxbXmlPart<Relationships> {
 
 	/** Gets a loaded Part by its id */
 	public Part getPart(String id) {
+	    final Relationship relation = getRelationshipByID(id);
+	    return relation!=null ? getPart(relation) :  null;
+	}
 
-		log.debug("looking for: " + id);
-		return getPart(getRelationshipByID(id));
+	public Part getPartByType(String type) {
+	    final Relationship relation = getRelationshipByType(type);
+	    return relation!=null ? getPart(relation) : null;
 	}
 
 	/**
@@ -274,13 +272,12 @@ public final class RelationshipsPart extends JaxbXmlPart<Relationships> {
 				return null;
 			}
 
-		} else {
-			// EXTERNAL
-			return getPackage().getExternalResources().get(
-					new ExternalTarget( r.getTarget() ) );
-			// TODO - doesn't handle a relative reference,
-			// because the keys are absolute references
 		}
+		// EXTERNAL
+		return getPackage().getExternalResources().get(
+				new ExternalTarget( r.getTarget() ) );
+		// TODO - doesn't handle a relative reference,
+		// because the keys are absolute references
 	}
 
 	// ----------------------------------------------------------
@@ -575,13 +572,9 @@ public final class RelationshipsPart extends JaxbXmlPart<Relationships> {
 			}
 			return rel;
 
-		} else {
-			// Usual case
-
-			loadPart(part, rel);
-			return rel;
-
 		}
+		loadPart(part, rel);
+		return rel;
 
 		// Is more than one rel with the same target
 		// ever permitted. For example, an image? YES
@@ -638,23 +631,23 @@ public final class RelationshipsPart extends JaxbXmlPart<Relationships> {
 		}
 
 		for (Relationship r : relationshipsToGo ) {
-
-			try {
-				String resolvedPartUri = URIHelper.resolvePartUri(
-						getSourceURI(), new URI(r.getTarget())).toString();
-
-				log.debug("Removing part: " + resolvedPartUri);
-
-				removedParts.addAll(
-						removePart(new PartName(resolvedPartUri)) );
-
-			} catch (URISyntaxException e) {
-				log.error("Cannot convert " + r.getTarget()
-						+ " in a valid relationship URI-> ignored", e);
-			} catch (InvalidFormatException e) {
-				// TODO Auto-generated catch block
-				e.printStackTrace();
-			}
+		    if(!"External".equals(r.getTargetMode())) {
+    			try {
+    				String resolvedPartUri = URIHelper.resolvePartUri(
+    						getSourceURI(), new URI(r.getTarget())).toString();
+    
+    				log.debug("Removing part: " + resolvedPartUri);
+    
+    				removedParts.addAll(
+    						removePart(new PartName(resolvedPartUri)) );
+    
+    			} catch (URISyntaxException e) {
+    				log.error("Cannot convert " + r.getTarget()
+    						+ " in a valid relationship URI-> ignored", e);
+    			} catch (InvalidFormatException e) {
+    			    //
+    			}
+		    }
 		}
 
 		return removedParts;
@@ -701,14 +694,6 @@ public final class RelationshipsPart extends JaxbXmlPart<Relationships> {
 //		this.isDirty = true;
 	}
 
-	/**
-	 * @see getRel
-	 */
-	@Deprecated // introduced in 1295, and used in MergeDocx v1.0-1.1
-	public boolean isATarget(PartName partName) {
-		return (getRel(partName)!=null);
-	}
-
 	/**
 	 * Is partname a target of any of these rels?
 	 * @param partName
@@ -785,6 +770,13 @@ public final class RelationshipsPart extends JaxbXmlPart<Relationships> {
 
 	}
 
+	public void removeRelationshipByType(String type) {
+	    final Relationship relationship = getRelationshipByType(type);
+	    if(relationship!=null) {
+	        removeRelationship(relationship);
+	    }
+	}
+
 	public void removeRelationship(PartName partName) {
 
 		// Remove the relationship for which it is a target from here
@@ -812,10 +804,8 @@ public final class RelationshipsPart extends JaxbXmlPart<Relationships> {
 			// The Part may be in the package somewhere, but its not
 			// a target of this relationships part!
 			throw new IllegalArgumentException(partName + " is not a target of " + this.partName );
-		} else {
-			removeRelationship(relToBeRemoved);
 		}
-
+		removeRelationship(relToBeRemoved);
 	}
 
 	/**
@@ -840,11 +830,10 @@ public final class RelationshipsPart extends JaxbXmlPart<Relationships> {
      *     If any unexpected errors occur while unmarshalling
      */
 	@Override
-    public Relationships unmarshal( java.io.InputStream is ) throws JAXBException {
-
+    public Relationships unmarshal(java.io.InputStream is) {
 		try {
 			log.debug("unmarshalling " + this.getClass().getName() );
-			jaxbElement = (Relationships) XmlUtils.unmarshal(is, jc, new org.docx4j.jaxb.JaxbValidationEventHandler());
+			jaxbElement = (Relationships) XmlUtils.unmarshal(is, jc, new org.docx4j.jaxb.JaxbValidationEventHandler(null));
 
 		} catch (Exception e ) {
 			e.printStackTrace();
@@ -856,41 +845,16 @@ public final class RelationshipsPart extends JaxbXmlPart<Relationships> {
 
     }
 
-	@Override // need this so that resetIdAllocator() is called
-    public Relationships unmarshal(org.w3c.dom.Element el) throws JAXBException {
-
-		try {
-
-			Unmarshaller u = jc.createUnmarshaller();
-
-			u.setEventHandler(new org.docx4j.jaxb.JaxbValidationEventHandler());
-
-			jaxbElement = (Relationships) u.unmarshal( el );
-
-		} catch (JAXBException e) {
-//			e.printStackTrace();
-			log.error(e.getMessage(), e);
-			throw e;
-		}
-
-		resetIdAllocator();
-		return jaxbElement;
-
+    @Override
+    public void marshal(java.io.OutputStream os) {
+        try {
+            marshal(os, NamespacePrefixMapperUtils.getPrefixMapperRelationshipsPart() );
+        }
+        catch(Exception e) {
+            throw new RuntimeException(e);
+        }
 	}
 
-
-    public void marshal(org.w3c.dom.Node node) throws JAXBException {
-		marshal(node,
-				NamespacePrefixMapperUtils.getPrefixMapperRelationshipsPart() );
-	}
-
-
-    public void marshal(java.io.OutputStream os) throws JAXBException {
-		marshal( os,
-				NamespacePrefixMapperUtils.getPrefixMapperRelationshipsPart() );
-	}
-
-
     /**
      * Identify the rels in this relationships part which aren't
      * in the other
@@ -926,50 +890,6 @@ public final class RelationshipsPart extends JaxbXmlPart<Relationships> {
     	return results;
     }
 
-    /**
-     * Identify rels common to both parts, but where rels have different
-     * content.
-     * @param otherRP
-     * @return
-     */
-    public List<Relationship> differingContent(RelationshipsPart otherRP) throws Docx4JException {
-
-    	List<Relationship> results = new ArrayList<Relationship>();
-
-		for ( Relationship r : jaxbElement.getRelationship()  ) {
-			Relationship otherR = getRelationshipByTarget(otherRP, r.getTarget());
-			if (otherR!=null ) {
-
-				if (r.getTargetMode() !=null && r.getTargetMode().equals("External") ) {
-					if (otherR.getTargetMode() !=null && otherR.getTargetMode().equals("External")) {
-						// Usual case
-						if (!r.getTarget().equals(otherR.getTarget()) ) {
-							// Should never happen, since we matched on target
-							throw new Docx4JException("broken logic!");
-							//results.add(r);
-							//log.debug("External: " + r.getTarget() );
-						}
-
-					} else {
-						// eg an image changed from embedded to linked
-						results.add(r);
-						log.debug("External: " + r.getTarget() );
-					}
-					continue;
-				}
-
-				// Compare content
-				Part thisPart = this.getPart(r);
-				Part otherPart = otherRP.getPart(otherR);
-				if (!thisPart.isContentEqual( otherPart)) {
-					results.add(r);
-					log.debug("Different: " + r.getTarget() );
-				}
-			}
-		}
-    	return results;
-    }
-
 	public static Relationship getRelationshipByTarget(RelationshipsPart rp, String relativeTarget) {
 
 		for ( Relationship r : rp.jaxbElement.getRelationship()  ) {
@@ -1039,11 +959,4 @@ public final class RelationshipsPart extends JaxbXmlPart<Relationships> {
 		        return value;
 		    }
 	  }
-
-//	public static void main(String[] args) throws Exception {
-//
-//		System.out.println(inferSourcePartName("word/_rels/document.xml.rels"));
-//		System.out.println(inferSourcePartName("/_rels/.rels"));
-//	}
-
 }
