@@ -29,8 +29,8 @@ import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
 import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
-import org.docx4j.Child;
 import org.docx4j.vml.STExt;
+import com.openexchange.office.filter.core.component.Child;
 
 
 /**
