@@ -29,7 +29,6 @@ import javax.xml.bind.annotation.XmlElementRef;
 import javax.xml.bind.annotation.XmlElementRefs;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.IndexedNodeList;
 import org.docx4j.vml.CTArc;
 import org.docx4j.vml.CTCurve;
 import org.docx4j.vml.CTGroup;
@@ -41,7 +40,8 @@ import org.docx4j.vml.CTRect;
 import org.docx4j.vml.CTRoundRect;
 import org.docx4j.vml.CTShape;
 import org.docx4j.vml.CTShapetype;
-import org.docx4j.wml.ContentAccessor;
+import com.openexchange.office.filter.core.IContentAccessor;
+import com.openexchange.office.filter.core.DLList;
 
 /**
  * <p>Java class for anonymous complex type.
@@ -67,7 +67,7 @@ import org.docx4j.wml.ContentAccessor;
     "content"
 })
 @XmlRootElement(name = "xml")
-public class Xml implements ContentAccessor {
+public class Xml implements IContentAccessor {
 
     @XmlAnyElement(lax = true)
     @XmlElementRefs({
@@ -83,7 +83,7 @@ public class Xml implements ContentAccessor {
         @XmlElementRef(name="shape", namespace="urn:schemas-microsoft-com:vml", type=CTShape.class),
         @XmlElementRef(name="shapetype", namespace="urn:schemas-microsoft-com:vml", type=CTShapetype.class)
     })
-    protected IndexedNodeList<Object> content;
+    protected DLList<Object> content;
 
     /**
      * Gets the value of the any property.
@@ -110,7 +110,7 @@ public class Xml implements ContentAccessor {
     @Override
     public List<Object> getContent() {
         if (content == null) {
-            content = new IndexedNodeList<Object>();
+            content = new DLList<Object>();
         }
         return content;
     }
