@@ -36,8 +36,8 @@ import javax.xml.bind.annotation.XmlType;
 import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
 import org.docx4j.adapter.IntegerAdapter;
 import com.openexchange.office.filter.core.component.Child;
+import com.openexchange.office.filter.core.spreadsheet.CellRef;
 import com.openexchange.office.filter.core.spreadsheet.ICellRefAccess;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
 
 
 /**
@@ -421,7 +421,7 @@ public class CTClientData implements Child, ICellRefAccess
     }
 
     @XmlTransient
-    protected SmlUtils.CellRef cellRef;
+    protected CellRef cellRef;
     @XmlElement(name = "Row", namespace = "urn:schemas-microsoft-com:office:excel")
     @XmlJavaTypeAdapter(IntegerAdapter.class)
     public void setRow(Integer r) {
@@ -430,7 +430,7 @@ public class CTClientData implements Child, ICellRefAccess
         }
         else {
             if(cellRef==null) {
-                cellRef = new SmlUtils.CellRef(0, r.intValue());
+                cellRef = new CellRef(0, r.intValue());
             }
             else {
                 cellRef.setRow(r.intValue());
@@ -453,7 +453,7 @@ public class CTClientData implements Child, ICellRefAccess
         }
         else {
             if(cellRef==null) {
-                cellRef = new SmlUtils.CellRef(c.intValue(), 0);
+                cellRef = new CellRef(c.intValue(), 0);
             }
             else {
                 cellRef.setColumn(c.intValue());
@@ -469,15 +469,15 @@ public class CTClientData implements Child, ICellRefAccess
     }
 
     @Override
-    public SmlUtils.CellRef getCellRef(boolean forceCreate) {
+    public CellRef getCellRef(boolean forceCreate) {
         if(cellRef==null&&forceCreate) {
-            cellRef = new SmlUtils.CellRef(0, 0);
+            cellRef = new CellRef(0, 0);
         }
         return cellRef;
     }
 
     @Override
-    public void setCellRef(SmlUtils.CellRef cellRef) {
+    public void setCellRef(CellRef cellRef) {
         this.cellRef = cellRef;
     }
 
