@@ -21,15 +21,10 @@
 
 package org.docx4j.w14; 
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 import org.docx4j.wml.CTEmpty;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_FillTextEffect complex type.
@@ -56,14 +51,11 @@ import com.openexchange.office.filter.core.component.Child;
     "solidFill",
     "gradFill"
 })
-public class CTFillTextEffect implements Child
-{
+public class CTFillTextEffect implements Cloneable {
 
     protected CTEmpty noFill;
     protected CTSolidColorFillProperties solidFill;
     protected CTGradientFillProperties gradFill;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the noFill property.
@@ -137,30 +129,12 @@ public class CTFillTextEffect implements Child
         this.gradFill = value;
     }
 
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
+    @Override
+    public CTFillTextEffect clone() {
+        try {   // TODO: deep copy
+            return (CTFillTextEffect)super.clone();
+        } catch (CloneNotSupportedException e) {
+            return null;
+        }
     }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
