@@ -21,15 +21,10 @@
 
 package org.docx4j.w14; 
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_LightRig complex type.
@@ -56,16 +51,13 @@ import com.openexchange.office.filter.core.component.Child;
 @XmlType(name = "CT_LightRig", propOrder = {
     "rot"
 })
-public class CTLightRig implements Child
+public class CTLightRig
 {
-
     protected CTSphereCoords rot;
     @XmlAttribute(name = "rig", namespace = "http://schemas.microsoft.com/office/word/2010/wordml", required = true)
     protected STLightRigType rig;
     @XmlAttribute(name = "dir", namespace = "http://schemas.microsoft.com/office/word/2010/wordml", required = true)
     protected STLightRigDirection dir;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the rot property.
@@ -138,31 +130,4 @@ public class CTLightRig implements Child
     public void setDir(STLightRigDirection value) {
         this.dir = value;
     }
-
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
-    }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
