@@ -21,15 +21,10 @@
 
 package org.docx4j.w14; 
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_LinearShadeProperties complex type.
@@ -51,15 +46,12 @@ import com.openexchange.office.filter.core.component.Child;
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_LinearShadeProperties")
-public class CTLinearShadeProperties implements Child
+public class CTLinearShadeProperties
 {
-
     @XmlAttribute(name = "ang", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
     protected Integer ang;
     @XmlAttribute(name = "scaled", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
     protected String scaled;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the ang property.
@@ -108,31 +100,4 @@ public class CTLinearShadeProperties implements Child
     public void setScaled(String value) {
         this.scaled = value;
     }
-
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
-    }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
