@@ -21,15 +21,10 @@
 
 package org.docx4j.w14; 
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_NumForm complex type.
@@ -50,13 +45,11 @@ import com.openexchange.office.filter.core.component.Child;
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_NumForm")
-public class CTNumForm implements Child
+public class CTNumForm implements Cloneable
 {
 
     @XmlAttribute(name = "val", namespace = "http://schemas.microsoft.com/office/word/2010/wordml", required = true)
     protected STNumForm val;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the val property.
@@ -82,30 +75,12 @@ public class CTNumForm implements Child
         this.val = value;
     }
 
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
+    @Override
+    public CTNumForm clone() {
+        try {
+            return (CTNumForm)super.clone();
+        } catch (CloneNotSupportedException e) {
+            return null;
+        }
     }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
