@@ -21,15 +21,10 @@
 
 package org.docx4j.w14; 
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_Props3D complex type.
@@ -63,9 +58,8 @@ import com.openexchange.office.filter.core.component.Child;
     "extrusionClr",
     "contourClr"
 })
-public class CTProps3D implements Child
+public class CTProps3D implements Cloneable
 {
-
     protected CTBevel bevelT;
     protected CTBevel bevelB;
     protected CTColor extrusionClr;
@@ -76,8 +70,6 @@ public class CTProps3D implements Child
     protected Long contourW;
     @XmlAttribute(name = "prstMaterial", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
     protected STPresetMaterialType prstMaterial;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the bevelT property.
@@ -247,30 +239,12 @@ public class CTProps3D implements Child
         this.prstMaterial = value;
     }
 
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
+    @Override
+    public CTProps3D clone() {
+        try {   // TODO: deep copy
+            return (CTProps3D)super.clone();
+        } catch (CloneNotSupportedException e) {
+            return null;
+        }
     }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
