@@ -21,15 +21,10 @@
 
 package org.docx4j.w14;
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_RelativeRect complex type.
@@ -53,9 +48,8 @@ import com.openexchange.office.filter.core.component.Child;
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_RelativeRect")
-public class CTRelativeRect implements Child
+public class CTRelativeRect
 {
-
     @XmlAttribute(name = "l", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
     protected Integer l;
     @XmlAttribute(name = "t", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
@@ -64,8 +58,6 @@ public class CTRelativeRect implements Child
     protected Integer r;
     @XmlAttribute(name = "b", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
     protected Integer b;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the l property.
@@ -162,31 +154,4 @@ public class CTRelativeRect implements Child
     public void setB(Integer value) {
         this.b = value;
     }
-
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
-    }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
