@@ -24,19 +24,14 @@ package org.docx4j.w14;
 import java.util.ArrayList;
 import java.util.List;
 import javax.xml.bind.JAXBElement;
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlElementRef;
 import javax.xml.bind.annotation.XmlElementRefs;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 import javax.xml.bind.annotation.adapters.HexBinaryAdapter;
 import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_SRgbColor complex type.
@@ -62,7 +57,7 @@ import com.openexchange.office.filter.core.component.Child;
 @XmlType(name = "CT_SRgbColor", propOrder = {
     "egColorTransform"
 })
-public class CTSRgbColor implements Child
+public class CTSRgbColor
 {
 
     @XmlElementRefs({
@@ -81,8 +76,6 @@ public class CTSRgbColor implements Child
     @XmlAttribute(name = "val", namespace = "http://schemas.microsoft.com/office/word/2010/wordml", required = true)
     @XmlJavaTypeAdapter(HexBinaryAdapter.class)
     protected byte[] val;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the egColorTransform property.
@@ -145,31 +138,4 @@ public class CTSRgbColor implements Child
     public void setVal(byte[] value) {
         this.val = value;
     }
-
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
-    }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
