@@ -21,15 +21,10 @@
 
 package org.docx4j.w14; 
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_Scene3D complex type.
@@ -56,15 +51,12 @@ import com.openexchange.office.filter.core.component.Child;
     "camera",
     "lightRig"
 })
-public class CTScene3D implements Child
+public class CTScene3D implements Cloneable
 {
-
     @XmlElement(required = true)
     protected CTCamera camera;
     @XmlElement(required = true)
     protected CTLightRig lightRig;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the camera property.
@@ -114,30 +106,12 @@ public class CTScene3D implements Child
         this.lightRig = value;
     }
 
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
+    @Override
+    public CTScene3D clone() {
+        try {   // TODO: deep copy
+            return (CTScene3D)super.clone();
+        } catch (CloneNotSupportedException e) {
+            return null;
+        }
     }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
