@@ -24,16 +24,12 @@ package org.docx4j.w14;
 import java.util.ArrayList;
 import java.util.List;
 import javax.xml.bind.JAXBElement;
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlElementRef;
 import javax.xml.bind.annotation.XmlElementRefs;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
 
 
 /**
@@ -60,7 +56,7 @@ import com.openexchange.office.filter.core.component.Child;
 @XmlType(name = "CT_SchemeColor", propOrder = {
     "egColorTransform"
 })
-public class CTSchemeColor implements Child
+public class CTSchemeColor
 {
 
     @XmlElementRefs({
@@ -78,8 +74,6 @@ public class CTSchemeColor implements Child
     protected List<JAXBElement<?>> egColorTransform;
     @XmlAttribute(name = "val", namespace = "http://schemas.microsoft.com/office/word/2010/wordml", required = true)
     protected STSchemeColorVal val;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the egColorTransform property.
@@ -142,31 +136,4 @@ public class CTSchemeColor implements Child
     public void setVal(STSchemeColorVal value) {
         this.val = value;
     }
-
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
-    }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
