@@ -21,15 +21,10 @@
 
 package org.docx4j.w14; 
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_SphereCoords complex type.
@@ -52,17 +47,14 @@ import com.openexchange.office.filter.core.component.Child;
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_SphereCoords")
-public class CTSphereCoords implements Child
+public class CTSphereCoords
 {
-
     @XmlAttribute(name = "lat", namespace = "http://schemas.microsoft.com/office/word/2010/wordml", required = true)
     protected int lat;
     @XmlAttribute(name = "lon", namespace = "http://schemas.microsoft.com/office/word/2010/wordml", required = true)
     protected int lon;
     @XmlAttribute(name = "rev", namespace = "http://schemas.microsoft.com/office/word/2010/wordml", required = true)
     protected int rev;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the lat property.
@@ -111,31 +103,4 @@ public class CTSphereCoords implements Child
     public void setRev(int value) {
         this.rev = value;
     }
-
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
-    }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
