@@ -22,15 +22,10 @@
 package org.docx4j.w14; 
 
 import java.math.BigInteger;
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_StyleSet complex type.
@@ -52,15 +47,12 @@ import com.openexchange.office.filter.core.component.Child;
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_StyleSet")
-public class CTStyleSet implements Child
+public class CTStyleSet
 {
-
     @XmlAttribute(name = "id", namespace = "http://schemas.microsoft.com/office/word/2010/wordml", required = true)
     protected BigInteger id;
     @XmlAttribute(name = "val", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
     protected String val;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the id property.
@@ -109,31 +101,4 @@ public class CTStyleSet implements Child
     public void setVal(String value) {
         this.val = value;
     }
-
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
-    }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
