@@ -23,14 +23,9 @@ package org.docx4j.w14;
 
 import java.util.ArrayList;
 import java.util.List;
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
-
 
 /**
  * <p>Java class for CT_StylisticSets complex type.
@@ -55,12 +50,9 @@ import com.openexchange.office.filter.core.component.Child;
 @XmlType(name = "CT_StylisticSets", propOrder = {
     "styleSet"
 })
-public class CTStylisticSets implements Child
+public class CTStylisticSets implements Cloneable
 {
-
     protected List<CTStyleSet> styleSet;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the styleSet property.
@@ -91,30 +83,12 @@ public class CTStylisticSets implements Child
         return this.styleSet;
     }
 
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
+    @Override
+    public CTStylisticSets clone() {
+        try {   // TODO: deep copy
+            return (CTStylisticSets)super.clone();
+        } catch (CloneNotSupportedException e) {
+            return null;
+        }
     }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
