@@ -1,41 +1,39 @@
 /*
  *  Copyright 2013, Plutext Pty Ltd.
- *   
+ *
  *  This file is part of docx4j.
 
-    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
-    you may not use this file except in compliance with the License. 
+    docx4j is licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
 
-    You may obtain a copy of the License at 
+    You may obtain a copy of the License at
 
-        http://www.apache.org/licenses/LICENSE-2.0 
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    Unless required by applicable law or agreed to in writing, software 
-    distributed under the License is distributed on an "AS IS" BASIS, 
-    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
-    See the License for the specific language governing permissions and 
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
     limitations under the License.
 
  */
 
 
-package org.docx4j.w15; 
+package org.docx4j.w15;
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlTransient;
+import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.component.Child;
-
-
+import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import org.docx4j.adapter.HexNumberIntegerAdapter;
 
 /**
  * <p>Java class for CT_CommentEx complex type.
- * 
+ *
  * <p>The following schema fragment specifies the expected content contained within this class.
- * 
+ *
  * <pre>
  * &lt;complexType name="CT_CommentEx">
  *   &lt;complexContent>
@@ -47,78 +45,78 @@ import com.openexchange.office.filter.core.component.Child;
  *   &lt;/complexContent>
  * &lt;/complexType>
  * </pre>
- * 
- * 
+ *
+ *
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_CommentEx")
-public class CTCommentEx implements Child
+@XmlRootElement(name="commentEx")
+public class CTCommentEx
 {
-
     @XmlAttribute(name = "paraId", namespace = "http://schemas.microsoft.com/office/word/2012/wordml", required = true)
-    protected String paraId;
+    @XmlJavaTypeAdapter(HexNumberIntegerAdapter.class)
+    protected Integer paraId;
     @XmlAttribute(name = "paraIdParent", namespace = "http://schemas.microsoft.com/office/word/2012/wordml")
-    protected String paraIdParent;
+    @XmlJavaTypeAdapter(HexNumberIntegerAdapter.class)
+    protected Integer paraIdParent;
     @XmlAttribute(name = "done", namespace = "http://schemas.microsoft.com/office/word/2012/wordml")
     protected String done;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the paraId property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link String }
-     *     
+     *
      */
-    public String getParaId() {
+    public Integer getParaId() {
         return paraId;
     }
 
     /**
      * Sets the value of the paraId property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link String }
-     *     
+     *
      */
-    public void setParaId(String value) {
+    public void setParaId(Integer value) {
         this.paraId = value;
     }
 
     /**
      * Gets the value of the paraIdParent property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link String }
-     *     
+     *
      */
-    public String getParaIdParent() {
+    public Integer getParaIdParent() {
         return paraIdParent;
     }
 
     /**
      * Sets the value of the paraIdParent property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link String }
-     *     
+     *
      */
-    public void setParaIdParent(String value) {
+    public void setParaIdParent(Integer value) {
         this.paraIdParent = value;
     }
 
     /**
      * Gets the value of the done property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link String }
-     *     
+     *
      */
     public String getDone() {
         return done;
@@ -126,40 +124,13 @@ public class CTCommentEx implements Child
 
     /**
      * Sets the value of the done property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link String }
-     *     
+     *
      */
     public void setDone(String value) {
         this.done = value;
     }
-
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
-    }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
