@@ -1,7 +1,7 @@
 package org.docx4j.wml;
 
 import java.util.List;
-import org.docx4j.Child;
+import com.openexchange.office.filter.core.component.Child;
 
 /**
  * @since 2.7
