@@ -21,12 +21,12 @@
 
 package org.docx4j.wml; 
 
-import java.math.BigInteger;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlType;
-
+import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import org.docx4j.adapter.UnsignedLongAdapter;
 
 /**
  * <p>Java class for CT_Height complex type.
@@ -51,7 +51,8 @@ import javax.xml.bind.annotation.XmlType;
 public class CTHeight {
 
     @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected BigInteger val;
+    @XmlJavaTypeAdapter(UnsignedLongAdapter.class)
+    protected Long val;
     @XmlAttribute(name = "hRule", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     protected STHeightRule hRule;
 
@@ -60,10 +61,10 @@ public class CTHeight {
      * 
      * @return
      *     possible object is
-     *     {@link BigInteger }
+     *     {@link Long }
      *     
      */
-    public BigInteger getVal() {
+    public Long getVal() {
         return val;
     }
 
@@ -72,10 +73,10 @@ public class CTHeight {
      * 
      * @param value
      *     allowed object is
-     *     {@link BigInteger }
+     *     {@link Long }
      *     
      */
-    public void setVal(BigInteger value) {
+    public void setVal(Long value) {
         this.val = value;
     }
 
