@@ -65,7 +65,10 @@ public class CTPPrChange
      *     {@link PPrBase }
      *     
      */
-    public PPrBase getPPr() {
+    public PPrBase getPPr(boolean forceCreate) {
+        if(pPr==null&&forceCreate) {
+            pPr = new PPrBase();
+        }
         return pPr;
     }
 
