@@ -250,4 +250,9 @@ public class CTParaRPrOriginal extends RPrBase
             return false;
         return true;
     }
+
+    @Override
+    public boolean isEmpty() {
+        return isEmpty() && del == null && ins == null && moveFrom == null && moveTo == null;
+    }
 }
