@@ -169,4 +169,28 @@ public class CTRPrChange
     	//
     }
 
+    @Override
+    public int hashCode() {
+        final int prime = 31;
+        int result = super.hashCode();
+        result = prime * result + ((rPr == null) ? 0 : rPr.hashCode());
+        return result;
+    }
+
+    @Override
+    public boolean equals(Object obj) {
+        if (this == obj)
+            return true;
+        if (!super.equals(obj))
+            return false;
+        if (getClass() != obj.getClass())
+            return false;
+        CTRPrChange other = (CTRPrChange) obj;
+        if (rPr == null) {
+            if (other.rPr != null)
+                return false;
+        } else if (!rPr.equals(other.rPr))
+            return false;
+        return true;
+    }
 }
