@@ -31,9 +31,9 @@ import javax.xml.bind.annotation.XmlElementRef;
 import javax.xml.bind.annotation.XmlElementRefs;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
 import org.docx4j.math.CTOMath;
 import org.docx4j.math.CTOMathPara;
+import com.openexchange.office.filter.core.component.Child;
 
 
 /**
