@@ -32,10 +32,10 @@ import javax.xml.bind.annotation.XmlElementRefs;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-
-import org.docx4j.IndexedNodeList;
 import org.docx4j.math.CTOMath;
 import org.docx4j.math.CTOMathPara;
+import com.openexchange.office.filter.core.IContentAccessor;
+import com.openexchange.office.filter.core.DLList;
 
 
 /**
@@ -60,7 +60,7 @@ import org.docx4j.math.CTOMathPara;
     "content"
 })
 @XmlRootElement(name = "sdtContent")
-public class CTSdtContentRun implements ContentAccessor, ISimpleFieldCollection
+public class CTSdtContentRun implements IContentAccessor, ISimpleFieldCollection
 {
     @XmlElementRefs({
         @XmlElementRef(name = "permEnd", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
@@ -96,7 +96,7 @@ public class CTSdtContentRun implements ContentAccessor, ISimpleFieldCollection
         @XmlElementRef(name = "moveToRangeEnd", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "customXml", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class)
     })
-    protected IndexedNodeList<Object> content;
+    protected DLList<Object> content;
     @XmlTransient
     private List<CTSimpleField> simpleFieldCollection;
 
@@ -154,9 +154,9 @@ public class CTSdtContentRun implements ContentAccessor, ISimpleFieldCollection
      *
      * @since 2.7
      */
-    public IndexedNodeList<Object> getContent() {
+    public DLList<Object> getContent() {
         if (content == null) {
-            content = new IndexedNodeList<Object>();
+            content = new DLList<Object>();
         }
         else if(simpleFieldCollection!=null&&!simpleFieldCollection.isEmpty()) {
             CTSimpleField.convertSimpleFieldToComplexField(this);
@@ -165,7 +165,7 @@ public class CTSdtContentRun implements ContentAccessor, ISimpleFieldCollection
     }
 
     // returns content without field conversion
-    public IndexedNodeList<Object> getRawContent() {
+    public DLList<Object> getRawContent() {
     	return content;
     }
 
