@@ -54,8 +54,7 @@ import javax.xml.bind.annotation.XmlType;
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_Shd")
-public class CTShd
-{
+public class CTShd implements Cloneable {
 
     @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
     protected STShd val;
@@ -291,4 +290,77 @@ public class CTShd
     public void setThemeFillShade(String value) {
         this.themeFillShade = value;
     }
+
+    @Override
+    public CTShd clone() {
+        try {
+            return (CTShd)super.clone();
+        } catch (CloneNotSupportedException e) {
+            return null;
+        }
+    }
+
+    @Override
+    public int hashCode() {
+        final int prime = 31;
+        int result = 1;
+        result = prime * result + ((color == null) ? 0 : color.hashCode());
+        result = prime * result + ((fill == null) ? 0 : fill.hashCode());
+        result = prime * result + ((themeColor == null) ? 0 : themeColor.hashCode());
+        result = prime * result + ((themeFill == null) ? 0 : themeFill.hashCode());
+        result = prime * result + ((themeFillShade == null) ? 0 : themeFillShade.hashCode());
+        result = prime * result + ((themeFillTint == null) ? 0 : themeFillTint.hashCode());
+        result = prime * result + ((themeShade == null) ? 0 : themeShade.hashCode());
+        result = prime * result + ((themeTint == null) ? 0 : themeTint.hashCode());
+        result = prime * result + ((val == null) ? 0 : val.hashCode());
+        return result;
+    }
+
+    @Override
+    public boolean equals(Object obj) {
+        if (this == obj)
+            return true;
+        if (obj == null)
+            return false;
+        if (getClass() != obj.getClass())
+            return false;
+        CTShd other = (CTShd) obj;
+        if (color == null) {
+            if (other.color != null)
+                return false;
+        } else if (!color.equals(other.color))
+            return false;
+        if (fill == null) {
+            if (other.fill != null)
+                return false;
+        } else if (!fill.equals(other.fill))
+            return false;
+        if (themeColor != other.themeColor)
+            return false;
+        if (themeFill != other.themeFill)
+            return false;
+        if (themeFillShade == null) {
+            if (other.themeFillShade != null)
+                return false;
+        } else if (!themeFillShade.equals(other.themeFillShade))
+            return false;
+        if (themeFillTint == null) {
+            if (other.themeFillTint != null)
+                return false;
+        } else if (!themeFillTint.equals(other.themeFillTint))
+            return false;
+        if (themeShade == null) {
+            if (other.themeShade != null)
+                return false;
+        } else if (!themeShade.equals(other.themeShade))
+            return false;
+        if (themeTint == null) {
+            if (other.themeTint != null)
+                return false;
+        } else if (!themeTint.equals(other.themeTint))
+            return false;
+        if (val != other.val)
+            return false;
+        return true;
+    }
 }
