@@ -33,11 +33,12 @@ import javax.xml.bind.annotation.XmlElementRefs;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
-import org.docx4j.IndexedNodeList;
 import org.docx4j.jaxb.Context;
 import org.docx4j.math.CTOMath;
 import org.docx4j.math.CTOMathPara;
+import com.openexchange.office.filter.core.IContentAccessor;
+import com.openexchange.office.filter.core.DLList;
+import com.openexchange.office.filter.core.component.Child;
 
 
 /**
@@ -70,7 +71,7 @@ import org.docx4j.math.CTOMathPara;
 })
 @XmlRootElement(name = "fldSimple")
 public class CTSimpleField
-    implements Child, ContentAccessor
+    implements Child, IContentAccessor
 {
     protected Text fldData;
     @XmlElementRefs({
@@ -107,7 +108,7 @@ public class CTSimpleField
         @XmlElementRef(name = "sdt", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "customXml", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class)
     })
-    protected IndexedNodeList<Object> content;
+    protected DLList<Object> content;
     @XmlAttribute(name = "instr", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
     protected String instr;
     @XmlAttribute(name = "fldLock", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
@@ -195,9 +196,9 @@ public class CTSimpleField
      * @since 2.7
      */
     @Override
-	public IndexedNodeList<Object> getContent() {
+	public DLList<Object> getContent() {
         if (content == null) {
-            content = new IndexedNodeList<Object>();
+            content = new DLList<Object>();
         }
         return this.content;
     }
@@ -322,7 +323,7 @@ public class CTSimpleField
     public static void convertSimpleFieldToComplexField(ISimpleFieldCollection iSimpleFieldCollection) {
 
     	final List<CTSimpleField> simpleFieldCollection = iSimpleFieldCollection.getSimpleFieldCollection(false);
-    	final IndexedNodeList<Object> content = iSimpleFieldCollection.getRawContent();
+    	final DLList<Object> content = iSimpleFieldCollection.getRawContent();
 
     	if(simpleFieldCollection==null || content==null) {
     		return;
@@ -335,7 +336,7 @@ public class CTSimpleField
     			content.add(i++, createFldChar(iSimpleFieldCollection, STFldCharType.BEGIN, simpleField.getInstr()));
     			content.add(i++, createFldChar(iSimpleFieldCollection, STFldCharType.SEPARATE, null));
 
-    			final IndexedNodeList<Object> simpleFieldContent = simpleField.getContent();
+    			final DLList<Object> simpleFieldContent = simpleField.getContent();
     			for(int j = 0; j < simpleFieldContent.size(); j++) {
     				Object o = simpleFieldContent.get(j);
     				if(o instanceof Child) {
