@@ -21,11 +21,12 @@
 
 package org.docx4j.wml; 
 
-import java.math.BigInteger;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlType;
+import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import org.docx4j.adapter.LongAdapter;
 
 
 /**
@@ -586,17 +587,18 @@ public class CTTblPrBase {
     public static class TblStyleColBandSize {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-        protected BigInteger val;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long val;
 
         /**
          * Gets the value of the val property.
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getVal() {
+        public Long getVal() {
             return val;
         }
 
@@ -605,10 +607,10 @@ public class CTTblPrBase {
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setVal(BigInteger value) {
+        public void setVal(Long value) {
             this.val = value;
         }
     }
@@ -641,17 +643,18 @@ public class CTTblPrBase {
     public static class TblStyleRowBandSize {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-        protected BigInteger val;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long val;
 
         /**
          * Gets the value of the val property.
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getVal() {
+        public Long getVal() {
             return val;
         }
 
@@ -660,10 +663,10 @@ public class CTTblPrBase {
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setVal(BigInteger value) {
+        public void setVal(Long value) {
             this.val = value;
         }
     }
