@@ -21,14 +21,15 @@
 
 package org.docx4j.wml; 
 
-import java.math.BigInteger;
 import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
+import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import org.docx4j.adapter.UnsignedLongAdapter;
+import com.openexchange.office.filter.core.component.Child;
 
 
 /**
@@ -54,7 +55,8 @@ public class CTTwipsMeasure implements Child
 {
 
     @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-    protected BigInteger val;
+    @XmlJavaTypeAdapter(UnsignedLongAdapter.class)
+    protected Long val;
     @XmlTransient
     private Object parent;
 
@@ -63,10 +65,10 @@ public class CTTwipsMeasure implements Child
      * 
      * @return
      *     possible object is
-     *     {@link BigInteger }
+     *     {@link Long }
      *     
      */
-    public BigInteger getVal() {
+    public Long getVal() {
         return val;
     }
 
@@ -75,10 +77,10 @@ public class CTTwipsMeasure implements Child
      * 
      * @param value
      *     allowed object is
-     *     {@link BigInteger }
+     *     {@link Long }
      *     
      */
-    public void setVal(BigInteger value) {
+    public void setVal(Long value) {
         this.val = value;
     }
 
