@@ -46,7 +46,7 @@ import javax.xml.bind.annotation.XmlType;
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_VerticalAlignRun")
-public class CTVerticalAlignRun {
+public class CTVerticalAlignRun implements Cloneable {
 
     @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
     protected STVerticalAlignRun val;
@@ -74,4 +74,37 @@ public class CTVerticalAlignRun {
     public void setVal(STVerticalAlignRun value) {
         this.val = value;
     }
+
+    @Override
+    public CTVerticalAlignRun clone() {
+        try {
+            return (CTVerticalAlignRun)super.clone();
+        } catch (CloneNotSupportedException e) {
+            return null;
+        }
+    }
+
+    @Override
+    public int hashCode() {
+        final int prime = 31;
+        int result = 1;
+        result = prime * result + ((val == null) ? 0 : val.hashCode());
+        return result;
+    }
+
+    @Override
+    public boolean equals(Object obj) {
+        if (this == obj)
+            return true;
+        if (obj == null)
+            return false;
+        if (getClass() != obj.getClass())
+            return false;
+        CTVerticalAlignRun other = (CTVerticalAlignRun) obj;
+        if (val != other.val)
+            return false;
+        return true;
+    }
+
+
 }
