@@ -51,7 +51,7 @@ import javax.xml.bind.annotation.XmlType;
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "")
 @XmlRootElement(name = "color")
-public class Color {
+public class Color implements Cloneable {
 
     @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
     protected String val;
@@ -157,4 +157,52 @@ public class Color {
     public void setThemeShade(String value) {
         this.themeShade = value;
     }
+
+    @Override
+    public Color clone() {
+        try {
+            return (Color)super.clone();
+        } catch (CloneNotSupportedException e) {
+            return null;
+        }
+    }
+
+    public int hashCode() {
+        final int prime = 31;
+        int result = 1;
+        result = prime * result + ((themeColor == null) ? 0 : themeColor.hashCode());
+        result = prime * result + ((themeShade == null) ? 0 : themeShade.hashCode());
+        result = prime * result + ((themeTint == null) ? 0 : themeTint.hashCode());
+        result = prime * result + ((val == null) ? 0 : val.hashCode());
+        return result;
+    }
+
+    @Override
+    public boolean equals(Object obj) {
+        if (this == obj)
+            return true;
+        if (obj == null)
+            return false;
+        if (getClass() != obj.getClass())
+            return false;
+        Color other = (Color) obj;
+        if (themeColor != other.themeColor)
+            return false;
+        if (themeShade == null) {
+            if (other.themeShade != null)
+                return false;
+        } else if (!themeShade.equals(other.themeShade))
+            return false;
+        if (themeTint == null) {
+            if (other.themeTint != null)
+                return false;
+        } else if (!themeTint.equals(other.themeTint))
+            return false;
+        if (val == null) {
+            if (other.val != null)
+                return false;
+        } else if (!val.equals(other.val))
+            return false;
+        return true;
+    }
 }
