@@ -111,7 +111,7 @@ public class Comments implements IContentAccessor<Object>
     public Comment getCommentByParaId(Integer paraId) {
         if(paraId!=null) {
             for(Comment c:comment) {
-                if(paraId.equals(c.getParaId())) {
+                if(paraId.equals(c.getParaIdFromParagraph())) {
                     return c;
                 }
             }
@@ -218,17 +218,17 @@ public class Comments implements IContentAccessor<Object>
         @XmlAttribute(name = "initials", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
         protected String initials;
         @XmlTransient
-        private Integer userId;
+        private Integer paraId;
         @XmlTransient
         private Integer parentId;
 
-        // returns a userId in the range from 0 to 0xffff (inclusive), a default of 0xffff is returned
-        public int getUserId() {
-            return userId != null ? userId & 0xffff : 0xffff;
+        // returns a paraId, a default of -1 is returned
+        public int getParaId() {
+            return paraId != null ? paraId : -1;
         }
 
-        public void setUserId(Integer userId) {
-            this.userId = userId;
+        public void setParaId(Integer userId) {
+            this.paraId = userId;
         }
 
         public Integer getParentId() {
@@ -248,12 +248,12 @@ public class Comments implements IContentAccessor<Object>
             return null;
         }
 
-        public Integer getParaId() {
+        public Integer getParaIdFromParagraph() {
             final P para = getFirstParagraph();
             return para!=null ? para.getParaId() : null;
         }
 
-        public void setParaId(Integer paraId) {
+        public void setParaIdToParagraph(Integer paraId) {
             final P para = getFirstParagraph();
             if(para!=null) {
                 para.setParaId(paraId);
