@@ -1,25 +1,25 @@
 /*
  *  Copyright 2007-2013, Plutext Pty Ltd.
- *   
+ *
  *  This file is part of docx4j.
 
-    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
-    you may not use this file except in compliance with the License. 
+    docx4j is licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
 
-    You may obtain a copy of the License at 
+    You may obtain a copy of the License at
 
-        http://www.apache.org/licenses/LICENSE-2.0 
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    Unless required by applicable law or agreed to in writing, software 
-    distributed under the License is distributed on an "AS IS" BASIS, 
-    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
-    See the License for the specific language governing permissions and 
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
     limitations under the License.
 
  */
 
 
-package org.docx4j.wml; 
+package org.docx4j.wml;
 
 import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
@@ -33,9 +33,9 @@ import com.openexchange.office.filter.core.component.Child;
 
 /**
  * <p>Java class for CT_FldChar complex type.
- * 
+ *
  * <p>The following schema fragment specifies the expected content contained within this class.
- * 
+ *
  * <pre>
  * &lt;complexType name="CT_FldChar">
  *   &lt;complexContent>
@@ -52,8 +52,8 @@ import com.openexchange.office.filter.core.component.Child;
  *   &lt;/complexContent>
  * &lt;/complexType>
  * </pre>
- * 
- * 
+ *
+ *
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_FldChar", propOrder = {
@@ -88,6 +88,14 @@ public class FldChar implements Child
     @XmlTransient
     private FldChar fldCharEnd;
 
+    public FldChar() {
+        // default constructor required for jaxb
+    }
+
+    public FldChar(STFldCharType fldCharType) {
+        this.fldCharType = fldCharType;
+    }
+
     public FldChar getParentFldChar() {
         return parentFldChar;
     }
@@ -165,13 +173,24 @@ public class FldChar implements Child
         return this;
     }
 
+    public static void initializeFld(FldChar begin, FldChar separate, FldChar end) {
+        begin.fldCharSeparate = separate;
+        begin.fldCharEnd = separate;
+        if(separate!=null) {
+            separate.fldCharBegin = begin;
+            separate.fldCharEnd = end;
+        }
+        end.fldCharBegin = begin;
+        end.fldCharSeparate = separate;
+    }
+
     /**
      * Gets the value of the fldData property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link Text }
-     *     
+     *
      */
     public Text getFldData() {
         return fldData;
@@ -179,11 +198,11 @@ public class FldChar implements Child
 
     /**
      * Sets the value of the fldData property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link Text }
-     *     
+     *
      */
     public void setFldData(Text value) {
         this.fldData = value;
@@ -191,11 +210,11 @@ public class FldChar implements Child
 
     /**
      * Gets the value of the ffData property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link CTFFData }
-     *     
+     *
      */
     public CTFFData getFfData() {
         return ffData;
@@ -203,11 +222,11 @@ public class FldChar implements Child
 
     /**
      * Sets the value of the ffData property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link CTFFData }
-     *     
+     *
      */
     public void setFfData(CTFFData value) {
         this.ffData = value;
@@ -215,11 +234,11 @@ public class FldChar implements Child
 
     /**
      * Gets the value of the numberingChange property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link CTTrackChangeNumbering }
-     *     
+     *
      */
     public CTTrackChangeNumbering getNumberingChange() {
         return numberingChange;
@@ -227,11 +246,11 @@ public class FldChar implements Child
 
     /**
      * Sets the value of the numberingChange property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link CTTrackChangeNumbering }
-     *     
+     *
      */
     public void setNumberingChange(CTTrackChangeNumbering value) {
         this.numberingChange = value;
@@ -239,11 +258,11 @@ public class FldChar implements Child
 
     /**
      * Gets the value of the fldCharType property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link STFldCharType }
-     *     
+     *
      */
     public STFldCharType getFldCharType() {
         return fldCharType;
@@ -251,11 +270,11 @@ public class FldChar implements Child
 
     /**
      * Sets the value of the fldCharType property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link STFldCharType }
-     *     
+     *
      */
     public void setFldCharType(STFldCharType value) {
         this.fldCharType = value;
@@ -263,11 +282,11 @@ public class FldChar implements Child
 
     /**
      * Gets the value of the fldLock property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link Boolean }
-     *     
+     *
      */
     public boolean isFldLock() {
         if (fldLock == null) {
@@ -278,11 +297,11 @@ public class FldChar implements Child
 
     /**
      * Sets the value of the fldLock property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link Boolean }
-     *     
+     *
      */
     public void setFldLock(Boolean value) {
         this.fldLock = value;
@@ -290,11 +309,11 @@ public class FldChar implements Child
 
     /**
      * Gets the value of the dirty property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link Boolean }
-     *     
+     *
      */
     public boolean isDirty() {
         if (dirty == null) {
@@ -305,11 +324,11 @@ public class FldChar implements Child
 
     /**
      * Sets the value of the dirty property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link Boolean }
-     *     
+     *
      */
     public void setDirty(Boolean value) {
         this.dirty = value;
@@ -317,7 +336,7 @@ public class FldChar implements Child
 
     /**
      * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
+     *
      * @return
      *     The parent object.
      */
@@ -333,7 +352,7 @@ public class FldChar implements Child
 
     /**
      * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
+     *
      * @param parent
      *     The parent object in the object tree.
      * @param unmarshaller
