@@ -21,14 +21,16 @@
 
 package org.docx4j.wml; 
 
-import java.math.BigInteger;
 import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
+import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import org.docx4j.adapter.LongAdapter;
+import org.docx4j.adapter.UnsignedLongAdapter;
+import com.openexchange.office.filter.core.component.Child;
 
 
 /**
@@ -177,7 +179,8 @@ public class Lvl implements Child
     protected PPr pPr;
     protected RPr rPr;
     @XmlAttribute(name = "ilvl", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-    protected BigInteger ilvl;
+    @XmlJavaTypeAdapter(LongAdapter.class)
+    protected Long ilvl;
     @XmlAttribute(name = "tplc", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     protected String tplc;
     @XmlAttribute(name = "tentative", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
@@ -478,10 +481,10 @@ public class Lvl implements Child
      * 
      * @return
      *     possible object is
-     *     {@link BigInteger }
+     *     {@link Long }
      *     
      */
-    public BigInteger getIlvl() {
+    public Long getIlvl() {
         return ilvl;
     }
 
@@ -490,10 +493,10 @@ public class Lvl implements Child
      * 
      * @param value
      *     allowed object is
-     *     {@link BigInteger }
+     *     {@link Long }
      *     
      */
-    public void setIlvl(BigInteger value) {
+    public void setIlvl(Long value) {
         this.ilvl = value;
     }
 
@@ -532,9 +535,8 @@ public class Lvl implements Child
     public boolean isTentative() {
         if (tentative == null) {
             return true;
-        } else {
-            return tentative;
         }
+        return tentative;
     }
 
     /**
@@ -555,10 +557,12 @@ public class Lvl implements Child
      * @return
      *     The parent object.
      */
+    @Override
     public Object getParent() {
         return this.parent;
     }
 
+    @Override
     public void setParent(Object parent) {
         this.parent = parent;
     }
@@ -603,9 +607,11 @@ public class Lvl implements Child
         @XmlAttribute(name = "legacy", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
         protected Boolean legacy;
         @XmlAttribute(name = "legacySpace", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger legacySpace;
+        @XmlJavaTypeAdapter(UnsignedLongAdapter.class)
+        protected Long legacySpace;
         @XmlAttribute(name = "legacyIndent", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger legacyIndent;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long legacyIndent;
         @XmlTransient
         private Object parent;
 
@@ -620,9 +626,8 @@ public class Lvl implements Child
         public boolean isLegacy() {
             if (legacy == null) {
                 return true;
-            } else {
-                return legacy;
             }
+            return legacy;
         }
 
         /**
@@ -642,10 +647,10 @@ public class Lvl implements Child
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getLegacySpace() {
+        public Long getLegacySpace() {
             return legacySpace;
         }
 
@@ -654,10 +659,10 @@ public class Lvl implements Child
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setLegacySpace(BigInteger value) {
+        public void setLegacySpace(Long value) {
             this.legacySpace = value;
         }
 
@@ -666,10 +671,10 @@ public class Lvl implements Child
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getLegacyIndent() {
+        public Long getLegacyIndent() {
             return legacyIndent;
         }
 
@@ -678,10 +683,10 @@ public class Lvl implements Child
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setLegacyIndent(BigInteger value) {
+        public void setLegacyIndent(Long value) {
             this.legacyIndent = value;
         }
 
@@ -691,10 +696,12 @@ public class Lvl implements Child
          * @return
          *     The parent object.
          */
+        @Override
         public Object getParent() {
             return this.parent;
         }
 
+        @Override
         public void setParent(Object parent) {
             this.parent = parent;
         }
@@ -742,7 +749,8 @@ public class Lvl implements Child
     {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-        protected BigInteger val;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long val;
         @XmlTransient
         private Object parent;
 
@@ -751,10 +759,10 @@ public class Lvl implements Child
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getVal() {
+        public Long getVal() {
             return val;
         }
 
@@ -763,10 +771,10 @@ public class Lvl implements Child
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setVal(BigInteger value) {
+        public void setVal(Long value) {
             this.val = value;
         }
 
@@ -776,10 +784,12 @@ public class Lvl implements Child
          * @return
          *     The parent object.
          */
+        @Override
         public Object getParent() {
             return this.parent;
         }
 
+        @Override
         public void setParent(Object parent) {
             this.parent = parent;
         }
@@ -827,7 +837,8 @@ public class Lvl implements Child
     {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-        protected BigInteger val;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long val;
         @XmlTransient
         private Object parent;
 
@@ -836,10 +847,10 @@ public class Lvl implements Child
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getVal() {
+        public Long getVal() {
             return val;
         }
 
@@ -848,10 +859,10 @@ public class Lvl implements Child
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setVal(BigInteger value) {
+        public void setVal(Long value) {
             this.val = value;
         }
 
@@ -861,10 +872,12 @@ public class Lvl implements Child
          * @return
          *     The parent object.
          */
+        @Override
         public Object getParent() {
             return this.parent;
         }
 
+        @Override
         public void setParent(Object parent) {
             this.parent = parent;
         }
@@ -949,9 +962,8 @@ public class Lvl implements Child
         public boolean isNull() {
             if (_null == null) {
                 return true;
-            } else {
-                return _null;
             }
+            return _null;
         }
 
         /**
@@ -972,10 +984,12 @@ public class Lvl implements Child
          * @return
          *     The parent object.
          */
+        @Override
         public Object getParent() {
             return this.parent;
         }
 
+        @Override
         public void setParent(Object parent) {
             this.parent = parent;
         }
@@ -1052,10 +1066,12 @@ public class Lvl implements Child
          * @return
          *     The parent object.
          */
+        @Override
         public Object getParent() {
             return this.parent;
         }
 
+        @Override
         public void setParent(Object parent) {
             this.parent = parent;
         }
@@ -1103,7 +1119,8 @@ public class Lvl implements Child
     {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-        protected BigInteger val;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long val;
         @XmlTransient
         private Object parent;
 
@@ -1112,10 +1129,10 @@ public class Lvl implements Child
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getVal() {
+        public Long getVal() {
             return val;
         }
 
@@ -1124,10 +1141,10 @@ public class Lvl implements Child
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setVal(BigInteger value) {
+        public void setVal(Long value) {
             this.val = value;
         }
 
@@ -1137,10 +1154,12 @@ public class Lvl implements Child
          * @return
          *     The parent object.
          */
+        @Override
         public Object getParent() {
             return this.parent;
         }
 
+        @Override
         public void setParent(Object parent) {
             this.parent = parent;
         }
@@ -1225,10 +1244,12 @@ public class Lvl implements Child
          * @return
          *     The parent object.
          */
+        @Override
         public Object getParent() {
             return this.parent;
         }
 
+        @Override
         public void setParent(Object parent) {
             this.parent = parent;
         }
