@@ -21,7 +21,6 @@
 
 package org.docx4j.wml; 
 
-import java.math.BigInteger;
 import java.util.ArrayList;
 import java.util.List;
 import javax.xml.bind.Unmarshaller;
@@ -32,7 +31,9 @@ import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
+import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import org.docx4j.adapter.LongAdapter;
+import com.openexchange.office.filter.core.component.Child;
 
 
 /**
@@ -323,10 +324,12 @@ public class Numbering implements Child
      * @return
      *     The parent object.
      */
+    @Override
     public Object getParent() {
         return this.parent;
     }
 
+    @Override
     public void setParent(Object parent) {
         this.parent = parent;
     }
@@ -433,7 +436,8 @@ public class Numbering implements Child
         protected Numbering.AbstractNum.NumStyleLink numStyleLink;
         protected List<Lvl> lvl;
         @XmlAttribute(name = "abstractNumId", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-        protected BigInteger abstractNumId;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long abstractNumId;
         @XmlTransient
         private Object parent;
 
@@ -615,10 +619,10 @@ public class Numbering implements Child
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getAbstractNumId() {
+        public Long getAbstractNumId() {
             return abstractNumId;
         }
 
@@ -627,10 +631,10 @@ public class Numbering implements Child
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setAbstractNumId(BigInteger value) {
+        public void setAbstractNumId(Long value) {
             this.abstractNumId = value;
         }
 
@@ -640,10 +644,12 @@ public class Numbering implements Child
          * @return
          *     The parent object.
          */
+        @Override
         public Object getParent() {
             return this.parent;
         }
 
+        @Override
         public void setParent(Object parent) {
             this.parent = parent;
         }
@@ -726,10 +732,12 @@ public class Numbering implements Child
              * @return
              *     The parent object.
              */
+            @Override
             public Object getParent() {
                 return this.parent;
             }
 
+            @Override
             public void setParent(Object parent) {
                 this.parent = parent;
             }
@@ -806,10 +814,12 @@ public class Numbering implements Child
              * @return
              *     The parent object.
              */
+            @Override
             public Object getParent() {
                 return this.parent;
             }
 
+            @Override
             public void setParent(Object parent) {
                 this.parent = parent;
             }
@@ -886,10 +896,12 @@ public class Numbering implements Child
              * @return
              *     The parent object.
              */
+            @Override
             public Object getParent() {
                 return this.parent;
             }
 
+            @Override
             public void setParent(Object parent) {
                 this.parent = parent;
             }
@@ -966,10 +978,12 @@ public class Numbering implements Child
              * @return
              *     The parent object.
              */
+            @Override
             public Object getParent() {
                 return this.parent;
             }
 
+            @Override
             public void setParent(Object parent) {
                 this.parent = parent;
             }
@@ -1062,7 +1076,8 @@ public class Numbering implements Child
         protected Numbering.Num.AbstractNumId abstractNumId;
         protected List<Numbering.Num.LvlOverride> lvlOverride;
         @XmlAttribute(name = "numId", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-        protected BigInteger numId;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long numId;
         @XmlTransient
         private Object parent;
 
@@ -1124,10 +1139,10 @@ public class Numbering implements Child
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getNumId() {
+        public Long getNumId() {
             return numId;
         }
 
@@ -1136,10 +1151,10 @@ public class Numbering implements Child
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setNumId(BigInteger value) {
+        public void setNumId(Long value) {
             this.numId = value;
         }
 
@@ -1149,10 +1164,12 @@ public class Numbering implements Child
          * @return
          *     The parent object.
          */
+        @Override
         public Object getParent() {
             return this.parent;
         }
 
+        @Override
         public void setParent(Object parent) {
             this.parent = parent;
         }
@@ -1198,7 +1215,8 @@ public class Numbering implements Child
         {
 
             @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-            protected BigInteger val;
+            @XmlJavaTypeAdapter(LongAdapter.class)
+            protected Long val;
             @XmlTransient
             private Object parent;
 
@@ -1207,10 +1225,10 @@ public class Numbering implements Child
              * 
              * @return
              *     possible object is
-             *     {@link BigInteger }
+             *     {@link Long }
              *     
              */
-            public BigInteger getVal() {
+            public Long getVal() {
                 return val;
             }
 
@@ -1219,10 +1237,10 @@ public class Numbering implements Child
              * 
              * @param value
              *     allowed object is
-             *     {@link BigInteger }
+             *     {@link Long }
              *     
              */
-            public void setVal(BigInteger value) {
+            public void setVal(Long value) {
                 this.val = value;
             }
 
@@ -1232,10 +1250,12 @@ public class Numbering implements Child
              * @return
              *     The parent object.
              */
+            @Override
             public Object getParent() {
                 return this.parent;
             }
 
+            @Override
             public void setParent(Object parent) {
                 this.parent = parent;
             }
@@ -1302,7 +1322,8 @@ public class Numbering implements Child
             protected Numbering.Num.LvlOverride.StartOverride startOverride;
             protected Lvl lvl;
             @XmlAttribute(name = "ilvl", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-            protected BigInteger ilvl;
+            @XmlJavaTypeAdapter(LongAdapter.class)
+            protected Long ilvl;
             @XmlTransient
             private Object parent;
 
@@ -1359,10 +1380,10 @@ public class Numbering implements Child
              * 
              * @return
              *     possible object is
-             *     {@link BigInteger }
+             *     {@link Long }
              *     
              */
-            public BigInteger getIlvl() {
+            public Long getIlvl() {
                 return ilvl;
             }
 
@@ -1371,10 +1392,10 @@ public class Numbering implements Child
              * 
              * @param value
              *     allowed object is
-             *     {@link BigInteger }
+             *     {@link Long }
              *     
              */
-            public void setIlvl(BigInteger value) {
+            public void setIlvl(Long value) {
                 this.ilvl = value;
             }
 
@@ -1384,10 +1405,12 @@ public class Numbering implements Child
              * @return
              *     The parent object.
              */
+            @Override
             public Object getParent() {
                 return this.parent;
             }
 
+            @Override
             public void setParent(Object parent) {
                 this.parent = parent;
             }
@@ -1433,7 +1456,8 @@ public class Numbering implements Child
             {
 
                 @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-                protected BigInteger val;
+                @XmlJavaTypeAdapter(LongAdapter.class)
+                protected Long val;
                 @XmlTransient
                 private Object parent;
 
@@ -1442,10 +1466,10 @@ public class Numbering implements Child
                  * 
                  * @return
                  *     possible object is
-                 *     {@link BigInteger }
+                 *     {@link Long }
                  *     
                  */
-                public BigInteger getVal() {
+                public Long getVal() {
                     return val;
                 }
 
@@ -1454,10 +1478,10 @@ public class Numbering implements Child
                  * 
                  * @param value
                  *     allowed object is
-                 *     {@link BigInteger }
+                 *     {@link Long }
                  *     
                  */
-                public void setVal(BigInteger value) {
+                public void setVal(Long value) {
                     this.val = value;
                 }
 
@@ -1467,10 +1491,12 @@ public class Numbering implements Child
                  * @return
                  *     The parent object.
                  */
+                @Override
                 public Object getParent() {
                     return this.parent;
                 }
 
+                @Override
                 public void setParent(Object parent) {
                     this.parent = parent;
                 }
@@ -1522,7 +1548,8 @@ public class Numbering implements Child
     {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-        protected BigInteger val;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long val;
         @XmlTransient
         private Object parent;
 
@@ -1531,10 +1558,10 @@ public class Numbering implements Child
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getVal() {
+        public Long getVal() {
             return val;
         }
 
@@ -1543,10 +1570,10 @@ public class Numbering implements Child
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setVal(BigInteger value) {
+        public void setVal(Long value) {
             this.val = value;
         }
 
@@ -1556,10 +1583,12 @@ public class Numbering implements Child
          * @return
          *     The parent object.
          */
+        @Override
         public Object getParent() {
             return this.parent;
         }
 
+        @Override
         public void setParent(Object parent) {
             this.parent = parent;
         }
@@ -1609,7 +1638,8 @@ public class Numbering implements Child
         @XmlElement(required = true)
         protected Pict pict;
         @XmlAttribute(name = "numPicBulletId", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-        protected BigInteger numPicBulletId;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long numPicBulletId;
         @XmlTransient
         private Object parent;
 
@@ -1642,10 +1672,10 @@ public class Numbering implements Child
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getNumPicBulletId() {
+        public Long getNumPicBulletId() {
             return numPicBulletId;
         }
 
@@ -1654,10 +1684,10 @@ public class Numbering implements Child
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setNumPicBulletId(BigInteger value) {
+        public void setNumPicBulletId(Long value) {
             this.numPicBulletId = value;
         }
 
@@ -1667,10 +1697,12 @@ public class Numbering implements Child
          * @return
          *     The parent object.
          */
+        @Override
         public Object getParent() {
             return this.parent;
         }
 
+        @Override
         public void setParent(Object parent) {
             this.parent = parent;
         }
