@@ -43,7 +43,7 @@ import org.docx4j.math.CTOMathPara;
 import org.docx4j.openpackaging.packages.OpcPackage;
 import com.openexchange.office.filter.core.INodeAccessor;
 import com.openexchange.office.filter.core.DLList;
-import com.openexchange.office.filter.core.DLNode;
+import com.openexchange.office.filter.core.IChildNodeCombiner;
 import com.openexchange.office.filter.core.component.Child;
 
 /**
@@ -116,16 +116,6 @@ public class P implements Child, INodeAccessor<Object>, ISimpleFieldCollection {
         @XmlElementRef(name = "bookmarkStart", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class)
     })
     protected DLList<Object> content;
-    @XmlAttribute(name = "rsidRPr", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected String rsidRPr;
-    @XmlAttribute(name = "rsidR", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected String rsidR;
-    @XmlAttribute(name = "rsidDel", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected String rsidDel;
-    @XmlAttribute(name = "rsidP", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected String rsidP;
-    @XmlAttribute(name = "rsidRDefault", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected String rsidRDefault;
     @XmlAttribute(name = "paraId", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
     @XmlJavaTypeAdapter(HexNumberIntegerAdapter.class)
     protected Integer paraId;
@@ -236,124 +226,44 @@ public class P implements Child, INodeAccessor<Object>, ISimpleFieldCollection {
     	return content;
     }
 
-    /**
-     * Gets the value of the rsidRPr property.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
+    @XmlAttribute(name = "rsidRPr", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     public String getRsidRPr() {
-        return rsidRPr;
+        return null;
+    }
+    public void setRsidRPr(@SuppressWarnings("unused") String value) {
+        // this value is always ignored and removed
     }
 
-    /**
-     * Sets the value of the rsidRPr property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setRsidRPr(String value) {
-        this.rsidRPr = value;
-    }
-
-    /**
-     * Gets the value of the rsidR property.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
+    @XmlAttribute(name = "rsidR", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     public String getRsidR() {
-        return rsidR;
+        return null;
+    }
+    public void setRsidR(@SuppressWarnings("unused") String value) {
+        // this value is always ignored and removed
     }
 
-    /**
-     * Sets the value of the rsidR property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setRsidR(String value) {
-        this.rsidR = value;
-    }
-
-    /**
-     * Gets the value of the rsidDel property.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
+    @XmlAttribute(name = "rsidDel", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     public String getRsidDel() {
-        return rsidDel;
+        return null;
+    }
+    public void setRsidDel(@SuppressWarnings("unused") String value) {
+        // this value is always ignored and removed
     }
 
-    /**
-     * Sets the value of the rsidDel property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setRsidDel(String value) {
-        this.rsidDel = value;
-    }
-
-    /**
-     * Gets the value of the rsidP property.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
+    @XmlAttribute(name = "rsidP", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     public String getRsidP() {
-        return rsidP;
+        return null;
+    }
+    public void setRsidP(@SuppressWarnings("unused") String value) {
+        // this value is always ignored and removed
     }
 
-    /**
-     * Sets the value of the rsidP property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setRsidP(String value) {
-        this.rsidP = value;
-    }
-
-    /**
-     * Gets the value of the rsidRDefault property.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
+    @XmlAttribute(name = "rsidRDefault", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     public String getRsidRDefault() {
-        return rsidRDefault;
+        return null;
     }
-
-    /**
-     * Sets the value of the rsidRDefault property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setRsidRDefault(String value) {
-        this.rsidRDefault = value;
+    public void setRsidRDefault(@SuppressWarnings("unused") String value) {
+        // this value is always ignored and removed
     }
 
     /**
@@ -479,28 +389,10 @@ public class P implements Child, INodeAccessor<Object>, ISimpleFieldCollection {
 
     final public void beforeMarshal(Marshaller marshaller) {
         if(modified && content!=null) {
-            DLNode<Object> node = content.getFirstNode();
-            while(node!=null) {
-                while(tryCombineChildNode(content, node)) {
-                    //
-                }
-                node = node.getNext();
-            }
+            IChildNodeCombiner.optimize(this);
         }
     }
 
-    // returns true if text of this and the next node could be combined, the next node will be removed then
-    private boolean tryCombineChildNode(DLList<Object> pContent, DLNode<Object> node) {
-        final Object child =  node.getData();
-        if(child instanceof RunIns) {
-            return RunIns.tryCombineWithNextNode(pContent, node);
-        }
-        else if(child instanceof R) {
-            return R.tryCombineWithNextNode(pContent, node);
-        }
-        return false;
-    }
-
     /**
      * Hyperlink
      *
@@ -818,6 +710,12 @@ public class P implements Child, INodeAccessor<Object>, ISimpleFieldCollection {
             setParent(parent);
         }
 
+        final public void beforeMarshal(Marshaller marshaller) {
+            if(content!=null) {
+                IChildNodeCombiner.optimize(this);
+            }
+        }
+
         public boolean isEmpty() {
             return tgtFrame==null&&tooltip==null&&docLocation==null&&history==null&&anchor==null&&id==null;
         }
