@@ -21,13 +21,15 @@
 
 package org.docx4j.wml; 
 
-import java.math.BigInteger;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlType;
+import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import org.docx4j.adapter.LongAdapter;
+import org.docx4j.adapter.UnsignedLongAdapter;
 
 
 /**
@@ -1144,17 +1146,18 @@ public class PPrBase
     @XmlType(name = "")
     public static class DivId {
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-        protected BigInteger val;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long val;
 
         /**
          * Gets the value of the val property.
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getVal() {
+        public Long getVal() {
             return val;
         }
 
@@ -1163,10 +1166,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setVal(BigInteger value) {
+        public void setVal(Long value) {
             this.val = value;
         }
     }
@@ -1202,31 +1205,39 @@ public class PPrBase
     public static class Ind {
 
         @XmlAttribute(name = "left", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger left;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long left;
         @XmlAttribute(name = "leftChars", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger leftChars;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long leftChars;
         @XmlAttribute(name = "right", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger right;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long right;
         @XmlAttribute(name = "rightChars", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger rightChars;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long rightChars;
         @XmlAttribute(name = "hanging", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger hanging;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long hanging;
         @XmlAttribute(name = "hangingChars", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger hangingChars;
+        @XmlJavaTypeAdapter(UnsignedLongAdapter.class)
+        protected Long hangingChars;
         @XmlAttribute(name = "firstLine", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger firstLine;
+        @XmlJavaTypeAdapter(UnsignedLongAdapter.class)
+        protected Long firstLine;
         @XmlAttribute(name = "firstLineChars", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger firstLineChars;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long firstLineChars;
 
         /**
          * Gets the value of the left property.
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getLeft() {
+        public Long getLeft() {
             return left;
         }
 
@@ -1235,10 +1246,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setLeft(BigInteger value) {
+        public void setLeft(Long value) {
             this.left = value;
         }
 
@@ -1247,10 +1258,10 @@ public class PPrBase
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getLeftChars() {
+        public Long getLeftChars() {
             return leftChars;
         }
 
@@ -1259,10 +1270,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setLeftChars(BigInteger value) {
+        public void setLeftChars(Long value) {
             this.leftChars = value;
         }
 
@@ -1271,10 +1282,10 @@ public class PPrBase
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getRight() {
+        public Long getRight() {
             return right;
         }
 
@@ -1283,10 +1294,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setRight(BigInteger value) {
+        public void setRight(Long value) {
             this.right = value;
         }
 
@@ -1295,10 +1306,10 @@ public class PPrBase
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getRightChars() {
+        public Long getRightChars() {
             return rightChars;
         }
 
@@ -1307,10 +1318,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setRightChars(BigInteger value) {
+        public void setRightChars(Long value) {
             this.rightChars = value;
         }
 
@@ -1319,10 +1330,10 @@ public class PPrBase
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getHanging() {
+        public Long getHanging() {
             return hanging;
         }
 
@@ -1331,10 +1342,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setHanging(BigInteger value) {
+        public void setHanging(Long value) {
             this.hanging = value;
         }
 
@@ -1343,10 +1354,10 @@ public class PPrBase
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getHangingChars() {
+        public Long getHangingChars() {
             return hangingChars;
         }
 
@@ -1355,10 +1366,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setHangingChars(BigInteger value) {
+        public void setHangingChars(Long value) {
             this.hangingChars = value;
         }
 
@@ -1367,10 +1378,10 @@ public class PPrBase
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getFirstLine() {
+        public Long getFirstLine() {
             return firstLine;
         }
 
@@ -1379,10 +1390,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setFirstLine(BigInteger value) {
+        public void setFirstLine(Long value) {
             this.firstLine = value;
         }
 
@@ -1391,10 +1402,10 @@ public class PPrBase
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getFirstLineChars() {
+        public Long getFirstLineChars() {
             return firstLineChars;
         }
 
@@ -1403,10 +1414,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setFirstLineChars(BigInteger value) {
+        public void setFirstLineChars(Long value) {
             this.firstLineChars = value;
         }
     }
@@ -1598,17 +1609,18 @@ public class PPrBase
         public static class Ilvl {
 
             @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-            protected BigInteger val;
+            @XmlJavaTypeAdapter(LongAdapter.class)
+            protected Long val;
 
             /**
              * Gets the value of the val property.
              * 
              * @return
              *     possible object is
-             *     {@link BigInteger }
+             *     {@link Long }
              *     
              */
-            public BigInteger getVal() {
+            public Long getVal() {
                 return val;
             }
 
@@ -1617,10 +1629,10 @@ public class PPrBase
              * 
              * @param value
              *     allowed object is
-             *     {@link BigInteger }
+             *     {@link Long }
              *     
              */
-            public void setVal(BigInteger value) {
+            public void setVal(Long value) {
                 this.val = value;
             }
         }
@@ -1652,17 +1664,18 @@ public class PPrBase
         public static class NumId {
 
             @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-            protected BigInteger val;
+            @XmlJavaTypeAdapter(LongAdapter.class)
+            protected Long val;
 
             /**
              * Gets the value of the val property.
              * 
              * @return
              *     possible object is
-             *     {@link BigInteger }
+             *     {@link Long }
              *     
              */
-            public BigInteger getVal() {
+            public Long getVal() {
                 return val;
             }
 
@@ -1671,10 +1684,10 @@ public class PPrBase
              * 
              * @param value
              *     allowed object is
-             *     {@link BigInteger }
+             *     {@link Long }
              *     
              */
-            public void setVal(BigInteger value) {
+            public void setVal(Long value) {
                 this.val = value;
             }
         }
@@ -1709,17 +1722,18 @@ public class PPrBase
     public static class OutlineLvl {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
-        protected BigInteger val;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long val;
 
         /**
          * Gets the value of the val property.
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getVal() {
+        public Long getVal() {
             return val;
         }
 
@@ -1728,10 +1742,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setVal(BigInteger value) {
+        public void setVal(Long value) {
             this.val = value;
         }
     }
@@ -2003,19 +2017,24 @@ public class PPrBase
     public static class Spacing {
 
         @XmlAttribute(name = "before", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger before;
+        @XmlJavaTypeAdapter(UnsignedLongAdapter.class)
+        protected Long before;
         @XmlAttribute(name = "beforeLines", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger beforeLines;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long beforeLines;
         @XmlAttribute(name = "beforeAutospacing", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
         protected Boolean beforeAutospacing;
         @XmlAttribute(name = "after", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger after;
+        @XmlJavaTypeAdapter(UnsignedLongAdapter.class)
+        protected Long after;
         @XmlAttribute(name = "afterLines", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger afterLines;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long afterLines;
         @XmlAttribute(name = "afterAutospacing", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
         protected Boolean afterAutospacing;
         @XmlAttribute(name = "line", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger line;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long line;
         @XmlAttribute(name = "lineRule", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
         protected STLineSpacingRule lineRule;
 
@@ -2024,10 +2043,10 @@ public class PPrBase
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getBefore() {
+        public Long getBefore() {
             return before;
         }
 
@@ -2036,10 +2055,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setBefore(BigInteger value) {
+        public void setBefore(Long value) {
             this.before = value;
         }
 
@@ -2048,10 +2067,10 @@ public class PPrBase
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getBeforeLines() {
+        public Long getBeforeLines() {
             return beforeLines;
         }
 
@@ -2060,10 +2079,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setBeforeLines(BigInteger value) {
+        public void setBeforeLines(Long value) {
             this.beforeLines = value;
         }
 
@@ -2099,10 +2118,10 @@ public class PPrBase
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getAfter() {
+        public Long getAfter() {
             return after;
         }
 
@@ -2111,10 +2130,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setAfter(BigInteger value) {
+        public void setAfter(Long value) {
             this.after = value;
         }
 
@@ -2123,10 +2142,10 @@ public class PPrBase
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getAfterLines() {
+        public Long getAfterLines() {
             return afterLines;
         }
 
@@ -2135,10 +2154,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setAfterLines(BigInteger value) {
+        public void setAfterLines(Long value) {
             this.afterLines = value;
         }
 
@@ -2174,10 +2193,10 @@ public class PPrBase
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getLine() {
+        public Long getLine() {
             return line;
         }
 
@@ -2186,10 +2205,10 @@ public class PPrBase
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setLine(BigInteger value) {
+        public void setLine(Long value) {
             this.line = value;
         }
 
