@@ -306,4 +306,9 @@ public class ParaRPr extends RPrBase
             return false;
         return true;
     }
+
+    @Override
+    public boolean isEmpty() {
+        return isEmpty() && del == null && ins == null && moveFrom == null && moveTo == null && rPrChange == null;
+    }
 }
