@@ -23,6 +23,7 @@ package org.docx4j.wml;
 
 import java.util.List;
 import javax.xml.bind.JAXBElement;
+import javax.xml.bind.Marshaller;
 import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
@@ -40,6 +41,7 @@ import org.docx4j.mce.AlternateContent.Fallback;
 import com.openexchange.office.filter.core.INodeAccessor;
 import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.DLNode;
+import com.openexchange.office.filter.core.IChildNodeCombiner;
 import com.openexchange.office.filter.core.component.Child;
 
 /**
@@ -71,11 +73,11 @@ import com.openexchange.office.filter.core.component.Child;
     "content"
 })
 @XmlRootElement(name = "r")
-public class R implements Child, INodeAccessor<Object> {
+public class R implements Child, IChildNodeCombiner, INodeAccessor<Object> {
 
     protected RPr rPr;
     @XmlElementRefs({
-        @XmlElementRef(name = "ptab", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
+        @XmlElementRef(name = "ptab", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = Ptab.class),
         @XmlElementRef(name = "yearLong", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "dayShort", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "noBreakHyphen", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
@@ -110,12 +112,7 @@ public class R implements Child, INodeAccessor<Object> {
         @XmlElementRef(name = "alternateContent", namespace = "http://schemas.openxmlformats.org/markup-compatibility/2006", type = AlternateContent.class)
     })
     protected DLList<Object> content;
-    @XmlAttribute(name = "rsidRPr", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected String rsidRPr;
-    @XmlAttribute(name = "rsidDel", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected String rsidDel;
-    @XmlAttribute(name = "rsidR", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected String rsidR;
+
     @XmlTransient
     private Object parent;
 
@@ -208,76 +205,28 @@ public class R implements Child, INodeAccessor<Object> {
         return this.content;
     }
 
-    /**
-     * Gets the value of the rsidRPr property.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
+    @XmlAttribute(name = "rsidRPr", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     public String getRsidRPr() {
-        return rsidRPr;
+        return null;
+    }
+    public void setRsidRPr(@SuppressWarnings("unused") String value) {
+        // this value is always ignored and removed
     }
 
-    /**
-     * Sets the value of the rsidRPr property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setRsidRPr(String value) {
-        this.rsidRPr = value;
-    }
-
-    /**
-     * Gets the value of the rsidDel property.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
+    @XmlAttribute(name = "rsidDel", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     public String getRsidDel() {
-        return rsidDel;
+        return null;
+    }
+    public void setRsidDel(@SuppressWarnings("unused") String value) {
+        // this value is always ignored and removed
     }
 
-    /**
-     * Sets the value of the rsidDel property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setRsidDel(String value) {
-        this.rsidDel = value;
-    }
-
-    /**
-     * Gets the value of the rsidR property.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
+    @XmlAttribute(name = "rsidR", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     public String getRsidR() {
-        return rsidR;
+        return null;
     }
-
-    /**
-     * Sets the value of the rsidR property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setRsidR(String value) {
-        this.rsidR = value;
+    public void setRsidR(@SuppressWarnings("unused") String value) {
+        // // this value is always ignored and removed
     }
 
     /**
@@ -296,6 +245,13 @@ public class R implements Child, INodeAccessor<Object> {
         this.parent = parent;
     }
 
+    final public void beforeMarshal(Marshaller marshaller) {
+        // remove empty RPr elements
+        if(rPr!=null && rPr.isEmpty()) {
+            rPr = null;
+        }
+    }
+
     /**
      * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
      *
@@ -349,37 +305,41 @@ public class R implements Child, INodeAccessor<Object> {
         }
     }
 
-    public static boolean tryCombineWithNextNode(DLList<Object> pContent, DLNode<Object> node) {
-        final R run = testObjectForRunWithOneTextOnly(node);
-        if(run!=null) {
-            final DLNode<Object> nextNode = node.getNext();
-            if(nextNode!=null) {
-                final R nextRun = testObjectForRunWithOneTextOnly(node.getNext());
-                if(nextRun!=null) {
-                    final RPr rPrRun = run.getRPr(false);
-                    final RPr rPrNextRun = nextRun.getRPr(false);
-                    if((rPrRun==null&&rPrNextRun==null)||(rPrRun!=null&&rPrRun.equals(rPrNextRun))) {
-                        final Text text = (Text)run.getContent().getFirst();
-                        final Text nextText = (Text)nextRun.getContent().getFirst();
-                        if("preserved".equals(nextText.getSpace())) {
-                            text.setSpace("preserved");
-                        }
-                        // text can be combined
-                        text.setValue(text.getValue() + nextText.getValue());
-                        pContent.removeNode(nextNode);
-                        return true;
-                    }
-                }
+    @Override
+    public boolean tryCombineWithNextNode(INodeAccessor<Object> parentNode, DLNode<Object> nextNode) {
+        if(nextNode==null || !(nextNode.getData() instanceof R)) {
+            return false;
+        }
+        final R nextRun = (R)nextNode.getData();
+        final DLNode<Object> child = getContent().getFirstNode();
+        final DLNode<Object> nextChild = nextRun.getContent().getFirstNode();
+
+        // ensure that each run has exact one IText child...
+        if((child==null || !(child.getData() instanceof IText) || child.getNext()!=null) || (nextChild==null || !(nextChild.getData() instanceof IText) || nextChild.getNext()!=null)) {
+            return false;
+        }
+        final IText text = (IText)child.getData();
+        final IText nextText = (IText)nextChild.getData();
+
+        // ensure that we do not combine text with delText
+        if(text.getClass()!=nextText.getClass()) {
+            return false;
+        }
+
+        final RPr rPrRun = getRPr(false);
+        final RPr rPrNextRun = nextRun.getRPr(false);
+        if((rPrRun==null&&rPrNextRun==null)||(rPrRun!=null&&rPrRun.equals(rPrNextRun))) {
+            if("preserved".equals(nextText.getSpace())) {
+                text.setSpace("preserved");
             }
+            // text can be combined
+            text.setValue(text.getValue() + nextText.getValue());
+            parentNode.getContent().removeNode(nextNode);
+            return true;
         }
         return false;
     }
 
-    static private R testObjectForRunWithOneTextOnly(DLNode<Object> node) {
-        final Object r = node.getData();
-        return (r instanceof R && ((R)r).content.size() == 1 && ((R)r).getContent().getFirst() instanceof Text) ? (R)r : null;
-    }
-
     /**
      * <p>Java class for anonymous complex type.
      *
