@@ -1,52 +1,3 @@
-/*
- *
- *    OPEN-XCHANGE legal information
- *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
- *
- *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- */
-
 package org.docx4j.wml;
 
 import javax.xml.bind.Marshaller;
@@ -934,6 +885,10 @@ public abstract class RPrBase implements Cloneable {
                 return false;
             return true;
         }
+
+        public boolean isEmpty() {
+            return commonPropsUsed == 0;
+        }
     }
 
     private void update_CommonProps(int flag, Object v) {
@@ -1597,7 +1552,7 @@ public abstract class RPrBase implements Cloneable {
                 final w14Props clone = (w14Props)super.clone();
 /*
  * shallow copy is sufficient, we do not change w14 attributes
- *  
+ *
                 if(glow!=null) {
                     clone.glow = glow.clone();
                 }
@@ -1699,6 +1654,10 @@ public abstract class RPrBase implements Cloneable {
             }
             return true;
         }
+
+        public boolean isEmpty() {
+            return w14PropsUsed == 0;
+        }
     }
 
     private void update_W14Props(int flag, Object v) {
@@ -1929,4 +1888,8 @@ public abstract class RPrBase implements Cloneable {
             return false;
         return true;
     }
+
+    public boolean isEmpty() {
+        return (flagsUsed == 0) && (commonProps == null || commonProps.isEmpty()) && (w14Props == null || w14Props.isEmpty());
+    }
 }
