@@ -26,8 +26,9 @@ import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.DLNode;
+import com.openexchange.office.filter.core.IChildNodeCombiner;
+import com.openexchange.office.filter.core.INodeAccessor;
 
 /**
  * Inserted Run Content
@@ -58,18 +59,24 @@ import com.openexchange.office.filter.core.DLNode;
     "content"
 })
 @XmlRootElement(name = "ins")
-public class RunIns extends RIBase
-{
-    public static boolean tryCombineWithNextNode(DLList<Object> pContent, DLNode<Object> node) {
-        final RunIns runIns = (RunIns)node.getData();
-        final DLNode<Object> nextNode = node.getNext();
+public class RunIns extends RIBase implements IChildNodeCombiner {
+
+    @Override
+    public boolean tryCombineWithNextNode(INodeAccessor<Object> parentNode, DLNode<Object> nextNode) {
         if(nextNode!=null && nextNode.getData() instanceof RunIns) {
             final RunIns nextRunIns = (RunIns)nextNode.getData();
-            if(runIns.getAuthor().equals(nextRunIns.getAuthor()) && ((runIns.getDate() == null && nextRunIns.getDate() == null) || runIns.getDate().equals(nextRunIns.getDate()))) {
-                // runIns can be combined, moving all childs from the nextNode into this node
-                nextRunIns.getContent().moveNodes(runIns.getContent(), runIns);
-                pContent.removeNode(nextNode);
-                return true;
+            if(getAuthor().equals(nextRunIns.getAuthor())) {
+                final long time = getDate() == null ? Long.valueOf(0) : getDate().toGregorianCalendar().getTimeInMillis();
+                final long nextTime = nextRunIns.getDate() == null ? Long.valueOf(0) : nextRunIns.getDate().toGregorianCalendar().getTimeInMillis();
+                if(Math.abs(nextTime - time) < 5000) {
+                    // runIns can be combined, moving all childs from the nextNode into this node
+                    nextRunIns.getContent().moveNodes(getContent(), this);
+                    parentNode.getContent().removeNode(nextNode);
+                    if(nextTime > time) {
+                        setDate(nextRunIns.getDate());
+                    }
+                    return true;
+                }
             }
         }
         return false;
@@ -79,22 +86,7 @@ public class RunIns extends RIBase
     final public void beforeMarshal(Marshaller marshaller) {
         super.beforeMarshal(marshaller);
         if(content!=null) {
-            DLNode<Object> node = content.getFirstNode();
-            while(node!=null) {
-                while(tryCombineChildNode(content, node)) {
-                    //
-                }
-                node = node.getNext();
-            }
+            IChildNodeCombiner.optimize(this);
         }
     }
-
-    // returns true if text of this and the next node could be combined, the next node will be removed then
-    private boolean tryCombineChildNode(DLList<Object> pContent, DLNode<Object> node) {
-        final Object child =  node.getData();
-        if(child instanceof R) {
-            return R.tryCombineWithNextNode(pContent, node);
-        }
-        return false;
-    }
 }
