@@ -1,5 +1,6 @@
 package org.docx4j.wml;
 
+import com.openexchange.office.filter.core.IContentAccessor;
 
 //import javax.xml.bind.Unmarshaller;
 
@@ -11,7 +12,7 @@ package org.docx4j.wml;
  * @since 2.7
  *
  */
-public interface SdtElement extends ContentAccessor  {
+public interface SdtElement extends IContentAccessor  {
 
     /**
      * Gets the value of the sdtPr property.
@@ -54,7 +55,7 @@ public interface SdtElement extends ContentAccessor  {
     public void setSdtEndPr(CTSdtEndPr value);
 
 
-    public ContentAccessor getSdtContent();
+    public IContentAccessor getSdtContent();
 
 //    /**
 //     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
