@@ -112,14 +112,6 @@ public class SectPr {
     @XmlElement(namespace = "http://schemas.microsoft.com/office/word/2012/wordml")
     protected CTDecimalNumber footnoteColumns;
     protected CTSectPrChange sectPrChange;
-    @XmlAttribute(name = "rsidRPr", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected String rsidRPr;
-    @XmlAttribute(name = "rsidDel", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected String rsidDel;
-    @XmlAttribute(name = "rsidR", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected String rsidR;
-    @XmlAttribute(name = "rsidSect", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected String rsidSect;
 
     /**
      * Gets the value of the egHdrFtrReferences property.
@@ -661,100 +653,36 @@ public class SectPr {
         this.sectPrChange = value;
     }
 
-    /**
-     * Gets the value of the rsidRPr property.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
+    @XmlAttribute(name = "rsidRPr", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     public String getRsidRPr() {
-        return rsidRPr;
+        return null;
+    }
+    public void setRsidRPr(@SuppressWarnings("unused") String value) {
+        // this value is always ignored and removed
     }
 
-    /**
-     * Sets the value of the rsidRPr property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setRsidRPr(String value) {
-        this.rsidRPr = value;
-    }
-
-    /**
-     * Gets the value of the rsidDel property.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
+    @XmlAttribute(name = "rsidDel", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     public String getRsidDel() {
-        return rsidDel;
+        return null;
+    }
+    public void setRsidDel(@SuppressWarnings("unused") String value) {
+        // this value is always ignored and removed
     }
 
-    /**
-     * Sets the value of the rsidDel property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setRsidDel(String value) {
-        this.rsidDel = value;
-    }
-
-    /**
-     * Gets the value of the rsidR property.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
+    @XmlAttribute(name = "rsidR", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     public String getRsidR() {
-        return rsidR;
+        return null;
+    }
+    public void setRsidR(@SuppressWarnings("unused") String value) {
+        // this value is always ignored and removed
     }
 
-    /**
-     * Sets the value of the rsidR property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setRsidR(String value) {
-        this.rsidR = value;
-    }
-
-    /**
-     * Gets the value of the rsidSect property.
-     *
-     * @return
-     *     possible object is
-     *     {@link String }
-     *
-     */
+    @XmlAttribute(name = "rsidSect", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     public String getRsidSect() {
-        return rsidSect;
+        return null;
     }
-
-    /**
-     * Sets the value of the rsidSect property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link String }
-     *
-     */
-    public void setRsidSect(String value) {
-        this.rsidSect = value;
+    public void setRsidSect(@SuppressWarnings("unused") String value) {
+        // this value is always ignored and removed
     }
 
     /**
