@@ -23,6 +23,7 @@ package org.docx4j.wml;
 
 import java.util.ArrayList;
 import java.util.List;
+import javax.xml.bind.Marshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
@@ -1142,4 +1143,10 @@ public class Style {
             this.val = value;
         }
     }
+
+    public void beforeMarshal(Marshaller marshaller) {
+        if(_default!=null && !_default.booleanValue()) {    // docs-4119, ensure to only write default "true" vaules (regardless of the property
+            _default = null;                                // value LO interprets the existence of this property as default "true" )
+        }
+    }
 }
