@@ -21,7 +21,6 @@
 
 package org.docx4j.wml;
 
-import java.math.BigInteger;
 import java.util.ArrayList;
 import java.util.List;
 import javax.xml.bind.Unmarshaller;
@@ -31,7 +30,9 @@ import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
+import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import org.docx4j.adapter.LongAdapter;
+import com.openexchange.office.filter.core.component.Child;
 
 
 /**
@@ -186,10 +187,12 @@ public class Styles implements Child
      * @return
      *     The parent object.
      */
+    @Override
     public Object getParent() {
         return this.parent;
     }
 
+    @Override
     public void setParent(Object parent) {
         this.parent = parent;
     }
@@ -256,7 +259,8 @@ public class Styles implements Child
         @XmlAttribute(name = "defLockedState", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
         protected Boolean defLockedState;
         @XmlAttribute(name = "defUIPriority", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger defUIPriority;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long defUIPriority;
         @XmlAttribute(name = "defSemiHidden", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
         protected Boolean defSemiHidden;
         @XmlAttribute(name = "defUnhideWhenUsed", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
@@ -264,7 +268,8 @@ public class Styles implements Child
         @XmlAttribute(name = "defQFormat", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
         protected Boolean defQFormat;
         @XmlAttribute(name = "count", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected BigInteger count;
+        @XmlJavaTypeAdapter(LongAdapter.class)
+        protected Long count;
         @XmlTransient
         private Object parent;
 
@@ -308,9 +313,8 @@ public class Styles implements Child
         public boolean isDefLockedState() {
             if (defLockedState == null) {
                 return true;
-            } else {
-                return defLockedState;
             }
+            return defLockedState;
         }
 
         /**
@@ -330,10 +334,10 @@ public class Styles implements Child
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getDefUIPriority() {
+        public Long getDefUIPriority() {
             return defUIPriority;
         }
 
@@ -342,10 +346,10 @@ public class Styles implements Child
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setDefUIPriority(BigInteger value) {
+        public void setDefUIPriority(Long value) {
             this.defUIPriority = value;
         }
 
@@ -388,9 +392,8 @@ public class Styles implements Child
         public boolean isDefUnhideWhenUsed() {
             if (defUnhideWhenUsed == null) {
                 return true;
-            } else {
-                return defUnhideWhenUsed;
             }
+            return defUnhideWhenUsed;
         }
 
         /**
@@ -416,9 +419,8 @@ public class Styles implements Child
         public boolean isDefQFormat() {
             if (defQFormat == null) {
                 return false;
-            } else {
-                return defQFormat;
             }
+            return defQFormat;
         }
 
         /**
@@ -438,10 +440,10 @@ public class Styles implements Child
          * 
          * @return
          *     possible object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public BigInteger getCount() {
+        public Long getCount() {
             return count;
         }
 
@@ -450,10 +452,10 @@ public class Styles implements Child
          * 
          * @param value
          *     allowed object is
-         *     {@link BigInteger }
+         *     {@link Long }
          *     
          */
-        public void setCount(BigInteger value) {
+        public void setCount(Long value) {
             this.count = value;
         }
 
@@ -463,10 +465,12 @@ public class Styles implements Child
          * @return
          *     The parent object.
          */
+        @Override
         public Object getParent() {
             return this.parent;
         }
 
+        @Override
         public void setParent(Object parent) {
             this.parent = parent;
         }
@@ -516,7 +520,8 @@ public class Styles implements Child
             @XmlAttribute(name = "locked", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
             protected Boolean locked;
             @XmlAttribute(name = "uiPriority", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-            protected BigInteger uiPriority;
+            @XmlJavaTypeAdapter(LongAdapter.class)
+            protected Long uiPriority;
             @XmlAttribute(name = "semiHidden", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
             protected Boolean semiHidden;
             @XmlAttribute(name = "unhideWhenUsed", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
@@ -561,9 +566,8 @@ public class Styles implements Child
             public boolean isLocked() {
                 if (locked == null) {
                     return true;
-                } else {
-                    return locked;
                 }
+                return locked;
             }
 
             /**
@@ -583,10 +587,10 @@ public class Styles implements Child
              * 
              * @return
              *     possible object is
-             *     {@link BigInteger }
+             *     {@link Long }
              *     
              */
-            public BigInteger getUiPriority() {
+            public Long getUiPriority() {
                 return uiPriority;
             }
 
@@ -595,10 +599,10 @@ public class Styles implements Child
              * 
              * @param value
              *     allowed object is
-             *     {@link BigInteger }
+             *     {@link Long }
              *     
              */
-            public void setUiPriority(BigInteger value) {
+            public void setUiPriority(Long value) {
                 this.uiPriority = value;
             }
 
@@ -613,9 +617,8 @@ public class Styles implements Child
             public boolean isSemiHidden() {
                 if (semiHidden == null) {
                     return true;
-                } else {
-                    return semiHidden;
                 }
+                return semiHidden;
             }
 
             /**
@@ -641,9 +644,8 @@ public class Styles implements Child
             public boolean isUnhideWhenUsed() {
                 if (unhideWhenUsed == null) {
                     return true;
-                } else {
-                    return unhideWhenUsed;
                 }
+                return unhideWhenUsed;
             }
 
             /**
@@ -670,9 +672,8 @@ public class Styles implements Child
             	
             	if (qFormat==null) {
             		return ((Styles.LatentStyles)this.parent).isDefQFormat();
-            	} else {            	
-            		return qFormat;
-            	}
+            	}            	
+            	return qFormat;
             }
 
             /**
@@ -693,10 +694,12 @@ public class Styles implements Child
              * @return
              *     The parent object.
              */
+            @Override
             public Object getParent() {
                 return this.parent;
             }
 
+            @Override
             public void setParent(Object parent) {
                 this.parent = parent;
             }
