@@ -31,10 +31,11 @@ import javax.xml.bind.annotation.XmlElementRefs;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
-import org.docx4j.IndexedNodeList;
 import org.docx4j.math.CTOMath;
 import org.docx4j.math.CTOMathPara;
+import com.openexchange.office.filter.core.IContentAccessor;
+import com.openexchange.office.filter.core.DLList;
+import com.openexchange.office.filter.core.component.Child;
 
 
 /**
@@ -66,7 +67,7 @@ import org.docx4j.math.CTOMathPara;
 })
 @XmlRootElement(name = "tbl")
 public class Tbl
-    implements Child, ContentAccessor
+    implements Child, IContentAccessor
 {
 
     @XmlElement(required = true)
@@ -103,7 +104,7 @@ public class Tbl
         @XmlElementRef(name = "bookmarkEnd", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "customXml", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class)
     })
-    protected IndexedNodeList<Object> content;
+    protected DLList<Object> content;
     @XmlTransient
     private Object parent;
 
@@ -211,19 +212,19 @@ public class Tbl
      * @since 2.7
      */
     @Override
-	public IndexedNodeList<Object> getContent() {
+	public DLList<Object> getContent() {
         if (content == null) {
-            content = new IndexedNodeList<Object>();
+            content = new DLList<Object>();
         }
         return this.content;
     }
 
-    public void setContent(IndexedNodeList<Object> _content) {
+    public void setContent(DLList<Object> _content) {
     	content = _content;
     }
 
     @Deprecated
-    public IndexedNodeList<Object> getEGContentRowContent() {
+    public DLList<Object> getEGContentRowContent() {
     	return getContent();
     }
 
