@@ -1,38 +1,39 @@
 /*
  *  Copyright 2007-2013, Plutext Pty Ltd.
- *   
+ *
  *  This file is part of docx4j.
 
-    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
-    you may not use this file except in compliance with the License. 
+    docx4j is licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
 
-    You may obtain a copy of the License at 
+    You may obtain a copy of the License at
 
-        http://www.apache.org/licenses/LICENSE-2.0 
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    Unless required by applicable law or agreed to in writing, software 
-    distributed under the License is distributed on an "AS IS" BASIS, 
-    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
-    See the License for the specific language governing permissions and 
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
     limitations under the License.
 
  */
 
 
-package org.docx4j.wml; 
+package org.docx4j.wml;
 
-import java.math.BigInteger;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlType;
+import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import org.docx4j.adapter.LongAdapter;
 
 
 /**
  * <p>Java class for CT_TblWidth complex type.
- * 
+ *
  * <p>The following schema fragment specifies the expected content contained within this class.
- * 
+ *
  * <pre>
  * &lt;complexType name="CT_TblWidth">
  *   &lt;complexContent>
@@ -52,52 +53,55 @@ import javax.xml.bind.annotation.XmlType;
  *   &lt;/complexContent>
  * &lt;/complexType>
  * </pre>
- * 
- * 
+ *
+ *
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_TblWidth")
 public class TblWidth {
-	
-	public final static String TYPE_AUTO = "auto";
-	public final static String TYPE_DXA = "dxa"; // twips	
 
+	public final static String TYPE_AUTO = "auto";
+	public final static String TYPE_DXA = "dxa"; // twips
+
+	// w is specified as integer but many applications are writing floats, so we will accept floats but will
+	// write create non float via setW only
     @XmlAttribute(name = "w", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-    protected BigInteger w;
+    @XmlJavaTypeAdapter(LongAdapter.class)
+    protected Long w;
     @XmlAttribute(name = "type", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     protected String type;
 
     /**
      * Gets the value of the w property.
-     * 
+     *
      * @return
      *     possible object is
-     *     {@link BigInteger }
-     *     
+     *     {@link Long }
+     *
      */
-    public BigInteger getW() {
+    public Long getW() {
         return w;
     }
 
     /**
      * Sets the value of the w property.
-     * 
+     *
      * @param value
      *     allowed object is
-     *     {@link BigInteger }
-     *     
+     *     {@link Long }
+     *
      */
-    public void setW(BigInteger value) {
-        this.w = value;
+    public void setW(Long value) {
+        w = value;
     }
 
     /**
      * Gets the value of the type property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link String }
-     *     
+     *
      */
     public String getType() {
         return type;
@@ -105,11 +109,11 @@ public class TblWidth {
 
     /**
      * Sets the value of the type property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link String }
-     *     
+     *
      */
     public void setType(String value) {
         this.type = value;
