@@ -160,6 +160,6 @@ public class Text implements IText {
      */
     public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
         setParent(parent);
-        org.docx4j.jaxb.Context.abortOnLowMemory();
+        Context.abortOnLowMemory(unmarshaller);
     }
 }
