@@ -52,7 +52,7 @@ import javax.xml.bind.annotation.XmlType;
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "")
 @XmlRootElement(name = "u")
-public class U {
+public class U implements Cloneable {
 
     @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     protected UnderlineEnumeration val;
@@ -184,4 +184,56 @@ public class U {
     public void setThemeShade(String value) {
         this.themeShade = value;
     }
+
+    @Override
+    public U clone() {
+        try {
+            return (U)super.clone();
+        } catch (CloneNotSupportedException e) {
+            return null;
+        }
+    }
+
+    @Override
+    public int hashCode() {
+        final int prime = 31;
+        int result = 1;
+        result = prime * result + ((color == null) ? 0 : color.hashCode());
+        result = prime * result + ((themeColor == null) ? 0 : themeColor.hashCode());
+        result = prime * result + ((themeShade == null) ? 0 : themeShade.hashCode());
+        result = prime * result + ((themeTint == null) ? 0 : themeTint.hashCode());
+        result = prime * result + ((val == null) ? 0 : val.hashCode());
+        return result;
+    }
+
+    @Override
+    public boolean equals(Object obj) {
+        if (this == obj)
+            return true;
+        if (obj == null)
+            return false;
+        if (getClass() != obj.getClass())
+            return false;
+        U other = (U) obj;
+        if (color == null) {
+            if (other.color != null)
+                return false;
+        } else if (!color.equals(other.color))
+            return false;
+        if (themeColor != other.themeColor)
+            return false;
+        if (themeShade == null) {
+            if (other.themeShade != null)
+                return false;
+        } else if (!themeShade.equals(other.themeShade))
+            return false;
+        if (themeTint == null) {
+            if (other.themeTint != null)
+                return false;
+        } else if (!themeTint.equals(other.themeTint))
+            return false;
+        if (val != other.val)
+            return false;
+        return true;
+    }
 }
