@@ -18,5 +18,8 @@
 
  */
 
-@javax.xml.bind.annotation.XmlSchema(namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", elementFormDefault = javax.xml.bind.annotation.XmlNsForm.QUALIFIED)
+@javax.xml.bind.annotation.XmlSchema(namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", xmlns = {
+    @javax.xml.bind.annotation.XmlNs(prefix = "mc", namespaceURI = "http://schemas.openxmlformats.org/markup-compatibility/2006") },
+elementFormDefault = javax.xml.bind.annotation.XmlNsForm.QUALIFIED)
+
 package org.docx4j.wml;
