@@ -21,14 +21,10 @@
 package org.docx4j.openpackaging.packages;
 
 import javax.xml.bind.JAXBException;
-
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 import org.docx4j.Docx4jProperties;
 import org.docx4j.openpackaging.contenttype.ContentType;
 import org.docx4j.openpackaging.contenttype.ContentTypeManager;
 import org.docx4j.openpackaging.contenttype.ContentTypes;
-import org.docx4j.openpackaging.exceptions.Docx4JException;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.parts.DocPropsCorePart;
 import org.docx4j.openpackaging.parts.DocPropsCustomPart;
@@ -40,9 +36,10 @@ import org.docx4j.openpackaging.parts.PresentationML.MainPresentationPart;
 import org.docx4j.openpackaging.parts.PresentationML.NotesSlidePart;
 import org.docx4j.openpackaging.parts.PresentationML.SlideLayoutPart;
 import org.docx4j.openpackaging.parts.PresentationML.SlideMasterPart;
-import org.docx4j.openpackaging.parts.PresentationML.SlidePart;
 import org.docx4j.openpackaging.parts.relationships.Namespaces;
 import org.pptx4j.model.SlideSizesWellKnown;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 
 /**
@@ -72,21 +69,9 @@ public class PresentationMLPackage  extends OpcPackage {
 		super(contentTypeManager);
 		setContentType(new ContentType(ContentTypes.PRESENTATIONML_MAIN));
 	}
-	
-	
-	/**
-	 * Convenience method to create a PresentationMLPackage
-	 * from an existing File (.pptx or .xml Flat OPC).
-     *
-	 * @param pptxFile
-	 *            The pptx file 
-	 */	
-	public static PresentationMLPackage load(java.io.File pptxFile) throws Docx4JException {
-		
-		return (PresentationMLPackage)OpcPackage.load(pptxFile);
-	}
-	
-	public boolean setPartShortcut(Part part, String relationshipType) {
+
+	@Override
+    public boolean setPartShortcut(Part part, String relationshipType) {
 		if (relationshipType.equals(Namespaces.PROPERTIES_CORE)) {
 			docPropsCorePart = (DocPropsCorePart)part;
 			log.info("Set shortcut for docPropsCorePart");
@@ -139,8 +124,7 @@ public class PresentationMLPackage  extends OpcPackage {
 	 * @throws InvalidFormatException
 	 * @since 2.7
 	 */
-	public static PresentationMLPackage createPackage(SlideSizesWellKnown sz, 
-			boolean landscape) throws InvalidFormatException {
+	public static PresentationMLPackage createPackage(SlideSizesWellKnown sz, boolean landscape) throws InvalidFormatException {
 		
 		
 		// Create a package
@@ -149,11 +133,9 @@ public class PresentationMLPackage  extends OpcPackage {
 		// Presentation part
 		MainPresentationPart pp;
 		try {
-			
 			pp = new MainPresentationPart();
-			pp.setJaxbElement(
-					MainPresentationPart.createJaxbPresentationElement(sz, landscape) );
-			pmlPack.addTargetPart(pp);		
+			pp.setJaxbElement(MainPresentationPart.createJaxbPresentationElement(pmlPack, sz, landscape) );
+			pmlPack.addTargetPart(pp);
 			
 //			// Slide part
 //			SlidePart slidePart = new SlidePart();
@@ -162,68 +144,36 @@ public class PresentationMLPackage  extends OpcPackage {
 //			slidePart.setJaxbElement( SlidePart.createSld() );
 			
 			// Slide layout part
-			SlideLayoutPart layoutPart = new SlideLayoutPart(); 
-			layoutPart.setJaxbElement( SlideLayoutPart.createSldLayout() );
-			
+			SlideLayoutPart layoutPart = new SlideLayoutPart();
+			layoutPart.setJaxbElement(SlideLayoutPart.createSldLayout(pmlPack));
+
 //			slidePart.addTargetPart(layoutPart);
-			
+
 			// Slide Master part
 			SlideMasterPart masterPart = new SlideMasterPart();
 			pp.addSlideMasterIdListEntry(masterPart);
 
-			masterPart.setJaxbElement(masterPart.createSldMaster() );
+			masterPart.setJaxbElement(SlideMasterPart.createSldMaster(pmlPack));
 			masterPart.addSlideLayoutIdListEntry(layoutPart);
-			
+
 			layoutPart.addTargetPart(masterPart);
-			
+
 			// Theme part
 			ThemePart themePart = new ThemePart(new PartName("/ppt/theme/theme1.xml"));
 			java.io.InputStream is = org.docx4j.utils.ResourceUtils.getResource(
 						"org/docx4j/openpackaging/parts/PresentationML/theme.xml");
 			themePart.unmarshal(is);
-			
+
 			// .. add it in 2 places ..
 			masterPart.addTargetPart(themePart);
 			pp.addTargetPart(themePart);
-			
-			
+
 		} catch (Exception e) {
-			e.printStackTrace();
 			throw new InvalidFormatException("Couldn't create package", e);
 		}
-		
-		// Return the new package
 		return pmlPack;
-		
 	}
-	
-	/**
-	 * Create a slide and add it to the package.
-	 * Deprecated, so use MainPresentationPart's addSlide method instead.
-	 * 
-	 * @param pp
-	 * @param layoutPart
-	 * @param partName
-	 * @return the slide
-	 * @throws InvalidFormatException
-	 * @throws JAXBException
-	 */
-	@Deprecated
-	public static SlidePart createSlidePart(MainPresentationPart pp, SlideLayoutPart layoutPart, PartName partName) 
-		throws InvalidFormatException, JAXBException {
-		
-		// Slide part
-		SlidePart slidePart = new SlidePart(partName);
-		pp.addSlideIdListEntry(slidePart);
 
-		slidePart.setJaxbElement( SlidePart.createSld() );
-		
-		// Slide layout part
-		slidePart.addTargetPart(layoutPart);
-		
-		return slidePart;
-	}
-  
 	/**
 	 * Create a notes slide and add it to slide relationships
 	 * 
@@ -240,8 +190,7 @@ public class PresentationMLPackage  extends OpcPackage {
         NotesSlidePart notesSlidePart = new NotesSlidePart(partName);
 
         notesSlidePart.getSourceRelationships().add(sourcePart.addTargetPart(notesSlidePart, proposedRelId));
-        notesSlidePart.setJaxbElement(NotesSlidePart.createNotes());
-
+        notesSlidePart.setJaxbElement(NotesSlidePart.createNotes(sourcePart.getPackage()));
         return notesSlidePart;
 
     }
