@@ -175,7 +175,7 @@ public final class SlidePart extends JaxbPmlPart<Sld> implements IContentAccesso
                 final CommentListPart commentListPart = new CommentListPart();
                 final CTCommentList commentList = new CTCommentList();
                 commentListPart.setJaxbElement(commentList);
-                relationshipsPart.addTargetPart(commentListPart, AddPartBehaviour.RENAME_IF_NAME_EXISTS);
+                addTargetPart(commentListPart, AddPartBehaviour.RENAME_IF_NAME_EXISTS);
                 return commentList;
             }
         }
