@@ -1,37 +1,39 @@
 /*
  *  Copyright 2010-2012, Plutext Pty Ltd.
- *   
+ *
  *  This file is part of pptx4j, a component of docx4j.
 
-    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
-    you may not use this file except in compliance with the License. 
+    docx4j is licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
 
-    You may obtain a copy of the License at 
+    You may obtain a copy of the License at
 
-        http://www.apache.org/licenses/LICENSE-2.0 
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    Unless required by applicable law or agreed to in writing, software 
-    distributed under the License is distributed on an "AS IS" BASIS, 
-    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
-    See the License for the specific language governing permissions and 
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
     limitations under the License.
 
  */
 package org.pptx4j.pml;
 
+import javax.xml.bind.JAXBElement;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
+import org.pptx4j.pml_2012.CTPresenceInfo;
 
 
 /**
  * <p>Java class for CT_CommentAuthor complex type.
- * 
+ *
  * <p>The following schema fragment specifies the expected content contained within this class.
- * 
+ *
  * <pre>
  * &lt;complexType name="CT_CommentAuthor">
  *   &lt;complexContent>
@@ -48,8 +50,8 @@ import javax.xml.bind.annotation.XmlType;
  *   &lt;/complexContent>
  * &lt;/complexType>
  * </pre>
- * 
- * 
+ *
+ *
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_CommentAuthor", propOrder = {
@@ -73,25 +75,49 @@ public class CTCommentAuthor {
     @XmlSchemaType(name = "unsignedInt")
     protected long clrIdx;
 
+    public CTPresenceInfo getPresenceInfo(boolean forceCreate) {
+
+        final CTExtensionList lst = getExtLst(forceCreate);
+        if(lst!=null) {
+            final CTExtension ext = lst.getExtensionByUri(CT_PRESENCE_INFO, forceCreate);
+            if(ext!=null) {
+                Object o = ext.getAny();
+                if(o instanceof JAXBElement) {
+                    // unmarshalling
+                    o = ((JAXBElement)o).getValue();
+                }
+                if(!(o instanceof CTPresenceInfo)) {
+                    o = new CTPresenceInfo();
+                }
+                ext.setAny(o);
+                return (CTPresenceInfo)o;
+            }
+        }
+        return null;
+    }
+
     /**
      * Gets the value of the extLst property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link CTExtensionList }
-     *     
+     *
      */
-    public CTExtensionList getExtLst() {
+    public CTExtensionList getExtLst(boolean forceCreate) {
+        if(extLst==null && forceCreate) {
+            extLst = new CTExtensionList();
+        }
         return extLst;
     }
 
     /**
      * Sets the value of the extLst property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link CTExtensionList }
-     *     
+     *
      */
     public void setExtLst(CTExtensionList value) {
         this.extLst = value;
@@ -99,7 +125,7 @@ public class CTCommentAuthor {
 
     /**
      * Gets the value of the id property.
-     * 
+     *
      */
     public long getId() {
         return id;
@@ -107,7 +133,7 @@ public class CTCommentAuthor {
 
     /**
      * Sets the value of the id property.
-     * 
+     *
      */
     public void setId(long value) {
         this.id = value;
@@ -115,11 +141,11 @@ public class CTCommentAuthor {
 
     /**
      * Gets the value of the name property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link String }
-     *     
+     *
      */
     public String getName() {
         return name;
@@ -127,11 +153,11 @@ public class CTCommentAuthor {
 
     /**
      * Sets the value of the name property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link String }
-     *     
+     *
      */
     public void setName(String value) {
         this.name = value;
@@ -139,11 +165,11 @@ public class CTCommentAuthor {
 
     /**
      * Gets the value of the initials property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link String }
-     *     
+     *
      */
     public String getInitials() {
         return initials;
@@ -151,11 +177,11 @@ public class CTCommentAuthor {
 
     /**
      * Sets the value of the initials property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link String }
-     *     
+     *
      */
     public void setInitials(String value) {
         this.initials = value;
@@ -163,7 +189,7 @@ public class CTCommentAuthor {
 
     /**
      * Gets the value of the lastIdx property.
-     * 
+     *
      */
     public long getLastIdx() {
         return lastIdx;
@@ -171,7 +197,7 @@ public class CTCommentAuthor {
 
     /**
      * Sets the value of the lastIdx property.
-     * 
+     *
      */
     public void setLastIdx(long value) {
         this.lastIdx = value;
@@ -179,7 +205,7 @@ public class CTCommentAuthor {
 
     /**
      * Gets the value of the clrIdx property.
-     * 
+     *
      */
     public long getClrIdx() {
         return clrIdx;
@@ -187,9 +213,11 @@ public class CTCommentAuthor {
 
     /**
      * Sets the value of the clrIdx property.
-     * 
+     *
      */
     public void setClrIdx(long value) {
         this.clrIdx = value;
     }
+
+    final static String CT_PRESENCE_INFO = "{19B8F6BF-5375-455C-9EA6-DF929625EA0E}";
 }
