@@ -33,7 +33,6 @@ import org.docx4j.dml.CTTextBodyProperties;
 import org.docx4j.dml.CTTransform2D;
 import org.docx4j.dml.IShape;
 import org.docx4j.dml.ITransform2DAccessor;
-import org.jvnet.jaxb2_commons.ppp.Child;
 
 /**
  * <p>Java class for CT_Connector complex type.
@@ -76,7 +75,7 @@ import org.jvnet.jaxb2_commons.ppp.Child;
     "style",
     "extLst"
 })
-public class CxnSp implements Child, ITransform2DAccessor, IShape, INvPrAccessor {
+public class CxnSp implements IShape, ITransform2DAccessor, INvPrAccessor {
 
     @XmlElement(required = true)
     protected CxnSp.NvCxnSpPr nvCxnSpPr;
@@ -84,8 +83,6 @@ public class CxnSp implements Child, ITransform2DAccessor, IShape, INvPrAccessor
     protected CTShapeProperties spPr;
     protected CTShapeStyle style;
     protected CTExtensionListModify extLst;
-    @XmlTransient
-    private Object parent;
 
     @Override
     public NvPr getNvPr(boolean forceCreate) {
@@ -244,28 +241,6 @@ public class CxnSp implements Child, ITransform2DAccessor, IShape, INvPrAccessor
 		return null;
 	}
 
-    @Override
-    public Object getParent() {
-        return this.parent;
-    }
-
-    @Override
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
     /**
      * <p>Java class for anonymous complex type.
      * 
@@ -389,4 +364,29 @@ public class CxnSp implements Child, ITransform2DAccessor, IShape, INvPrAccessor
 	@Override
 	public void setTextBody(CTTextBodyProperties textBodyProperties) {
 	}
+
+    @XmlTransient
+    private Object parent;
+
+    @Override
+    public Object getParent() {
+        return this.parent;
+    }
+
+    @Override
+    public void setParent(Object parent) {
+        this.parent = parent;
+    }
+
+    /**
+     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
+     * 
+     * @param parent
+     *     The parent object in the object tree.
+     * @param unmarshaller
+     *     The unmarshaller that generated the instance.
+     */
+    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
+        setParent(parent);
+    }
 }
