@@ -26,15 +26,15 @@ import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlElements;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.docx4j.Child;
-import org.docx4j.IndexedNodeList;
 import org.docx4j.dml.CTGroupShapeProperties;
 import org.docx4j.dml.CTGroupTransform2D;
 import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.CTNonVisualGroupDrawingShapeProps;
 import org.docx4j.dml.IGroupShape;
 import org.docx4j.dml.ITransform2DAccessor;
-import org.docx4j.wml.ContentAccessor;
+import com.openexchange.office.filter.core.IContentAccessor;
+import com.openexchange.office.filter.core.DLList;
+import com.openexchange.office.filter.core.component.Child;
 
 /**
  * <p>Java class for CT_GroupShape complex type.
@@ -84,7 +84,7 @@ import org.docx4j.wml.ContentAccessor;
     "content",
     "extLst"
 })
-public class GroupShape implements Child, ITransform2DAccessor, IGroupShape, INvPrAccessor, ContentAccessor {
+public class GroupShape implements Child, ITransform2DAccessor, IGroupShape, INvPrAccessor, IContentAccessor {
 
     @XmlElement(required = true)
     protected GroupShape.NvGrpSpPr nvGrpSpPr;
@@ -98,7 +98,7 @@ public class GroupShape implements Child, ITransform2DAccessor, IGroupShape, INv
         @XmlElement(name = "pic", type = Pic.class),
         @XmlElement(name = "contentPart", type = CTRel.class)
     })
-    protected IndexedNodeList<Object> content;
+    protected DLList<Object> content;
     protected CTExtensionListModify extLst;
     @XmlTransient
     private Object parent;
@@ -201,9 +201,9 @@ public class GroupShape implements Child, ITransform2DAccessor, IGroupShape, INv
      * 
      */
     @Override
-    public IndexedNodeList<Object> getContent() {
+    public DLList<Object> getContent() {
         if (content == null) {
-            content = new IndexedNodeList<Object>();
+            content = new DLList<Object>();
         }
         return content;
     }
