@@ -12,6 +12,7 @@ import org.xlsx4j.sml.CTCommentList;
 import org.xlsx4j.sml.CTComments;
 import org.xlsx4j.sml.CTLegacyDrawing;
 import org.xlsx4j.sml.Worksheet;
+import org.xlsx4j.sml_2018.CTThreadedComments;
 
 public class WorksheetPart extends JaxbSmlPart<Worksheet> {
 
@@ -34,10 +35,10 @@ public class WorksheetPart extends JaxbSmlPart<Worksheet> {
 		setRelationshipType(Namespaces.SPREADSHEETML_WORKSHEET);
 	}
 
-	final public CommentsPart getCommentsPart(boolean forceCreate) throws InvalidFormatException {
-        CommentsPart commentsPart = (CommentsPart)getRelationshipsPart().getPartByType(Namespaces.COMMENTS);
+	final public SpreadsheetCommentsPart getCommentsPart(boolean forceCreate) throws InvalidFormatException {
+        SpreadsheetCommentsPart commentsPart = (SpreadsheetCommentsPart)getRelationshipsPart().getPartByType(Namespaces.COMMENTS);
         if(commentsPart==null&&forceCreate) {
-            commentsPart = new CommentsPart();
+            commentsPart = new SpreadsheetCommentsPart();
             final CTComments c = new CTComments();
             c.setCommentList(new CTCommentList());
             c.setAuthors(new CTAuthors());
@@ -48,7 +49,7 @@ public class WorksheetPart extends JaxbSmlPart<Worksheet> {
 	}
 
     final public CTComments getComments(boolean forceCreate) throws InvalidFormatException {
-        final CommentsPart commentsPart = getCommentsPart(forceCreate);
+        final SpreadsheetCommentsPart commentsPart = getCommentsPart(forceCreate);
         return commentsPart!=null ? commentsPart.getJaxbElement() : null;
     }
 
@@ -71,4 +72,30 @@ public class WorksheetPart extends JaxbSmlPart<Worksheet> {
 	    }
         return vmlPart;
     }
+    
+    final public ThreadedCommentsPart getThreadedCommentsPart(boolean forceCreate) throws InvalidFormatException {
+        ThreadedCommentsPart threadedCommentsPart = (ThreadedCommentsPart)getRelationshipsPart().getPartByType(Namespaces.SPREADSHEETML_THREADED_COMMENTS);
+        
+        if (threadedCommentsPart == null && forceCreate) {
+            threadedCommentsPart = new ThreadedCommentsPart();
+            final CTThreadedComments ct =  new CTThreadedComments();
+            threadedCommentsPart.setJaxbElement(ct);
+            addTargetPart(threadedCommentsPart, AddPartBehaviour.RENAME_IF_NAME_EXISTS);
+        }
+        
+        return threadedCommentsPart;
+    }
+    
+    final public CTThreadedComments getThreadedComments(boolean forceCreate) throws InvalidFormatException {
+        final ThreadedCommentsPart threadedCommentsPart = getThreadedCommentsPart(forceCreate);
+        return threadedCommentsPart == null ? null : threadedCommentsPart.getJaxbElement();
+    }
+    
+    final public void deleteThreadedCommentsPartIfEmpty() throws InvalidFormatException {
+        CTThreadedComments threadedComments = getThreadedComments(false);
+        if (threadedComments != null && threadedComments.getThreadedComments().isEmpty()) {
+            getRelationshipsPart().removeRelationshipByType(Namespaces.SPREADSHEETML_THREADED_COMMENTS);
+        }
+    }
+
 }
