@@ -100,7 +100,7 @@ public class CTDxfs
      */
     public int getOrApply(CTDxf ctDxf) {
         if(xfHelper==null) {
-            xfHelper = new JAXBListHelper<CTDxf>(this.dxf, Context.getJcSML());
+            xfHelper = new JAXBListHelper<CTDxf>(getDxf(), Context.getJcSML());
         }
         return xfHelper.getOrApply(ctDxf);
     }
