@@ -19,14 +19,10 @@
  */
 package org.xlsx4j.sml;
 
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlRootElement;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-
-import org.jvnet.jaxb2_commons.ppp.Child;
 import org.xlsx4j.jaxb.Context;
 
 
@@ -56,22 +52,18 @@ import org.xlsx4j.jaxb.Context;
     "gradientFill"
 })
 @XmlRootElement
-public class CTFill implements Child, Cloneable
+public class CTFill implements Cloneable
 {
     protected CTPatternFill patternFill;
     protected CTGradientFill gradientFill;
-    @XmlTransient
-    private Object parent;
 
     public CTFill clone() {
         final CTFill clone = Context.getsmlObjectFactory().createCTFill();
         if(patternFill!=null) {
             clone.patternFill = patternFill.clone();
-            clone.patternFill.setParent(clone);
         }
         if(gradientFill!=null) {
             clone.gradientFill = gradientFill.clone();
-            clone.gradientFill.setParent(clone);
         }
         return clone;
     }
@@ -123,33 +115,4 @@ public class CTFill implements Child, Cloneable
     public void setGradientFill(CTGradientFill value) {
         this.gradientFill = value;
     }
-
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     *
-     * @return
-     *     The parent object.
-     */
-    @Override
-    public Object getParent() {
-        return this.parent;
-    }
-
-    @Override
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     *
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
-     */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
-
 }
