@@ -98,7 +98,7 @@ public class CTFills
      */
     public int getOrApply(CTFill ctFill) {
         if(fillHelper==null) {
-            fillHelper = new JAXBListHelper<CTFill>(this.fill, Context.getJcSML());
+            fillHelper = new JAXBListHelper<CTFill>(getFill(), Context.getJcSML());
         }
         return fillHelper.getOrApply(ctFill);
     }
