@@ -24,8 +24,8 @@ import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
+import com.openexchange.office.filter.core.spreadsheet.CellRefRange;
 import com.openexchange.office.filter.core.spreadsheet.ICellRefRangeAccess;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
 
 /**
  * <p>Java class for CT_MergeCell complex type.
@@ -49,7 +49,7 @@ import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
 public class CTMergeCell implements ICellRefRangeAccess
 {
     @XmlTransient
-    private SmlUtils.CellRefRange cellRefRange;
+    private CellRefRange cellRefRange;
 
     /**
      * Gets the value of the ref property.
@@ -64,7 +64,7 @@ public class CTMergeCell implements ICellRefRangeAccess
     	if(cellRefRange==null) {
     		return "";
     	}
-        return SmlUtils.getCellRefRange(cellRefRange);
+        return CellRefRange.getCellRefRange(cellRefRange);
     }
 
     /**
@@ -76,17 +76,17 @@ public class CTMergeCell implements ICellRefRangeAccess
      *     
      */
     protected void setRef(String value) {
-    	cellRefRange = SmlUtils.createCellRefRange(value);
+    	cellRefRange = CellRefRange.createCellRefRange(value);
     }
 
-    public SmlUtils.CellRefRange getCellRefRange(boolean forceCreate) {
+    public CellRefRange getCellRefRange(boolean forceCreate) {
     	if(cellRefRange==null&&forceCreate) {
-    		cellRefRange = new SmlUtils.CellRefRange();
+    		cellRefRange = new CellRefRange();
     	}
     	return cellRefRange;
     }
 
-    public void setCellRefRange(SmlUtils.CellRefRange range) {
+    public void setCellRefRange(CellRefRange range) {
     	cellRefRange = range;
     }
 }
