@@ -21,15 +21,13 @@ package org.xlsx4j.sml;
 
 import java.util.ArrayList;
 import java.util.List;
+
 import javax.xml.bind.Marshaller;
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlSchemaType;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import org.jvnet.jaxb2_commons.ppp.Child;
 
 
 /**
@@ -92,6 +90,45 @@ public class CTNumFmts
         return this.numFmt;
     }
 
+    /**
+     * Replaces an existing number format, or appends a new number format.
+     */
+    public void insertNumberFormat(long formatId, String formatCode) {
+
+    	// force creation of the missing list
+    	getNumFmt();
+
+    	// try to find an existing number format, and replace its format code
+        for (CTNumFmt fmt: numFmt) {
+        	if (fmt.getNumFmtId() == formatId) {
+        		fmt.setFormatCode(formatCode);
+        		return;
+        	}
+        }
+
+        // create a new entry in the list
+        final CTNumFmt newFmt = new CTNumFmt();
+        newFmt.setNumFmtId(formatId);
+        newFmt.setFormatCode(formatCode);
+        numFmt.add(newFmt);
+    }
+
+    /**
+     * Deletes an existing number format from the list.
+     */
+    public void deleteNumberFormat(long formatId) {
+
+    	// try to find an existing number format
+        if (numFmt != null) {
+	        for (CTNumFmt fmt: numFmt) {
+	        	if (fmt.getNumFmtId() == formatId) {
+	        		numFmt.remove(fmt);
+	        		return;
+	        	}
+	        }
+        }
+    }
+
     public void beforeMarshal(Marshaller marshaller) {
         this.count = numFmt!=null?(long)numFmt.size():0;
     }
