@@ -27,9 +27,8 @@ import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils.CellRef;
-import com.openexchange.office.filter.core.spreadsheet.SmlUtils.CellRefRange;
+import com.openexchange.office.filter.core.spreadsheet.CellRef;
+import com.openexchange.office.filter.core.spreadsheet.CellRefRange;
 
 
 /**
@@ -379,7 +378,7 @@ public class CTTable implements IAutoFilterAccessor, ISortStateAccessor
     @XmlAttribute(name = "ref", required = true)
     public String getRef() {
     	if(cellRefRange!=null) {
-    		return SmlUtils.getCellRefRange(cellRefRange);
+    		return CellRefRange.getCellRefRange(cellRefRange);
     	}
         return null;
     }
@@ -393,7 +392,7 @@ public class CTTable implements IAutoFilterAccessor, ISortStateAccessor
      *     
      */
     public void setRef(String value) {
-    	cellRefRange = SmlUtils.createCellRefRange(value);
+    	cellRefRange = CellRefRange.createCellRefRange(value);
     }
 
     public void setCellRefRange(CellRefRange cellRefRange) {
