@@ -27,6 +27,7 @@ import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
+import org.docx4j.jaxb.Context;
 
 /**
  * <p>Java class for CT_Cell complex type.
@@ -415,6 +416,6 @@ public class Cell
      *     The unmarshaller that generated the instance.
      */
     public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        org.docx4j.jaxb.Context.abortOnLowMemory();
+        Context.abortOnLowMemory(unmarshaller);
     }
 }
