@@ -7,10 +7,10 @@ public class CellDataWritable extends CellDataReadonly {
 
 	CellDataWritable(CellDataReadonly cellData) {
 		if(cellData.is!=null) {
-			is = XmlUtils.deepCopy(cellData.is, Context.getJcSML());
+			is = XmlUtils.deepCopy(cellData.is, /* TODO provide package */ null, Context.getJcSML());
 		}
 		if(cellData.extLst!=null) {
-			extLst = XmlUtils.deepCopy(cellData.extLst, Context.getJcSML());
+			extLst = XmlUtils.deepCopy(cellData.extLst, /* TODO provide package */ null, Context.getJcSML());
 		}
 		s = cellData.s;
 		t = cellData.t;
