@@ -30,9 +30,6 @@ import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 
-import org.jvnet.jaxb2_commons.ppp.Child;
-
-
 /**
  * <p>Java class for CT_DefinedNames complex type.
  *
@@ -56,13 +53,11 @@ import org.jvnet.jaxb2_commons.ppp.Child;
 @XmlType(name = "CT_DefinedNames", propOrder = {
     "definedName"
 })
-public class DefinedNames implements Child
+public class DefinedNames
 {
     @XmlTransient
     protected List<CTDefinedName> definedName;
     @XmlTransient
-    private Object parent;
-    @XmlTransient
     private HashMap<String, CTDefinedName> definedNameMap;
 
     /**
@@ -95,12 +90,13 @@ public class DefinedNames implements Child
         }
         else if(definedName==null) {
             definedName = new ArrayList<CTDefinedName>();
+            definedNameMap = null;
         }
         return definedName;
     }
 
     public static String getDefinedNameKey(Long localSheetId, String name) {
-        if(localSheetId!=null) {
+        if(localSheetId!=null&&localSheetId>=0) {
             return localSheetId.toString() + "." + name;
         }
         return "." + name;
@@ -119,20 +115,6 @@ public class DefinedNames implements Child
         return definedNameMap;
     }
 
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     *
-     * @return
-     *     The parent object.
-     */
-    public Object getParent() {
-        return this.parent;
-    }
-
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
     /**
      * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
      *
@@ -142,7 +124,6 @@ public class DefinedNames implements Child
      *     The unmarshaller that generated the instance.
      */
     public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
 
         // calling this once to remove double entries using the same name
         getDefinedNameMap();
