@@ -177,7 +177,7 @@ public class Row
             final Cell cell = cells.get(i);
             final int col = cell.getColumn();
             final int to = col+insertCount;
-            if (to>16384) {
+            if (to>=16384) {
                 cells.remove(i--);
             } else if (col>=start) {
                 cell.setColumn(to);
