@@ -212,11 +212,11 @@ public class SheetData
 
     	final List<Row> rows = getListArray();
 
-        for(int i=0, l=rows.size(); i<l; ++i) {
+        for(int i = 0; i < rows.size(); ++i) {
         	final Row row = rows.get(i);
         	final int r = row.getRow();
         	final int to = r + insertCount;
-        	if (r>=1048576) {
+        	if (to>=1048576) {
     			rows.remove(i--);
         	} else if (r>=start) {
                 row.setRow(to);
