@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.api;
 
 import java.util.Collections;
@@ -147,6 +145,7 @@ public enum OCKey {
     COORD_HEIGHT("coordHeight", null),
     COORD_WIDTH("coordWidth", null),
     COUNT("count", null),
+    CREATED("created", null),
     CROP_BOTTOM("cropBottom", null),
     CROP_LEFT("cropLeft", null),
     CROP_RIGHT("cropRight", null),
@@ -279,6 +278,7 @@ public enum OCKey {
     IMAGE("image", null),
     IMAGE_DATA("imageData", null),
     IMAGE_URL("imageUrl", null),
+    INDENT("indent", null),
     INDENT_FIRST_LINE("indentFirstLine", null),
     INDENT_LEFT("indentLeft", null),
     INDENT_RIGHT("indentRight", null),
@@ -343,6 +343,7 @@ public enum OCKey {
     LIST_LABEL_HIDDEN("listLabelHidden", null),
     LIST_LEVEL("listLevel", null),
     LIST_LEVEL_POSITION_AND_SPACE_MODE("listLevelPositionAndSpaceMode", null),
+    LIST_OVERRIDE_START_VALUE("listOverrideStartValue", null),
     LIST_START_VALUE("listStartValue", null),
     LIST_STYLE("listStyle", null),
     LIST_STYLE_ID("listStyleId", null),
