@@ -38,7 +38,6 @@ import org.odftoolkit.odfdom.dom.OdfSchemaDocument;
 import org.odftoolkit.odfdom.pkg.MediaType;
 import org.odftoolkit.odfdom.pkg.OdfPackage;
 import org.odftoolkit.odfdom.pkg.OdfValidationException;
-import org.xml.sax.ErrorHandler;
 import org.xml.sax.SAXException;
 import com.openexchange.office.filter.core.NotSupportedMediaTypeException;
 import com.openexchange.office.filter.odf.MetaData;
@@ -53,18 +52,13 @@ public abstract class OdfDocument extends OdfSchemaDocument {
 
 	private static final String SLASH = "/";
 	private OdfMediaType mMediaType;
-	private long documentOpeningTime;
 	private static final Pattern CONTROL_CHAR_PATTERN = Pattern.compile("\\p{Cntrl}");
 	private static final String EMPTY_STRING = "";
-	private Calendar mCreationDate;
-	private static final String FORMER_OPEN_OFFICE_VERSION = "StarOffice/8$Win32 OpenOffice.org_project/680m18$Build-9161";
 
 	// Using static factory instead of constructor
-	protected OdfDocument(OdfPackage pkg, String internalPath, OdfMediaType mediaType) throws SAXException {
+	protected OdfDocument(OdfPackage pkg, String internalPath, OdfMediaType mediaType) {
 		super(pkg, internalPath, mediaType.getMediaTypeString());
 		mMediaType = mediaType;
-		//set document opening time.
-		documentOpeningTime = System.currentTimeMillis();
 	}
 
 	/**
@@ -158,7 +152,6 @@ public abstract class OdfDocument extends OdfSchemaDocument {
 		}
 		OdfDocument newDocument = newDocument(pkg, ROOT_DOCUMENT_PATH, odfMediaType);
 		//add creation time, the metadata have to be explicitly set
-		newDocument.mCreationDate = Calendar.getInstance();
 		return newDocument;
 	}
 
@@ -255,25 +248,19 @@ public abstract class OdfDocument extends OdfSchemaDocument {
 			// the returned NULL will be taking care of afterwards
 		}
 		if (odfMediaType == null) {
-			ErrorHandler errorHandler = odfPackage.getErrorHandler();
-
 			if (documentMediaType != null) {
 				Matcher matcherCTRL = CONTROL_CHAR_PATTERN.matcher(documentMediaType);
 				if (matcherCTRL.find()) {
 					documentMediaType = matcherCTRL.replaceAll(EMPTY_STRING);
 				}
 			}
-			OdfValidationException ve = new OdfValidationException(OdfSchemaConstraint.DOCUMENT_WITHOUT_ODF_MIMETYPE, internalPath, documentMediaType);
-			if (errorHandler != null) {
-				errorHandler.fatalError(ve);
-			}
-			throw ve;
+			throw new OdfValidationException(OdfSchemaConstraint.DOCUMENT_WITHOUT_ODF_MIMETYPE, internalPath, documentMediaType);
 		}
 		return newDocument(odfPackage, internalPath, odfMediaType);
 	}
 
 	//return null if the media type can not be recognized.
-	private static OdfDocument loadDocumentFromTemplate(OdfMediaType odfMediaType) throws Exception {
+	public static OdfDocument loadDocumentFromTemplate(OdfMediaType odfMediaType) throws Exception {
 
 		final Resource documentTemplate;
 		switch (odfMediaType) {
@@ -353,7 +340,6 @@ public abstract class OdfDocument extends OdfSchemaDocument {
 			default:
 				throw new NotSupportedMediaTypeException("Given mediaType '" + odfMediaType.mMediaType + "' is not yet supported!", odfMediaType.mMediaType);
 		}
-		// returning null if MediaType is not supported
 		return newDoc;
 	}
 
@@ -508,7 +494,7 @@ public abstract class OdfDocument extends OdfSchemaDocument {
 	 * of the embedded document will be copied to a new document package. If the
 	 * embedded document is outside of the current document directory, you have
 	 * to embed it to the sub directory and refresh the link of the embedded
-	 * document. You should reload it from the given file to get the saved
+	 * document. You should reload it from the given file to get the savedloadTemplate
 	 * embedded document.
 	 *
 	 * @param file - the file to save the document
@@ -529,19 +515,6 @@ public abstract class OdfDocument extends OdfSchemaDocument {
 		}
 	}
 
-	/**
-	 * Close the document and release all temporary created data. After
-	 * execution of this method, this class is no longer usable. Do this as the
-	 * last action to free resources. Closing an already closed document has no
-	 * effect.
-	 */
-	@Override
-	public void close() {
-		// set all member variables explicit to null
-		mMediaType = null;
-		super.close();
-	}
-
 	@Override
 	public String toString() {
 		return "\n" + getMediaTypeString() + " - ID: " + this.hashCode() + " " + getPackage().getBaseURI();
