@@ -32,10 +32,10 @@ import org.odftoolkit.odfdom.pkg.OdfPackage;
 import org.w3c.dom.Document;
 import org.xml.sax.SAXException;
 import com.openexchange.office.filter.odf.OdfOperationDoc;
-import com.openexchange.office.filter.ods.dom.JsonOperationConsumer;
-import com.openexchange.office.filter.ods.dom.JsonOperationProducer;
-import com.openexchange.office.filter.ods.dom.SpreadsheetContent;
-import com.openexchange.office.filter.ods.dom.SpreadsheetStyles;
+import com.openexchange.office.filter.odf.ods.dom.JsonOperationConsumer;
+import com.openexchange.office.filter.odf.ods.dom.JsonOperationProducer;
+import com.openexchange.office.filter.odf.ods.dom.SpreadsheetContent;
+import com.openexchange.office.filter.odf.ods.dom.SpreadsheetStyles;
 
 public class OdfSpreadsheetDocument extends OdfDocument {
 
