@@ -108,9 +108,7 @@ public abstract class OdfSchemaDocument extends OdfPackageDocument {
         }
     }
 
-    public JSONObject getOperations(OdfOperationDoc operationDoc)
-    	throws SAXException, JSONException {
-
+    public JSONObject getOperations(OdfOperationDoc operationDoc) throws Exception {
         return null;
     }
 
