@@ -24,7 +24,6 @@ package org.odftoolkit.odfdom.pkg;
 import java.io.BufferedInputStream;
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
-import java.io.Closeable;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
@@ -32,7 +31,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.UnsupportedEncodingException;
-import java.lang.reflect.Constructor;
 import java.net.URI;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -80,10 +78,8 @@ import org.w3c.dom.ls.LSOutput;
 import org.w3c.dom.ls.LSParserFilter;
 import org.w3c.dom.ls.LSSerializerFilter;
 import org.xml.sax.EntityResolver;
-import org.xml.sax.ErrorHandler;
 import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
-import org.xml.sax.SAXParseException;
 import org.xml.sax.XMLReader;
 import com.openexchange.office.filter.core.Tools;
 import com.openexchange.office.tools.common.parser.CharMatcher;
@@ -94,7 +90,7 @@ import com.openexchange.office.tools.common.parser.CharMatcher;
  * loaded document, where files can be inserted and deleted. The changes take
  * effect, when the OdfPackage is being made persisted by save().
  */
-public class OdfPackage implements Closeable {
+public class OdfPackage {
 
 	// Static parts of file references
 	private static final String DOUBLE_DOT = "..";
@@ -135,7 +131,6 @@ public class OdfPackage implements Closeable {
 	private Map<String, Object> mConfiguration = new HashMap<String, Object>();
 	private Map<String, Pair<Integer, Integer>> pixelSizes = new HashMap<String, Pair<Integer, Integer>>();
     private Map<String, Pair<Double, Double>> dpiFromImage = new HashMap<String, Pair<Double, Double>>();
-	private ErrorHandler mErrorHandler;
     private String mManifestVersion;
 
     private Set<String> allUsedDrawings;
@@ -149,7 +144,7 @@ public class OdfPackage implements Closeable {
 		MANIFEST("META-INF/manifest.xml"),
 		/** The "mimetype" file is defined by the ODF 1.2 part 3 Package specification. It contains the mediatype string of the root document and must be the first file in the ZIP and must not be compressed. */
 		MEDIA_TYPE("mimetype");
-		private final String internalPath;
+		final String internalPath;
 
 		OdfFile(String internalPath) {
 			this.internalPath = internalPath;
@@ -203,24 +198,6 @@ public class OdfPackage implements Closeable {
 		mMemoryFileCache = new HashMap<String, byte[]>();
 		mManifestEntries = new HashMap<String, OdfFileEntry>();
 		// specify whether validation should be enabled and what SAX ErrorHandler should be used.
-		if (mErrorHandler == null) {
-			String errorHandlerProperty = System.getProperty("org.odftoolkit.odfdom.validation");
-			if (errorHandlerProperty != null) {
-				if (errorHandlerProperty.equalsIgnoreCase("true")) {
-					mErrorHandler = new DefaultErrorHandler();
-					Logger.getLogger(OdfPackage.class.getName()).finer("Activated validation with default ErrorHandler!");
-				} else {
-					try {
-						Class<?> cl = Class.forName(errorHandlerProperty);
-						Constructor<?> ctor = cl.getDeclaredConstructor(new Class[]{});
-						mErrorHandler = (ErrorHandler) ctor.newInstance();
-						Logger.getLogger(OdfPackage.class.getName()).log(Level.FINER, "Activated validation with ErrorHandler:''{0}''!", errorHandlerProperty);
-					} catch (Exception ex) {
-						Logger.getLogger(OdfPackage.class.getName()).log(Level.SEVERE, "Could not initiate validation with the given ErrorHandler: '" + errorHandlerProperty + "'", ex);
-					}
-				}
-			}
-		}
 	}
 
 	// is called if a low memory notification was received... then its tried to free as much memory as possible
@@ -234,7 +211,6 @@ public class OdfPackage implements Closeable {
 		mPkgDoms = null;
 		mMemoryFileCache = null;
 		mConfiguration = null;
-		mErrorHandler = null;
 	}
 
 	/**
@@ -251,7 +227,7 @@ public class OdfPackage implements Closeable {
 	 * @throws IOException if there's an I/O error while loading the package
 	 */
 	private OdfPackage(File pkgFile) throws SAXException, IOException {
-		this(pkgFile, getBaseURLFromFile(pkgFile), null);
+		this(pkgFile, getBaseURLFromFile(pkgFile));
 	}
 
 	/**
@@ -270,17 +246,11 @@ public class OdfPackage implements Closeable {
 	 *
 	 * @see #getErrorHandler*
 	 */
-	private OdfPackage(File pkgFile, String baseURI, ErrorHandler errorHandler) throws SAXException, IOException {
+	private OdfPackage(File pkgFile, String baseURI) throws SAXException, IOException {
 		this();
-		if (errorHandler != null) {
-			mErrorHandler = errorHandler;
-		}
 		mBaseURI = baseURI;
-		InputStream packageStream = new FileInputStream(pkgFile);
-		try {
+		try(InputStream packageStream = new FileInputStream(pkgFile)) {
 			initializeZip(packageStream);
-		} finally {
-			close(packageStream);
 		}
 	}
 
@@ -301,41 +271,15 @@ public class OdfPackage implements Closeable {
 	 *
 	 * @see #getErrorHandler*
 	 */
-	private OdfPackage(InputStream packageStream, String baseURI, ErrorHandler errorHandler, Map<String, Object> configuration)
+	private OdfPackage(InputStream packageStream, String baseURI, Map<String, Object> configuration)
 			throws SAXException, IOException {
 		this(); // calling private constructor
-		if(errorHandler != null){
-			mErrorHandler = errorHandler;
-		}
+
 		mConfiguration = configuration;
 		mBaseURI = baseURI;
 		initializeZip(packageStream);
 	}
 
-
-	/**
-	 * Creates an OdfPackage from the OpenDocument provided by a InputStream.
-	 *
-	 * <p>Since an InputStream does not provide the arbitrary (non sequential)
-	 * read access needed by OdfPackage, the InputStream is cached. This usually
-	 * takes more time compared to the other constructors. </p>
-	 *
-	 * @param packageStream - an inputStream representing the ODF package
-	 * @param baseURI defining the base URI of ODF package.
-	 * @param errorHandler - SAX ErrorHandler used for ODF validation
-	 * @throws SAXException if there's an XML- or validation-related error while loading the package
-	 * @throws IOException if there's an I/O error while loading the package
-	 *
-	 * @see #getErrorHandler
-	 */
-	private OdfPackage(InputStream packageStream, String baseURI, ErrorHandler errorHandler)
-			throws SAXException, IOException {
-		this(); // calling private constructor
-		mErrorHandler = errorHandler;
-		mBaseURI = baseURI;
-		initializeZip(packageStream);
-	}
-
 	/**
 	 * Loads an OdfPackage from the given documentURL.
 	 *
@@ -352,7 +296,7 @@ public class OdfPackage implements Closeable {
 	 */
 	public static OdfPackage loadPackage(String path) throws Exception {
 		File pkgFile = new File(path);
-		return new OdfPackage(pkgFile, getBaseURLFromFile(pkgFile), null);
+		return new OdfPackage(pkgFile, getBaseURLFromFile(pkgFile));
 	}
 
 	/**
@@ -368,7 +312,7 @@ public class OdfPackage implements Closeable {
 	 * @throws java.lang.Exception - if the package could not be loaded
 	 */
 	public static OdfPackage loadPackage(File pkgFile) throws Exception {
-		return new OdfPackage(pkgFile, getBaseURLFromFile(pkgFile), null);
+		return new OdfPackage(pkgFile, getBaseURLFromFile(pkgFile));
 	}
 
 	/**
@@ -409,46 +353,7 @@ public class OdfPackage implements Closeable {
 	 */
 	public static OdfPackage loadPackage(InputStream packageStream, Map<String, Object> configuration)
 			throws Exception {
-		return new OdfPackage(packageStream, null, null, configuration);
-	}
-
-
-
-
-	/**
-	 * Creates an OdfPackage from the given InputStream.
-	 *
-	 * <p>OdfPackage relies on the file being available for read access over
-	 * the whole life-cycle of OdfPackage.</p>
-	 *
-	 * @param packageStream - an inputStream representing the ODF package
-	 * @param baseURI allows to explicitly set the base URI from the document, As the URL can not be derived from a stream.
-	 * In addition it is possible to set the baseURI to any arbitrary URI, e.g. an URN.
-	 * One usage of the baseURI to describe the source of validation exception thrown by the ErrorHandler.
-	 * @param errorHandler - SAX ErrorHandler used for ODF validation
-	 * @throws SAXException if there's an XML- or validation-related error while loading the package
-	 * @throws IOException if there's an I/O error while loading the package
-	 * @see #getErrorHandler
-	 */
-	public static OdfPackage loadPackage(InputStream packageStream, String baseURI, ErrorHandler errorHandler)
-			throws SAXException, IOException {
-		return new OdfPackage(packageStream, baseURI, errorHandler);
-	}
-
-	/**
-	 * Loads an OdfPackage from the given File.
-	 *
-	 * <p>OdfPackage relies on the file being available for read access over
-	 * the whole life-cycle of OdfPackage.</p>
-	 * @param pkgFile - the ODF Package. A baseURL is being generated based on its location.
-	 * @param errorHandler - SAX ErrorHandler used for ODF validation.
-	 * @throws SAXException if there's an XML- or validation-related error while loading the package
-	 * @throws IOException if there's an I/O error while loading the package
-	 * @see #getErrorHandler
-	 */
-	public static OdfPackage loadPackage(File pkgFile, ErrorHandler errorHandler)
-			throws SAXException, IOException {
-		return new OdfPackage(pkgFile, getBaseURLFromFile(pkgFile), errorHandler);
+		return new OdfPackage(packageStream, null, configuration);
 	}
 
 	/**
@@ -467,9 +372,6 @@ public class OdfPackage implements Closeable {
 		tempBuf.close();
 		if (mTempByteBuf.length < 3) {
 			OdfValidationException ve = new OdfValidationException(OdfPackageConstraint.PACKAGE_IS_NO_ZIP, getBaseURI());
-			if (mErrorHandler != null) {
-				mErrorHandler.fatalError(ve);
-			}
 			throw new IllegalArgumentException(ve);
 		}
 		mZipFile = new ZipHelper(this, mTempByteBuf);
@@ -481,114 +383,39 @@ public class OdfPackage implements Closeable {
 		String firstEntryName = mZipFile.entriesToMap(mZipEntries);
 		if (mZipEntries.isEmpty()) {
 			OdfValidationException ve = new OdfValidationException(OdfPackageConstraint.PACKAGE_IS_NO_ZIP, getBaseURI());
-			if (mErrorHandler != null) {
-				mErrorHandler.fatalError(ve);
-			}
 			throw new IllegalArgumentException(ve);
-		} else {
-			// initialize the files of the package (fileEnties of Manifest)
-			parseManifest();
-
-			// initialize the package media type
-			initializeMediaType(firstEntryName);
-
-			// ToDo: Remove all META-INF/* files from the fileEntries of Manifest
-			mOriginalZipEntries = new HashMap<String, ZipEntry>();
-			mOriginalZipEntries.putAll(mZipEntries);
-			mZipEntries.remove(OdfPackage.OdfFile.MEDIA_TYPE.getPath());
-			mZipEntries.remove(OdfPackage.OdfFile.MANIFEST.getPath());
-			mZipEntries.remove("META-INF/");
-			if (mErrorHandler != null) {
-				validateManifest();
-			}
-			Iterator<String> zipPaths = mZipEntries.keySet().iterator();
-			while (zipPaths.hasNext()) {
-				String internalPath = zipPaths.next();
-				// every resource aside the /META-INF/manifest.xml (and META-INF/ directory)
-				// and "mimetype" will be added as fileEntry
-				if (!internalPath.equals(OdfPackage.OdfFile.MANIFEST.getPath())
-						&& !internalPath.equals("META-INF/")
-						&& !internalPath.equals(OdfPackage.OdfFile.MEDIA_TYPE.getPath())) {
-					// aside "mediatype" and "META-INF/manifest"
-					// add manifest entry as to be described by a <manifest:file-entry>
-					ensureFileEntryExistence(internalPath);
-				}
-			}
 		}
-	}
+		// initialize the files of the package (fileEnties of Manifest)
+		parseManifest();
 
-	/** Validates if all file entries exist in the ZIP and vice versa */
-	private void validateManifest() throws SAXException {
-		Set<String> zipPaths = mZipEntries.keySet();
-		Set<String> manifestPaths = mManifestEntries.keySet();
-		Set<String> sharedPaths = new HashSet<String>(zipPaths);
-		sharedPaths.retainAll(manifestPaths);
+		// initialize the package media type
+		initializeMediaType(firstEntryName);
 
-		if (sharedPaths.size() < zipPaths.size()) {
-			Set<String> zipPathSuperset = new HashSet<String>(mZipEntries.keySet());
-			zipPathSuperset.removeAll(sharedPaths);
-			Set<String> sortedSet = new TreeSet<String>(zipPathSuperset);
-			Iterator<String> iter = sortedSet.iterator();
-			String documentURL = getBaseURI();
-			String internalPath;
-			while (iter.hasNext()) {
-				internalPath = iter.next();
-				if (!internalPath.endsWith(SLASH)) { // not for directories!
-					logValidationError(OdfPackageConstraint.MANIFEST_DOES_NOT_LIST_FILE, documentURL, internalPath);
-				}
-			}
-		}
-		if (sharedPaths.size() < manifestPaths.size()) {
-			Set<String> zipPathSubset = new HashSet<String>(mManifestEntries.keySet());
-			zipPathSubset.removeAll(sharedPaths);
-			// removing root directory
-			zipPathSubset.remove(SLASH);
-
-			// No directory are listed in a ZIP removing all directory with content
-			Iterator<String> manifestOnlyPaths = zipPathSubset.iterator();
-			while (manifestOnlyPaths.hasNext()) {
-				String manifestOnlyPath = manifestOnlyPaths.next();
-				// assumption: all directories end with slash
-				if (manifestOnlyPath.endsWith(SLASH)) {
-					removeDirectory(manifestOnlyPath);
-				} else {
-					// if it is a nonexistent file
-					logValidationError(OdfPackageConstraint.MANIFEST_LISTS_NONEXISTENT_FILE, getBaseURI(), manifestOnlyPath);
-					mManifestEntries.remove(manifestOnlyPath);
-				}
-			}
-		}
-		// remove none document directories
-		Iterator<String> sharedPathsIter = sharedPaths.iterator();
-		while (sharedPathsIter.hasNext()) {
-			String sharedPath = sharedPathsIter.next();
-			// assumption: all directories end with slash
-			if (sharedPath.endsWith(SLASH)) {
-				removeDirectory(sharedPath);
-			}
-		}
-	}
-
-	/** Removes directories without a mimetype (all none documents) */
-	private void removeDirectory(String path) throws SAXException {
-		if (path.endsWith(SLASH)) {
-			// Check if it is a sub-document?
-			// Our assumption: it is a document if it has a mimetype...
-			String dirMimeType = mManifestEntries.get(path).getMediaTypeString();
-			if (dirMimeType == null || EMPTY_STRING.equals(dirMimeType)) {
-				logValidationWarning(OdfPackageConstraint.MANIFEST_LISTS_DIRECTORY, getBaseURI(), path);
-				mManifestEntries.remove(path);
+		// ToDo: Remove all META-INF/* files from the fileEntries of Manifest
+		mOriginalZipEntries = new HashMap<String, ZipEntry>();
+		mOriginalZipEntries.putAll(mZipEntries);
+		mZipEntries.remove(OdfPackage.OdfFile.MEDIA_TYPE.getPath());
+		mZipEntries.remove(OdfPackage.OdfFile.MANIFEST.getPath());
+		mZipEntries.remove("META-INF/");
+		Iterator<String> zipPaths = mZipEntries.keySet().iterator();
+		while (zipPaths.hasNext()) {
+			String internalPath = zipPaths.next();
+			// every resource aside the /META-INF/manifest.xml (and META-INF/ directory)
+			// and "mimetype" will be added as fileEntry
+			if (!internalPath.equals(OdfPackage.OdfFile.MANIFEST.getPath())
+					&& !internalPath.equals("META-INF/")
+					&& !internalPath.equals(OdfPackage.OdfFile.MEDIA_TYPE.getPath())) {
+				// aside "mediatype" and "META-INF/manifest"
+				// add manifest entry as to be described by a <manifest:file-entry>
+				ensureFileEntryExistence(internalPath);
 			}
 		}
 	}
 
 	/** Reads the uncompressed "mimetype" file, which contains the package media/mimte type*/
-	private void initializeMediaType(String firstEntryName) throws SAXException, IOException {
+	private void initializeMediaType(String firstEntryName) throws IOException {
 		ZipEntry mimetypeEntry = mZipEntries.get(OdfPackage.OdfFile.MEDIA_TYPE.getPath());
 		if (mimetypeEntry != null) {
-			if (mErrorHandler != null) {
-				validateMimeTypeEntry(mimetypeEntry, firstEntryName);
-			}
 			// get mediatype value of the root document/package from the mediatype file stream
 			String entryMediaType = getMediaTypeFromEntry(mimetypeEntry);
 			// get mediatype value of the root document/package from the manifest.xml
@@ -597,17 +424,6 @@ public class OdfPackage implements Closeable {
 			if (entryMediaType != null && !entryMediaType.equals(EMPTY_STRING)) {
 				// the root document's mediatype is taken from the "mimetype" file
 				mMediaType = entryMediaType;
-				if (mErrorHandler != null) {
-					// if the "mediatype" does exist, the "/META-INF/manifest.xml" have to contain a MIMETYPE for the root document);
-					if (manifestMediaType != null && !manifestMediaType.equals(EMPTY_STRING)) {
-						// if the two media-types are inconsistent
-						if (!entryMediaType.equals(manifestMediaType)) {
-							logValidationError(OdfPackageConstraint.MIMETYPE_DIFFERS_FROM_PACKAGE, getBaseURI(), CONTROL_CHAR_PATTERN.matcher(mMediaType).replaceAll(EMPTY_STRING), manifestMediaType);
-						}
-					} else { // if "mimetype" file exists, there have to be a mimetype in the manifest.xml for the root document (see ODF 1.2 part 3)
-						logValidationError(OdfPackageConstraint.MIMETYPE_WITHOUT_MANIFEST_MEDIATYPE, getBaseURI(), CONTROL_CHAR_PATTERN.matcher(mMediaType).replaceAll(EMPTY_STRING), manifestMediaType);
-					}
-				}
 			} else { // if there is no media-type was set by the "mimetype" file
 				// try as fall-back the mediatype of the root document from the manifest.xml
 				if (manifestMediaType != null && !manifestMediaType.equals(EMPTY_STRING)) {
@@ -621,22 +437,6 @@ public class OdfPackage implements Closeable {
 				// if not mimetype file exists, the root document mediaType from the manifest.xml is taken
 				mMediaType = manifestMediaType;
 			}
-			if (mErrorHandler != null) {
-				logValidationWarning(OdfPackageConstraint.MIMETYPE_NOT_IN_PACKAGE, getBaseURI());
-			}
-		}
-	}
-
-	private void validateMimeTypeEntry(ZipEntry mimetypeEntry, String firstEntryName) throws SAXException {
-
-		if (mimetypeEntry.getMethod() != ZipEntry.STORED) {
-			logValidationError(OdfPackageConstraint.MIMETYPE_IS_COMPRESSED, getBaseURI());
-		}
-		if (mimetypeEntry.getExtra() != null) {
-			logValidationError(OdfPackageConstraint.MIMETYPE_HAS_EXTRA_FIELD, getBaseURI());
-		}
-		if (!OdfFile.MEDIA_TYPE.getPath().equals(firstEntryName)) {
-			logValidationError(OdfPackageConstraint.MIMETYPE_NOT_FIRST_IN_PACKAGE, getBaseURI());
 		}
 	}
 
@@ -645,60 +445,20 @@ public class OdfPackage implements Closeable {
 		OdfFileEntry rootDocumentEntry = mManifestEntries.get(SLASH);
 		if (rootDocumentEntry != null) {
 			return rootDocumentEntry.getMediaTypeString();
-		} else {
-			return null;
 		}
+		return null;
 	}
 
 	/** @returns the media type of the root document from the manifest.xml */
-	private String getMediaTypeFromEntry(ZipEntry mimetypeEntry) throws SAXException, IOException {
+	private String getMediaTypeFromEntry(ZipEntry mimetypeEntry) throws IOException {
 		String entryMediaType = null;
-		ByteArrayOutputStream out = new ByteArrayOutputStream();
-		try {
+		try(ByteArrayOutputStream out = new ByteArrayOutputStream()) {
 			StreamHelper.transformStream(mZipFile.getInputStream(mimetypeEntry), out);
 			entryMediaType = new String(out.toByteArray(), 0, out.size(), "UTF-8");
-		} catch (IOException ex) {
-			handleIOException(ex, false);
-		} finally {
-			close(out);
 		}
 		return entryMediaType;
 	}
 
-	private void close(Closeable closeable) throws SAXException, IOException {
-		if (closeable != null) {
-			try {
-				closeable.close();
-			} catch (IOException ioe) {
-				//Warning only. This is usually just logged.
-				//Allow user to throw an exception all the same
-				handleIOException(ioe, true);
-			}
-		}
-	}
-
-	private void handleIOException(IOException ex, boolean warningOnly) throws SAXException, IOException{
-		if (mErrorHandler != null) {
-			SAXParseException se = new SAXParseException(ex.getMessage(), null, ex);
-			try {
-				if (warningOnly) {
-					mErrorHandler.warning(se);
-				} else {
-					mErrorHandler.error(se);
-				}
-			} catch (SAXException e1) {
-				if (e1 == se) {
-					throw ex;
-					//We re-throw the original exception if the error handler
-					//just threw the SAXException we gave it.
-				} else {
-					throw e1; //Throw what the error handler threw.
-				}
-			}
-		}
-		throw ex; //No error handler? Just throw the original IOException
-	}
-
 	/**
 	 * Insert an Odf document into the package at the given path.
 	 * The path has to be a directory and will receive the MIME type of the OdfPackageDocument.
@@ -862,12 +622,11 @@ public class OdfPackage implements Closeable {
 		if (internalPath != null) {
 			if (internalPath.equals(EMPTY_STRING) || internalPath.equals(SLASH)) {
 				return mMediaType;
-			} else {
-				mediaType = getMediaTypeFromEntry(normalizePath(internalPath));
-				// if no file was found, look for a normalized directory name
-				if (mediaType == null) {
-					mediaType = getMediaTypeFromEntry(normalizeDirectoryPath(internalPath));
-				}
+			}
+			mediaType = getMediaTypeFromEntry(normalizePath(internalPath));
+			// if no file was found, look for a normalized directory name
+			if (mediaType == null) {
+				mediaType = getMediaTypeFromEntry(normalizeDirectoryPath(internalPath));
 			}
 		}
 		return mediaType;
@@ -878,9 +637,8 @@ public class OdfPackage implements Closeable {
 		// if the document is not in the package, the return is NULL
 		if (entry != null) {
 			return entry.getMediaTypeString();
-		} else {
-			return null;
 		}
+		return null;
 	}
 
 	/**
@@ -949,8 +707,7 @@ public class OdfPackage implements Closeable {
 	 *             - if the package could not be saved
 	 * @throws SAXException
 	 */
-	public void save(String odfPath)
-			throws IOException, SAXException {
+	public void save(String odfPath) throws IOException {
 		File f = new File(odfPath);
 		save(f);
 	}
@@ -964,8 +721,7 @@ public class OdfPackage implements Closeable {
 	 *             - if the package could not be saved
 	 * @throws SAXException
 	 */
-	public void save(File pkgFile)
-			throws IOException, SAXException {
+	public void save(File pkgFile) throws IOException {
 		String baseURL = getBaseURLFromFile(pkgFile);
 //		if (baseURL.equals(mBaseURI)) {
 //			// save to the same file: cache everything first
@@ -973,11 +729,8 @@ public class OdfPackage implements Closeable {
 //			// to the original one - would be less memory footprint
 //			cacheContent();
 //		}
-		FileOutputStream fos = new FileOutputStream(pkgFile);
-		try {
+		try(FileOutputStream fos = new FileOutputStream(pkgFile)) {
 			save(fos, baseURL);
-		} finally {
-			fos.close();
 		}
 	}
 
@@ -987,8 +740,7 @@ public class OdfPackage implements Closeable {
 	 * @throws IOException if an I/O error occurs while saving the package
 	 * @throws SAXException
 	 */
-	public void save(OutputStream odfStream)
-			throws IOException, SAXException {
+	public void save(OutputStream odfStream) throws IOException {
 		save(odfStream, null);
 	}
 
@@ -1002,7 +754,7 @@ public class OdfPackage implements Closeable {
 	 * @throws SAXException
 	 */
 	private void save(OutputStream odfStream, String baseURL)
-			throws IOException, SAXException {
+			throws IOException {
 		mBaseURI = baseURL;
 		OdfFileEntry rootEntry = mManifestEntries.get(SLASH);
 		if (rootEntry == null) {
@@ -1109,51 +861,11 @@ public class OdfPackage implements Closeable {
 		return result;
 	}
 
-	/**
-	 * Close the OdfPackage after it is no longer needed. Even after saving it
-	 * is still necessary to close the package to have again full access about
-	 * the file. Closing the OdfPackage will release all temporary created data.
-	 * Do this as the last action to free resources. Closing an already closed
-	 * document has no effect.
-	 */
-	@Override
-    public void close() {
-		if (mZipFile != null) {
-			try {
-				mZipFile.close();
-			} catch (IOException ex) {
-				// log exception and continue
-				Logger.getLogger(OdfPackage.class.getName()).log(Level.FINER,
-						null, ex);
-			}
-		}
-		// release all stuff - this class is impossible to use afterwards
-		mZipFile = null;
-		mMediaType = null;
-		mZipEntries = null;
-		mPkgDoms = null;
-		mMemoryFileCache = null;
-		mManifestEntries = null;
-		mBaseURI = null;
-		mResolver = null;
-	}
-
 	/**
 	 * Parse the Manifest file
 	 */
 	private void parseManifest() throws SAXException, IOException {
-		InputStream is = null;
-		try {
-			ZipEntry entry = null;
-			// loading the MANIFEST once from the ZIP, as it will never be cached, just once read
-			// during load (now) and on save serialized from file status (ie. mManifestEntries)
-			if ((entry = mZipEntries.get(OdfPackage.OdfFile.MANIFEST.internalPath)) != null) {
-				is = mZipFile.getInputStream(entry);
-			}
-			if (is == null) {
-				logValidationError(OdfPackageConstraint.MANIFEST_NOT_IN_PACKAGE, getBaseURI());
-				throw new IOException("parseManifest: manifest not found");
-			}
+		try(InputStream is = mZipFile.getInputStream(mZipEntries.get(OdfPackage.OdfFile.MANIFEST.internalPath))) {
 			XMLReader xmlReader = getXMLReader();
 			xmlReader.setEntityResolver(getEntityResolver());
 			xmlReader.setContentHandler(new OdfManifestSaxHandler(this));
@@ -1163,10 +875,6 @@ public class OdfPackage implements Closeable {
 			xmlReader.parse(ins);
 			// ToDo: manifest.xml will be held in the future as DOM, now its being generated for each save()
 			mMemoryFileCache.remove(OdfPackage.OdfFile.MANIFEST.internalPath);
-		} catch (IOException ioe) {
-			handleIOException(ioe, false);
-		} finally {
-			close(is);
 		}
 	}
 
@@ -1482,8 +1190,7 @@ public class OdfPackage implements Closeable {
 	 * @throws TransformerException
 	 */
 	public Document getDom(String internalPath) throws SAXException,
-			ParserConfigurationException, IllegalArgumentException,
-			TransformerConfigurationException, TransformerException, IOException {
+			ParserConfigurationException, IllegalArgumentException, IOException {
 
 		Document doc = mPkgDoms.get(internalPath);
 		if (doc != null) {
@@ -1497,10 +1204,6 @@ public class OdfPackage implements Closeable {
 
 		String uri = getBaseURI() + internalPath;
 
-		if (mErrorHandler != null) {
-			builder.setErrorHandler(mErrorHandler);
-		}
-
 		InputSource ins = new InputSource(is);
 		ins.setSystemId(uri);
 
@@ -1618,93 +1321,92 @@ public class OdfPackage implements Closeable {
 	public String getManifestAsString() {
 		if (mManifestEntries == null) {
 			return null;
-		} else {
-			StringBuilder buf = new StringBuilder();
-			buf.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
-			buf.append("<manifest:manifest xmlns:manifest=\"urn:oasis:names:tc:opendocument:xmlns:manifest:1.0\"");
+		}
+		StringBuilder buf = new StringBuilder();
+		buf.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
+		buf.append("<manifest:manifest xmlns:manifest=\"urn:oasis:names:tc:opendocument:xmlns:manifest:1.0\"");
 // REMOVING VERSION DUE TO MS OFFICE 2010 issue
 //                        if(mManifestVersion != null){
 //                            buf.append(" manifest:version=\"" + mManifestVersion + "\"");
 //                        }
-                        buf.append(" >\n");
-			Iterator<String> it = new TreeSet<String>(mManifestEntries.keySet()).iterator();
-			while (it.hasNext()) {
-				String key = it.next();
-				String s = null;
-				OdfFileEntry fileEntry = mManifestEntries.get(key);
-				if (fileEntry != null) {
-					s = fileEntry.getPath();
-					// only directories with a mimetype (documents) will be written into the manifest.xml
-					if (s != null && !s.endsWith(SLASH) || !fileEntry.getMediaTypeString().equals(EMPTY_STRING)) {
-						buf.append(" <manifest:file-entry");
-						if (s != null) {
-							buf.append(" manifest:full-path=\"");
-							buf.append(encodeXMLAttributes(s));
-							buf.append("\"");
-
-						}
-						s = fileEntry.getMediaTypeString();
-						buf.append(" manifest:media-type=\"");
+                    buf.append(" >\n");
+		Iterator<String> it = new TreeSet<String>(mManifestEntries.keySet()).iterator();
+		while (it.hasNext()) {
+			String key = it.next();
+			String s = null;
+			OdfFileEntry fileEntry = mManifestEntries.get(key);
+			if (fileEntry != null) {
+				s = fileEntry.getPath();
+				// only directories with a mimetype (documents) will be written into the manifest.xml
+				if (s != null && !s.endsWith(SLASH) || !fileEntry.getMediaTypeString().equals(EMPTY_STRING)) {
+					buf.append(" <manifest:file-entry");
+					if (s != null) {
+						buf.append(" manifest:full-path=\"");
 						buf.append(encodeXMLAttributes(s));
 						buf.append("\"");
 
-						int i = fileEntry.getSize();
-						if (i > 0) {
-							buf.append(" manifest:size=\"");
-							buf.append(i);
-							buf.append("\"");
-						}
-						EncryptionData enc = fileEntry.getEncryptionData();
-						if (enc != null) {
-							buf.append(">\n");
-							buf.append("  <manifest:encryption-data>\n");
-							Algorithm alg = enc.getAlgorithm();
-							if (alg != null) {
-								buf.append("   <manifest:algorithm");
-								s = alg.getName();
-								if (s != null) {
-									buf.append(" manifest:algorithm-name=\"");
-									buf.append(encodeXMLAttributes(s));
-									buf.append("\"");
-								}
-								s = alg.getInitializationVector();
-								if (s != null) {
-									buf.append(" manifest:initialization-vector=\"");
-									buf.append(encodeXMLAttributes(s));
-									buf.append("\"");
-								}
-								buf.append("/>\n");
+					}
+					s = fileEntry.getMediaTypeString();
+					buf.append(" manifest:media-type=\"");
+					buf.append(encodeXMLAttributes(s));
+					buf.append("\"");
+
+					int i = fileEntry.getSize();
+					if (i > 0) {
+						buf.append(" manifest:size=\"");
+						buf.append(i);
+						buf.append("\"");
+					}
+					EncryptionData enc = fileEntry.getEncryptionData();
+					if (enc != null) {
+						buf.append(">\n");
+						buf.append("  <manifest:encryption-data>\n");
+						Algorithm alg = enc.getAlgorithm();
+						if (alg != null) {
+							buf.append("   <manifest:algorithm");
+							s = alg.getName();
+							if (s != null) {
+								buf.append(" manifest:algorithm-name=\"");
+								buf.append(encodeXMLAttributes(s));
+								buf.append("\"");
 							}
-							KeyDerivation keyDerivation = enc.getKeyDerivation();
-							if (keyDerivation != null) {
-								buf.append("   <manifest:key-derivation");
-								s = keyDerivation.getName();
-								if (s != null) {
-									buf.append(" manifest:key-derivation-name=\"");
-									buf.append(encodeXMLAttributes(s));
-									buf.append("\"");
-								}
-								s = keyDerivation.getSalt();
-								if (s != null) {
-									buf.append(" manifest:salt=\"");
-									buf.append(encodeXMLAttributes(s));
-									buf.append("\"");
-								}
-								buf.append(" manifest:iteration-count=\"");
-								buf.append(keyDerivation.getIterationCount());
-								buf.append("\"/>\n");
+							s = alg.getInitializationVector();
+							if (s != null) {
+								buf.append(" manifest:initialization-vector=\"");
+								buf.append(encodeXMLAttributes(s));
+								buf.append("\"");
 							}
-							buf.append("  </manifest:encryption-data>\n");
-							buf.append(" </<manifest:file-entry>\n");
-						} else {
 							buf.append("/>\n");
 						}
+						KeyDerivation keyDerivation = enc.getKeyDerivation();
+						if (keyDerivation != null) {
+							buf.append("   <manifest:key-derivation");
+							s = keyDerivation.getName();
+							if (s != null) {
+								buf.append(" manifest:key-derivation-name=\"");
+								buf.append(encodeXMLAttributes(s));
+								buf.append("\"");
+							}
+							s = keyDerivation.getSalt();
+							if (s != null) {
+								buf.append(" manifest:salt=\"");
+								buf.append(encodeXMLAttributes(s));
+								buf.append("\"");
+							}
+							buf.append(" manifest:iteration-count=\"");
+							buf.append(keyDerivation.getIterationCount());
+							buf.append("\"/>\n");
+						}
+						buf.append("  </manifest:encryption-data>\n");
+						buf.append(" </<manifest:file-entry>\n");
+					} else {
+						buf.append("/>\n");
 					}
 				}
 			}
-			buf.append("</manifest:manifest>");
-			return buf.toString();
 		}
+		buf.append("</manifest:manifest>");
+		return buf.toString();
 	}
 
 	/**
@@ -1734,13 +1436,12 @@ public class OdfPackage implements Closeable {
 		if (internalPath.equals(OdfPackage.OdfFile.MEDIA_TYPE.getPath())) {
 			if (mMediaType == null) {
 				return null;
-			} else {
-				try {
-					data = mMediaType.getBytes("UTF-8");
-				} catch (UnsupportedEncodingException use) {
-					Logger.getLogger(OdfPackage.class.getName()).log(Level.SEVERE, null, use);
-					return null;
-				}
+			}
+			try {
+				data = mMediaType.getBytes("UTF-8");
+			} catch (UnsupportedEncodingException use) {
+				Logger.getLogger(OdfPackage.class.getName()).log(Level.SEVERE, null, use);
+				return null;
 			}
 			// if the file is "/META-INF/manifest.xml"
 		} else if (internalPath.equals(OdfPackage.OdfFile.MANIFEST.internalPath)) {
@@ -1751,12 +1452,11 @@ public class OdfPackage implements Closeable {
 			String s = getManifestAsString();
 			if (s == null) {
 				return null;
-			} else {
-				try {
-					data = s.getBytes("UTF-8");
-				} catch (UnsupportedEncodingException ex) {
-					Logger.getLogger(OdfPackage.class.getName()).log(Level.SEVERE, null, ex);
-				}
+			}
+			try {
+				data = s.getBytes("UTF-8");
+			} catch (UnsupportedEncodingException ex) {
+				Logger.getLogger(OdfPackage.class.getName()).log(Level.SEVERE, null, ex);
 			}
 			// if the path is already loaded as DOM (highest priority)
 		} else if (mPkgDoms.get(internalPath) != null) {
@@ -1967,8 +1667,7 @@ public class OdfPackage implements Closeable {
 	 * @throws java.lang.Exception
 	 *             when the DOM tree could not be inserted
 	 */
-	public OutputStream insertOutputStream(String internalPath, String mediaType)
-			throws IOException {
+	public OutputStream insertOutputStream(String internalPath, String mediaType) {
 		internalPath = normalizeFilePath(internalPath);
 		final String fPath = internalPath;
 		final OdfFileEntry fFileEntry = getFileEntry(internalPath);
@@ -2090,9 +1789,8 @@ public class OdfPackage implements Closeable {
 			String errMsg = "The internalPath given by parameter is an empty string!";
 			Logger.getLogger(OdfPackage.class.getName()).severe(errMsg);
 			throw new IllegalArgumentException(errMsg);
-		} else {
-			return normalizePath(internalPath);
 		}
+		return normalizePath(internalPath);
 	}
 
 	/**
@@ -2199,13 +1897,12 @@ public class OdfPackage implements Closeable {
 		}
 		if (removeDirLevel > 0) {
 			return EMPTY_STRING;
-		} else {
-			if (!isDirectory) {
-				// remove trailing slash /
-				out.deleteCharAt(out.length() - 1);
-			}
-			return out.toString();
 		}
+		if (!isDirectory) {
+			// remove trailing slash /
+			out.deleteCharAt(out.length() - 1);
+		}
+		return out.toString();
 	}
 
 	/**
@@ -2219,83 +1916,8 @@ public class OdfPackage implements Closeable {
 	public static boolean isExternalReference(String internalPath) {
 		if (mightBeExternalReference(internalPath)) {
 			return true;
-		} else {
-			return mightBeExternalReference(normalizePath(internalPath));
-		}
-	}
-
-	/**
-	 * Allow an application to register an error event handler.
-	 *
-	 * <p>If the application does not register an error handler, all
-	 * error events reported by the ODFDOM (e.g. the SAX Parser) will be silently
-	 * ignored; however, normal processing may not continue.  It is
-	 * highly recommended that all ODF applications implement an
-	 * error handler to avoid unexpected bugs.</p>
-	 *
-	 * <p>Applications may register a new or different handler in the
-	 * middle of a parse, and the ODFDOM will begin using the new
-	 * handler immediately.</p>
-	 *
-	 * @param handler The error handler.
-	 * @see #getErrorHandler
-	 */
-	public void setErrorHandler(ErrorHandler handler) {
-		mErrorHandler = handler;
-	}
-
-	/**
-	 * Return the current error handler used for ODF validation.
-	 *
-	 * @return The current error handler, or null if none
-	 *         has been registered and validation is disabled.
-	 * @see #setErrorHandler
-	 */
-	public ErrorHandler getErrorHandler() {
-		return mErrorHandler;
-	}
-
-	void logValidationWarning(ValidationConstraint constraint, String baseURI, Object... o)
-			throws SAXException {
-		if(mErrorHandler != null){
-			int varCount = 0;
-			if (o != null) {
-				varCount = o.length;
-			}
-			switch (varCount) {
-				case 0:
-					mErrorHandler.warning(new OdfValidationException(constraint, baseURI, o));
-					break;
-				case 1:
-					mErrorHandler.warning(new OdfValidationException(constraint, baseURI, o[0]));
-					break;
-				case 2:
-					mErrorHandler.warning(new OdfValidationException(constraint, baseURI, o[0], o[1]));
-					break;
-			}
-		}
-
-	}
-
-	void logValidationError(ValidationConstraint constraint, String baseURI, Object... o)
-				throws SAXException {
-		if(mErrorHandler != null){
-			int varCount = 0;
-			if (o != null) {
-				varCount = o.length;
-			}
-			switch (varCount) {
-				case 0:
-					mErrorHandler.error(new OdfValidationException(constraint, baseURI, o));
-					break;
-				case 1:
-					mErrorHandler.error(new OdfValidationException(constraint, baseURI, o[0]));
-					break;
-				case 2:
-					mErrorHandler.error(new OdfValidationException(constraint, baseURI, o[0], o[1]));
-					break;
-			}
 		}
+		return mightBeExternalReference(normalizePath(internalPath));
 	}
 
 	public Pair<Integer, Integer> getPixelSize(String imageUrl) {
@@ -2336,8 +1958,7 @@ public class OdfPackage implements Closeable {
 
 	}
 
-	private void checkUnusedRelations(Set<String> drawings, Set<String> usedDrawings)
-			throws SAXException {
+	private void checkUnusedRelations(Set<String> drawings, Set<String> usedDrawings) {
 		if (null != usedDrawings) {
 			Set<String> toDel = new HashSet<>();
 
