@@ -21,7 +21,6 @@
  ************************************************************************/
 package org.odftoolkit.odfdom.pkg;
 
-import java.io.Closeable;
 import java.io.File;
 import java.io.InputStream;
 import java.util.HashMap;
@@ -35,7 +34,8 @@ import org.odftoolkit.odfdom.dom.OdfSchemaDocument;
 import org.w3c.dom.Document;
 import org.xml.sax.EntityResolver;
 import org.xml.sax.SAXException;
-import com.openexchange.office.filter.odf.INodeAccessor;
+import com.openexchange.office.filter.core.INodeAccessor;
+import com.openexchange.office.filter.odf.Authors;
 import com.openexchange.office.filter.odf.MetaData;
 import com.openexchange.office.filter.odf.Settings;
 import com.openexchange.office.filter.odf.draw.Shape;
@@ -48,11 +48,13 @@ import com.openexchange.office.filter.odf.styles.StyleManager;
  *
  * Still the abstract concept of documents exist in the ODF Package layer.
  */
-public class OdfPackageDocument implements Closeable {
+public class OdfPackageDocument {
 
     private final StyleManager styleManager;
     // modified shapes
     private final Set<Shape> modifiedShapes;
+    // authors
+    private Authors authors;
 
     // target nodes...
     private Map<String, INodeAccessor> mTargetNodes = new HashMap<String, INodeAccessor>();
@@ -351,19 +353,6 @@ public class OdfPackageDocument implements Closeable {
 		return mResolver;
 	}
 
-	/**
-	 * Close the OdfPackageDocument, its OdfPackage and release all temporary created data.
-	 * Acter execution of this method, this class is no longer usable.
-	 * Do this as the last action to free resources.
-	 * Closing an already closed document has no effect.
-	 */
-	@Override
-	public void close() {
-		mPackage.close();
-		// set all member variables explicit to null
-		mPackage = null;
-	}
-
 	/** Helper class to receive an ODF document template for new documents from the environment (ie. from the JAR via classloader)*/
 	protected static class Resource {
 
@@ -390,6 +379,13 @@ public class OdfPackageDocument implements Closeable {
         return modifiedShapes;
     }
 
+    public Authors getAuthors(boolean forceCreate) {
+        if(authors==null && forceCreate) {
+            authors = new Authors();
+        }
+        return authors;
+    }
+
     public Map<String, INodeAccessor> getTargetNodes() {
         return mTargetNodes;
     }
