@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.odf;
 
 import java.io.ByteArrayInputStream;
@@ -56,6 +54,8 @@ import com.openexchange.office.filter.core.DocumentComplexity;
 import com.openexchange.office.filter.core.NotSupportedMediaTypeException;
 import com.openexchange.office.filter.core.OperationDocument;
 import com.openexchange.office.filter.odf.ods.dom.SpreadsheetContent;
+import com.openexchange.office.filter.odf.odt.dom.TextContent;
+import com.openexchange.office.filter.odf.odt.dom.TextStyles;
 import com.openexchange.office.filter.odf.styles.DocumentStyles;
 import com.openexchange.office.imagemgr.IResourceManager;
 import com.openexchange.office.tools.common.memory.MemoryObserver;
@@ -225,7 +225,11 @@ public class OdfOperationDoc extends OperationDocument implements InitializingBe
                 addOriginalOdfAsDebug();
                 addOperationFileAsDebug(operationString);
             }
-            operationCount = getDocument().applyOperations(this, ops);
+            final OdfDocument document = getDocument();
+            document.getStylesDom(); // ensure that the dom is loaded for styles and content
+            document.getContentDom();
+            document.getStyleManager().removeUnusedStyles();
+            operationCount = document.applyOperations(this, ops);
             if(operationCount > 0) {
                 // remove the cached view
                 removeCachedView();
