@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 /**
  * @author sven.jacobi@open-xchange.com
  */
@@ -63,7 +61,7 @@ public class EnhancedGeometryHandler extends ElementToBase64Handler {
                 }
                 if(presetShape==null) {
                     final String enhancedPath = attributes.getValue("draw:enhanced-path");
-                    if(!enhancedPath.contains("$")&&!enhancedPath.contains("?")) {
+                    if(enhancedPath!=null&&!enhancedPath.contains("$")&&!enhancedPath.contains("?")) {
                         enhancedGeometry.setPathList(SVGPathParser.getPathList(enhancedPath, new ViewBox(attributes.getValue("svg:viewBox")), false));
                     }
                 }
