@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 /**
  * @author sven.jacobi@open-xchange.com
  */
@@ -649,7 +647,7 @@ public class Shape implements IDrawing, INodeAccessor {
                 }
                 else {
 
-                    final StyleBase styleBase = styleManager.getStyleBaseClone(StyleFamily.GRAPHIC, getStyleName(), isContentStyle());
+                    final StyleBase styleBase = styleManager.getStyleBaseClone(attributes.containsKey("presentation:style-name") ? StyleFamily.PRESENTATION: StyleFamily.GRAPHIC, getStyleName(), isContentStyle());
                     if(styleBase instanceof IGraphicProperties) {
                         final GraphicProperties graphicProperties = ((IGraphicProperties) styleBase).getGraphicProperties();
                         boolean styleFlipH = false;
