@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,10 +19,10 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.odf.ods.dom;
 
+import java.time.Duration;
+import java.time.format.DateTimeParseException;
 import java.util.Calendar;
 import java.util.List;
 import java.util.TimeZone;
@@ -352,21 +352,11 @@ public class CellHandler extends SaxContextHandler {
 
     //convert xmlschema-2 duration to double
     private static Double timeToDouble(String duration) {
-        Double ret = new Double(0.);
-        //PThhHmmMss.sssS
-        int length = duration.length();
-        double hours = 0;
-        double mins = 0;
-        double millisecs = 0.;
-        if(length >= 11 ){
-            int hPos = duration.indexOf('H');
-            int mPos = duration.indexOf('M');
-
-            hours = Integer.parseInt(duration.substring(2, hPos));
-            mins = Integer.parseInt(duration.substring(hPos + 1, mPos ));
-            millisecs = Double.parseDouble(duration.substring(mPos +1,length - 1));
-            ret = hours /24. + mins / 1440. + millisecs/ 86400.;
+        try {
+            return Long.valueOf(Duration.parse(duration).toMillis()).doubleValue() / 86400000.0;
+        }
+        catch(DateTimeParseException e) {
+            return null;
         }
-        return ret;
     }
 }
