@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.odf.ods.dom;
 
 import java.util.ArrayList;
@@ -196,20 +194,27 @@ public class DatabaseRange {
                     break;
                 }
             }
-
-            if (null == sortNode) {
-                sortNode = new ElementNS(content, Namespaces.TABLE, "table:sort");
-                getChilds().add((ElementNSImpl)sortNode);
+            final String type = sort.optString(OCKey.TYPE.value(), "none");
+            if(type.equals("none")) {
+                if (sortNode!=null) {
+                    childs.remove(sortNode);
+                }
             }
+            else {
+                if (null == sortNode) {
+                    sortNode = new ElementNS(content, Namespaces.TABLE, "table:sort");
+                    getChilds().add((ElementNSImpl)sortNode);
+                }
 
-            if (null == sortByChildNode) {
-                sortByChildNode = new ElementNS(content, Namespaces.TABLE, "table:sort-by");
-                sortNode.appendChild(sortByChildNode);
+                if (null == sortByChildNode) {
+                    sortByChildNode = new ElementNS(content, Namespaces.TABLE, "table:sort-by");
+                    sortNode.appendChild(sortByChildNode);
+                }
+
+                ((ElementNSImpl)sortByChildNode).setAttributeNS(Namespaces.TABLE, "table:field-number", Integer.toString(col));
+                String order = sort.optBoolean("descending", false) ? "descending" : "ascending";
+                ((ElementNSImpl)sortByChildNode).setAttributeNS(Namespaces.TABLE, "table:order", order);
             }
-
-            ((ElementNSImpl)sortByChildNode).setAttributeNS(Namespaces.TABLE, "table:field-number", Integer.toString(col));
-            String order = sort.optBoolean("descending", false) ? "descending" : "ascending";
-            ((ElementNSImpl)sortByChildNode).setAttributeNS(Namespaces.TABLE, "table:order", order);
         }
 	}
 
