@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 /**
  * @author sven.jacobi@open-xchange.com
  */
@@ -326,23 +324,26 @@ final public class ParagraphProperties extends StylePropertiesBase {
         if (cellAttributes != null) {
             Object alignHor = cellAttributes.opt(OCKey.ALIGN_HOR.value());
             if (null != alignHor) {
-                if (alignHor == JSONObject.NULL) {
-                    attributes.remove("fo:text-align");
-                } else {
-                    String textAlign = alignHor.toString();
-                    switch (textAlign) {
-                        case "left":
-                            textAlign = "start";
-                            break;
-                        case "right":
-                            textAlign = "end";
-                            break;
-                        default:
-                            textAlign = "center";
-                            break;
+                String textAlign = alignHor.toString();
+                switch (textAlign) {
+                    case "left": {
+                        textAlign = "start";
+                        break;
+                    }
+                    case "right": {
+                        textAlign = "end";
+                        break;
+                    }
+                    case "center": // PATHTHROUGH INTENDED
+                    case "justify": {
+                        break;
+                    }
+                    default: {
+                        textAlign = null;
+                        break;
                     }
-                    attributes.setValue(Namespaces.FO, "text-align", "fo:text-align", textAlign);
                 }
+                attributes.setValue(Namespaces.FO, "text-align", "fo:text-align", textAlign);
             }
         }
     }
