@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 /**
  * @author sven.jacobi@open-xchange.com
  */
@@ -103,22 +101,20 @@ final public class TableCellProperties extends StylePropertiesBase {
                         break;
                     }
                     case ALIGN_VERT : {
-                        if(value==JSONObject.NULL) {
-                            attributes.remove("style:vertical-align");
-                        }
-                        else {
-                            final String vAlign;
-                            if("center".equals(value)) {
-                                vAlign = "middle";
+                        String vAlign = value.toString();
+                        switch(vAlign) {
+                            case "middle": // PASSTHROUGH INTENDED
+                            case "bottom":
+                            case "top":
+                            case "justify": {
+                                break;
                             }
-                            else if("bottom".equals(value)) {
-                                vAlign = "bottom";
+                            default: {
+                                vAlign = null;
+                                break;
                             }
-                            else {
-                                vAlign = "top";
-                            }
-                            attributes.setValue(Namespaces.STYLE, "vertical-align", "style:vertical-align", vAlign);
                         }
+                        attributes.setValue(Namespaces.STYLE, "vertical-align", "style:vertical-align", vAlign);
                         break;
                     }
                     case PADDING_BOTTOM : {
@@ -367,11 +363,14 @@ final public class TableCellProperties extends StylePropertiesBase {
                 case "style:vertical-align": {
                     final String vAlign;
                     if("middle".equals(propValue)) {
-                        vAlign = "center";
+                        vAlign = "middle";
                     }
                     else if("bottom".equals(propValue)) {
                         vAlign = "bottom";
                     }
+                    else if("justify".equals(propValue)) {
+                        vAlign = "justify";
+                    }
                     else {
                         vAlign = "top";
                     }
