@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 /**
  * @author sven.jacobi@open-xchange.com
  */
@@ -42,14 +40,18 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import org.odftoolkit.odfdom.dom.OdfDocumentNamespace;
 import org.odftoolkit.odfdom.pkg.OdfPackage;
+import com.google.common.collect.ImmutableSet;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.api.OCValue;
+import com.openexchange.office.filter.core.DLList;
 import com.openexchange.office.filter.core.DLNode;
 import com.openexchange.office.filter.core.INodeAccessor;
 import com.openexchange.office.filter.core.spreadsheet.FormatCode;
 import com.openexchange.office.filter.odf.AttributesImpl;
+import com.openexchange.office.filter.odf.IStartElementListener;
 import com.openexchange.office.filter.odf.Namespaces;
 import com.openexchange.office.filter.odf.OpAttrs;
+import com.openexchange.office.filter.odf.SaxContextHandler;
 import com.openexchange.office.filter.odf.listlevel.ListLevelStyleEntry;
 import com.openexchange.office.filter.odf.properties.FontFace;
 import com.openexchange.office.filter.odf.properties.GraphicProperties;
@@ -338,7 +340,9 @@ public class StyleManager {
 					}
 					case LIST_STYLE : {
 						if(documentType.equals("text")) {
-							_createInsertStyleOperation(style, "list-style", false, createdStyles, operationsQueue);
+		                    if(usedStyles.contains(style.getName())) {
+		                        _createInsertStyleOperation(style, "list-style", false, createdStyles, operationsQueue);
+		                    }
 						}
 						break;
 					}
@@ -362,9 +366,11 @@ public class StyleManager {
 			final HashSet<String> createdStyles = new HashSet<String>();
 			while(styleIter.hasNext()) {
 				final StyleBase style = (StyleBase)styleIter.next().getData();
-				if(style.getFamily()==StyleFamily.LIST_STYLE) {
-					_createInsertStyleOperation(style, "list-style", false, createdStyles, operationsQueue);
-				}
+                if(usedStyles.contains(style.getName())) {
+    				if(style.getFamily()==StyleFamily.LIST_STYLE) {
+    					_createInsertStyleOperation(style, "list-style", false, createdStyles, operationsQueue);
+    				}
+                }
 			}
 		}
 	}
@@ -664,21 +670,15 @@ public class StyleManager {
 
     /* returns a style clone of the given parameters, the style is not inserted */
     public StyleBase getStyleBaseClone(StyleFamily family, String styleId, boolean contentAutoStyle) {
-        final StyleBase currentStyleBase;
         if(styleId!=null&&!styleId.isEmpty()) {
             final StyleBase originalStyleBase = getStyle(styleId, family, contentAutoStyle);
             if(originalStyleBase!=null) {
-                currentStyleBase = originalStyleBase.clone();
-                currentStyleBase.setName(getUniqueStyleName(family, contentAutoStyle));
-            }
-            else {
-                currentStyleBase = createStyleBase(family, styleId, true, contentAutoStyle);
+                final StyleBase clonedStyle = originalStyleBase.clone();
+                clonedStyle.setName(getUniqueStyleName(family, contentAutoStyle));
+                return clonedStyle;
             }
         }
-        else {
-            currentStyleBase = createStyleBase(family, getUniqueStyleName(family, contentAutoStyle), true, contentAutoStyle);
-        }
-        return currentStyleBase;
+        return createStyleBase(family, getUniqueStyleName(family, contentAutoStyle), true, contentAutoStyle);
     }
 
     public void applyAttrs(StyleBase styleBase, boolean contentAutoStyle, JSONObject attrs)
@@ -1541,4 +1541,119 @@ public class StyleManager {
 			fontFaceDeclsMaster = fontFaceDecls;
 		}
 	}
+
+	// ------------------------------------------------------------------------------------------------------------------
+	// Style optimizations ...
+	// ------------------------------------------------------------------------------------------------------------------
+
+	// the set of styles that are referenced via styleRefAttributes when loading
+	final Set<String> usedStyles = new HashSet<String>();
+
+	// all attributes of the odf file format that are referencing a style (styleRef). !If the attribute name is ending
+	// with "names" then the value of the attribute is a space separated list of style names (styleRefs) e.g. "text:class-names"
+    static final public ImmutableSet<String> styleRefAttributes = new ImmutableSet.Builder<String>()
+        .add("chart:style-name")
+        .add("db:default-cell-style-name")
+        .add("db:default-row-style-name")
+        .add("db:style-name")
+        .add("draw:stroke-dash-names")                      // styleRefs
+        .add("draw:class-names")                            // styleRefs
+        .add("draw:fill-gradient-name")
+        .add("draw:fill-hatch-name")
+        .add("draw:fill-image-name")
+        .add("draw:marker-end")
+        .add("draw:marker-start")
+        .add("draw:master-page-name")
+        .add("draw:opacity-name")
+        .add("draw:stroke-dash")
+        .add("draw:style-name")
+        .add("draw:text-style-name")
+        .add("form:text-style-name")
+        .add("presentation:class-names")                    // styleRefs
+        .add("presentation:presentation-page-layout-name")
+        .add("presentation:style-name")
+        .add("style:apply-style-name")
+        .add("style:data-style-name")
+        .add("style:leader-text-style")
+        .add("style:list-style-name")
+        .add("style:master-page-name")
+        .add("style:next-style-name")
+        .add("style:page-layout-name")
+        .add("style:parent-style-name")
+        .add("style:percentage-data-style-name")
+        .add("style:register-truth-ref-style-name")
+        .add("style:style-name")
+        .add("style:text-line-through-text-style")
+        .add("table:default-cell-style-name")
+        .add("table:paragraph-style-name")
+        .add("table:style-name")
+        .add("text:citation-body-style-name")
+        .add("text:citation-style-name")
+        .add("text:class-names")                            // styleRefs
+        .add("text:cond-style-name")
+        .add("text:default-style-name")
+        .add("text:main-entry-style-name")
+        .add("text:master-page-name")
+        .add("text:style-name")
+        .add("text:style-override")
+        .add("text:visited-style-name")
+        .build();
+
+    final private IStartElementListener startElementListener = (attributes, uri, localName, qName) -> {
+        for(int i = 0; i < attributes.getLength(); i++) {
+            final String attr = attributes.getQName(i);
+            if(styleRefAttributes.contains(attr)) {
+                if(attr.endsWith("names")) { // taking care of the type "styleRefs"
+                    final String[] styleNames = attributes.getValue(i).split(" ", -1);
+                    for(String styleName:styleNames) {
+                        if(!styleName.isEmpty()) {
+                            usedStyles.add(styleName);
+                        }
+                    }
+                }
+                else {
+                    usedStyles.add(attributes.getValue(i));
+                }
+            }
+        }
+    };
+
+    public void removeUnusedStyles() {
+        removeUnusedStyles(StyleFamily.TEXT, true, true);
+        removeUnusedStyles(StyleFamily.TEXT, true, false);
+        removeUnusedStyles(StyleFamily.PARAGRAPH, true, true);
+        removeUnusedStyles(StyleFamily.PARAGRAPH, true, false);
+    }
+
+    private void removeUnusedStyles(StyleFamily styleFamily, boolean automaticStyle, boolean contentStyle) {
+        final HashMap<String, DLNode<Object>> styleMap;
+        final DLList<Object> contentAccessor;
+        if (automaticStyle) {
+            styleMap = contentStyle ? familyAutomaticStylesContent.getStylesByFamily(styleFamily) : familyAutomaticStylesMaster.getStylesByFamily(styleFamily);
+            contentAccessor = contentStyle ? automaticStylesContent.getContent() : automaticStylesMaster.getContent();
+        }
+        else {
+            styleMap = contentStyle ? familyStyles.getStylesByFamily(styleFamily) : familyMasterStyles.getStylesByFamily(styleFamily);
+            contentAccessor = contentStyle ? styles.getContent() : masterStyles.getContent();
+        }
+        if(styleMap!=null) {
+            styleMap.entrySet().removeIf(entry -> {
+                if(!usedStyles.contains(entry.getKey())) {
+                    final DLNode<Object> styleBaseNode = entry.getValue();
+                    final StyleBase styleBase = (StyleBase)styleBaseNode.getData();
+                    contentAccessor.removeNode(styleBaseNode);
+                    final String allStyleName = allStyles.get(styleBase);
+                    if (entry.getKey().equals(allStyleName)) {
+                        allStyles.remove(styleBase);
+                    }
+                    return true;
+                }
+                return false;
+            });
+        }
+    }
+
+    public void initializeStyleOptimizations(SaxContextHandler contextHandler) {
+	    contextHandler.addStartElementListener(startElementListener);
+	}
 }
