@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.docx;
 
 import java.io.ByteArrayInputStream;
@@ -29,6 +27,7 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import javax.xml.datatype.DatatypeConfigurationException;
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.Docx4JException;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
@@ -514,7 +513,7 @@ public class DocxOperationDocument extends OfficeOpenXMLOperationDocument {
             }
         }
         if(commentsPart!=null) {
-            commentsPart.mergeParaIdToUserId();
+            commentsPart.mergeParaIdToComment();
             final CommentsExPart commentsExPart = getCommentsExPart(false);
             if(commentsExPart!=null) {
                 // the commentsEx are containing relationships to parent comments only, we will merge
@@ -531,10 +530,8 @@ public class DocxOperationDocument extends OfficeOpenXMLOperationDocument {
         final CommentsPart commentsPart = getCommentsPart(false);
         if(commentsPart!=null) {
             final Comments comments = commentsPart.getJaxbElement();
-            int unique = 0;
             for(Comment c:comments.getComments()) {
-                unique += 0x10000;
-                c.setParaId((c.getUserId() & 0xffff) | unique);
+                c.setParaIdToParagraph(getPackage().getNextMarkupId());
             }
             final CTCommentsEx commentsEx = new CTCommentsEx();
             final Iterator<Comment> commentIter = comments.getComments().iterator();
@@ -697,12 +694,12 @@ public class DocxOperationDocument extends OfficeOpenXMLOperationDocument {
     }
 
     @Override
-    protected void switchToNonTemplateDocument() {
+    protected void switchToNonTemplateDocument() throws Exception {
         super.switchToNonTemplateDocument();
     }
 
     @Override
-    protected void switchToTemplateDocument() {
+    protected void switchToTemplateDocument() throws Exception {
         super.switchToTemplateDocument();
 
         final MainDocumentPart mainDocumentPart = getPackage().getMainDocumentPart();
@@ -713,50 +710,12 @@ public class DocxOperationDocument extends OfficeOpenXMLOperationDocument {
         removePart(mainRelationshipsPart, "/word/printerSettings/printerSettings2.bin");
         removePart(mainRelationshipsPart, "/word/printerSettings/printerSettings3.bin");
 
-        // removing changeIds from the document
-        final RootComponent rootComponent = new RootComponent(this, mainDocumentPart);
-        removeRSids(rootComponent.getNextChildComponent(null, null));
-
         // removing rsIds from settings if available
         final DocumentSettingsPart documentSettingsPart = (DocumentSettingsPart)mainDocumentPart.getRelationshipsPart(true).getPartByType(Namespaces.SETTINGS);
         if(documentSettingsPart!=null) {
             final CTSettings settings = documentSettingsPart.getJaxbElement();
             settings.setRsids(null);
         }
-        final SectPr secPr = mainDocumentPart.getJaxbElement().getBody().getSectPr(false);
-        if(secPr!=null) {
-            secPr.setRsidDel(null);
-            secPr.setRsidR(null);
-            secPr.setRsidRPr(null);
-            secPr.setRsidSect(null);
-        }
-    }
-
-    private void removeRSids(IComponent<OfficeOpenXMLOperationDocument> c) {
-        while(c!=null) {
-            removeRSids(c.getNextChildComponent(null, null));
-            if(c instanceof ParagraphComponent) {
-                final P p = (P)c.getObject();
-                p.setRsidDel(null);
-                p.setRsidR(null);
-                p.setRsidRDefault(null);
-                p.setRsidRPr(null);
-            }
-            else if (c instanceof TextRun_Base) {
-                final R r = ((TextRun_Base)c).getTextRun();
-                r.setRsidDel(null);
-                r.setRsidR(null);
-                r.setRsidRPr(null);
-            }
-            else if(c instanceof TrComponent) {
-                final Tr tr = (Tr)c.getObject();
-                tr.setRsidDel(null);
-                tr.setRsidR(null);
-                tr.setRsidRPr(null);
-                tr.setRsidTr(null);
-            }
-            c = c.getNextComponent();
-        }
     }
 
     private void insertPredefinedLatentStyles(Styles styles) {
@@ -941,25 +900,15 @@ public class DocxOperationDocument extends OfficeOpenXMLOperationDocument {
         }
     }
 
-    // is converting a comment id "cmtffff_0" into an integer
-    public static int operationIdToIndex(String v) {
-        return Integer.parseInt(v.substring(8));
+    // is converting a comment id "cmtffffffff" into an integer
+    public static int commentOperationIdToId(String v) {
+        return Integer.parseUnsignedInt(v.substring(3), 16);
     }
 
-    public static int operationIdToUserId(String v) {
-        return Integer.parseUnsignedInt(v.substring(3, 7), 16);
-    }
-
-    public static String getOperationId(int index, int userId) {
-        final String userIdHex = Integer.toHexString(userId & 0xffff);
+    public static String getCommentOperationId(int id) {
         final StringBuilder builder = new StringBuilder();
         builder.append("cmt");
-        for(int i = 4 - userIdHex.length(); i > 0; i--) {
-            builder.append('0');
-        }
-        builder.append(userIdHex);
-        builder.append('_');
-        builder.append(Integer.valueOf(index & 0x7fff).toString());
+        builder.append(Integer.toHexString(id));
         return builder.toString();
     }
 }
