@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,13 +19,12 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.docx.components;
 
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.parts.WordprocessingML.CommentsPart;
 import org.docx4j.wml.Comments;
+import org.docx4j.wml.ParaRPr;
 import org.docx4j.wml.R;
 import org.docx4j.wml.SdtBlock;
 import org.json.JSONObject;
@@ -63,8 +62,8 @@ public abstract class DocxComponent extends OfficeOpenXMLComponent {
     @Override
     public void delete(int count) {
     	final ComponentContext<OfficeOpenXMLOperationDocument> contextChild = getContextChild(null);
-
     	final int endComponent = (getComponentNumber()+count)-1;
+
     	IComponent<OfficeOpenXMLOperationDocument> component = this;
         while(true) {
             if(component instanceof CommentReferenceComponent) {
@@ -77,6 +76,11 @@ public abstract class DocxComponent extends OfficeOpenXMLComponent {
                     }
                 }
             }
+            else if(component instanceof TextRun_Base) {
+                /* docs-3603 -> when deleting the last textrun its properties must be set to the paragraph...
+                   (we set each deleted textrun to the paragraph, this is no problem and saves us to check if a textrun is the last textrun in a paragraph) */
+                ((TextRun_Base)component).getParagraph().getPPr(true).setRPr(ParaRPr.cloneFromRPrBase(  ((TextRun_Base)component).getTextRun().getRPr(false)));
+            }
             if(component.getNextComponentNumber()>endComponent) {
                 break;
             }
