@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.docx.components;
 
 import javax.xml.datatype.XMLGregorianCalendar;
@@ -136,6 +134,7 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
         }
         return nextComponent;
     }
+
     @Override
     public IComponent<OfficeOpenXMLOperationDocument> insertChildComponent(int textPosition, JSONObject attrs, ComponentType childType) throws Exception {
 
@@ -202,9 +201,6 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
                 childComponent.splitEnd(textPosition-1, SplitMode.ATTRIBUTE);
             }
 
-            final DLNode<Object> referenceNode = childComponent instanceof TextRun_Base ? ((TextRun_Base)childComponent).getTextRunNode() : childComponent.getNode();
-            final IContentAccessor<Object> destination = (IContentAccessor<Object>)((Child)referenceNode.getData()).getParent();
-
             // the r element can't be shared with multiple components, office 365 for instance will not display comments if
             // following construct is used, the commentReference needs to be in its own text run -> always create a new r
 
@@ -215,14 +211,32 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
             </w:r>
 */
 
-            final R newRun = Context.getWmlObjectFactory().createR();
-            newChild.setParent(newRun);
-            newRun.getContent().add(newChild);
-            newRun.setParent(destination);
-            ((DLList<Object>)destination.getContent()).addNode(referenceNode, new DLNode<Object>(newRun), textPosition == 0);
+            if (childComponent instanceof TextRun_Base) {
 
-            // todo: search for previous text runs and get a clone of RPr
+                final DLNode<Object> referenceTextRunNode = ((TextRun_Base)childComponent).getTextRunNode();
+                final IContentAccessor<Object> destination = (IContentAccessor<Object>)((Child)referenceTextRunNode.getData()).getParent();
 
+                final R newRun = Context.getWmlObjectFactory().createR();
+                newRun.setRPr(RPr.cloneFromRPrBase(((R)referenceTextRunNode.getData()).getRPr(false)));
+                newChild.setParent(newRun);
+                newRun.getContent().add(newChild);
+                newRun.setParent(destination);
+                ((DLList<Object>)destination.getContent()).addNode(referenceTextRunNode, new DLNode<Object>(newRun), textPosition == 0);
+            }
+            else {
+
+                // only ranges and bookmarks do not have a textrun
+
+                final DLNode<Object> referenceNode = childComponent.getNode();
+                final IContentAccessor<Object> destination = (IContentAccessor<Object>)((Child)referenceNode.getData()).getParent();
+
+                final R newRun = Context.getWmlObjectFactory().createR();
+                newRun.setRPr(getClonedRPrInheritance(childComponent));
+                newChild.setParent(newRun);
+                newRun.getContent().add(newChild);
+                newRun.setParent(destination);
+                ((DLList<Object>)destination.getContent()).addNode(referenceNode, new DLNode<Object>(newRun), textPosition == 0);
+            }
         }
         else {
             final R newRun = Context.getWmlObjectFactory().createR();
@@ -670,7 +684,8 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
             IComponent<OfficeOpenXMLOperationDocument> cRet = null;
 
             if(childComponent!=null) {
-            	if(textPosition>0) {
+
+                if(textPosition>0) {
             		childComponent = childComponent.getComponent(textPosition-1);
             	}
                 // check if the character could be inserted into an existing text:
@@ -683,30 +698,38 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
                 }
                 else {
 
-                    final DLNode<Object> referenceNode = childComponent instanceof TextRun_Base ? ((TextRun_Base)childComponent).getTextRunNode() : childComponent.getNode();
-                    final IContentAccessor<Object> destination = (IContentAccessor<Object>)((Child)referenceNode.getData()).getParent();
+                    if (childComponent instanceof TextRun_Base) {
 
-                    t = Context.getWmlObjectFactory().createText();
-                    t.setValue(text);
+                        final DLNode<Object> referenceTextRunNode = ((TextRun_Base)childComponent).getTextRunNode();
+                        final IContentAccessor<Object> destination = (IContentAccessor<Object>)((Child)referenceTextRunNode.getData()).getParent();
 
-                    // the r element can't be shared with multiple components, office 365 for instance will not display comments if
-                    // following construct is used, the commentReference needs to be in its own text run -> always create a new r
+                        t = Context.getWmlObjectFactory().createText();
+                        t.setValue(text);
 
-/*
-                    <w:r>
-                        <w:commentReference w:id="0"/>
-                        <w:t>rtrhrt</w:t>
-                    </w:r>
-*/
+                        final R newRun = Context.getWmlObjectFactory().createR();
+                        newRun.setRPr(RPr.cloneFromRPrBase(((R)referenceTextRunNode.getData()).getRPr(false)));
+                        t.setParent(newRun);
+                        newRun.getContent().add(t);
+                        newRun.setParent(destination);
+                        ((DLList<Object>)destination.getContent()).addNode(referenceTextRunNode, new DLNode<Object>(newRun), textPosition == 0);
+                    }
+                    else {
 
-                    final R newRun = Context.getWmlObjectFactory().createR();
-                    t.setParent(newRun);
-                    newRun.getContent().add(t);
-                    newRun.setParent(destination);
-                    ((DLList<Object>)destination.getContent()).addNode(referenceNode, new DLNode<Object>(newRun), textPosition == 0);
+                        // only ranges and bookmarks do not have a textrun
 
-                    // todo: search for previous text runs and get a clone of RPr
+                        final DLNode<Object> referenceNode = childComponent.getNode();
+                        final IContentAccessor<Object> destination = (IContentAccessor<Object>)((Child)referenceNode.getData()).getParent();
 
+                        t = Context.getWmlObjectFactory().createText();
+                        t.setValue(text);
+
+                        final R newRun = Context.getWmlObjectFactory().createR();
+                        newRun.setRPr(getClonedRPrInheritance(childComponent));
+                        t.setParent(newRun);
+                        newRun.getContent().add(t);
+                        newRun.setParent(destination);
+                        ((DLList<Object>)destination.getContent()).addNode(referenceNode, new DLNode<Object>(newRun), textPosition == 0);
+                    }
                     if(textPosition>0) {
                         cRet = childComponent.getNextComponent();
                     }
@@ -747,7 +770,7 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
         }
 	}
 
-    @Override
+	@Override
     public void splitParagraph(int textPosition) {
 
     	final P paragraph = (P)getObject();
@@ -852,4 +875,44 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
         	}
     	}
     }
+
+    // returns a clone of the previous RPr or if that does not exist a clone of the RPr that comes next to the reference or if no RPr is available at all a RPr clone of the paragraph is returned
+    private RPr getClonedRPrInheritance(IComponent<OfficeOpenXMLOperationDocument> referenceComponent) {
+        TextRun_Base textRunBase = getPreviousTextRun(referenceComponent);
+        if(textRunBase == null) {
+            textRunBase = getNextTextRun(referenceComponent);
+        }
+        if(textRunBase!=null) {
+            return RPr.cloneFromRPrBase(textRunBase.getTextRun().getRPr(false));
+        }
+        final P paragraph = (P)getObject();
+        final PPr pPr = paragraph.getPPr(false);
+        if(pPr!=null) {
+            return RPr.cloneFromRPrBase(paragraph.getPPr(false).getRPr(false));
+        }
+        return null;
+    }
+
+    private TextRun_Base getPreviousTextRun(IComponent<OfficeOpenXMLOperationDocument> reference) {
+        TextRun_Base lastRPr = null;
+        IComponent<OfficeOpenXMLOperationDocument> component = getNextChildComponent(null, null);
+        while(component!=null&&component.getNextComponentNumber()<=reference.getComponentNumber()) {
+            if(component instanceof TextRun_Base) {
+                lastRPr = (TextRun_Base)component;
+            }
+            component = component.getNextComponent();
+        }
+        return lastRPr;
+    }
+
+    private TextRun_Base getNextTextRun(IComponent<OfficeOpenXMLOperationDocument> reference) {
+        IComponent<OfficeOpenXMLOperationDocument> component = reference.getNextComponent();
+        while(component!=null) {
+            if(component instanceof TextRun_Base) {
+                return (TextRun_Base)component;
+            }
+            component = component.getNextComponent();
+        }
+        return null;
+    }
 }
