@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.docx.components;
 
 import org.docx4j.mce.AlternateContent;
@@ -33,6 +31,7 @@ import org.docx4j.wml.IText;
 import org.docx4j.wml.InstrText;
 import org.docx4j.wml.Pict;
 import org.docx4j.wml.R;
+import org.docx4j.wml.R.Ptab;
 import org.docx4j.wml.R.Tab;
 import org.docx4j.wml.STFldCharType;
 import com.openexchange.office.filter.core.DLNode;
@@ -72,6 +71,8 @@ public class TextRunContext extends ComponentContext<OfficeOpenXMLOperationDocum
                 nextComponent = new PictVMLComponent(this, childNode, nextComponentNumber);
             else if(o instanceof Tab)
                 nextComponent = new TabComponent(this, childNode, nextComponentNumber);
+            else if(o instanceof Ptab)
+                nextComponent = new TabComponent(this, childNode, nextComponentNumber);
             else if(o instanceof Br)
                 nextComponent = new HardBreakComponent(this, childNode, nextComponentNumber);
             else if(o instanceof R.CommentReference)
