@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,13 +19,10 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.docx.components;
 
 import org.docx4j.wml.P;
 import org.docx4j.wml.P.Hyperlink;
-import org.docx4j.wml.ParaRPr;
 import org.docx4j.wml.R;
 import org.docx4j.wml.RDBase;
 import org.docx4j.wml.RIBase;
@@ -65,9 +62,6 @@ public class TextRun_Base extends DocxComponent implements ITextRunState {
 
     @Override
     public void delete(int count) {
-        if(getComponentNumber()==0&&getNextComponent()==null) {
-            textRunStateContext.getParagraph().getPPr(true).setRPr(ParaRPr.cloneFromRPrBase(textRunStateContext.getTextRun().getRPr(false)));
-        }
         DLNode<Object> hyperlinkNode = textRunStateContext.getHyperlinkNode(false);
     	DLNode<Object> previousHyperlinkNode = null;
     	if (hyperlinkNode!=null) {
