@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,10 +19,9 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.docx.operations;
 
+import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
@@ -30,6 +29,7 @@ import java.util.Map.Entry;
 import javax.xml.bind.JAXBElement;
 import javax.xml.namespace.QName;
 import java.util.TreeMap;
+import org.apache.commons.lang3.tuple.Triple;
 import org.docx4j.XmlUtils;
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
@@ -842,24 +842,21 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
         }
     }
 
-    public void insertComment(JSONArray start, String text, JSONArray mentions, String id, String parentId, String uid, String author, String date, JSONArray children, JSONObject attrs)
+    public void insertComment(JSONArray start, String text, JSONArray mentions, String operationId, String parentId, String uid, String author, String date, JSONArray children, JSONObject attrs)
         throws Exception {
 
         final IComponent<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
             .insertChildComponent(start.getInt(start.length()-1), attrs, ComponentType.COMMENT_REFERENCE);
 
-        final int index = DocxOperationDocument.operationIdToIndex(id);
-        final int userId = DocxOperationDocument.operationIdToUserId(id);
+        final int id = DocxOperationDocument.commentOperationIdToId(operationId);
 
         final R.CommentReference commentReference = (R.CommentReference)component.getObject();
-        commentReference.setId(index);
-
-        final Comment comment = getOperationDocument().getComment(index, true);
-        comment.setUserId(userId);
+        commentReference.setId(id);
 
+        final Comment comment = getOperationDocument().getComment(id, true);
         comment.getContent().clear();
         if(parentId!=null) {
-            comment.setParentId(Integer.parseInt(parentId.substring(8)));
+            comment.setParentId(DocxOperationDocument.commentOperationIdToId(parentId));
         }
         else {
             comment.setParent(null);
@@ -867,10 +864,10 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
         if(children!=null) {
             for(int i = 0; i < children.length(); i++) {
                 final String childId = children.getString(i);
-                final int childIndex = DocxOperationDocument.operationIdToIndex(childId);
+                final int childIndex = DocxOperationDocument.commentOperationIdToId(childId);
                 final Comment child = getOperationDocument().getComment(childIndex, false);
                 if(child!=null) {
-                    child.setParentId(index);
+                    child.setParentId(id);
                 }
             }
         }
@@ -912,82 +909,98 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
                 }
             }
 
-            for(int i = 0; i < mentions.length(); i++) {
-                final JSONObject mention = mentions.getJSONObject(i);
-                final String email = mention.optString(OCKey.EMAIL.value(), null);
-                if(email!=null && !email.isEmpty()) { // email is necessary for a mention...
+            if(!mentions.isEmpty()) {
+                final List<Triple<DLNode<Object>, DLNode<Object>, String>> mTextRuns = new ArrayList<Triple<DLNode<Object>, DLNode<Object>, String>>(mentions.length());
+                for(int i = 0; i < mentions.length(); i++) {
+                    final JSONObject mention = mentions.getJSONObject(i);
+                    final String email = mention.optString(OCKey.EMAIL.value(), null);
+                    if(email!=null && !email.isEmpty()) { // email is necessary for a mention...
 
-                    addMentionToAuthorsList(mention);
+                        addMentionToAuthorsList(mention);
 
-                    final int simpleTextPos = mention.getInt(OCKey.POS.value());
-                    final Entry<Integer, Integer> pEntry = newLines.floorEntry(simpleTextPos);
+                        final int simpleTextPos = mention.getInt(OCKey.POS.value());
+                        final Entry<Integer, Integer> pEntry = newLines.floorEntry(simpleTextPos);
 
-                    final JSONArray start = new JSONArray(2);
-                    start.put(pEntry.getValue());
-                    final int startIndex = (simpleTextPos - pEntry.getKey()) - 1;
-                    start.put(startIndex);
-                    final int endIndex = (startIndex + mention.getInt(OCKey.LENGTH.value())) - 1;
+                        final JSONArray start = new JSONArray(2);
+                        start.put(pEntry.getValue());
+                        final int startIndex = (simpleTextPos - pEntry.getKey()) - 1;
+                        start.put(startIndex);
+                        final int endIndex = (startIndex + mention.getInt(OCKey.LENGTH.value())) - 1;
 
-                    final IComponent<OfficeOpenXMLOperationDocument> startComponent = getOperationDocument().getRootComponent().getComponent(start, start.length());
-                    startComponent.splitStart(startIndex, SplitMode.ATTRIBUTE);
-                    final IComponent<OfficeOpenXMLOperationDocument> endComponent = startComponent.getComponent(endIndex);
-                    endComponent.splitEnd(endIndex, SplitMode.ATTRIBUTE);
+                        final IComponent<OfficeOpenXMLOperationDocument> startComponent = getOperationDocument().getRootComponent().getComponent(start, start.length());
+                        startComponent.splitStart(startIndex, SplitMode.ATTRIBUTE);
+                        final IComponent<OfficeOpenXMLOperationDocument> endComponent = startComponent.getComponent(endIndex);
+                        endComponent.splitEnd(endIndex, SplitMode.ATTRIBUTE);
 
-                    final P startParagraph = (P)startComponent.getParentComponent().getObject();
-                    final P endParagraph = (P)endComponent.getParentComponent().getObject();
-                    final DLNode<Object> startTextRunNode = startComponent.getParentContext().getNode();
-                    ((R)startTextRunNode.getData()).getRPr(true).setrStyle(new RStyle("Mention"));
-
-/* adding following elements before the text referenced by mention.start and mention.length
-                    <w:r>
-                        <w:fldChar w:fldCharType="begin" />
-                    </w:r>
-                    <w:r>
-                        <w:instrText xml:space="preserve"> HYPERLINK "mailto:john.doe@example.com"</w:instrText>
-                    </w:r>
-                    <w:bookmarkStart w:name="_@_1234567890123456789012345678901234Z" w:id="2345627" />
-                    <w:r>
-                        <w:fldChar w:fldCharType="separate" />
-                    </w:r>
-                    <w:bookmarkEnd w:id="2345627" />
-*/
-
-                    final FldChar fldCharBegin = new FldChar(STFldCharType.BEGIN);
-                    final FldChar fldCharSeparate = new FldChar(STFldCharType.SEPARATE);
-                    final FldChar fldCharEnd = new FldChar(STFldCharType.END);
-                    FldChar.initializeFld(fldCharBegin, fldCharSeparate, fldCharEnd);
-
-                    insertTextRunContent(startParagraph, startTextRunNode, fldCharBegin, true);
-                    final InstrText instrText = new InstrText();
-                    instrText.setValue(" HYPERLINK \"mailto:" + email + "\"");
-                    insertTextRunContent(startParagraph, startTextRunNode, instrText, true);
-                    final CTBookmark bookmarkStart = new CTBookmark();
-                    bookmarkStart.setParent(startParagraph);
-                    final Integer bookmarkId = wordMLPackage.getNextMarkupId();
-                    bookmarkStart.setId(bookmarkId);
-                    bookmarkStart.setName("_@_" + "123400000000000000000000" + Integer.toHexString(bookmarkId) + "Z");
-                    startParagraph.getContent().addNode(startTextRunNode, new DLNode<Object>(bookmarkStart), true);
-                    insertTextRunContent(startParagraph, startTextRunNode, fldCharSeparate, true);
-                    final CTMarkupRange bookmarkEndRange = new CTMarkupRange();
-                    bookmarkEndRange.setId(bookmarkId);
-                    bookmarkEndRange.setParent(startParagraph);
-                    final JAXBElement<CTMarkupRange> bookmarkEnd = new JAXBElement<CTMarkupRange>(new QName("http://schemas.openxmlformats.org/wordprocessingml/2006/main", "bookmarkEnd"), CTMarkupRange.class, P.class, bookmarkEndRange);
-                    startParagraph.getContent().addNode(startTextRunNode, new DLNode<Object>(bookmarkEnd), true);
-
-/* adding following elements behind the text referenced by< mention.start and mention.length
-                    <w:r>
-                        <w:fldChar w:fldCharType="end" />
-                    </w:r>
-*/
-
-                    insertTextRunContent(endParagraph, endComponent.getParentContext().getNode(), fldCharEnd, false);
+                        mTextRuns.add(Triple.of(startComponent.getParentContext().getNode(), endComponent.getParentContext().getNode(), email));
+                    }
                 }
+                _addHyperlinks(mTextRuns);
             }
         }
         getOperationDocument().setContextPart(oldContextPart);
     }
 
-    public void addMentionToAuthorsList(JSONObject mention) {
+    private void _addHyperlinks(List<Triple<DLNode<Object>, DLNode<Object>, String>> mTextRuns) {
+        for(int i=0; i < mTextRuns.size(); i++) {
+
+            final Triple<DLNode<Object>, DLNode<Object>, String> t = mTextRuns.get(i);
+            final DLNode<Object> startTextRunNode = t.getLeft();
+            final DLNode<Object> endTextRunNode = t.getMiddle();
+            final String email = t.getRight();
+
+            final P startParagraph = (P)((Child)startTextRunNode.getData()).getParent();
+            final P endParagraph = (P)((Child)endTextRunNode.getData()).getParent();
+
+            ((R)startTextRunNode.getData()).getRPr(true).setrStyle(new RStyle("Mention"));
+
+    /* adding following elements before the text referenced by mention.start and mention.length
+            <w:r>
+                <w:fldChar w:fldCharType="begin" />
+            </w:r>
+            <w:r>
+                <w:instrText xml:space="preserve"> HYPERLINK "mailto:john.doe@example.com"</w:instrText>
+            </w:r>
+            <w:bookmarkStart w:name="_@_1234567890123456789012345678901234Z" w:id="2345627" />
+            <w:r>
+                <w:fldChar w:fldCharType="separate" />
+            </w:r>
+            <w:bookmarkEnd w:id="2345627" />
+    */
+
+            final FldChar fldCharBegin = new FldChar(STFldCharType.BEGIN);
+            final FldChar fldCharSeparate = new FldChar(STFldCharType.SEPARATE);
+            final FldChar fldCharEnd = new FldChar(STFldCharType.END);
+            FldChar.initializeFld(fldCharBegin, fldCharSeparate, fldCharEnd);
+
+            insertTextRunContent(startParagraph, startTextRunNode, fldCharBegin, true);
+            final InstrText instrText = new InstrText();
+            instrText.setValue(" HYPERLINK \"mailto:" + email + "\"");
+            insertTextRunContent(startParagraph, startTextRunNode, instrText, true);
+            final CTBookmark bookmarkStart = new CTBookmark();
+            bookmarkStart.setParent(startParagraph);
+            final Integer bookmarkId = wordMLPackage.getNextMarkupId();
+            bookmarkStart.setId(bookmarkId);
+            bookmarkStart.setName("_@_" + "123400000000000000000000" + Integer.toHexString(bookmarkId) + "Z");
+            startParagraph.getContent().addNode(startTextRunNode, new DLNode<Object>(bookmarkStart), true);
+            insertTextRunContent(startParagraph, startTextRunNode, fldCharSeparate, true);
+            final CTMarkupRange bookmarkEndRange = new CTMarkupRange();
+            bookmarkEndRange.setId(bookmarkId);
+            bookmarkEndRange.setParent(startParagraph);
+            final JAXBElement<CTMarkupRange> bookmarkEnd = new JAXBElement<CTMarkupRange>(new QName("http://schemas.openxmlformats.org/wordprocessingml/2006/main", "bookmarkEnd"), CTMarkupRange.class, P.class, bookmarkEndRange);
+            startParagraph.getContent().addNode(startTextRunNode, new DLNode<Object>(bookmarkEnd), true);
+
+    /* adding following elements behind the text referenced by< mention.start and mention.length
+            <w:r>
+                <w:fldChar w:fldCharType="end" />
+            </w:r>
+    */
+
+            insertTextRunContent(endParagraph, endTextRunNode, fldCharEnd, false);
+        }
+    }
+
+    private void addMentionToAuthorsList(JSONObject mention) {
         final String author = mention.optString(OCKey.DISPLAY_NAME.value(), null);
         final String userId = mention.optString(OCKey.USER_ID.value(), null);
         final String provider = mention.optString(OCKey.PROVIDER_ID.value(), null);
@@ -1052,7 +1065,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
     public void insertRange(JSONArray start, String id, String type, String position, JSONObject attrs) throws Exception {
 
         if(type.equals("comment")) {
-            final int cId = DocxOperationDocument.operationIdToIndex(id);
+            final int cId = DocxOperationDocument.commentOperationIdToId(id);
             final ComponentType rangeType = position.equals("start") ? ComponentType.COMMENT_RANGE_START : ComponentType.COMMENT_RANGE_END;
             final IComponent<OfficeOpenXMLOperationDocument> component = getOperationDocument().getRootComponent().getComponent(start, start.length()-1)
                 .insertChildComponent(start.getInt(start.length()-1), attrs, rangeType);
