@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.docx.operations;
 
 import java.net.URI;
@@ -266,6 +264,9 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
                 }
             }
         }
+
+        createCoreProperties(jsonDocumentSettings);
+
         if(!jsonDocumentSettings.isEmpty()) {
             documentAttributes.put(OCKey.DOCUMENT.value(), jsonDocumentSettings);
         }
@@ -411,18 +412,14 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
     public void AddInsertTextOperation(List<Integer> paragraphPosition, int textPosition, String target, TextComponent textComponent, JSONObject attrs)
         throws JSONException {
 
+        String text = ((IText)textComponent.getObject()).getValue();
         if(!operationsArray.isEmpty()) {
-            // checking target is not required
-            final JSONObject last = operationsArray.getJSONObject(operationsArray.length() - 1);
-            if(last.getString(OCKey.NAME.value()).equals(OCValue.INSERT_TEXT.value())) {
-                if(attrs==null || attrs.isEmpty()) {
-                    if(!getOperationDocument().isCreateFastLoadOperations() || !last.has(OCKey.ATTRS.value())) {
-                        // the lenght of the insert position must be the same
-                        final JSONArray lastPosition = last.optJSONArray(OCKey.START.value());
-                        if(lastPosition!=null && lastPosition.length() - 1 == paragraphPosition.size()) {
-                            last.put(OCKey.TEXT.value(), last.getString(OCKey.TEXT.value()) + ((IText)textComponent.getObject()).getValue());
-                            return;
-                        }
+            final JSONObject lastOperation = operationsArray.getJSONObject(operationsArray.length() - 1);
+            if(lastOperation.getString(OCKey.NAME.value()).equals(OCValue.INSERT_TEXT.value())) {
+                final JSONArray lastStart = lastOperation.getJSONArray(OCKey.START.value());
+                if(lastStart.length() == paragraphPosition.size() + 1) {
+                    if(tryCombineTextOperation(lastOperation, text, attrs)) {
+                        return;
                     }
                 }
             }
@@ -437,7 +434,7 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
         if(target!=null) {
         	insertTextObject.put(OCKey.TARGET.value(), target);
         }
-        insertTextObject.put(OCKey.TEXT.value(), ((IText)textComponent.getObject()).getValue());
+        insertTextObject.put(OCKey.TEXT.value(), text);
         if(attrs!=null && !attrs.isEmpty()) {
             insertTextObject.put(OCKey.ATTRS.value(), attrs );
         }
@@ -459,6 +456,35 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
     	operationsArray.put(headerFooterOperation);
     }
 
+    // returns true if a oncoming insert text operation was combined with the last operation
+    private boolean tryCombineTextOperation(JSONObject lastOperation, String text, JSONObject attrs)
+        throws JSONException {
+
+        final boolean hasAttrs = attrs != null && !attrs.isEmpty();
+
+        /* it is not necessary to check target because operations are in order and the first insertText
+           operation of a new target is always preceded by a insertParagraph operation */
+        if(getOperationDocument().isCreateFastLoadOperations()) {
+            final JSONObject lastAttrs = lastOperation.optJSONObject(OCKey.ATTRS.value());
+            final boolean hasLastAttrs = lastAttrs != null && !lastAttrs.isEmpty();
+            if(hasLastAttrs != hasAttrs) {
+                return false;
+            }
+            if(hasLastAttrs) {
+                // fastload text operations can only be combined if attrs has same attributes as used in the previous text operation
+                if(!lastAttrs.isEqualTo(attrs)) {
+                    return false;
+                }
+            }
+        }
+        else if(hasAttrs) { // without fastload attrs contains differences, so the operations can be combined if there are no attrs
+            return false;
+        }
+        // combine text operations:
+        lastOperation.put(OCKey.TEXT.value(), lastOperation.getString(OCKey.TEXT.value()) + text);
+        return true;
+    }
+
     public void AddInsertTabOperation(final List<Integer> start, String target, JSONObject attrs)
         throws JSONException {
 
@@ -484,16 +510,14 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
         	insertComment.put(OCKey.TARGET.value(), target);
         }
 
-        int index = comment.getId();
-        int userId = comment.getUserId();
-        final String operationId = DocxOperationDocument.getOperationId(index, userId);
+        final String operationId = DocxOperationDocument.getCommentOperationId(comment.getId());
         insertComment.put(OCKey.ID.value(), operationId);
 
         final Integer parentId = comment.getParentId();
         if(parentId!=null) {
             final Comment parent = getOperationDocument().getComment(parentId, false);
             if(parent!=null) {
-                insertComment.put(OCKey.PARENT_ID.value(), DocxOperationDocument.getOperationId(parentId, parent.getUserId()));
+                insertComment.put(OCKey.PARENT_ID.value(), DocxOperationDocument.getCommentOperationId(parentId));
             }
         }
 
@@ -603,7 +627,7 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
         }
         insertRangeObject.put(OCKey.POSITION.value(), startRange ? "start" : "end");
         final Comment comment = getOperationDocument().getComment(commentId, false);
-        insertRangeObject.put(OCKey.ID.value(), comment != null ? DocxOperationDocument.getOperationId(comment.getId(), comment.getUserId()) : "");
+        insertRangeObject.put(OCKey.ID.value(), comment != null ? DocxOperationDocument.getCommentOperationId(comment.getId()) : "");
         if(attrs!=null) {
             insertRangeObject.put(OCKey.ATTRS.value(), attrs);
         }
@@ -659,7 +683,7 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
         }
         insertCommentRangeObject.put(OCKey.POSITION.value(), startRange?"start":"end");
         if(attrs!=null) {
-            insertCommentRangeObject.put(OCKey.VALUE.value(), attrs);
+            insertCommentRangeObject.put(OCKey.ATTRS.value(), attrs);
         }
         operationsArray.put(insertCommentRangeObject);
     }
@@ -1306,9 +1330,10 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
                     LvlOverride override = lvlIter.next();
                     long ilvlOverride = override.getIlvl().longValue();
                     JSONObject levelObject = listObject.getJSONObject(OCKey.LIST_LEVEL.value() + ilvlOverride);
-                    StartOverride startOverride = override.getStartOverride();
-                    if( startOverride != null )
-                        levelObject.put(OCKey.LIST_START_VALUE.value(), startOverride.getVal().longValue());
+                    final StartOverride startOverride = override.getStartOverride();
+                    if(startOverride!=null) {
+                        levelObject.put(OCKey.LIST_OVERRIDE_START_VALUE.value(), startOverride.getVal().longValue());
+                    }
                     Lvl level = override.getLvl();
                     if( level != null ){
                         createLevel( levelObject, level, picMap );
