@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.docx.tools;
 
 import java.util.Iterator;
@@ -249,8 +247,12 @@ public class Character {
             U u = characterProperties.getU();
             if(u!=null) {
                 boolean bUnderline = false;
-                if (u.getVal()!=UnderlineEnumeration.NONE)
+                // docs-3434: this fix should be sufficient (to fully support this feature access to parent paragraph level is required.
+                // the specification: u.getVal(), If this attribute is omitted, its value is determined by the setting previously set at any level
+                // of the style hierarchy. If this setting is never specified in the style hierarchy, then its value shall be "auto")
+                if (u.getVal()!=null && u.getVal()!=UnderlineEnumeration.NONE) {
                     bUnderline = true;
+                }
                 jsonCharacterProperties.put(OCKey.UNDERLINE.value(), bUnderline);
             }
             Commons.jsonPut(jsonCharacterProperties, OCKey.FONT_NAME.value(), operationDocument.getThemeFonts().getFont(characterProperties.getrFonts(false)));
