@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.docx.tools;
 
 import java.util.Iterator;
@@ -344,22 +342,22 @@ public class Paragraph {
                     }
                     List<CTTabStop> tabStops = tabs.getTab();
                     tabStops.clear();
-    
+
                     for (int i = 0; i < newTabs.length(); i++)
                     {
                         JSONObject newTab = newTabs.getJSONObject(i);
                         CTTabStop tab = new CTTabStop();
-    
+
                         String fillChar = newTab.optString(OCKey.FILL_CHAR.value(), null);
                         if(fillChar != null){
                             tab.setLeader(STTabTlc.fromValue(fillChar));
                         }
                         long pos = newTab.getLong(OCKey.POS.value());
                         tab.setPos(Utils.map100THMMToTwip(pos));
-    
+
                         String val = newTab.getString(OCKey.VALUE.value());
                         tab.setVal(STTabJc.fromValue(val));
-    
+
                         tabStops.add(tab);
                     }
                 }
@@ -437,13 +435,18 @@ public class Paragraph {
                     Utils.createFillColor(shd));
             }
             final PPrBase.NumPr numPr = paragraphProperties.getNumPr(false);
-            if(numPr != null){
-                PPrBase.NumPr.Ilvl ilvl = numPr.getIlvl();
-                PPrBase.NumPr.NumId numId = numPr.getNumId();
-                if(ilvl != null)
-                    jsonParagraphProperties.put(OCKey.LIST_LEVEL.value(), ilvl.getVal().intValue() );
-                if(numId != null)
-                    jsonParagraphProperties.put(OCKey.LIST_STYLE_ID.value(), 'L' + Integer.toString(numId.getVal().intValue()) );
+            if(numPr!=null){
+                Long ilvl = numPr.getIlvl() != null ? numPr.getIlvl().getVal() : null;
+                final PPrBase.NumPr.NumId numId = numPr.getNumId();
+                if(numId!=null) {
+                    jsonParagraphProperties.put(OCKey.LIST_STYLE_ID.value(), 'L' + Integer.toString(numId.getVal().intValue()));
+                    if ((ilvl==null) && (numId.getVal().intValue()!=0)) { // fix for docs-3388, setting default iLvl of 0 if numIdId is given
+                        ilvl = Long.valueOf(0);
+                    }
+                }
+                if(ilvl!=null) {
+                    jsonParagraphProperties.put(OCKey.LIST_LEVEL.value(), ilvl.intValue());
+                }
             }
             OutlineLvl outlineLvl = paragraphProperties.getOutlineLvl();
             if (outlineLvl != null){
