@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.docx.tools;
 
 import java.util.Iterator;
@@ -218,6 +216,8 @@ public class Table {
                 }
             } else if(attr.equals(OCKey.WIDTH.value())) {
                 newTableWidth = value;
+            } else if(attr.equals(OCKey.INDENT.value())) {
+                tblPr.setTblInd(createTblWidthFromJSON(objectFactory, value));
             }
             else if(attr.equals(OCKey.BORDER_LEFT.value()))
                 tblPr.getTblBorders(true).setLeft(createCTBorderFromJSON(operationDocument, objectFactory, value));
@@ -242,19 +242,6 @@ public class Table {
             else if(attr.equals(OCKey.FILL_COLOR.value())) {
                 if(value instanceof JSONObject) {
                     Utils.initShdFromJSONColor(operationDocument, (JSONObject)value, tblPr.getShd(true));
-
-                    if(tableComponent!=null) {
-                        IComponent<OfficeOpenXMLOperationDocument> tableRowComponent = tableComponent.getNextChildComponent(null, null);
-	                    while(tableRowComponent!=null) {
-	                        IComponent<OfficeOpenXMLOperationDocument> tableCellComponent = tableRowComponent.getNextChildComponent(null, null);
-	                        while(tableCellComponent!=null) {
-	                            Tc tc = (Tc)tableCellComponent.getNode().getData();
-	                            Utils.initShdFromJSONColor(operationDocument, (JSONObject)value, tc.getTcPr(true).getShd(true));
-	                            tableCellComponent = tableCellComponent.getNextComponent();
-	                        }
-	                        tableRowComponent = tableRowComponent.getNextComponent();
-	                    }
-                    }
                 }
                 else
                     tblPr.setShd(null);
@@ -319,6 +306,11 @@ public class Table {
 
             final long referenceWidth = isRootTable ? Utils.getPageWidth(document.getMainDocumentPart(), 19000) : 0;
             Commons.jsonPut(jsonTableProperties, OCKey.WIDTH.value(), createJSONFromTblWidth(tableProperties.getTblW(), referenceWidth, firstRowWidth));
+            Object indent = createJSONFromTblWidth(tableProperties.getTblInd(), 0, 0);
+            if("auto".equals(indent)) {
+                indent = Integer.valueOf(0);
+            }
+            Commons.jsonPut(jsonTableProperties, OCKey.INDENT.value(), indent);
 
             // creating table borders
             TblBorders tblBorders = tableProperties.getTblBorders(false);
@@ -626,29 +618,8 @@ public class Table {
                 Commons.jsonPut(jsonCellProperties, OCKey.BORDER_INSIDE_VERT.value(), createJSONfromCTBorder(tcBorder.getInsideV()));
             }
 
-            // only create cell fill color if it differ from the table fill color
-            final CTShd shd = cellProperties.getShd(false);
-            boolean createCellFill = true;
-            if(table!=null&&shd!=null) {
-                final TblPr tblPr = table.getTblPr(false);
-                if(tblPr!=null) {
-                    final CTShd tblShd = tblPr.getShd(false);
-                    if(tblShd!=null) {
-                        if((tblShd.getVal() == shd.getVal())
-                            && Utils.equals(tblShd.getFill(), shd.getFill())
-                            && (tblShd.getThemeColor() == shd.getThemeColor())
-                            && (tblShd.getThemeFill() == shd.getThemeFill())
-                            && Utils.equals(tblShd.getThemeFillShade(), shd.getThemeFillShade())
-                            && Utils.equals(tblShd.getThemeFillTint(), shd.getThemeFillTint())
-                            && Utils.equals(tblShd.getThemeShade(), shd.getThemeShade())
-                            && Utils.equals(tblShd.getThemeTint(), shd.getThemeTint()))
-
-                            createCellFill = false;
-                    }
-                }
-            }
-            if(createCellFill)
-                Commons.jsonPut(jsonCellProperties, OCKey.FILL_COLOR.value(), Utils.createFillColor(shd));
+            // docs-3464, always create cell fill, there is no inheritance from table fill
+            Commons.jsonPut(jsonCellProperties, OCKey.FILL_COLOR.value(), Utils.createFillColor(cellProperties.getShd(false)));
 
             TcMar tcMar = cellProperties.getTcMar(false);
             if(tcMar!=null) {
@@ -759,7 +730,9 @@ public class Table {
     }
 
     private static TblWidth createTblWidthFromJSON(ObjectFactory objectFactory, Object jsonWidth) {
-
+        if(jsonWidth==JSONObject.NULL) {
+            return null;
+        }
         TblWidth tblWidth = null;
         if (jsonWidth instanceof Integer||jsonWidth instanceof String) {
             tblWidth = objectFactory.createTblWidth();
