@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.pptx.operations;
 
 import java.util.ArrayList;
@@ -116,6 +114,13 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         getOperationDocument().setContextPart(mainPresentationPart);
         final Presentation presentation = mainPresentationPart.getJaxbElement();
 
+        // core settings (modified/created)
+        final JSONObject jsonDocumentSettings = new JSONObject();
+        createCoreProperties(jsonDocumentSettings);
+        if(!jsonDocumentSettings.isEmpty()) {
+            documentAttributes.put(OCKey.DOCUMENT.value(), jsonDocumentSettings);
+        }
+
         // page settings
         final JSONObject jsonPageSettings = new JSONObject(3);
         final SldSz slideSz = presentation.getSldSz(true);
