@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.xlsx.operations;
 
 import java.text.ParseException;
@@ -527,6 +525,9 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
             documentAttrs.put(OCKey.CALC_ON_LOAD.value(), true);
         }
 
+        // core settings (modified/created)
+        createCoreProperties(documentAttrs);
+
         final JSONObject attrs = new JSONObject(1);
         attrs.put(OCKey.DOCUMENT.value(), documentAttrs);
         addSetDocumentAttributesOperation(attrs);
