@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml;
 
 import java.io.ByteArrayInputStream;
@@ -31,10 +29,13 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.UnsupportedEncodingException;
+import java.util.GregorianCalendar;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.SimpleTimeZone;
+import java.util.TimeZone;
 import java.util.TreeSet;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipException;
@@ -43,12 +44,15 @@ import java.util.zip.ZipOutputStream;
 
 import javax.xml.bind.JAXBElement;
 import javax.xml.bind.JAXBException;
-
+import javax.xml.datatype.DatatypeConfigurationException;
+import javax.xml.datatype.DatatypeFactory;
+import javax.xml.datatype.XMLGregorianCalendar;
 import org.apache.commons.io.IOUtils;
 import org.docx4j.XmlUtils;
 import org.docx4j.dml.Theme;
 import org.docx4j.docProps.core.CoreProperties;
 import org.docx4j.docProps.core.dc.elements.SimpleLiteral;
+import org.docx4j.docProps.core.dc.terms.W3CDTF;
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.contenttype.ContentTypeManager.NonPersistContent;
 import org.docx4j.openpackaging.contenttype.ContentTypes;
@@ -199,13 +203,14 @@ abstract public class OfficeOpenXMLOperationDocument extends OperationDocument i
     }
     abstract public void _applyOperations(String applyOperations) throws Exception;
 
-    final public void updateDocumentProperties() {
+    final public void updateDocumentProperties() throws Exception {
         // applying some document properties...
         OpcPackage opcPackage = getPackage();
         CoreProperties coreProperties = opcPackage.getDocPropsCorePart(true).getJaxbElement();
         org.docx4j.docProps.core.dc.elements.ObjectFactory of = new org.docx4j.docProps.core.dc.elements.ObjectFactory();
         String userName = documentProperties.optString(DocumentProperties.PROP_LAST_MODIFIED_BY, "");
         coreProperties.setLastModifiedBy(userName);
+        coreProperties.setModified(new W3CDTF(currentDate()));
         coreProperties.setRevision(documentProperties.optString(DocumentProperties.PROP_REVISION, null));
         coreProperties.setVersion(documentProperties.optString(DocumentProperties.PROP_VERSION, null));
 
@@ -223,6 +228,12 @@ abstract public class OfficeOpenXMLOperationDocument extends OperationDocument i
         }
     }
 
+    public static String currentDate() throws DatatypeConfigurationException {
+        final DatatypeFactory datatypeFactory = DatatypeFactory.newInstance();
+        final XMLGregorianCalendar now = datatypeFactory.newXMLGregorianCalendar(new GregorianCalendar(new SimpleTimeZone(SimpleTimeZone.UTC_TIME, "UTC")));
+        return now.toXMLFormat();
+    }
+
     final public InputStream save() {
         return debugSave(null);
     }
@@ -546,7 +557,7 @@ abstract public class OfficeOpenXMLOperationDocument extends OperationDocument i
         throw ret;
     }
 
-    protected void switchToTemplateDocument() {
+    protected void switchToTemplateDocument() throws Exception {
 
         resetCoreProperties();
         removePart(getPackage().getRelationshipsPart(), "/docProps/app.xml");
@@ -562,20 +573,20 @@ abstract public class OfficeOpenXMLOperationDocument extends OperationDocument i
         }
     }
 
-    protected void switchToNonTemplateDocument() {
+    protected void switchToNonTemplateDocument() throws Exception {
 
         resetCoreProperties();
         removePart(getPackage().getRelationshipsPart(), "/docProps/app.xml");
     }
 
-    private void resetCoreProperties() {
+    private void resetCoreProperties() throws DatatypeConfigurationException {
         final DocPropsCorePart corePart = getPackage().getDocPropsCorePart(false);
         if(corePart!=null) {
             final CoreProperties coreProperties = corePart.getJaxbElement();
             coreProperties.setCategory(removeEmptyElement(coreProperties.getCategory()));
             coreProperties.setContentStatus(removeEmptyElement(coreProperties.getContentStatus()));
             coreProperties.setContentType(removeEmptyElement(coreProperties.getContentType()));
-            coreProperties.setCreated(null);
+            coreProperties.setCreated(new W3CDTF(currentDate()));
             coreProperties.setCreator(null);
             coreProperties.setDescription(removeEmptyElement(coreProperties.getDescription()));
             coreProperties.setIdentifier(removeEmptyElement(coreProperties.getIdentifier()));
