@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,11 +19,11 @@
  *
  */
 
-
-
 package com.openexchange.office.filter.ooxml.operations;
 
 import org.docx4j.dml.BaseStyles.FontScheme;
+import org.docx4j.docProps.core.CoreProperties;
+import org.docx4j.docProps.core.dc.elements.SimpleLiteral;
 import java.util.Iterator;
 import java.util.Set;
 import java.util.Map.Entry;
@@ -31,11 +31,13 @@ import org.docx4j.dml.CTColorMapping;
 import org.docx4j.dml.CTColorScheme;
 import org.docx4j.dml.FontCollection;
 import org.docx4j.dml.Theme;
+import org.docx4j.openpackaging.parts.DocPropsCorePart;
 import org.docx4j.openpackaging.parts.ThemePart;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.google.common.collect.ImmutableSet;
+import com.google.common.collect.UnmodifiableIterator;
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.api.OCValue;
@@ -177,6 +179,23 @@ abstract public class CreateOperationHelper {
         return documentAttributes;
     }
 
+    public void createCoreProperties(JSONObject documentProperties) throws JSONException {
+        final DocPropsCorePart corePropertiesPart = operationDocument.getPackage().getDocPropsCorePart(false);
+        if(corePropertiesPart!=null) {
+            final CoreProperties coreProperties = corePropertiesPart.getJaxbElement();
+            if(coreProperties!=null) {
+                final SimpleLiteral modified = coreProperties.getModified();
+                if(modified!=null && !modified.getContent().isEmpty()) {
+                    documentProperties.put(OCKey.MODIFIED.value(), modified.getContent().get(0));
+                }
+                final SimpleLiteral created = coreProperties.getCreated();
+                if(created!=null && !created.getContent().isEmpty()) {
+                    documentProperties.put(OCKey.CREATED.value(), created.getContent().get(0));
+                }
+            }
+        }
+    }
+
     // usedLanguages are only available after creating operations for the whole document (via _createOperations)
     public void createUsedLanguages(JSONObject documentAttributes) throws JSONException {
         applyLanguages(documentAttributes, OCKey.USED_LANGUAGES, getOperationDocument().getUsedLanguages());
@@ -194,12 +213,49 @@ abstract public class CreateOperationHelper {
         }
     }
 
-    static final private ImmutableSet<String> deepFamilies = ImmutableSet.<String> builder()
+    static final private ImmutableSet<String> familiesWithDeepAttrsInheritance = ImmutableSet.<String> builder()
         .add(OCKey.CHARACTER.value())
         .add(OCKey.PARAGRAPH.value())
         .build();
 
     protected JSONObject createDifference(JSONObject currentAttrs, JSONObject newAttrs) throws JSONException {
+        final JSONObject difference = new JSONObject();
+        final UnmodifiableIterator<String> iter = familiesWithDeepAttrsInheritance.iterator();
+        while(iter.hasNext()) {
+            final String family = iter.next();
+            final JSONObject c = currentAttrs.optJSONObject(family);
+            if (c!=null) {
+                final JSONObject result = createDifferenceWithDeepInheritance(c, newAttrs!= null ? newAttrs.optJSONObject(family) : null);
+                if(result!=null) {
+                    difference.put(family, result);
+                }
+            }
+            else if (newAttrs!=null) {
+                final JSONObject n = newAttrs.optJSONObject(family);
+                if (n!=null) {
+                    difference.put(family, n);
+                    currentAttrs.put(family, cloneJSONObject(n));
+                }
+            }
+        }
+        String newStyleId = null;
+        if(newAttrs!=null) {
+            newStyleId = newAttrs.optString(OCKey.STYLE_ID.value(), null);
+            final Iterator<Entry<String, Object>> newAttrsIter = newAttrs.entrySet().iterator();
+            while(newAttrsIter.hasNext()) {
+                final Entry<String, Object> newAttrsEntry = newAttrsIter.next();
+                if(!familiesWithDeepAttrsInheritance.contains(newAttrsEntry.getKey())) {
+                    difference.put(newAttrsEntry.getKey(), newAttrsEntry.getValue());
+                }
+            }
+        }
+        if(newStyleId==null) {
+            difference.put(OCKey.STYLE_ID.value(), JSONObject.NULL);
+        }
+        return difference.isEmpty() ? null : difference;
+    }
+
+    private JSONObject createDifferenceWithDeepInheritance(JSONObject currentAttrs, JSONObject newAttrs) throws JSONException {
 
         final JSONObject difference = new JSONObject();
         final Iterator<Entry<String, Object>> currentAttrsIter = currentAttrs.entrySet().iterator();
@@ -210,50 +266,29 @@ abstract public class CreateOperationHelper {
             final String key = currentAttrsEntry.getKey();
             final Object newValue = newAttrs !=null ? newAttrs.opt(key) : null;
 
-            if((newValue instanceof JSONObject) && (currentValue instanceof JSONObject && deepFamilies.contains(key))) {
-                // key is available on both sides as jsonObject
-                final JSONObject result = createDifference((JSONObject)currentValue, (JSONObject)newValue);
-                if(result!=null) {
-                    difference.put(key, result);
-                }
-            }
-            else if(newValue!=null) {
+            if(newValue!=null) {
                 // key is available on both sides
                 if(!currentValue.equals(newValue)) {
                     difference.put(key, newValue);
                     currentAttrs.put(key, newValue);
                 }
             }
-            else {
-                // key is available only in current attributes
-                if(currentValue instanceof JSONObject && deepFamilies.contains(key)) {
-                    final JSONObject result = createDifference((JSONObject)currentValue, null);
-                    if(result!=null) {
-                        difference.put(key, result);
-                    }
-                }
-                else {
-                    difference.put(key, JSONObject.NULL);
-                    currentAttrsIter.remove();
-                }
+            else { // key is available only in current attributes
+                difference.put(key, JSONObject.NULL);
+                currentAttrsIter.remove();
             }
         }
 
         if(newAttrs!=null) {
-            // now only applying everything that is not part in lastAttrs
+            // now only applying everything that is not part in currentAttrs
             final Iterator<Entry<String, Object>> newAttrsIter = newAttrs.entrySet().iterator();
             while(newAttrsIter.hasNext()) {
                 final Entry<String, Object> newAttrsEntry = newAttrsIter.next();
-                if(!currentAttrs.has(newAttrsEntry.getKey())) {
+                final String key = newAttrsEntry.getKey();
+                if(!currentAttrs.has(key)) {
                     Object value = newAttrsEntry.getValue();
-                    if(value instanceof JSONObject) {
-                        value = cloneJSONObject((JSONObject)value);
-                    }
-                    else if(value instanceof JSONArray) {
-                        value = cloneJSONArray((JSONArray)value);
-                    }
-                    difference.put(newAttrsEntry.getKey(),  value);
-                    currentAttrs.put(newAttrsEntry.getKey(), newAttrsEntry.getValue());
+                    difference.put(key,  value);
+                    currentAttrs.put(key, value);
                 }
             }
         }
