@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.htmldoc;
 
 import java.util.concurrent.atomic.AtomicInteger;
@@ -125,14 +123,10 @@ public class Drawing extends NodeHolder {
     }
 
     @Override
-    public boolean appendContent(
-        StringBuilder document)
-            throws Exception
-    {
+    public boolean appendContent(StringBuilder document) throws Exception {
 
-        if (emptySpans)
-        {
-            GenDocHelper.addEmptySpan(document, emptySpanStyle);
+        if (emptySpans) {
+            GenDocHelper.addEmptySpan(document, getAttribute(), emptySpanStyle);
         }
 
         document.append(CONTENT_START);
@@ -155,8 +149,7 @@ public class Drawing extends NodeHolder {
 
         String content = START;
 
-        if (presentation)
-        {
+        if (presentation) {
             content = "";
             if (null != target) {
                 content += " target='" + GenDocHelper.escapeUIString(target) + "'";
@@ -167,8 +160,7 @@ public class Drawing extends NodeHolder {
 
         document.append(content);
         // System.out.println("Drawing.appendContent() " + content);
-        if (type.equalsIgnoreCase("image"))
-        {
+        if (type.equalsIgnoreCase("image")) {
 
             document.append(DRAWING_CONTENT);
 
@@ -186,19 +178,16 @@ public class Drawing extends NodeHolder {
             }
 
         }
-        else if (type.equalsIgnoreCase("group"))
-        {
+        else if (type.equalsIgnoreCase("group")) {
             document.append(GROUP_CONTENT);
             super.appendContent(document);
         }
-        else if (type.equalsIgnoreCase("shape") || type.equalsIgnoreCase("connector"))
-        {
+        else if (type.equalsIgnoreCase("shape") || type.equalsIgnoreCase("connector")) {
             document.append(SHAPE_CONTENT);
             super.appendContent(document);
             document.append(DIV_END);
         }
-        else if (type.equalsIgnoreCase("table"))
-        {
+        else if (type.equalsIgnoreCase("table")) {
             document.append(SHAPE_CONTENT);
 
         	// Handling for the table node
@@ -221,8 +210,7 @@ public class Drawing extends NodeHolder {
 
             document.append(DIV_END);
         }
-        else
-        {
+        else {
             // default behavior for types we cant handle yet (chart)
             document.append(PLACEHOLDER_CONTENT);
             super.appendContent(document);
@@ -231,14 +219,13 @@ public class Drawing extends NodeHolder {
         document.append(DIV_END);
         document.append(DIV_END);
 
-        if (!presentation && emptySpans)
-        {
-            GenDocHelper.addEmptySpan(document, emptySpanStyle);
+        if (!presentation && emptySpans) {
+            GenDocHelper.addEmptySpan(document, getAttribute(), emptySpanStyle);
         }
         return false;
     }
 
-    public String getPHType(){
+    public String getPHType() {
         JSONObject attrs = getAttribute();
         if (null == attrs) {
             return null;
@@ -256,51 +243,38 @@ public class Drawing extends NodeHolder {
     }
 
     @Override
-    public boolean needsEmptySpan()
-    {
+    public boolean needsEmptySpan() {
         return false;
     }
 
     @Override
-    public int getTextLength()
-    {
+    public int getTextLength() {
         return 1;
     }
 
     @Override
-    public void insert(
-        JSONArray start,
-        INode newChild)
-            throws Exception
-    {
+    public void insert(JSONArray start, INode newChild) throws Exception {
         // System.out.println("Drawing.insert() " + start + " " + newChild.getClass());
-        if (start.length() == 1)
-        {
-            if (newChild instanceof Drawing)
-            {
+        if (start.length() == 1) {
+            if (newChild instanceof Drawing) {
                 ((Drawing) newChild).disableEmptySpans();
             }
-            else if ((newChild instanceof Paragraph) || (newChild instanceof Table))
-            {
+            else if ((newChild instanceof Paragraph) || (newChild instanceof Table)) {
                 havePlaceholder = false;
             }
         }
         super.insert(start, newChild);
     }
 
-    public void disableEmptySpans()
-    {
+    public void disableEmptySpans() {
         this.emptySpans = false;
     }
 
-    public void disableEmptySpanStyle()
-    {
+    public void disableEmptySpanStyle() {
         this.emptySpanStyle = false;
     }
 
-    public Drawing setTarget(
-        String target)
-    {
+    public Drawing setTarget(String target) {
         this.target = target;
         return this;
     }
