@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.htmldoc;
 
 import org.json.JSONArray;
@@ -28,14 +26,9 @@ import org.json.JSONObject;
 
 public interface INode {
 
-    public boolean appendContent(
-        StringBuilder document)
-        throws Exception;
+    public boolean appendContent(StringBuilder document) throws Exception;
 
-    public abstract void insert(
-        JSONArray start,
-        INode node)
-        throws Exception;
+    public abstract void insert(JSONArray start, INode node) throws Exception;
 
     public abstract boolean needsEmptySpan();
 
