@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,13 +19,12 @@
  *
  */
 
-
-
 package com.openexchange.office.htmldoc;
 
 import java.util.ArrayList;
 import java.util.List;
 import org.json.JSONArray;
+import org.json.JSONException;
 import org.json.JSONObject;
 
 public class Paragraph implements INode, ISplitpoint {
@@ -54,50 +53,32 @@ public class Paragraph implements INode, ISplitpoint {
     }
 
     @Override
-    public final
-            boolean
-            isSplitpoint()
-    {
+    public final boolean isSplitpoint() {
         return splitpoint;
     }
 
     @Override
-    public final
-            void
-            setSplitpoint(
-                boolean splitpoint)
-    {
+    public final void setSplitpoint(boolean splitpoint) {
         this.splitpoint = splitpoint;
     }
 
     @Override
-    public
-            void
-            insert(
-                JSONArray start,
-                INode newChild)
-                throws Exception
-    {
-        if (start.length() == 1)
-        {
+    public void insert(JSONArray start, INode newChild) throws Exception {
+        if (start.length() == 1) {
             nodes.add(newChild);
 
-            if (newChild instanceof SubNode)
-            {
-                if (((SubNode) newChild).hasManualPageBreak())
-                {
+            if (newChild instanceof SubNode) {
+                if (((SubNode) newChild).hasManualPageBreak()) {
                     this.manualPageBreak = true;
                 }
             }
         }
-        else
-        {
+        else {
             int startTextIndex = start.getInt(0);
 
             int current = 0;
 
-            for (final INode node : nodes)
-            {
+            for (final INode node : nodes) {
                 if (current == startTextIndex) {
                     start = GenDocHelper.shiftedCopy(start);
                     node.insert(start, newChild);
@@ -109,60 +90,33 @@ public class Paragraph implements INode, ISplitpoint {
         }
     }
 
-    protected
-            void
-            appendHTMLCLasses(
-                StringBuilder document)
-                throws Exception
-    {
-        if (splitpoint && manualPageBreak)
-        {
+    protected void appendHTMLCLasses(StringBuilder document) throws Exception {
+        if (splitpoint && manualPageBreak) {
             document.append(" splitpoint manual-page-break");
         }
-        else if (manualPageBreak)
-        {
+        else if (manualPageBreak) {
             document.append(" manual-page-break");
         }
-        else if (splitpoint)
-        {
+        else if (splitpoint) {
             document.append(" splitpoint");
         }
     }
 
-    protected
-            void
-            appendHTMLAttributes(
-                StringBuilder document)
-                throws Exception
-    {
+    protected void appendHTMLAttributes(StringBuilder document) throws Exception {
 
     }
 
-    protected
-            void
-            appendHTMLStyles(
-                StringBuilder document)
-                throws Exception
-    {
-
-        if (inTable)
-        {
+    protected void appendHTMLStyles(StringBuilder document) throws Exception {
+        if (inTable) {
             document.append(DEFPARAATTRSINTABLE);
         }
-        else
-        {
+        else {
             document.append(DEFPARAATTRS);
         }
-
     }
 
     @Override
-    public final
-            boolean
-            appendContent(
-                StringBuilder document)
-                throws Exception
-    {
+    public final boolean appendContent(StringBuilder document) throws Exception {
 
         document.append(PARASTARTWITHOUTCLASS);
 
@@ -188,10 +142,8 @@ public class Paragraph implements INode, ISplitpoint {
             boolean contentAdded = false;
             boolean firstNode = true;
 
-            for (final INode node : nodes)
-            {
-                if (!firstNode && !contentAdded && node.needsEmptySpan())
-                {
+            for (final INode node : nodes) {
+                if (!firstNode && !contentAdded && node.needsEmptySpan()) {
                     // In case our previous node didn't add content and the
                     // current node MUST have a previous node, we have to force
                     // the creation now setting addEmptySpan to true.
@@ -201,76 +153,58 @@ public class Paragraph implements INode, ISplitpoint {
                     // an empty text node before the tab!
                     addEmptySpan = true;
                 }
-                addEmptySpan = GenDocHelper.addEmptySpanForNecessaryNode(document, node, addEmptySpan);
+                if (addEmptySpan && node.needsEmptySpan()) {
+                    addEmptySpan(document, node.getAttribute());
+                }
+                addEmptySpan = node.needsEmptySpan();
+
                 contentAdded |= node.appendContent(document);
                 firstNode = false;
             }
-            if (addEmptySpan || !contentAdded)
-            {
-                addEmptySpan(document);
+            if (addEmptySpan || !contentAdded) {
+                addEmptySpan(document, nodes.isEmpty() ? null : nodes.get(nodes.size() - 1).getAttribute()); // if possible we use the attributes of the last node
             }
         }
-        else
-        {
+        else {
             document.append(EMPTYSPAN);
         }
-
         document.append("</div>");
         return true;
     }
 
-    protected void addEmptySpan(StringBuilder document) {
-        GenDocHelper.addEmptySpan(document, true);
+    protected void addEmptySpan(StringBuilder document, JSONObject attrs) throws JSONException {
+        GenDocHelper.addEmptySpan(document, attrs, true);
     }
 
     @Override
-    public String toString()
-    {
+    public String toString() {
         return "Paragraph " + nodes;
     }
 
-    public final
-            void
-            setInTable(
-                boolean inTable)
-    {
+    public final void setInTable(boolean inTable) {
         this.inTable = inTable;
     }
 
-    public final
-            void
-            setImplicit(
-                boolean isImplicit)
-    {
+    public final void setImplicit(boolean isImplicit) {
         this.isImplicit = isImplicit;
     }
 
     @Override
-    public final
-            int
-            getTextLength()
-    {
+    public final int getTextLength() {
         int res = 0;
-        for (INode sn : nodes)
-        {
+        for (INode sn : nodes) {
             res += sn.getTextLength();
         }
         return res;
     }
 
     @Override
-    public final
-            boolean
-            needsEmptySpan()
-    {
+    public final boolean needsEmptySpan() {
         return false;
     }
 
     @Override
-    public final
-            JSONObject
-            getAttribute()
-    {
+    public final JSONObject getAttribute() {
         return myAttrs;
     }
 }
