@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,11 +19,10 @@
  *
  */
 
-
-
 package com.openexchange.office.htmldoc;
 
 import org.json.JSONArray;
+import org.json.JSONException;
 import org.json.JSONObject;
 
 public class SlideParagraph extends Paragraph {
@@ -69,8 +68,7 @@ public class SlideParagraph extends Paragraph {
     }
 
     @Override
-    protected void addEmptySpan(StringBuilder document) {
-        GenDocHelper.addEmptySpan(document, false);
+    protected void addEmptySpan(StringBuilder document, JSONObject attrs) throws JSONException {
+        GenDocHelper.addEmptySpan(document, null, false);
     }
-
 }
