@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,42 +19,49 @@
  *
  */
 
-
-
 package com.openexchange.office.ot.osgi;
 
 import java.util.HashSet;
 import java.util.Set;
-
+import java.util.concurrent.atomic.AtomicReference;
 import com.openexchange.office.tools.common.osgi.context.OsgiBundleContextAndActivator;
 import com.openexchange.office.tools.monitoring.Statistics;
 
 //=============================================================================
 public class OfficeOTBundleContextAndActivator extends OsgiBundleContextAndActivator {
 
-	private static OfficeOTBundleContextAndActivator INSTANCE;
-	
-	public OfficeOTBundleContextAndActivator() {
-		super(new OfficeOTBundleContextIdentificator(), true);
-		INSTANCE = this;
-	}
+    private static OfficeOTBundleContextAndActivator INSTANCE;
 
-	@Override
-	protected Set<Class<?>> getAdditionalNeededServices() {
-		Set<Class<?>> res = new HashSet<>();
-		res.add(Statistics.class);
-		return res;
-	}
-	
-	public static Statistics getStatistics() {
-		if (INSTANCE == null) {
-			return null;
-		}
-		return INSTANCE.getOptionalService(Statistics.class);
-	}
+    private static AtomicReference<Statistics> REF_STATISTICS = new AtomicReference<>();
 
-	@Override
-	protected boolean logEntry(String entry) {
-		return false;
-	}
+    public OfficeOTBundleContextAndActivator() {
+        super(new OfficeOTBundleContextIdentificator(), true);
+        INSTANCE = this;
+    }
+
+    @Override
+    protected Set<Class<?>> getAdditionalNeededServices() {
+        Set<Class<?>> res = new HashSet<>();
+        res.add(Statistics.class);
+        return res;
+    }
+
+    public static Statistics getStatistics() {
+        if (INSTANCE == null) {
+            return null;
+        }
+
+        Statistics statistics = REF_STATISTICS.get();
+        if (statistics == null) {
+            if (REF_STATISTICS.compareAndSet(null, INSTANCE.getOptionalService(Statistics.class))) {
+                statistics = REF_STATISTICS.get();
+            }
+        }
+        return statistics;
+    }
+
+    @Override
+    protected boolean logEntry(String entry) {
+        return false;
+    }
 }
