@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.recentfilelist.impl;
 
 import java.util.ArrayList;
@@ -77,13 +75,13 @@ public class RecentFileListManagerImpl implements RecentFileListManager, Initial
 
 	private Session session = null;
 	private UserConfigurationHelper userConfHelper;
-	
+
 	@Autowired
 	private UserConfigurationFactory userConfigFactory;
 
 	@Autowired
 	private FolderService folderService;
-	
+
 	/**
 	 * Stores user/client specific data to retrieve path information from the
 	 * FolderService.
@@ -154,14 +152,14 @@ public class RecentFileListManagerImpl implements RecentFileListManager, Initial
 	                locale = ((ServerSession)session).getUser().getLocale();
 	                timeZoneId = ((ServerSession)session).getUser().getTimeZone();
 	            }
-	
+
 	            final TimeZone timeZone = TimeZoneHelper.getTimeZone(timeZoneId);
 	            final FolderContextData folderContextData = new FolderContextData(locale, timeZone);
-	
+
 	            try {
 	                final JSONArray recentFileArray = new JSONArray(jsonRecentFileListString);
 	                final ArrayList<JSONObject> list = new ArrayList<>();
-	
+
 	                for (int i = 0; i < Math.min(recentFileArray.length(), MAX_RECENT_ENTRIES); i++) {
 	                    try {
 	                        final Object obj = recentFileArray.get(i);
@@ -209,7 +207,7 @@ public class RecentFileListManagerImpl implements RecentFileListManager, Initial
 
 	   		if ((id1.length() > 0) && (folder1.length() > 0)) {
 	   		    int foundIndex = -1;
-	
+
 				for (int i = 0; i < recentFiles.size(); i++) {
 				    Object obj = recentFiles.get(i);
 				   	if (obj instanceof JSONObject) {
@@ -220,7 +218,7 @@ public class RecentFileListManagerImpl implements RecentFileListManager, Initial
 				   		}
 				   	}
 				}
-	
+
 			    // an entry which already exists must be moved to the first pos
 			    if (foundIndex >= 0) {
 			        recentFiles.remove(foundIndex);
@@ -294,10 +292,10 @@ public class RecentFileListManagerImpl implements RecentFileListManager, Initial
         if ((null != recentFiles) && (null != fileToBeRemoved)) {
 	   		String id1 = fileToBeRemoved.optString("id", "");
 	   		String folder1 = fileToBeRemoved.optString("folder_id", "");
-	
+
 	   		if ((id1.length() > 0) && (folder1.length() > 0)) {
 	   		    int foundIndex = -1;
-	
+
 			    for (int i = 0; i < recentFiles.size(); i++) {
 			    	Object obj = recentFiles.get(i);
 			    	if (obj instanceof JSONObject) {
@@ -308,7 +306,7 @@ public class RecentFileListManagerImpl implements RecentFileListManager, Initial
 			    		}
 			    	}
 			    }
-	
+
 			    if (foundIndex >= 0) {
 			    	recentFiles.remove(foundIndex);
 			    	return true;
@@ -385,20 +383,20 @@ public class RecentFileListManagerImpl implements RecentFileListManager, Initial
     @Override
     public boolean migrateOldRecentFileList(ApplicationType app) {
 	   	boolean result = false;
-	
+
 	   	String userConfEntryKey = "portal/recents";
 	   	String oldRecentFiles = userConfHelper.getString(userConfEntryKey);
-	
+
 	   	if ((null != oldRecentFiles) && (app != ApplicationType.APP_NONE)) {
 	   		HashSet<String> appExtensionSet = null;
-	
+
 	   		if (app == ApplicationType.APP_TEXT)
 	   			appExtensionSet = new HashSet<>(Arrays.asList(ExtensionHelper.TEXT_EXTENSIONS));
 	   		else if (app == ApplicationType.APP_SPREADSHEET)
 	   			appExtensionSet = new HashSet<>(Arrays.asList(ExtensionHelper.SPREADSHEET_EXTENSIONS));
 	   		else if (app == ApplicationType.APP_PRESENTATION)
 	   			appExtensionSet = new HashSet<>(Arrays.asList(ExtensionHelper.PRESENTATION_EXTENSIONS));
-	
+
 	   		final ArrayList<JSONObject> recentAppFiles = new ArrayList<>();
 	   		try {
 	   			final JSONArray oldRecentFilesArray = new JSONArray(oldRecentFiles);
@@ -406,7 +404,7 @@ public class RecentFileListManagerImpl implements RecentFileListManager, Initial
 	   				Object obj = oldRecentFilesArray.get(i);
 	   				if (obj instanceof JSONObject) {
 	   					JSONObject fileDescriptor = (JSONObject)obj;
-	
+
 	   					filterFileDescriptorAttributes(fileDescriptor);
 	   					String fileName = fileDescriptor.optString("filename", null);
 	   					String ext = FileHelper.getExtension(fileName);
@@ -415,7 +413,7 @@ public class RecentFileListManagerImpl implements RecentFileListManager, Initial
 	   					}
 	   				}
 	   			}
-	
+
 	   			// prepare the new data structure to write to the new recent
 	   			// data structure
 	   			prepareNewRecentDataStructure(app);
@@ -518,7 +516,7 @@ public class RecentFileListManagerImpl implements RecentFileListManager, Initial
                 final JSONObject folderInfo = new JSONObject();
 
                 folderInfo.put("id", folder.getID());
-                folderInfo.put("filename", folder.getLocalizedName(folderContextData.getLocale(), folder.isAltNames()));
+                folderInfo.put("filename", folder.getName(folderContextData.getLocale(), true));
                 result.add(0, folderInfo);
             }
         }
