@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,10 +19,9 @@
  *
  */
 
-
-
 package com.openexchange.office.rest;
 
+import java.io.BufferedInputStream;
 import java.io.ByteArrayInputStream;
 import java.io.FileInputStream;
 import java.io.IOException;
@@ -34,7 +33,6 @@ import java.util.HashSet;
 import java.util.Optional;
 import java.util.Set;
 import java.util.function.Function;
-
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.io.input.BoundedInputStream;
 import org.apache.commons.lang3.StringUtils;
@@ -51,9 +49,12 @@ import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.upload.UploadFile;
+import com.openexchange.imagetransformation.ImageInformation;
 import com.openexchange.imagetransformation.ImageMetadata;
 import com.openexchange.imagetransformation.ImageMetadataOptions;
 import com.openexchange.imagetransformation.ImageMetadataService;
+import com.openexchange.imagetransformation.Utility;
+import com.openexchange.java.BoolReference;
 import com.openexchange.net.HostList;
 import com.openexchange.office.document.api.DocFileServiceFactory;
 import com.openexchange.office.document.tools.DocFileHelper;
@@ -69,6 +70,7 @@ import com.openexchange.office.tools.common.memory.MemoryObserver;
 import com.openexchange.office.tools.doc.DocumentFormat;
 import com.openexchange.office.tools.doc.StreamInfo;
 import com.openexchange.tools.encoding.Base64;
+import com.openexchange.tools.images.ImageTransformationUtility;
 import com.openexchange.tools.net.URITools;
 import com.openexchange.tools.session.ServerSession;
 
@@ -101,8 +103,10 @@ public class AddFileAction extends DocumentRESTAction implements InitializingBea
     private static final int MAX_IMAGE_SIZE_IN_MB = 10;
     private static final int MAX_URL_LENGTH = 255;
 
-    static final protected String m_resourceIdKey = "added_fileid";
-    static final protected String m_resourceNameKey = "added_filename";
+    static final protected String RESOURCE_ID_KEY = "added_fileid";
+    static final protected String RESOURCE_NAME_KEY = "added_filename";
+    static final protected String IMAGE_TRANSFORMATION_KEY = "image_transformation";
+    static final protected String EXIF_ORIENTATION_KEY = "exif_orientation";
 
     private long maxImageSizeSupported = MAX_IMAGE_SIZE_IN_MB * 1024L * 1024L;
 
@@ -147,7 +151,7 @@ public class AddFileAction extends DocumentRESTAction implements InitializingBea
     @Override
     public AJAXRequestResult perform(AJAXRequestData request, ServerSession session) throws OXException {
         final RequestDataHelper requestDataHelper = new RequestDataHelper(request);
-        final JSONObject jsonObj = new JSONObject();
+        final JSONObject resultData = new JSONObject();
         AJAXRequestResult ajaxResult = null;
         String sha256 = null;
 
@@ -274,12 +278,22 @@ public class AddFileAction extends DocumentRESTAction implements InitializingBea
 
                     // add the managed file id to the result object
                     if ((null != resource) && (null != (managedResourceId = resource.getManagedId()))) {
-                        jsonObj.put(m_resourceIdKey, managedResourceId);
+                        resultData.put(RESOURCE_ID_KEY, managedResourceId);
                     }
 
                     // add the filename to the result object
-                    jsonObj.put(m_resourceNameKey, resname);
+                    resultData.put(RESOURCE_NAME_KEY, resname);
                 }
+
+                if (data.length > 2 && ((data[0] & 0x00ff) == 0x00ff) && ((data[1] & 0x00ff) == 0x00d8)) {
+                    final ImageInformation information = ImageTransformationUtility.readImageInformation(new BufferedInputStream(new ByteArrayInputStream(data)), new BoolReference(false));
+                    if (information.orientation > 1) {
+                        final JSONObject imageTransformation = new JSONObject(1);
+                        imageTransformation.put(EXIF_ORIENTATION_KEY, information.orientation);
+                        resultData.put(IMAGE_TRANSFORMATION_KEY, imageTransformation);
+                    }
+                }
+
             } catch (Exception e1) {
                 LOG.error("Could not add to resource manager", e1);
             }
@@ -287,15 +301,11 @@ public class AddFileAction extends DocumentRESTAction implements InitializingBea
 
         // set resource id at connection object; return the
         // object with fragment name and id in case of success
-        if (jsonObj.has(m_resourceIdKey)) {
+        if (resultData.has(RESOURCE_ID_KEY)) {
             try {
-                JSONObject resultData = new JSONObject();
-                resultData.put(m_resourceNameKey, jsonObj.get(m_resourceNameKey));
-                resultData.put(m_resourceIdKey, jsonObj.get(m_resourceIdKey));
-
                 ajaxResult = getAjaxRequestResult(resultData);
 
-                LOG.debug("AddFileAction with sha256=" + sha256 + " results in " + m_resourceIdKey + "=" + jsonObj.getString(m_resourceIdKey));
+                LOG.debug("AddFileAction with sha256=" + sha256 + " results in " + RESOURCE_ID_KEY + "=" + resultData.getString(RESOURCE_ID_KEY));
             } catch (JSONException e) {
                 LOG.error("Could not send resource to realtime session", e);
             }
