@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,14 +19,15 @@
  *
  */
 
-
-
 package com.openexchange.office.rest;
 
+import java.io.BufferedInputStream;
+import java.io.ByteArrayInputStream;
+import java.io.IOException;
 import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.Map;
-
+import javax.servlet.http.HttpServletRequest;
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.lang3.StringUtils;
 import org.json.JSONException;
@@ -48,12 +49,15 @@ import com.openexchange.file.storage.composition.IDBasedFileAccess;
 import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.crypto.CryptographicAwareIDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.crypto.CryptographyMode;
+import com.openexchange.imagetransformation.ImageInformation;
+import com.openexchange.java.BoolReference;
 import com.openexchange.office.document.api.DocumentConstants;
 import com.openexchange.office.rest.tools.ParamValidatorService;
 import com.openexchange.office.tools.common.files.FileHelper;
 import com.openexchange.office.tools.doc.DocumentMetaData;
 import com.openexchange.office.tools.service.http.AjaxActionServiceWithConcreteModel;
 import com.openexchange.server.ServiceExceptionCode;
+import com.openexchange.tools.images.ImageTransformationUtility;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
 
@@ -134,6 +138,27 @@ public abstract class DocumentRESTAction<TO, DO> extends AjaxActionServiceWithCo
             request.setFormat("json");
             requestResult = new AJAXRequestResult(jsonObject, "json");
         } else {
+
+            if (data.length > 2 && ((data[0] & 0x00ff) == 0x00ff) && ((data[1] & 0x00ff) == 0x00d8)) { // quick jpeg check
+                try {
+                    final ImageInformation information = ImageTransformationUtility.readImageInformation(new BufferedInputStream(new ByteArrayInputStream(data)), new BoolReference(false));
+                    if (information!=null && information.orientation > 1) {
+                        // DOCS-2109 and DOCS-2992:
+                        // we don't want to let the image response renderer perform
+                        // an auto rotation or transformation at all in case the Exif data
+                        // of the image indicates this, as all transformations (e.g. Exif
+                        // rotation) should be done via explicit rotation attributes for
+                        // the document image element
+                        if (mimeType.startsWith("image/")) {
+                            request.putParameter("transformationNeeded", "false");
+                        }
+                    }
+                }
+                catch(IOException e) {
+                    LOG.error("Exception detected while trying to detect exif orientation of a jpeg image", e);
+                }
+            }
+
             final ByteArrayFileHolder fileHolder = new ByteArrayFileHolder(data);
 
             fileHolder.close();
@@ -144,7 +169,6 @@ public abstract class DocumentRESTAction<TO, DO> extends AjaxActionServiceWithCo
 
             setETag(getETag(fileId, fileVersion), 0, requestResult);
         }
-
         return requestResult;
     }
 
