@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.rest;
 
 import java.security.NoSuchAlgorithmException;
@@ -114,17 +112,6 @@ public class GetOperationsAction extends DocumentRESTAction {
             return new AJAXRequestResult(jsonResult);
         }
 
-        try {
-            if (!dataSourceAccess.canRead(folderId, id, versionOrAttachmentId))
-                return ParamValidatorService.getResultFor(HttpStatusCode.FORBIDDEN.getStatusCode());
-        } catch (DataSourceException e) {
-            LOG.error("GetOperationsAction: DataSourceException caught trying to retrieve document meta data for provided parameters", e);
-
-            errorCode = e.getErrorCode();
-            try {jsonResult.put(MessagePropertyKey.KEY_ERROR_DATA, errorCode.getAsJSON()); } catch (final JSONException je) { /* ignore it */ }
-            return new AJAXRequestResult(jsonResult);
-        }
-
         final Optional<String> authCode = Optional.ofNullable(authCodeStr);
         String subAction = requestData.getParameter(ParameterDefinitions.PARAM_SUB_ACTION);
         subAction = (null == subAction) ? ParameterDefinitions.PARAM_SUBACTION_OPEN : subAction;
