@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,7 +19,6 @@
  *
  */
 
-
 package com.openexchange.office.rt2.core;
 
 import java.lang.ref.WeakReference;
@@ -267,8 +266,8 @@ public class RT2GarbageCollector implements Runnable, DisposableBean, Initializi
     //-------------------------------------------------------------------------
     private void impl_doGC () {
         try {
-        	MDC.put(MDCEntries.BACKEND_PART, "RT2GarbageCollector");
-        	MDC.put(MDCEntries.BACKEND_UID, clusterService.getLocalMemberUuid());        	
+            MDC.put(MDCEntries.BACKEND_PART, "RT2GarbageCollector");
+            MDC.put(MDCEntries.BACKEND_UID, clusterService.getLocalMemberUuid());        	
             checkAndGCOfflineOrStaleDocProxies();
             checkAndGCStaleDocResources();
             checkAndGCAtomicLongAsClientRef();
@@ -278,8 +277,8 @@ public class RT2GarbageCollector implements Runnable, DisposableBean, Initializi
         } catch (Exception ex) {
             log.error(ex.getMessage(), ex);
         } finally {
-        	MDC.clear();
-		}
+            MDC.clear();
+        }
     }
 
     //-------------------------------------------------------------------------    
@@ -591,28 +590,28 @@ public class RT2GarbageCollector implements Runnable, DisposableBean, Initializi
 
     //-------------------------------------------------------------------------
     private void removeDocOnNodeEntryAndAtomicLongForDocUid(RT2DocUidType docUid, boolean destroyRefCountGlobally) {
-        RT2DocOnNodeMap aDocOnNodeMap = docOnNodeMap;
-        MDC.put(MDCEntries.DOC_UID, docUid.getValue());
-        log.info("Removing docOnNodeMap entry with key {}", docUid.getValue());
-        ClusterLock clusterLock = clusterLockService.getLock(docUid);
         try {
-            clusterLock.lock();
-            if (aDocOnNodeMap.remove(docUid.getValue()) == null) {
-                MDC.put(MDCEntries.DOC_UID, docUid.getValue());
-                log.error("Cannot remove entry with doc-uid {} from DocOnNodeMap", docUid.getValue());
+            RT2DocOnNodeMap aDocOnNodeMap = docOnNodeMap;
+            MDC.put(MDCEntries.DOC_UID, docUid.getValue());
+            log.info("Removing docOnNodeMap entry with key {}", docUid.getValue());
+            ClusterLock clusterLock = clusterLockService.getLock(docUid);
+            try {
+                clusterLock.lock();
+                if (aDocOnNodeMap.remove(docUid.getValue()) == null) {
+                    log.error("Cannot remove entry with doc-uid {} from DocOnNodeMap", docUid.getValue());
+                }
+                docOnNodeMapEntryRemovedCounter.inc();
+                if (!distributedDocInfoMap.freeDocInfos(docUid)) { 
+                    log.warn("No RefCount4Clients for document with doc-uid {} found!", docUid.getValue());
+                }
+            } catch (ClusterLockException e) {
+                // Ignore, try again next time
+            } finally {
+                clusterLock.unlock();
             }
-            docOnNodeMapEntryRemovedCounter.inc();
-            if (!distributedDocInfoMap.freeDocInfos(docUid)) { 
-                MDC.put(MDCEntries.DOC_UID, docUid.getValue());
-                log.warn("No RefCount4Clients for document with doc-uid {} found!", docUid.getValue());
-            }
-        } catch (ClusterLockException e) {
-            // Ignore, try again next time
         } finally {
-            clusterLock.unlock();
             MDC.remove(MDCEntries.DOC_UID);
         }
-        MDC.remove(MDCEntries.DOC_UID);
     }
 
     //-------------------------------------------------------------------------
