@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,20 +19,18 @@
  *
  */
 
-
-
 package com.openexchange.office.rt2.core.control;
 
+import org.eclipse.microprofile.health.HealthCheckResponse;
 import com.openexchange.office.rt2.protocol.RT2Message;
 
-public interface IRT2NodeHealthManager
-{
-    //-------------------------------------------------------------------------
+public interface IRT2NodeHealthManager {
+
+    public HealthCheckResponse checkHealth();
+
     public void crashedNodeDocCleanupCompleted(final RT2Message aCleanupOrderCompletedMsg);
 
-    //-------------------------------------------------------------------------
     public void startLocalNodeDocCleanup(final RT2Message aCleanupOrderMsg);
 
-    //-------------------------------------------------------------------------
     public void checkCorrectNodeShutdown(final String nodeUUID);
 }
