@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,14 +19,14 @@
  *
  */
 
-
-
 package com.openexchange.office.rt2.core.control;
 
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
 import java.util.NoSuchElementException;
+import java.util.Optional;
 import java.util.Set;
 import java.util.UUID;
 import java.util.concurrent.ConcurrentHashMap;
@@ -35,6 +35,8 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.Validate;
+import org.eclipse.microprofile.health.HealthCheckResponse;
+import org.eclipse.microprofile.health.HealthCheckResponse.Status;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.slf4j.MDC;
@@ -106,6 +108,9 @@ public class RT2NodeHealthMonitor implements IRT2NodeHealthManager, ClusterMembe
 	private static final long               FREQ_CHECK_OBSOLETE_NODE          = 120000; // 2 minutes
 	private static final long               TIMESPAN_REMOVE_OBSOLETE_NODE     = 900000; // 15 minutes
 	private static final String []          RT2_SYMBOLIC_BUNDLENAMES_TO_STOP  = { "com.openexchange.office.rt2.osgi", "com.openexchange.office.rt2.core" };
+	private static final String             IS_ACTIVE_HZ_MEMBER               = "nodeIsActiveHZMember";
+	private static final String             NODE_SHUTDOWN_STATE               = "nodeShutdownState";
+	private static final String             DOCS_SERVICES_SHUTDOWN            = "docsServicesShutdown";
 
     //-----------------------------Services------------------------------------
 
@@ -146,6 +151,8 @@ public class RT2NodeHealthMonitor implements IRT2NodeHealthManager, ClusterMembe
 
 	private AtomicBoolean                   m_isPartOfSafeCluster = new AtomicBoolean(false);
 
+	private AtomicBoolean                   m_shutdownDocumentsService = new AtomicBoolean(false);
+
 	private AtomicReference<LifecycleState> m_aLifeCycleState = new AtomicReference<>(LifecycleState.CLIENT_DISCONNECTED); // impossible case
 
 	private AtomicReference<String>         m_nodeUUID = new AtomicReference<>("");
@@ -154,6 +161,8 @@ public class RT2NodeHealthMonitor implements IRT2NodeHealthManager, ClusterMembe
 
 	private ScheduledTimerTask              m_checkObsoleteNodesTimerTask = null;
 
+	private AtomicBoolean                   m_disposed = new AtomicBoolean(false);
+
     //-------------------------------------------------------------------------    
     @Override
     public void afterPropertiesSet() {
@@ -188,6 +197,8 @@ public class RT2NodeHealthMonitor implements IRT2NodeHealthManager, ClusterMembe
 	public void destroy() throws Exception {
         if (m_isStarted.compareAndSet(true, false))
         {
+            m_disposed.set(true);
+
             final CleanupTaskProcessor aCleanupTaskProcessor = m_aCleanupTaskProcessor;
             if (null != aCleanupTaskProcessor)
             {
@@ -219,6 +230,33 @@ public class RT2NodeHealthMonitor implements IRT2NodeHealthManager, ClusterMembe
         }
 	}
 
+    //-------------------------------------------------------------------------
+    public boolean isDisposed() {
+        return m_disposed.get();
+    }
+
+    //-------------------------------------------------------------------------
+    @Override
+    public HealthCheckResponse checkHealth() {
+        Map<String, Object> data = new HashMap<>();
+        Status status = Status.DOWN;
+        if (!m_disposed.get()) {
+            final String clusterNodeUuid = clusterService.getLocalMemberUuid();
+            boolean isActiveHzMember = clusterService.isActiveHzMember(clusterNodeUuid);
+            boolean nodeShutdown = isNodeShuttingDown();
+            boolean docsServicesShutdown = m_shutdownDocumentsService.get();
+            if (!nodeShutdown && !docsServicesShutdown && isActiveHzMember) {
+                status = Status.UP;
+            } else {
+                status = Status.DOWN;
+            }
+            data.put(IS_ACTIVE_HZ_MEMBER, isActiveHzMember);
+            data.put(NODE_SHUTDOWN_STATE, (nodeShutdown ? "shutting down" : "up"));
+            data.put(DOCS_SERVICES_SHUTDOWN, docsServicesShutdown);
+        }
+        return new HealthCheckResponse(this.getClass().getCanonicalName(), status, Optional.of(data));
+    }
+
     //-------------------------------------------------------------------------
     @Override
     public void crashedNodeDocCleanupCompleted(RT2Message aCleanupOrderCompletedMsg)
@@ -319,7 +357,7 @@ public class RT2NodeHealthMonitor implements IRT2NodeHealthManager, ClusterMembe
                 handleStateChangedToMerged();
             }
         } finally {
-            MDC.clear();
+            MDC.remove(MDCEntries.BACKEND_UID);
         }
     }
 
@@ -330,7 +368,7 @@ public class RT2NodeHealthMonitor implements IRT2NodeHealthManager, ClusterMembe
             MDC.put(MDCEntries.BACKEND_UID, membershipEvent.getMemberUid());
             log.info("RT2NodeHealthMonitor.memberAdded {}", membershipEvent.getMemberUid());
         } finally {
-            MDC.clear();
+            MDC.remove(MDCEntries.BACKEND_UID);
         }
     }
 
@@ -363,7 +401,8 @@ public class RT2NodeHealthMonitor implements IRT2NodeHealthManager, ClusterMembe
             if (!bClusterIsSafe)
             {
                 log.error("Cluster is not in safe state - to prevent alteration of document data this node will shutdown office service!");
-                // this node is part of a not-safe cluster therefore  it MUST NEVER do a clean-up
+                // this node is part of a non-safe cluster therefore  it MUST NEVER do a clean-up
+                m_shutdownDocumentsService.set(true);
                 asyncShutdownRT2();
                 return;
             }
@@ -839,7 +878,8 @@ public class RT2NodeHealthMonitor implements IRT2NodeHealthManager, ClusterMembe
                 MDC.put(MDCEntries.BACKEND_UID, clusterService.getLocalMemberUuid());
                 checkAndRemoveObsoleteNodeEntries();
             } finally {
-                MDC.clear();
+                MDC.remove(MDCEntries.BACKEND_PART);
+                MDC.remove(MDCEntries.BACKEND_UID);
             }
         }
 
