@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.rt2.core.doc;
 
 import java.util.HashMap;
@@ -31,14 +29,10 @@ import org.apache.commons.lang3.mutable.MutableInt;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-public final class DocStatistics implements IDocNotificationHandler, IStatisticData
-{
-    //-------------------------------------------------------------------------
-	private static final Logger log = LoggerFactory.getLogger(DocStatistics.class);
+public final class DocStatistics implements IDocNotificationHandler, IStatisticData {
 
-    //-------------------------------------------------------------------------
-    private static class Holder
-    {
+	private static final Logger log = LoggerFactory.getLogger(DocStatistics.class);
+    private static class Holder {
         static final DocStatistics INSTANCE = new DocStatistics();
     }
 
@@ -47,74 +41,63 @@ public final class DocStatistics implements IDocNotificationHandler, IStatisticD
     private Map<String, MutableInt> m_aNumForDocTypeMap = new HashMap<>();
 
     //-------------------------------------------------------------------------
-    private DocStatistics()
-    {
+    private DocStatistics() {
+        // nothing to do
     }
 
     //-------------------------------------------------------------------------
     @Override
-    public void docProcessorCreated(final RT2DocProcessor aCreatedInstance)
-    {
+    public void docProcessorCreated(final RT2DocProcessor aCreatedInstance) {
         m_aNum.incrementAndGet();
 
         final String sDocType = aCreatedInstance.getDocTypeIdentifier();
-        synchronized(m_aNumForDocTypeMap)
-        {
+        synchronized(m_aNumForDocTypeMap) {
             MutableInt aInteger = m_aNumForDocTypeMap.get(sDocType);
-            if (aInteger == null)
-            {
+            if (aInteger == null) {
                 aInteger = new MutableInt(1);
                 m_aNumForDocTypeMap.put(sDocType, aInteger);
-            }
-            else
+            } else {
                 aInteger.increment();
+            }
         }
     }
 
     //-------------------------------------------------------------------------
     @Override
-    public void docProcessorDisposed(final RT2DocProcessor aDisposedInstance)
-    {
+    public void docProcessorDisposed(final RT2DocProcessor aDisposedInstance) {
         m_aNum.decrementAndGet();
 
         final String sDocType = aDisposedInstance.getDocTypeIdentifier();
-        synchronized(m_aNumForDocTypeMap)
-        {
+        synchronized(m_aNumForDocTypeMap) {
             MutableInt aInteger = m_aNumForDocTypeMap.get(sDocType);
-            if (aInteger == null)
-            {
+            if (aInteger == null) {
                 log.warn("RT2StatisticDocManager: docProcessorDisposed received but no number instance available");
-            }
-            else
+            } else {
                 aInteger.decrement();
+            }
         }
     }
 
 	//-------------------------------------------------------------------------
-    public int getNumberOfDocs()
-    {
+    public int getNumberOfDocs() {
         return m_aNum.get();
     }
 
     //-------------------------------------------------------------------------
-    public DocStatistics getInstance()
-    {
+    public DocStatistics getInstance() {
         return Holder.INSTANCE;
     }
 
     //-------------------------------------------------------------------------
     @Override
-    public int getNumberOfOpenDocuments()
-    {
+    public int getNumberOfOpenDocuments() {
         return m_aNum.get();
     }
 
     //-------------------------------------------------------------------------
     @Override
-    public int getNumberOfOpenDocuments(String sDocType)
-    {
-        synchronized (m_aNumForDocTypeMap)
-        {
+    public int getNumberOfOpenDocuments(String sDocType) {
+        synchronized (m_aNumForDocTypeMap) {
             final MutableInt aInteger = m_aNumForDocTypeMap.get(sDocType);
             return (aInteger != null) ? aInteger.getValue() : 0;
         }
