@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.rt2.core.doc;
 
 import java.util.Arrays;
@@ -219,9 +217,11 @@ public abstract class LoadableDocProcessor extends DocProcessor {
     //-------------------------------------------------------------------------
 	@Override
 	public boolean onJoin(RT2Message request) throws Exception {
+	    log.info("Loadable DocProcessor.onJoin for doc-uid {}", this.getDocUID().getValue());
 		super.onJoin(request);
 
 		final RT2Message aResponse = createJoinResponse(request);
+        log.info("Loadable DocProcessor send join_response via RT2MessageSender");
         messageSender.sendMessageWOSeqNrTo (request.getClientUID(), aResponse);
         return true;
 	}
@@ -543,6 +543,11 @@ public abstract class LoadableDocProcessor extends DocProcessor {
 
                         // Load the document in two parts
                         // We should change this in the future providing many chunks
+                        // DOCS-3742: Ensure that getGlobalOperations & getActiveOperations are called
+                        // before getPartsCount()/getActivePartIndex get called. The calls fill up the
+                        // internal map of the ChunkDocLoader. Otherwise defaults are provided.
+                        final JSONObject globalOpsObject  = chunkDocLoader.getGlobalOperations();
+                        final JSONObject activeObsObject  = chunkDocLoader.getActiveOperations();
                         final int        nPartsCount      = chunkDocLoader.getPartsCount();
                         final int        nActivePartIndex = chunkDocLoader.getActivePartIndex();
 
@@ -556,8 +561,8 @@ public abstract class LoadableDocProcessor extends DocProcessor {
                         if (useFastLoad) {
 
                             final JSONObject documentOpsObject  = new JSONObject();
-                            OperationHelper.appendJSON(documentOpsObject, chunkDocLoader.getGlobalOperations());
-                            OperationHelper.appendJSON(documentOpsObject, chunkDocLoader.getActiveOperations());
+                            OperationHelper.appendJSON(documentOpsObject, globalOpsObject);
+                            OperationHelper.appendJSON(documentOpsObject, activeObsObject);
 
                             // fast load needs all operations to create the DOM string
                             OperationHelper.appendJSON(documentOpsObject, chunkDocLoader.getRemainingOperations());
@@ -574,8 +579,8 @@ public abstract class LoadableDocProcessor extends DocProcessor {
                         if(sFastLoadHtmlDoc==null) {
 
                             final JSONObject documentOpsObject  = new JSONObject();
-                            OperationHelper.appendJSON(documentOpsObject, chunkDocLoader.getGlobalOperations());
-                            OperationHelper.appendJSON(documentOpsObject, chunkDocLoader.getActiveOperations());
+                            OperationHelper.appendJSON(documentOpsObject, globalOpsObject);
+                            OperationHelper.appendJSON(documentOpsObject, activeObsObject);
 
                             if (nPartsCount > 1) {
                                 // multi-part - preview and remaining operations object
@@ -808,7 +813,12 @@ public abstract class LoadableDocProcessor extends DocProcessor {
             return errorCode;
 
         // make sure that filter exception is logged on log-level warn
-        specialLogService.log(Level.WARN, log, getDocUID().getValue(), new Throwable(), "LoadableDocProcessor: loading document stream resulted in a filter exception.", e);
+        if(e.getErrorcode() == FilterException.ErrorCode.COMPLEXITY_TOO_HIGH) {
+            specialLogService.log(Level.INFO, log, getDocUID().getValue(), new Throwable(), "LoadableDocProcessor: Document could not be loaded because it exceeds the maxWordCount / maxCells limit.");
+        }
+        else {
+            specialLogService.log(Level.WARN, log, getDocUID().getValue(), new Throwable(), "LoadableDocProcessor: loading document stream resulted in a filter exception.", e);
+        }
 
         if ((e.getErrorcode() == FilterException.ErrorCode.MEMORY_USAGE_TOO_HIGH) || (e.getErrorcode() == FilterException.ErrorCode.MEMORY_USAGE_MIN_FREE_HEAP_SPACE_REACHED)) {
             // try to figure out what happened with the memory usage of the filter as
