@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,7 +19,6 @@
  *
  */
 
-
 package com.openexchange.office.rt2.core.jms;
 
 import java.io.ByteArrayOutputStream;
@@ -30,6 +29,7 @@ import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
 import java.util.UUID;
+import java.util.concurrent.atomic.AtomicLong;
 import java.util.stream.Collectors;
 
 import javax.jms.BytesMessage;
@@ -74,12 +74,14 @@ import com.openexchange.office.rt2.protocol.RT2GoogleProtocol.VersionMessageRequ
 import com.openexchange.office.rt2.protocol.RT2GoogleProtocol.VersionMessageResponse;
 import com.openexchange.office.rt2.protocol.RT2Message;
 import com.openexchange.office.rt2.protocol.RT2MessageFactory;
+import com.openexchange.office.rt2.protocol.RT2MessageGetSet;
 import com.openexchange.office.rt2.protocol.RT2MessageJmsPostProcessor;
 import com.openexchange.office.rt2.protocol.RT2MessagePostProcessor;
 import com.openexchange.office.rt2.protocol.internal.Cause;
 import com.openexchange.office.rt2.protocol.value.RT2AdminIdType;
 import com.openexchange.office.rt2.protocol.value.RT2CliendUidType;
 import com.openexchange.office.rt2.protocol.value.RT2DocUidType;
+import com.openexchange.office.rt2.protocol.value.RT2MessageType;
 import com.openexchange.office.rt2.protocol.value.RT2SessionIdType;
 import com.openexchange.office.tools.annotation.RegisteredService;
 import com.openexchange.office.tools.annotation.ShutdownOrder;
@@ -130,10 +132,18 @@ public class RT2AdminJmsConsumer implements MessageListener, JmsMessageListener,
     
 	@Autowired
 	private RT2JmsMessageSender jmsMessageSender;
-    
-	//------------------------------------------------------------------------    
-    private DefaultMessageListenerContainer msgListenerCont;     
 
+	//------------------------------------------------------------------------    
+    private DefaultMessageListenerContainer msgListenerCont;
+
+    private AtomicLong lastHealthCheckResponseReceived = new AtomicLong(0);
+
+    //-------------------------------------------------------------------------
+    public long getLastHealthCheckResponseReceived() {
+        return lastHealthCheckResponseReceived.get();
+    }
+
+    //-------------------------------------------------------------------------    
 	@Override
 	public void afterPropertiesSet() throws Exception {
 		   this.adminId = generateAdminID();
@@ -180,10 +190,11 @@ public class RT2AdminJmsConsumer implements MessageListener, JmsMessageListener,
     //-------------------------------------------------------------------------
     @Override
     public void onMessage(Message jmsMsg) {
-    	MDC.put(MDCEntries.BACKEND_PART, "RT2AdminJmsConsumer");
-    	MDC.put(MDCEntries.BACKEND_UID, clusterService.getLocalMemberUuid());      	            	
         log.debug("Received admin message...");
+        boolean removeAdminMsgType = false;
         try {
+        	MDC.put(MDCEntries.BACKEND_PART, "RT2AdminJmsConsumer");
+        	MDC.put(MDCEntries.BACKEND_UID, clusterService.getLocalMemberUuid());      	            	
         	if (jmsMsg.getBooleanProperty(RT2MessagePostProcessor.HEADER_VERSION_MSG_RCV)) {
         		return;
         	}
@@ -225,6 +236,7 @@ public class RT2AdminJmsConsumer implements MessageListener, JmsMessageListener,
 	        	try {
 	        		RT2Message rt2Msg = RT2MessageFactory.fromJmsMessage(jmsMsg);
 	        		MDC.put(MDCEntries.ADMIN_MSG_TYPE, rt2Msg.getType().getValue());
+	        		removeAdminMsgType = true;
 	        		handleResponse(rt2Msg);
 	        	} catch (Exception ex) {
 	        		log.error(ex.getMessage(), ex);
@@ -233,8 +245,12 @@ public class RT2AdminJmsConsumer implements MessageListener, JmsMessageListener,
         } catch (JMSException | UnknownHostException | InvalidProtocolBufferException ex) {
         	log.error(ex.getMessage(), ex);
         } finally {
-			MDC.clear();
-		}        
+			MDC.remove(MDCEntries.BACKEND_PART);
+			MDC.remove(MDCEntries.BACKEND_UID);
+			if (removeAdminMsgType) {
+				MDC.remove(MDCEntries.ADMIN_MSG_TYPE);
+			}
+		}
     }
 
     //-------------------------------------------------------------------------
@@ -349,6 +365,22 @@ public class RT2AdminJmsConsumer implements MessageListener, JmsMessageListener,
             case ADMIN_TASK_COMPLETED_CLEANUP_FOR_CRASHED_NODE:
                 nodeHealthManager.crashedNodeDocCleanupCompleted(aTask);
                 break;
+            case ADMIN_HEALTH_CHECK_REQUEST: {
+                String nodeUuid = clusterService.getLocalMemberUuid();
+                if (StringUtils.equals(nodeUuid, RT2MessageGetSet.getNodeUUID(aTask))) {
+                    RT2Message adminHealthCheckResponse = RT2MessageFactory.newAdminMessage(RT2MessageType.ADMIN_HEALTH_CHECK_RESPONSE);
+                    RT2MessageGetSet.setNodeUUID(adminHealthCheckResponse, nodeUuid);
+                    send(adminHealthCheckResponse);
+                }
+                break;
+            }
+            case ADMIN_HEALTH_CHECK_RESPONSE: {
+                String nodeUuid = clusterService.getLocalMemberUuid();
+                if (StringUtils.equals(nodeUuid, RT2MessageGetSet.getNodeUUID(aTask))) {
+                    lastHealthCheckResponseReceived.set(System.nanoTime());
+                }
+                break;
+            }
             default:
                 log.error("No support for task {} implemented yet.", aTask.getType());
                 throw new UnsupportedOperationException ("No support for task '"+aTask.getType()+"' implemented yet.");
@@ -356,7 +388,14 @@ public class RT2AdminJmsConsumer implements MessageListener, JmsMessageListener,
     }
 
     //-------------------------------------------------------------------------
+    public void sendAdminHealthCheckRequest() {
+        String nodeUuid = clusterService.getLocalMemberUuid();
+        RT2Message adminHealthCheckRequest = RT2MessageFactory.newAdminMessage(RT2MessageType.ADMIN_HEALTH_CHECK_REQUEST);
+        RT2MessageGetSet.setNodeUUID(adminHealthCheckRequest, nodeUuid);
+        send(adminHealthCheckRequest);
+    }
 
+    //-------------------------------------------------------------------------
     public RT2AdminIdType generateAdminID () {
         final String        sNodeID     = rt2ConfigService.getOXNodeID();
         String        sNormalized = sNodeID;
