@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.rt2.core.jms;
 
 import javax.jms.Message;
@@ -48,6 +46,7 @@ import com.openexchange.office.rt2.core.metric.DocProcessorMetricService;
 import com.openexchange.office.rt2.protocol.RT2Message;
 import com.openexchange.office.rt2.protocol.RT2MessageFactory;
 import com.openexchange.office.rt2.protocol.RT2MessageGetSet;
+import com.openexchange.office.rt2.protocol.value.RT2DocUidType;
 import com.openexchange.office.rt2.protocol.value.RT2MessageType;
 import com.openexchange.office.tools.annotation.ShutdownOrder;
 import com.openexchange.office.tools.common.jms.JmsMessageListener;
@@ -72,22 +71,22 @@ public class RT2DocProcessorJmsConsumer implements MessageListener, JmsMessageLi
 
     @Autowired
     private DocProcessorMetricService docProcessorMetricService;
-    
+
     @Autowired
     private RT2DocProcessorFactory docProcessorFactory;
-    
+
     @Autowired
     private PooledConnectionFactoryProxy pooledConnectionFactoryProxy;
-    
+
     @Autowired
     private ClusterService clusterService;
-    
+
     @Autowired
     private RT2MessageSender messageSender;
 
     //------------------------------------------------------------------------
     private DefaultMessageListenerContainer msgListenerCont;
-    
+
     @Override
     public void afterPropertiesSet() throws Exception {
         String queueName = RT2JmsProperties.DOCUMENT_QUEUE_NAME + clusterService.getLocalMemberUuid();
@@ -103,7 +102,7 @@ public class RT2DocProcessorJmsConsumer implements MessageListener, JmsMessageLi
             msgListenerCont = new DefaultMessageListenerContainer();
             ExponentialBackOff exponentialBackOff = new ExponentialBackOff();
             exponentialBackOff.setMaxInterval(60000);
-            msgListenerCont.setBackOff(exponentialBackOff);            
+            msgListenerCont.setBackOff(exponentialBackOff);
             msgListenerCont.setConnectionFactory(pooledConnectionFactoryProxy.getPooledConnectionFactory());
             msgListenerCont.setConcurrentConsumers(3);
             msgListenerCont.setDestination(this.queue);
@@ -143,7 +142,14 @@ public class RT2DocProcessorJmsConsumer implements MessageListener, JmsMessageLi
                 return;
             }
 
+            boolean joinRequest = RT2MessageType.REQUEST_JOIN.equals(rt2Msg.getType());
             log.debug("Received msg {}", rt2Msg.getHeader());
+            if (joinRequest) {
+                // ensure that join round-trip is logged on info
+                log.info("Received join_request");
+            }
+
+            RT2DocUidType docUid = rt2Msg.getDocUID();
             RT2DocProcessor rt2DocProc = docProcessorManager.getDocProcessor(rt2Msg.getDocUID());
             if (rt2DocProc == null) {
                 if (RT2MessageType.REQUEST_JOIN.equals(rt2Msg.getType())) {
@@ -155,10 +161,13 @@ public class RT2DocProcessorJmsConsumer implements MessageListener, JmsMessageLi
                     } catch (ValidationException ex) {
                         log.debug("No doc processor found for request message {}", rt2Msg);
                     }
-                } 
+                }
             }
             try {
                 if (rt2DocProc != null) {
+                    if (joinRequest) {
+                        log.info("Enqueueing join_request - com.openexchange.rt2.document.uid {}, com.openexchange.rt2.client.uid {}", docUid, rt2Msg.getClientUID().getValue());
+                    }
                     rt2DocProc.enqueueMessage(rt2Msg);
                 }
             } catch (RT2InvalidClientUIDException ex) {
@@ -169,7 +178,11 @@ public class RT2DocProcessorJmsConsumer implements MessageListener, JmsMessageLi
                 messageSender.sendErrorResponseToClient(rt2Msg.getClientUID(), rt2Msg, null, ex);
             }
         } finally {
-            MDC.clear();
+            MDC.remove(MDCEntries.DOC_UID);
+            MDC.remove(MDCEntries.CLIENT_UID);
+            MDC.remove(MDCEntries.BACKEND_PART);
+            MDC.remove(MDCEntries.BACKEND_UID);
+            MDC.remove(MDCEntries.REQUEST_TYPE);
         }
     }
 }
