@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.rt2.core.jms;
 
 import java.io.ByteArrayOutputStream;
@@ -123,9 +121,10 @@ public class RT2JmsMessageSender {
 
     public void sendToAdminTopic(RT2Message msg, RT2AdminIdType adminId) {
         msg.setAdminID(adminId);
-        MDC.put(MDCEntries.REQUEST_TYPE, msg.getType().getValue());
         try {
             log.debug("admin send request ''{}''...", msg);
+
+            MDC.put(MDCEntries.REQUEST_TYPE, msg.getType().getValue());
             String rt2MsgAsStr = msg.getBodyString();
             try {
                 jmsTemplateWithoutTtl.convertAndSend(RT2JmsDestination.adminTopic, rt2MsgAsStr, new RT2MessageJmsPostProcessor(msg));
@@ -133,7 +132,7 @@ public class RT2JmsMessageSender {
                 log.error("sendToAdminTopic-Exception", jmsEx);
             }
         } finally {
-            MDC.clear();
+            MDC.remove(MDCEntries.REQUEST_TYPE);
         }
     }
 
@@ -167,16 +166,20 @@ public class RT2JmsMessageSender {
 
         msg.setInternalBackendProcessingNode(nodeId);
         String queueName = RT2JmsProperties.DOCUMENT_QUEUE_NAME + nodeId;
-        MDC.put(MDCEntries.REQUEST_TYPE, msg.getType().getValue());
-        log.debug("Sending msg [{}] to documentQueue: [{}]", msg, queueName);
-        ActiveMQQueue activeMQQueue = new ActiveMQQueue(queueName);
-        String rt2MsgAsStr = msg.getBodyString();
-        docProxyRequestMetricService.stopTimer(msg.getMessageID());
         try {
-            jmsTemplateWithTtl.convertAndSend(activeMQQueue, rt2MsgAsStr, new RT2MessageJmsPostProcessor(msg));
-        } catch (JmsException jmsEx) {
-            log.error("sendToDocumentQueue-Exception", jmsEx);
-            throw new RT2TypedException(ErrorCode.GENERAL_SERVER_COMPONENT_NOT_WORKING_ERROR, new ArrayList<>(msgs));
+            MDC.put(MDCEntries.REQUEST_TYPE, msg.getType().getValue());
+            log.debug("Sending msg [{}] to documentQueue: [{}]", msg, queueName);
+            ActiveMQQueue activeMQQueue = new ActiveMQQueue(queueName);
+            String rt2MsgAsStr = msg.getBodyString();
+            docProxyRequestMetricService.stopTimer(msg.getMessageID());
+            try {
+                jmsTemplateWithTtl.convertAndSend(activeMQQueue, rt2MsgAsStr, new RT2MessageJmsPostProcessor(msg));
+            } catch (JmsException jmsEx) {
+                log.error("sendToDocumentQueue-Exception", jmsEx);
+                throw new RT2TypedException(ErrorCode.GENERAL_SERVER_COMPONENT_NOT_WORKING_ERROR, new ArrayList<>(msgs));
+            }
+        } finally {
+            MDC.remove(MDCEntries.REQUEST_TYPE);
         }
     }
 }
