@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -37,9 +37,7 @@ import java.util.Optional;
 import java.util.Set;
 import java.util.UUID;
 import java.util.stream.Collectors;
-
 import javax.jms.JMSException;
-
 import org.apache.activemq.ActiveMQConnectionFactory;
 import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
@@ -47,7 +45,6 @@ import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.jmx.export.annotation.ManagedResource;
 import org.springframework.stereotype.Service;
-
 import com.openexchange.office.rt2.core.DocProcessorMessageLoggerService;
 import com.openexchange.office.rt2.core.RT2DocProcessorExistsTester;
 import com.openexchange.office.rt2.core.RT2GarbageCollector;
@@ -87,7 +84,6 @@ import com.udojava.jmx.wrapper.JMXBean;
 import com.udojava.jmx.wrapper.JMXBeanAttribute;
 import com.udojava.jmx.wrapper.JMXBeanOperation;
 import com.udojava.jmx.wrapper.JMXBeanParameter;
-
 import ch.qos.logback.classic.spi.ILoggingEvent;
 
 @Service
@@ -96,10 +92,10 @@ import ch.qos.logback.classic.spi.ILoggingEvent;
 public class RT2BackendManagement {
 
     private static final Logger log = LoggerFactory.getLogger(RT2BackendManagement.class);
-        
+
     private static DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
 
-    //------------------------Services-----------------------------------------    
+    //------------------------Services-----------------------------------------
     @Autowired
     private RT2DocProcessorManager rt2DocProcessorManager;
 
@@ -108,34 +104,34 @@ public class RT2BackendManagement {
 
     @Autowired
     private DistributedDocInfoMap distributedDocInfoMap;
-            
+
     @Autowired
     private RT2GarbageCollector garbageCollector;
-    
+
     @Autowired
     private QueueProcessorDisposer queueProcessorDisposer;
-    
+
     @Autowired
     private RT2DocProcessorExistsTester docProcExistsTester;
-    
+
     @Autowired
     private ClusterLockService clusterLockService;
-    
+
     @Autowired
     private DocProcessorMessageLoggerService msgLoggerService;
-        
+
 	@Autowired
 	private MsgBackupAndAckProcessorService msgBackupAndAckProcessorService;
-    
+
 	@Autowired
 	private RT2ConfigService rt2ConfigService;
-	
+
     @Autowired
-    private PooledConnectionFactoryProxy pooledConnectionFactoryProxy;    
+    private PooledConnectionFactoryProxy pooledConnectionFactoryProxy;
 
     @Autowired
     private ClientEventService clientEventService;
-    
+
     @Autowired
     private SpecialLogService specialLogService;
 
@@ -144,10 +140,10 @@ public class RT2BackendManagement {
 
     @Autowired
     private SessiondService sessiondService;
-    
+
     @Autowired
     private CachingFacade cachingFacade;
-    
+
     @Autowired
     private ClusterService clusterService;
 
@@ -172,7 +168,7 @@ public class RT2BackendManagement {
     		clientEventService.notifyClientRemoved(new ClientEventData(new RT2DocUidType(docUid), new RT2CliendUidType(clientUid)));
     	}
     }
-    
+
     @JMXBeanAttribute(name="HazelcastUid")
 	public String getHazelcastUid() {
     	return clusterService.getLocalMemberUuid();
@@ -180,14 +176,14 @@ public class RT2BackendManagement {
 
     @JMXBeanOperation
     public Set<String> getClientsOfDocUid(@JMXBeanParameter(name="docUid") String docUid) {
-    	return distributedDocInfoMap.getClientsOfDocUid(new RT2DocUidType(docUid));  
+    	return distributedDocInfoMap.getClientsOfDocUid(new RT2DocUidType(docUid));
     }
-    
+
     @JMXBeanOperation
     public String getStatusOfDocUid(@JMXBeanParameter(name="docUid") String docUid) {
     	return distributedDocInfoMap.getStatus(new RT2DocUidType(docUid)).name();
     }
-    
+
 	@JMXBeanAttribute(name="RT2DocProxies")
 	public Map<String, String> getRT2DocProxies() {
         Map<String, String> res = new HashMap<>();
@@ -220,7 +216,7 @@ public class RT2BackendManagement {
     public int getCountRT2DocProxies() {
         return getRT2DocProxies().size();
     }
-	
+
 	@JMXBeanOperation(description="Sets the offline time of a doc proxy - use only for testing purpose")
 	public void setOfflineTimeOfRT2DocProxy(@JMXBeanParameter(name="clientUid") String clientUid, @JMXBeanParameter(name="docUid") String docUid, @JMXBeanParameter(name="offlineTime") long offlineTime) {
 		String id = RT2DocProxy.calcID(new RT2CliendUidType(clientUid.trim()), new RT2DocUidType(docUid.trim()));
@@ -240,7 +236,7 @@ public class RT2BackendManagement {
             .count() > 0;
 	}
 
-	@JMXBeanAttribute(name="DocProcessors")	
+	@JMXBeanAttribute(name="DocProcessors")
     public Map<String, String> getDocProcessors() {
         Map<String, String> res = new HashMap<>();
         for (WeakReference<RT2DocProcessor> ref : rt2DocProcessorManager.getWeakReferenceToDocProcessors()) {
@@ -314,7 +310,7 @@ public class RT2BackendManagement {
 	public String getDcsConnectionUrl() throws JMSException {
 		return ((ActiveMQConnectionFactory) pooledConnectionFactoryProxy.getPooledConnectionFactory().getConnectionFactory()).getBrokerURL();
 	}
-	
+
 	@JMXBeanAttribute(name="StatusMsgsWaitingForAckOfDoc")
 	public Map<String, String> getStatusMsgsWaitingForAckOfDoc() {
 		return msgBackupAndAckProcessorService.getStatusMsgsWaitingForAckOfDoc();
@@ -344,7 +340,7 @@ public class RT2BackendManagement {
 	public Set<String> getDocProxyMarkedForRemove() {
 		return docProcExistsTester.getMarkedForRemove().stream().map(p -> p.getValue()).collect(Collectors.toSet());
 	}
-	
+
 	@JMXBeanOperation
 	public boolean removeDocProxy(@JMXBeanParameter(name="clientUid") String clientUid, @JMXBeanParameter(name="docUid") String docUid) {
 		String id = RT2DocProxy.calcID(new RT2CliendUidType(clientUid.trim()), new RT2DocUidType(docUid.trim()));
@@ -363,14 +359,14 @@ public class RT2BackendManagement {
 			docProxy.setThrowExceptionOnLeave(value);
 		}
 	}
-	
+
 	@JMXBeanOperation
 	public List<String> getMsgsOfDocUid(@JMXBeanParameter(name="docUid") String docUid) {
 		List<ILoggingEvent> loggingEvents = new ArrayList<>(specialLogService.getLoggingEventsForDocUid(docUid));
 		Collections.sort(loggingEvents, (ILoggingEvent o1, ILoggingEvent o2)->new Long(o1.getTimeStamp()).compareTo(new Long(o2.getTimeStamp())));
 		return loggingEvents.stream().map(e -> e.getFormattedMessage()).collect(Collectors.toList());
 	}
-	
+
 	@JMXBeanOperation
 	public boolean removeDocProxy(@JMXBeanParameter(name="docProxyId") String docProxyId) {
 		RT2DocProxy docProxy = rt2DocRegistry.getDocProxy(docProxyId.trim());
@@ -450,9 +446,9 @@ public class RT2BackendManagement {
 		if (docProxy != null) {
 			return docProxy.formatMsgsLogInfo();
 		}
-		return Arrays.asList("Not found!");		
+		return Arrays.asList("Not found!");
 	}
-	
+
 	@JMXBeanOperation
 	public List<String> getMsgsOfDocProcessor(@JMXBeanParameter(name="docUid") String docUid) {
 		return msgLoggerService.formatMsgsLogInfo(new RT2DocUidType(docUid));
@@ -470,7 +466,7 @@ public class RT2BackendManagement {
 
 	@JMXBeanAttribute(name="CurrentJmsConnections")
 	public Set<String> getCurrentJmsConnections() throws Exception {
-		Set<String> res = new HashSet<>();		
+		Set<String> res = new HashSet<>();
 		EnhActiveMQSSLConnectionFactory amqConnFact = (EnhActiveMQSSLConnectionFactory) pooledConnectionFactoryProxy.getPooledConnectionFactory().getConnectionFactory();
 		amqConnFact.getConnections().forEach(c -> {
 			try {
@@ -481,7 +477,7 @@ public class RT2BackendManagement {
 		});
 		return res;
 	}
-	
+
 	@JMXBeanAttribute(name="MessageProcessorRunningThreadTime")
 	public Map<String, String> getMessageProcessorRunningThreadTime() {
 		Map<String, String> res = new HashMap<>();
@@ -503,7 +499,7 @@ public class RT2BackendManagement {
 		}
 		return false;
 	}
-	
+
 	@JMXBeanOperation
 	public List<String> getStackTraceOfMessageProcessorThread(@JMXBeanParameter(name="docUid") String docUid) {
 		List<String> res = new ArrayList<>();
@@ -525,7 +521,7 @@ public class RT2BackendManagement {
 		List<String> res = distributedLocks.stream().map(l -> l.getName() + ":" + l.getLockCount()).collect(Collectors.toList());
 		return res;
 	}
-	
+
 	@JMXBeanAttribute(name="RegisteredRT2LockObjects")
     public List<String> getRegisteredRT2LockObjects() {
     	return new ArrayList<>(clusterLockService.getLocks());
@@ -539,6 +535,14 @@ public class RT2BackendManagement {
 		}
 	}
 
+    @JMXBeanOperation
+    public void forceUnlockRT2LockObject(@JMXBeanParameter(name="docUid") String docUid) {
+        DistributedMap<String, String> hzLockMap = cachingFacade.getDistributedMap(ClusterLockService.LOCK_MAP_NAME, String.class, String.class);
+        if (hzLockMap.isLocked(ClusterLockService.LOCK_PREFIX + docUid)) {
+            hzLockMap.forceUnlock(ClusterLockService.LOCK_PREFIX + docUid);
+        }
+    }
+
 	@JMXBeanOperation
 	public void destroyRT2LockObject(@JMXBeanParameter(name="docUid") String docUid) {
 		unlockRT2LockObject(docUid);
@@ -595,7 +599,7 @@ public class RT2BackendManagement {
 		atomicLongsToGc.forEach((k, v) -> {
 			res.add("DocUid: " + k.getValue() + ", date: " + formatter.format(v));
 		});
-		return res;		
+		return res;
 	}
 
 	@JMXBeanAttribute(name="AtomicLongsToBeVerified")
@@ -607,5 +611,5 @@ public class RT2BackendManagement {
 		});
 		return res;
 	}
-	
+
 }
