@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -37,6 +37,7 @@ import com.hazelcast.core.HazelcastInstance;
 import com.hazelcast.core.HazelcastInstanceNotActiveException;
 import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.exception.OXException;
+import com.openexchange.health.MWHealthCheckService;
 import com.openexchange.office.rt2.core.RT2Constants;
 import com.openexchange.office.rt2.core.RemoveSessionListenerService;
 import com.openexchange.office.rt2.core.config.RT2ConfigService;
@@ -146,6 +147,7 @@ public class RT2CoreContextAndActivator extends OsgiBundleContextAndActivator {
 		res.add(HazelcastInstance.class);
 		res.add(RT2NodeHealthMap.class);
 		res.add(SessiondService.class);
+		res.add(MWHealthCheckService.class);
 		return res;
 	}
 	
