@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,7 +19,6 @@
  *
  */
 
-
 package com.openexchange.office.rt2.core.proxy;
 
 import java.util.Collections;
@@ -75,7 +74,7 @@ import com.openexchange.office.tools.common.log.Loggable;
 import com.openexchange.office.tools.service.cluster.ClusterService;
 
 //=============================================================================
-public class RT2DocProxy implements Loggable, IMessagesLoggable {    
+public class RT2DocProxy implements Loggable, IMessagesLoggable {
 
     public static final long TIMEOUT_HARD_CLOSE = 30000;
 
@@ -92,43 +91,43 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
     //---------------------------------Services--------------------------------
 
     @Autowired
-    private RT2DocProxyRegistry docProxyRegistry;    
-    
+    private RT2DocProxyRegistry docProxyRegistry;
+
     @Autowired
     private DistributedDocInfoMap distributedDocInfoMap;
-    
+
     @Autowired
     private RT2NodeInfoService rt2NodeInfo;
-    
+
     @Autowired
     private RT2JmsMessageSender jmsMessageSender;
-    
+
     @Autowired
     private RT2WSChannelDisposer channelDisposer;
-    
+
     @Autowired
     private MessageCounters messageCounters;
-    
+
     @Autowired
     private RT2DocProcessorManager docProcessorManager;
-    
+
     @Autowired
     private RT2GarbageCollector garbageCollector;
-    
+
     @Autowired
-    private RT2DocOnNodeMap rt2DocOnNodeMap;          
-    
+    private RT2DocOnNodeMap rt2DocOnNodeMap;
+
     @Autowired
     private DocProxyMessageLoggerService docProxyMessageLoggerService;
-    
+
     @Autowired
     private ClusterLockService clusterLockService;
 
 	@Autowired
 	private ClusterService clusterService;
-    
+
     private RT2CoreContextAndActivator contextAndActivator;
-    
+
     //-------------------------------------------------------------------------
     protected RT2DocProxyStateHolder docProxyStateHolder;
 
@@ -143,11 +142,11 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
     private final AtomicReference<RT2SessionIdType> sessionId;
 
     private Map<RT2MessageIdType, CompletableFuture<RT2Message>> waitingForResponseDuringCloseHard = Collections.synchronizedMap(new HashMap<>());
-    
+
     private boolean throwExceptionOnLeave = false;
-    
+
     //-------------------------------------------------------------------------
-    public RT2DocProxy (RT2CliendUidType clientUID, RT2DocUidType docUID, RT2ChannelId channelId, 
+    public RT2DocProxy (RT2CliendUidType clientUID, RT2DocUidType docUID, RT2ChannelId channelId,
     					RT2DocProxyStateHolder docProxyStateHolder, RT2SessionIdType sessionId) {
         this.clientUID = clientUID;
         this.docUID = docUID;
@@ -173,13 +172,13 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
     public String getID() {
     	return proxyID;
     }
-    
+
 	//-------------------------------------------------------------------------
     public void addMsgFromWebSocket(RT2Message msg) {
     	docProxyMessageLoggerService.addMessageForQueueToLog(Direction.FROM_JMS, msg);
    		docProxyConnectionStateHolder.goOnlineIfOffline();
     }
-    
+
     //-------------------------------------------------------------------------
     public void closeHard (Cause closeHardCause) throws RT2Exception
     {
@@ -188,14 +187,14 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
         log.debug("RT2: hard-close : wait for the results for proxy with id ''{}''...", getProxyID(), new Exception("DocProxy::closeHard"));
         CompletableFuture<RT2Message> resultFtrOfCloseLeaveMsg = new CompletableFuture<RT2Message>();
         resultFtrOfCloseLeaveMsg.thenAccept(msg -> {
-        	this.messageCounters.incCloseResponseCounter();            
+        	this.messageCounters.incCloseResponseCounter();
         	handleFinalLeave(msg);
         	this.messageCounters.incLeaveResponseCounter();
         	log.debug("RT2: hard-close : got response for proxy with id ''{}''...", getProxyID());
         });
-        waitingForResponseDuringCloseHard.put(closeLeaveMsg.getMessageID(), resultFtrOfCloseLeaveMsg);        
+        waitingForResponseDuringCloseHard.put(closeLeaveMsg.getMessageID(), resultFtrOfCloseLeaveMsg);
         sendRequest(closeLeaveMsg);
-        
+
         long waitTime = Long.parseLong(System.getProperty("TIMEOUT_HARD_CLOSE", Long.toString(TIMEOUT_HARD_CLOSE)));
         RT2Message responseMsg = null;
         try {
@@ -206,17 +205,17 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
         if (responseMsg == null) {
         	log.warn("RT2: hard-close : timeout : result of operation ''{}'' for docProxy with id ''{}'' is undefined !", closeLeaveMsg, getProxyID());
         }
-        
+
         log.debug("RT2: hard-close for docProxy with id ''{}'': DONE", getProxyID());
     }
-        
+
      //-------------------------------------------------------------------------
     public void join (final RT2Message aJoinRequest) throws Exception {
         LogMethodCallHelper.logMethodCall(this, "join", aJoinRequest.getHeader());
         this.messageCounters.incJoinRequestCounter();
 
         RT2MessageGetSet.setNodeUUID(aJoinRequest, clusterService.getLocalMemberUuid());
-        
+
         // Tricky part :
         // If this instance is already in "shutdown mode" ...
         // we need to sync with that operation.
@@ -230,19 +229,19 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
 
         final ClusterLock clusterLock = clusterLockService.getLock(docUID);
         boolean locked = false;
-        
+
         try {
 	        log.debug("Lock call by client [{}] for doc with id [{}]", clientUID, docUID);
         	locked = clusterLock.lock();
         	if (locked) {
 		        docProxyStateHolder.switchProxyStateOrFail(EDocProxyState.E_IN_JOIN);
-	        
+
 		        Set<RT2CliendUidType> remainingClients = distributedDocInfoMap.addClient(docUID, clientUID);
-		        int clientRefCount = remainingClients.size();	        
+		        int clientRefCount = remainingClients.size();
 		        final boolean bIsFirstJoin = (clientRefCount == 1L) && remainingClients.contains(clientUID);
-	
+
 		        if (bIsFirstJoin) {
-		        	log.debug("RT2: join context - accepted : is first");
+		            log.info("RT2: join context - accepted : com.openexchange.rt2.client.uid {} is first", clientUID.getValue());
 		        	rt2NodeInfo.registerDocOnNode(docUID);
 		        }
 		        else {
@@ -252,7 +251,7 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
 		        			log.warn("RT2: join context - clientRefCount is greater 0 but rt2DocOnNodeMap has no entry for docUID {}", docUID);
 		        			triggerGc = true;
 		        		} else {
-		        			log.debug("RT2: join context - accepted : is {}", clientRefCount);
+		        		    log.info("RT2: join context - accepted : ref-count {} and doc-processor located at node-uuid {}", clientRefCount, nodeId);
 		        		}
 		        	}
 		        	else {
@@ -266,7 +265,7 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
 			            // registered at the garbage collector service for verification and alternative
 			            // clean-up.
 			        	garbageCollector.registerDocRefCountForRemovalVerification(docUID);
-			
+
 			            log.info("RT2: join context - detected ref-count {} set by gc process - join must be aborted", clientRefCount);
 			            if (clientRefCount > RT2Constants.REF_COUNT_TRESHHOLD) {
 			            	throw new RT2TypedException(ErrorCode.GENERAL_NODE_IN_MAINTENANCE_MODE_ERROR, getMsgsAsList());
@@ -286,15 +285,17 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
                 clusterLock.unlock();
         	}
         }
-        
+
         if (triggerGc) {
+            log.info("RT2: join - trigger gc for doc-uid {}", docUID);
         	if (!garbageCollector.doGcForDocUid(docUID, true)) {
         		throw new RT2TypedException(ErrorCode.GENERAL_SYSTEM_BUSY_ERROR, getMsgsAsList());
-        	} 
+        	}
         	join(aJoinRequest);
         	return;
         }
         // forward join request to doc processor (which might exist on a different node).
+        log.info("RT2: send join_request via jms message sender");
         sendRequest (aJoinRequest);
     }
 
@@ -303,11 +304,11 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
         LogMethodCallHelper.logMethodCall(this, "leave", aLeaveRequest.getHeader());
         this.messageCounters.incLeaveRequestCounter();
        	docProxyStateHolder.checkDocumentAlreadyDisposed(getMsgsAsList());
-        
+
         Boolean bForce = RT2MessageGetSet.getInternalHeader(aLeaveRequest, RT2Protocol.HEADER_AUTO_CLOSE, false) ||
                 aLeaveRequest.isType(RT2MessageType.REQUEST_EMERGENCY_LEAVE);
         docProxyStateHolder.setForceQuit(bForce);
-        docProxyStateHolder.switchProxyStateOrFail(EDocProxyState.E_IN_LEAVE); 
+        docProxyStateHolder.switchProxyStateOrFail(EDocProxyState.E_IN_LEAVE);
         sendRequest(aLeaveRequest);
         if (throwExceptionOnLeave) {
         	log.error("Test exception");
@@ -343,7 +344,7 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
        	docProxyStateHolder.setAbortOpen(true);
         sendRequest (aAbortOpenRequest);
     }
-    
+
 	//-------------------------------------------------------------------------
 	public RT2SessionIdType getSessionId() {
 		return sessionId.get();
@@ -363,7 +364,7 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
     public void setOfflineTimeInMS(long offlineTime) {
     	docProxyConnectionStateHolder.setOfflineTimeInMS(offlineTime);
     }
-    
+
     //-------------------------------------------------------------------------
     public EDocProxyState getDocState() {
         return docProxyStateHolder.getProxyState();
@@ -374,12 +375,12 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
         return creationTime;
     }
 
-    //-------------------------------------------------------------------------    
+    //-------------------------------------------------------------------------
     public RT2ChannelId getChannelId() {
 		return channelId;
 	}
 
-	//-------------------------------------------------------------------------    
+	//-------------------------------------------------------------------------
     public boolean isOnline() {
     	return docProxyConnectionStateHolder.isOnline();
     }
@@ -453,15 +454,16 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
             switch (aResponse.getType()) {
                 case RESPONSE_UNAVAILABILITY: bForwardResponseToHandler = false;
                     break;
-                case RESPONSE_JOIN: 
+                case RESPONSE_JOIN:
+                    log.info("RT2: DocProxy join_response for client-uid {} received", aResponse.getClientUID());
                 	docProxyStateHolder.switchProxyStateOrFail(EDocProxyState.E_JOINED);
                 	this.messageCounters.incJoinResponseCounter();
                     break;
-                case RESPONSE_OPEN_DOC: 
+                case RESPONSE_OPEN_DOC:
                 	docProxyStateHolder.switchProxyStateOrFail(EDocProxyState.E_OPEN);
                 	this.messageCounters.incOpenResponseCounter();
                     break;
-                case RESPONSE_CLOSE_DOC: 
+                case RESPONSE_CLOSE_DOC:
                 	docProxyStateHolder.switchProxyStateOrFail(EDocProxyState.E_CLOSED);
                 	this.messageCounters.incCloseResponseCounter();
                     break;
@@ -473,7 +475,7 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
                 case BROADCAST_SHUTDOWN: handleRemoteNodeShutdown (aResponse);
                     break;
                 case RESPONSE_CLOSE_AND_LEAVE: bForwardResponseToHandler = false;
-                	handleCloseAndLeaveMsg(aResponse);                	
+                	handleCloseAndLeaveMsg(aResponse);
                 	break;
                 default: /* nothing to do */;
             }
@@ -493,9 +495,9 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
     public void sendRequest (final RT2Message aRequest) throws RT2TypedException
     {
         // For sync request check if proxy state is sufficient to handle it
-        if (RT2MessageType.REQUEST_SYNC.equals(aRequest.getType()) && !docProxyStateHolder.isProxyInOpenState()) {        	
+        if (RT2MessageType.REQUEST_SYNC.equals(aRequest.getType()) && !docProxyStateHolder.isProxyInOpenState()) {
         	throw new RT2TypedException(ErrorCode.GENERAL_DOCUMENT_ALREADY_DISPOSED_ERROR, getMsgsAsList());
-        }	
+        }
         jmsMessageSender.sendToDocumentQueue(aRequest, getMsgsAsList());
     }
 
@@ -538,7 +540,7 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
     		future.complete(closeAndLeaveMsg);
     	}
     }
-    
+
     //-------------------------------------------------------------------------
     private void handleRemoteNodeShutdown (final RT2Message aShutdownMsg) throws Exception {
         LogMethodCallHelper.logMethodCall(this, "handleRemoteNodeShutdown", aShutdownMsg.getHeader());
@@ -557,28 +559,28 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
         	final ClusterLock clusterLock = clusterLockService.getLock(docUID);
         	try {
 	        	locked = clusterLock.lock();
-	        	if (locked) {        		
+	        	if (locked) {
 		            distributedDocInfoMap.removeClient(docUID, clientUID);
-		
+
 		            // now it's time to deregister THIS proxy from global registry
 		            docProxyRegistry.deregisterDocProxy(this, true);
 		            log.debug("RT2DocProxy [{}] was shutdown...", this);
 		            docProxyStateHolder.switchProxyStateOrFail(EDocProxyState.E_SHUTDOWN);
-		
+
 		            rt2NodeInfo.setNodeShutdown(false);
 		            m_bJoinLeaveSyncPoint.countDown();
 	        	}
         	} finally {
 				if (locked) {
 					clusterLock.unlock();
-				}					
+				}
 			}
         }
     }
 
     //-------------------------------------------------------------------------
     private void syncJoinWithLeaveIfNeeded () throws RT2TypedException, InterruptedException {
-    	    	
+
         if ( !docProxyStateHolder.isInShutdown () && !rt2NodeInfo.isNodeShutdown()) {
             return;
         }
@@ -592,7 +594,7 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
         final boolean bOK = m_bJoinLeaveSyncPoint.await(5000, TimeUnit.MILLISECONDS);
         if ( ! bOK) {
         	log.error("System busy error!", new RT2TypedException (ErrorCode.GENERAL_SYSTEM_BUSY_ERROR, getMsgsAsList()));
-        	throw new RT2TypedException (ErrorCode.GENERAL_SYSTEM_BUSY_ERROR, getMsgsAsList());				
+        	throw new RT2TypedException (ErrorCode.GENERAL_SYSTEM_BUSY_ERROR, getMsgsAsList());
         }
         m_bJoinLeaveSyncPoint = new CountDownLatch((int) m_bJoinLeaveSyncPoint.getCount());
     }
@@ -628,7 +630,7 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
             res += msgsLogInfos.toString();
         }
         return res;
-    } 
+    }
 
     //-------------------------------------------------------------------------
     @Override
@@ -643,11 +645,11 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
     public List<String> formatMsgsLogInfo() {
     	return docProxyMessageLoggerService.formatMsgsLogInfo(getClientUID());
     }
-    
+
     private List<RT2LogInfo> getMsgsAsList() {
     	return docProxyMessageLoggerService.getMsgsAsList(getClientUID());
     }
-    
+
     //-------------------------------------------------------------------------
     @Override
     public Logger getLogger() {
@@ -668,19 +670,19 @@ public class RT2DocProxy implements Loggable, IMessagesLoggable {
     public RT2DocUidType getDocUID () {
         return docUID;
     }
-    
+
     //-------------------------------------------------------------------------
     public void markProxyAsDisposed() throws RT2Exception {
     	docProxyMessageLoggerService.add(docUID, Direction.INTERNAL, "forceCleanup", clientUID);
         docProxyStateHolder.switchProxyStateOrFail(EDocProxyState.E_SHUTDOWN);
     }
 
-    //-------------------------------------------------------------------------    
+    //-------------------------------------------------------------------------
 	public void setContextAndActivator(RT2CoreContextAndActivator contextAndActivator) {
 		this.contextAndActivator = contextAndActivator;
 	}
 
-    //-------------------------------------------------------------------------	
+    //-------------------------------------------------------------------------
 	public void setThrowExceptionOnLeave(boolean throwExceptionOnLeave) {
 		this.throwExceptionOnLeave = throwExceptionOnLeave;
 	}
