@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -54,27 +54,27 @@ import com.openexchange.office.tools.service.logging.MDCEntries;
 @Service
 @Async(initialDelay=ClientLeftRemovedService.FREQ_CLEANUP_CLIENTS_LEFT, period=ClientLeftRemovedService.FREQ_CLEANUP_CLIENTS_LEFT, timeUnit=TimeUnit.MILLISECONDS)
 public class ClientLeftRemovedService implements Runnable, IDocProcessorEventListener, IClientEventListener {
-	
+
 	private static final Logger log = LoggerFactory.getLogger(ClientLeftRemovedService.class);
-	
+
 	//-------------------------------------------------------------------------	
 	public static final long TIME_CLEANUP_CLIENTS_LEFT = 300000;
-	
+
 	public static final long FREQ_CLEANUP_CLIENTS_LEFT = 60000;
 
 	//--------------------------Services--------------------------------------	
 	@Autowired
 	private ClientSequenceQueueDisposerService clientSequenceQueueDisposerService;
-	
+
 	@Autowired
 	private RT2MessageSender messageSender;
-	
+
 	@Autowired
 	private DocProcessorMessageLoggerService messageLoggerService;
-	
+
 	@Autowired
 	private ClusterService clusterService;
-	
+
 	//-------------------------------------------------------------------------
 	private final ConcurrentHashMap<RT2DocUidType, Map<RT2CliendUidType, Long>> clientsLeft = new ConcurrentHashMap<>();
 
@@ -82,7 +82,7 @@ public class ClientLeftRemovedService implements Runnable, IDocProcessorEventLis
 	public void addClientLeft(RT2DocUidType docUid, RT2CliendUidType clientUid) {
 		getClientMapOfDoc(docUid).put(clientUid, System.currentTimeMillis());
 	}
-	
+
 	//-------------------------------------------------------------------------
 	public long getClientLeft(RT2DocUidType docUid, RT2CliendUidType clientUid) {
 		Map<RT2CliendUidType, Long> clientMap = getClientMapOfDoc(docUid);
@@ -91,11 +91,11 @@ public class ClientLeftRemovedService implements Runnable, IDocProcessorEventLis
 		}
 		return -1l;
 	}
-	
+
 	//-------------------------------------------------------------------------	
     public boolean checkStateIfClientUnknown(final RT2DocUidType docUid, final RT2CliendUidType sClientUID, final RT2Message msgFromUnknownClient) throws RT2InvalidClientUIDException {
     	final RT2MessageType msgType = msgFromUnknownClient.getType();
-    	
+
 		switch (msgType) {
 			case ACK_SIMPLE:
 			case NACK_SIMPLE: {
@@ -125,7 +125,7 @@ public class ClientLeftRemovedService implements Runnable, IDocProcessorEventLis
 		log.warn("RT2: received message {} with unknown client-uid {}", msgFromUnknownClient, sClientUID);
 		throw new RT2InvalidClientUIDException(messageLoggerService.getMsgsAsList(docUid));
     }
-		
+
 	//-------------------------------------------------------------------------	
 	@Override
 	public void run() {
@@ -149,15 +149,15 @@ public class ClientLeftRemovedService implements Runnable, IDocProcessorEventLis
 				} catch (Exception ex) {
 					log.warn(ex.getMessage());
 				}
-			}			
+			}
 		});
 	}
-	
+
 	private void checkIfClientHasToBeRemoved() {
 		try {
 			MDC.put(MDCEntries.BACKEND_PART, "ClientLeftRemoveThread");
-			MDC.put(MDCEntries.BACKEND_UID, clusterService.getLocalMemberUuid());        												
-	        
+			MDC.put(MDCEntries.BACKEND_UID, clusterService.getLocalMemberUuid());
+
 			final long now = System.currentTimeMillis();
 
 			clientsLeft.values().forEach(c -> {
@@ -168,10 +168,13 @@ public class ClientLeftRemovedService implements Runnable, IDocProcessorEventLis
 				clientsToCleanup.forEach(k -> { c.remove(k); });
 				if ((clientsToCleanup != null) && (!clientsToCleanup.isEmpty())) {
 					log.debug("RT2: removing {} left client-uids after timeout", clientsToCleanup.size());
-				}				
+				}
 			});
 		} catch (Exception e) {
             log.warn("RT2: Exception caught while trying to lazy remove stored left client-uids", e);
+		} finally {
+			MDC.remove(MDCEntries.BACKEND_PART);
+			MDC.remove(MDCEntries.BACKEND_UID);
 		}
 	}
 
@@ -179,10 +182,10 @@ public class ClientLeftRemovedService implements Runnable, IDocProcessorEventLis
 	private static boolean needToCleanupClientUID(final Long time, long now) {
 		return (time != null) ? ((now - time) >= TIME_CLEANUP_CLIENTS_LEFT) : false;
 	}
-	
+
 	@Override
 	public void docCreated(RT2DocUidType docUid) {
-		if (clientsLeft.put(docUid, Collections.synchronizedMap(new HashMap<>())) != null) {			
+		if (clientsLeft.put(docUid, Collections.synchronizedMap(new HashMap<>())) != null) {
 			log.warn("New doc added, but old doc with doc-uid {} found! Overwrite it!", docUid);
 		}
 	}
@@ -202,7 +205,7 @@ public class ClientLeftRemovedService implements Runnable, IDocProcessorEventLis
 			clientsLeft.get(clientEventData.getDocUid()).remove(clientEventData.getClientUid());
 		}
 	}
-	
+
 	private Map<RT2CliendUidType, Long> getClientMapOfDoc(RT2DocUidType docUid) {
 		Map<RT2CliendUidType, Long> newMap = Collections.synchronizedMap(new HashMap<>());
 		Map<RT2CliendUidType, Long> oldMap = clientsLeft.putIfAbsent(docUid, newMap);
