@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.rt2.core.ws;
 
 import java.lang.ref.WeakReference;
@@ -98,10 +96,11 @@ public class ChannelStore {
     public boolean remove(RT2EnhDefaultWebSocket ws) {
     	if (ws != null) {
     		synchronized(channels) {
-        		final ChannelData channelData = channels.get(ws.getId());
+    			final RT2ChannelId id = ws.getId();
+        		final ChannelData channelData = channels.get(id);
         		if ((channelData != null) && (channelData.creationTime == ws.getCreationTime())) {
-        			channels.remove(ws.getId());
-        			log.debug("websocket {} with id {} removed from ChannelStore");
+        			channels.remove(id);
+        			log.debug("websocket {} with id {} removed from ChannelStore", ws, id);
         			return true;
         		}
     		}
