@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.rt2.core.ws;
 
 import java.nio.charset.MalformedInputException;
@@ -81,7 +79,7 @@ public class RT2WSChannelDisposer implements DisposableBean {
 
 	@Autowired
 	private DocProxyResponseMetricService docProxyResponseMetricService;
-	
+
 	@Autowired
 	private RT2ConfigService rt2ConfigService;
 
@@ -90,7 +88,7 @@ public class RT2WSChannelDisposer implements DisposableBean {
 
 	@Autowired
 	private ClusterService clusterService;
-	
+
 	//------------------------------------------------------------------------
 	private final Map<RT2CliendUidType, Pair<RT2DocUidType, RT2ChannelId>> channels = new ConcurrentHashMap<>();
 
@@ -105,7 +103,7 @@ public class RT2WSChannelDisposer implements DisposableBean {
 	private final ScheduledExecutorService detectNonActiveClientsExecutorService = Executors.newSingleThreadScheduledExecutor(new ThreadFactoryBuilder("RT2ChannelDetectNonActiveClients-%d").build());
 
 	private long gcTimeout;
-	
+
 	private AtomicBoolean stopped = new AtomicBoolean(false);
 
 	public void startExecuterServices() {
@@ -205,15 +203,18 @@ public class RT2WSChannelDisposer implements DisposableBean {
 
 	public void removeClientUid(RT2CliendUidType clientUid) {
 		log.debug("removeClient client-uid {} from channels", clientUid);
-		RT2ChannelId channelId = channels.get(clientUid).getValue();		
+		RT2ChannelId channelId = channels.get(clientUid).getValue();
 		channels.remove(clientUid);
 		channelsOffline.remove(channelId);
 	}
 
 	static int sendBack = 0;
-	
+
  	public void addMessageToResponseQueue(RT2Message msg) {
  		log.debug("sendBack: {}", msg.getHeader());
+ 		if (RT2MessageType.RESPONSE_JOIN.equals(msg.getType())) {
+ 		    log.info("add join_response to response queue for client-uid {}", msg.getClientUID().getValue());
+ 		}
 		this.responseQueue.add(msg);
 	}
 
@@ -257,8 +258,15 @@ public class RT2WSChannelDisposer implements DisposableBean {
                         	MDC.put(MDCEntries.DOC_UID, responseMsg.getDocUID().getValue());
                         	docProxyMessageLoggerService.add(responseMsg.getDocUID(), Direction.TO_WS, responseMsg.getType().getValue(), responseMsg.getClientUID());
                         }
+
+                        RT2MessageType msgType = responseMsg.getType();
                        	MDC.put(MDCEntries.CLIENT_UID, responseMsg.getClientUID().getValue());
-                        MDC.put(MDCEntries.REQUEST_TYPE, responseMsg.getType().getValue());                        
+                        MDC.put(MDCEntries.REQUEST_TYPE, responseMsg.getType().getValue());
+                        MDC.put(MDCEntries.CLIENT_UID, responseMsg.getClientUID().getValue());
+                        MDC.put(MDCEntries.REQUEST_TYPE, msgType.getValue());
+                        if (RT2MessageType.RESPONSE_JOIN.equals(msgType)) {
+                            log.info("Sending join_response to ws client");
+                        }
                         log.debug("Sending response [{}] to ws client", responseMsg.getHeader());
 
                         final RT2CliendUidType clientUid = responseMsg.getClientUID();
@@ -273,7 +281,7 @@ public class RT2WSChannelDisposer implements DisposableBean {
                        				GrizzlyFuture<DataFrame> fut = webSocket.send(sResponse);
                        				fut.get(3, TimeUnit.SECONDS);
                        				webSocket.close(WebSocket.ABNORMAL_CLOSE);
-                       			} else {                       				
+                       			} else {
                        				webSocket.send (sResponse);
                        			}
                        		} else {
@@ -308,9 +316,12 @@ public class RT2WSChannelDisposer implements DisposableBean {
                     com.openexchange.exception.ExceptionUtils.handleThrowable(ex);
                     log.error(ex.getMessage(), ex);
                 } finally {
-
+                    MDC.remove(MDCEntries.DOC_UID);
+                    MDC.remove(MDCEntries.CLIENT_UID);
+                    MDC.remove(MDCEntries.REQUEST_TYPE);
 				}
 			}
+			MDC.clear();
 		}
 	}
 
@@ -345,41 +356,41 @@ public class RT2WSChannelDisposer implements DisposableBean {
 		}
 	}
 
-	class RT2WSChannelKeepAliveThread implements Runnable {
+    class RT2WSChannelKeepAliveThread implements Runnable {
 
-		@Override
-		public void run() {
-			// DOCS-1396: make sure that an exception doesn't lead to a cancellation
-			// of this periodically called implementation (vital keep alive code which
-			// triggers ping-messages).
-			log.trace("Running keepAliveThread...");
+        @Override
+        public void run() {
+            // DOCS-1396: make sure that an exception doesn't lead to a cancellation
+            // of this periodically called implementation (vital keep alive code which
+            // triggers ping-messages).
+            log.trace("Running keepAliveThread...");
             webSocketApplication.getCurrentActiveWebsocketIds().parallelStream().forEach(id -> {
-            	MDC.put(MDCEntries.BACKEND_PART, "RT2WSChannelKeepAliveThread");
-            	MDC.put(MDCEntries.BACKEND_UID, clusterService.getLocalMemberUuid());
-            	try {
-					final RT2EnhDefaultWebSocket webSocket = webSocketApplication.getWebSocketWithId(id);
-					if (webSocket != null) {
-						webSocket.sendPing();
-					}
-            	} catch (Throwable t) {
-            		com.openexchange.exception.ExceptionUtils.handleThrowable(t);
-            		log.warn(t.getMessage(), t);
-            	} finally {
-            		MDC.clear();
-				}
+                try {
+                    MDC.put(MDCEntries.BACKEND_PART, "RT2WSChannelKeepAliveThread");
+                    MDC.put(MDCEntries.BACKEND_UID, clusterService.getLocalMemberUuid());
+                    final RT2EnhDefaultWebSocket webSocket = webSocketApplication.getWebSocketWithId(id);
+                    if (webSocket != null) {
+                        webSocket.sendPing();
+                    }
+                } catch (Throwable t) {
+                    com.openexchange.exception.ExceptionUtils.handleThrowable(t);
+                    log.warn(t.getMessage(), t);
+                } finally {
+                    MDC.clear();
+                }
             });
-		}
-	}
+        }
+    }
 
 	class RT2WSChannelDetectNonActiveClientsThread implements Runnable {
 
-		@Override
-		public void run() {
-			log.trace("Checking for non-active clients...");
+        @Override
+        public void run() {
+            log.trace("Checking for non-active clients...");
             webSocketApplication.getCurrentActiveWebsocketIds().parallelStream().forEach(id -> {
-            	MDC.put(MDCEntries.BACKEND_PART, "RT2WSChannelKeepAliveThread");
-            	MDC.put(MDCEntries.BACKEND_UID, clusterService.getLocalMemberUuid());
-            	try {
+                try {
+                    MDC.put(MDCEntries.BACKEND_PART, "RT2WSChannelKeepAliveThread");
+                    MDC.put(MDCEntries.BACKEND_UID, clusterService.getLocalMemberUuid());
 					final RT2EnhDefaultWebSocket webSocket = webSocketApplication.getWebSocketWithId(id);
 					if (webSocket != null) {
 						if (webSocket.isAvaible()) {
