@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,7 +19,6 @@
  *
  */
 
-
 package com.openexchange.office.rt2.core.ws;
 
 import java.net.MalformedURLException;
@@ -160,7 +159,7 @@ public class RT2WebSocketListener implements WebSocketListener, DisposableBean {
 		rt2WebSocket.updateLastRecMsgTime();
 		RT2Message request = null;
 		try {
-			request = RT2MessageFactory.fromJSONString(msg);		
+			request = RT2MessageFactory.fromJSONString(msg);
 		} catch (JSONException | ValidationException ex) {
 			log.warn(ex.getMessage(), ex);
 			return;
@@ -168,7 +167,7 @@ public class RT2WebSocketListener implements WebSocketListener, DisposableBean {
 		try {
 			if (request.getType() == RT2MessageType.PONG) {
 				log.debug("RT2: pong msg {} received from ws {}", msg, socket);
-				onPong(socket, data);				
+				onPong(socket, data);
 				Set<Pair<RT2CliendUidType, RT2DocUidType>> clientDocPairsAssociatedToChannel = channelDisposer.getClientDocPairsAssociatedToChannel(rt2WebSocket.getId());
 				clientDocPairsAssociatedToChannel.stream().forEach(p -> {
 					RT2DocProxy docProxy =  docProxyRegistry.getDocProxy(p.getKey(), p.getValue());
@@ -184,16 +183,16 @@ public class RT2WebSocketListener implements WebSocketListener, DisposableBean {
 				rt2WebSocket.setAvaible(true);
 				channelDisposer.notifyUnavailability(Direction.FROM_WS, rt2WebSocket, 0);
 			}
-        } catch (final Throwable ex) {        	
+        } catch (final Throwable ex) {
             log.error(ex.getMessage(), ex);
             // no further handling !
             // All responses was send within impl_handleRequest() already !
         } finally {
         	MDC.clear();
             rt2WebSocket.setCurrentlyProcessingRequest(false);
-        }					
+        }
 	}
-	
+
 	@Override
 	public void onMessage(WebSocket socket, byte[] bytes) {
 		onMessage(socket, new String(bytes));
@@ -323,6 +322,7 @@ public class RT2WebSocketListener implements WebSocketListener, DisposableBean {
 				websocketResponseMetriceService.incMessageFailed(request.getMessageID());				
 			}
 			websocketResponseMetriceService.stopTimer(request.getMessageID());
+			resetMDCVariables();
 		}
     }
 
@@ -424,6 +424,15 @@ public class RT2WebSocketListener implements WebSocketListener, DisposableBean {
         MDC.put(MDCEntries.REQUEST_TYPE, aRequest.getType().getValue());
     }
 
+    //-------------------------------------------------------------------------	
+	private void resetMDCVariables() {
+        MDC.remove(MDCEntries.DOC_UID);
+        MDC.remove(MDCEntries.CLIENT_UID);
+        MDC.remove(MDCEntries.BACKEND_PART);
+        MDC.remove(MDCEntries.BACKEND_UID);
+        MDC.remove(MDCEntries.REQUEST_TYPE);
+	}
+
     //-------------------------------------------------------------------------
     private void startMetricsMeasurement(final RT2Message aRequest) {
     	if (websocketResponseMetriceService != null) {
