@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.spellcheck.impl.client;
 
 import java.io.IOException;
@@ -78,10 +76,11 @@ import com.openexchange.timer.TimerService;
 @RegisteredService(registeredClass = Reloadable.class)
 public class SpellCheckClient implements InitializingBean, Reloadable, IValidator, ISpellCheck {
 
+    final public static String CONFIG_KEY_SPELLCHECK_SERVICE_URL = "com.openexchange.office.spellcheck.remoteURL";
+
     final private static String HTTPSERVER_ID_SPELLCHECK = "77fdc062-570b-11ea-91c3-8bd6e5445cb5";
 
     final private static String CONFIG_KEY_SPELLCHECK_ENABLED = "io.ox/office//module/spellingEnabled";
-    final private static String CONFIG_KEY_SPELLCHECK_SERVICE_URL = "com.openexchange.office.spellcheck.remoteURL";
 
     final private static String CONFIG_DEFAULT_SPELLCHECK_SERVICE_URL = "http://localhost:8003";
 
@@ -153,7 +152,7 @@ public class SpellCheckClient implements InitializingBean, Reloadable, IValidato
             // try connection in 15s
             if (null != m_timerService) {
                 m_timerService.schedule(() -> {
-                    m_versionValidator.getVersion();
+                    m_versionValidator.getVersion(false);
                 }, 15000);
             }
         }
@@ -333,6 +332,20 @@ public class SpellCheckClient implements InitializingBean, Reloadable, IValidato
         // TODO (KA): check if nothing is to be done!
     }
 
+    /**
+     * @return
+     */
+    public String getSpellCheckURL() {
+        return m_spellCheckURL;
+    }
+
+    /**
+     * @return
+     */
+    public boolean isHealthy() {
+        return m_versionValidator.isHealthy();
+    }
+
     // - Implementation --------------------------------------------------------
 
     /**
@@ -350,6 +363,9 @@ public class SpellCheckClient implements InitializingBean, Reloadable, IValidato
 
             if (StringUtils.isBlank(spellCheckServiceUrlStr)) {
                 spellCheckServiceUrlStr = CONFIG_DEFAULT_SPELLCHECK_SERVICE_URL;
+
+                LOG.info("SpellCheck client service URL is not set via config item {}. Using default service URL {}",
+                    CONFIG_KEY_SPELLCHECK_SERVICE_URL, CONFIG_DEFAULT_SPELLCHECK_SERVICE_URL);
             }
 
             if (StringUtils.isNotBlank(spellCheckServiceUrlStr)) {
