@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -19,8 +19,6 @@
  *
  */
 
-
-
 package com.openexchange.office.tools.common;
 
 public class TimeStampUtils {
@@ -37,6 +35,10 @@ public class TimeStampUtils {
 		return (end > start) ? end - start : start - end;
 	}
 
+	public static long nanoToMillis(long time) {
+	    return (time / 1000000);
+	}
+
 	public static boolean inBetween(long start, long end, long timeStamp) {
 	    return ((start <= timeStamp) && (timeStamp <= end));
 	}
