@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -92,41 +92,41 @@ import com.udojava.jmx.wrapper.JMXBeanWrapper;
 public abstract class OsgiBundleContextAndActivator extends HousekeepingActivator implements ServiceLookup, ListableBeanFactory {
 
 	public static final String IN_UNIT_TEST = "IN_UNIT_TEST";
-	
+
 	protected List<Object> services = new ArrayList<>();
-	
-	private Set<ServiceRegistration<?>> serviceRegistrations = new HashSet<>(); 
-	
+
+	private Set<ServiceRegistration<?>> serviceRegistrations = new HashSet<>();
+
 	protected Set<Class<?>> neededServices = null;
 	private Set<Class<?>> optionalServices = null;
-	
+
 	private Set<Class<?>> classesOfBundle = null;
-	
+
 	private List<ScheduledExecutorService> scheduledExecutorServices = new ArrayList<>();
-	
+
 	private final IOsgiBundleContextIdentificator bundleIdentificator;
-	
+
 	private Map<String, Class<?>> classNameToClassInstanceMapping = new HashMap<>();
-	
+
 	private final AtomicBoolean stopped = new AtomicBoolean(true);
-	
+
 	private Logger log = null;
-	
+
 	private boolean loggedNeededServices = false;
 
 	private boolean bundleContainsNoServices = false;
-	
+
 	protected boolean logEntry(String entry) {
 		return true;
 	}
-	
+
 	protected Logger getLogger() {
 		if (log == null) {
 			log = LoggerFactory.getLogger(this.getClass());
 		}
 		return log;
 	}
-	
+
 	protected OsgiBundleContextAndActivator(IOsgiBundleContextIdentificator bundleIdentificator) {
 		this.bundleIdentificator = bundleIdentificator;
 	}
@@ -139,38 +139,38 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 	protected String getBundleId() {
 		return bundleIdentificator.getName();
 	}
-	
+
 	@Override
 	protected Class<?>[] getNeededServices() {
 		initNeededAndOptionalServices();
 		neededServices.addAll(getAdditionalNeededServices());
 		Class<?>[] res = neededServices.toArray(new Class<?>[0]);
-		if (!loggedNeededServices) {		    
+		if (!loggedNeededServices) {
 		    String packageName = "com.openexchange.";
-		    Set<String> logSet = 
+		    Set<String> logSet =
 		    		neededServices.stream()
 		    				.map(c -> c.getName())
 		    				.map(s -> s.startsWith(packageName) ? s.substring(packageName.length()) : s)
-		    				.collect(Collectors.toSet());	    
+		    				.collect(Collectors.toSet());
 			getLogger().info("Needed services of bundle with id " + getBundleId() + ": " + Arrays.toString(logSet.toArray()));
 			loggedNeededServices = true;
 		}
 		return res;
 	}
-	
+
 	protected Set<Class<?>> getServicesOfModuleWithForeignPackage() {
 		return Collections.emptySet();
 	}
-	
+
 	protected Set<Class<?>> getAdditionalNeededServices() {
 		return Collections.emptySet();
 	}
-	
+
 	protected Class<?>[] getOptionalServices() {
 		initNeededAndOptionalServices();
 		return optionalServices.toArray(new Class<?>[0]);
 	}
-	
+
 	protected void initNeededAndOptionalServices() {
 		if ((neededServices == null) || (optionalServices == null)) {
 			neededServices = new HashSet<>();
@@ -179,7 +179,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 			getClassesOfBundle();
 			classesOfBundle.forEach(c -> {
 				getDependenciesOfClass(c, true);
-			});		
+			});
 			getAdditionalDependenciesOfClasses().forEach(c -> {
 				getDependenciesOfClass(c, false);
 			});
@@ -188,29 +188,29 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 			optionalServices.removeAll(neededServices);
 		}
 	}
-	
+
 	protected Set<Class<?>> getClassesOfBundle() {
 		if (classesOfBundle == null) {
 			classesOfBundle = new HashSet<>();
 			final Bundle bundle = FrameworkUtil.getBundle(bundleIdentificator.getClass());
 			String topLevelPackage = bundleIdentificator.getClass().getPackage().getName().substring(0, bundleIdentificator.getClass().getPackage().getName().length() - 5);
-			
+
 		    BundleWiring bundleWiring = bundle.adapt(BundleWiring.class);
-	
+
 		    // Getting all the class files (also from imported packages)
-		    Set<String> resources = new HashSet<>(); 
+		    Set<String> resources = new HashSet<>();
 		    resources.addAll(bundleWiring.listResources("/", "*.class", BundleWiring.LISTRESOURCES_RECURSE));
 		    getLogger().debug("Classes of bundle with LISTRESOURCES_RECURSE: {}", bundleWiring.listResources("/", "*.class", BundleWiring.LISTRESOURCES_RECURSE));
 		    resources.addAll(bundleWiring.listResources("/", "*.class", BundleWiring.FINDENTRIES_RECURSE));
 		    getLogger().debug("Classes of bundle with FINDENTRIES_RECURSE: {}", bundleWiring.listResources("/", "*.class", BundleWiring.FINDENTRIES_RECURSE));
 		    resources.addAll(bundleWiring.listResources("/", "*.class", BundleWiring.LISTRESOURCES_LOCAL));
-		    getLogger().debug("Classes of bundle with LISTRESOURCES_LOCAL: {}", bundleWiring.listResources("/", "*.class", BundleWiring.LISTRESOURCES_LOCAL));		    
+		    getLogger().debug("Classes of bundle with LISTRESOURCES_LOCAL: {}", bundleWiring.listResources("/", "*.class", BundleWiring.LISTRESOURCES_LOCAL));
 		    getLogger().debug("All classes of bundle with class path scanning: " + Arrays.toString(resources.toArray()));
 		    resources = resources.stream().
 		    		map(str -> generateNormalClassNameOfOsgiClassName(str)).
 		    		filter(str -> str.startsWith(topLevelPackage)).collect(Collectors.toSet());
 	    	getLogger().info("Classes of bundle {} with class path scanning: {}", bundle.getSymbolicName(), reduceLoggingEntriesByMainPackageName(resources));
-		    for (String className : resources) {	    		
+		    for (String className : resources) {
 	    		try {
 	    			Class<?> clazz = bundleWiring.getClassLoader().loadClass(className);
 	    			classNameToClassInstanceMapping.put(className, clazz);
@@ -225,26 +225,26 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 		    } else {
 		    	getLogger().debug("Classes of bundle {}: {}", getBundleId(), classesOfBundle);
 		    }
-		    
+
 		}
-	    return classesOfBundle;	    
+	    return classesOfBundle;
 	}
-	
+
 	private Collection<String> reduceLoggingEntriesByMainPackageName(Collection<String> toReduce) {
 	    String packageNameWithOsgi = bundleIdentificator.getClass().getPackage().getName();
 	    String packageName = packageNameWithOsgi.substring(0, packageNameWithOsgi.length() - 4);
-	    Set<String> logSet = 
+	    Set<String> logSet =
 	    		toReduce.stream()
 	    				.filter(s -> logEntry(s) && !s.startsWith("com.openexchange.office.tools.service.validation."))
 	    				.map(s -> s.startsWith(packageName) ? s.substring(packageName.length()) : s)
-	    				.collect(Collectors.toSet());	    
+	    				.collect(Collectors.toSet());
 	    return logSet;
 	}
-	
+
 	private static String generateNormalClassNameOfOsgiClassName(String osgiClassname) {
 		return osgiClassname.replaceAll("\\.class$", "").replace('/', '.').replaceAll("bin\\.", "");
 	}
-	
+
 	public Collection<Class<?>> getMandantoryDependenciesOfClass(Class<?> clazz) {
 		Collection<Class<?>> res = new HashSet<>();
 		if ((clazz != null) && !clazz.equals(Object.class)) {
@@ -254,44 +254,49 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 				Class<?> fieldClass = field.getType();
 				Autowired autowiredAnno = field.getAnnotation(Autowired.class);
 				if (autowiredAnno != null) {
-					if (autowiredAnno.required()) {		
-						res.add(fieldClass);								
+					if (autowiredAnno.required()) {
+						res.add(fieldClass);
 					}
 				}
 			}
 			res.addAll(getMandantoryDependenciesOfClass(clazz.getSuperclass()));
-		}		
+		}
 		return res;
 	}
-	
-	protected void getDependenciesOfClass(Class<?> clazz, boolean isSingletonService) {		
+
+	protected void getDependenciesOfClass(Class<?> clazz, boolean isSingletonService) {
 		if (isSingletonService && (clazz.getAnnotation(RestController.class) == null) && (clazz.getAnnotation(Service.class) == null) && (clazz.getAnnotation(org.springframework.stereotype.Component.class) == null)) {
 			return;
 		}
 		if ((clazz != null) && !clazz.equals(Object.class)) {
-			Field [] fields = clazz.getDeclaredFields();
-			for (Field field : fields) {
-				field.setAccessible(true);
-				Class<?> fieldClass = field.getType();
-				if (!classesOfBundle.contains(fieldClass)) {
-					Autowired autowiredAnno = field.getAnnotation(Autowired.class);
-					if (autowiredAnno != null) {
-						if (autowiredAnno.required()) {		
-							neededServices.add(fieldClass);								
-						} else {
-							optionalServices.add(fieldClass);
-						}
-					}
-				}
-			}
-			getDependenciesOfClass(clazz.getSuperclass(), false);
+		    try {
+	            Field [] fields = clazz.getDeclaredFields();
+	            for (Field field : fields) {
+	                field.setAccessible(true);
+	                Class<?> fieldClass = field.getType();
+	                if (!classesOfBundle.contains(fieldClass)) {
+	                    Autowired autowiredAnno = field.getAnnotation(Autowired.class);
+	                    if (autowiredAnno != null) {
+	                        if (autowiredAnno.required()) {
+	                            neededServices.add(fieldClass);
+	                        } else {
+	                            optionalServices.add(fieldClass);
+	                        }
+	                    }
+	                }
+	            }
+	            getDependenciesOfClass(clazz.getSuperclass(), false);
+		    } catch (Throwable t) {
+                ExceptionUtils.handleThrowable(t);
+                getLogger().error("Exception caught trying to get dependencies for class {}", clazz.getCanonicalName(), t);
+		    }
 		}
 	}
-	
+
 	protected Set<Class<?>> getAdditionalDependenciesOfClasses() {
 		return Collections.emptySet();
 	}
-	
+
 	@Override
 	protected void handleUnavailability(Class<?> clazz) {
 	    getLogger().info("{} is handling unavailibility of needed service {}. Going to stop bundle.", getBundleId(), clazz.getSimpleName());
@@ -313,20 +318,20 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 	        } catch (Exception e) {
 	            getLogger().error("Error while starting bundle.", e);
 	        }
-	    }		
+	    }
 	}
 
 	@Override
 	protected void startBundle() throws Exception {
 		if (stopped.compareAndSet(true, false)) {
-		    getLogger().info("activate bundle with id {} ...", getBundleId());	   	
+		    getLogger().info("activate bundle with id {} ...", getBundleId());
 		    try {
 		    	start();
 		        getLogger().info("Bundle with id {} activated", getBundleId());
 		    } catch (Throwable e) {
 		    	ExceptionUtils.handleThrowable(e);
 		        getLogger().error("Bundle with id {} caught exception on start-up, it's possible that bundle with id {} is not correctly working, please check your configuration & set-up!", getBundleId(), getBundleId(), e);
-		    }	   
+		    }
 		}
 	}
 
@@ -338,29 +343,29 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 		    getLogger().info("Bundle with id {} deactivated.", getBundleId());
 		}
 	}
-	
+
 	public boolean isStopped() {
 		return stopped.get();
 	}
 
 	public void registerAllListenersToEventServices() {}
-	
+
 	public void registerServiceToEventServices(Object service) {}
-	
+
 	public void start() throws OXException {
 		createInstances();
-        injectValues();        
+        injectValues();
         injectDependencies();
         injectApplicationContext();
-        callPostContruct();        
+        callPostContruct();
         registerHttpConverter();
         registerAllListenersToEventServices();
         registerManagementObjects();
         startScheduledExecutorServices();
         registerServicesToOsgi();
-        startJmsMessageReceivers();        
+        startJmsMessageReceivers();
 	}
-	
+
 	public void startJmsMessageReceivers() {
 		for (Object obj : services) {
 			if (obj instanceof JmsMessageListener) {
@@ -369,41 +374,41 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 			}
 		}
 	}
-	
+
 	public void prepareObject(Object obj) {
 		injectValues(obj);
 		injectDependencies(obj);
 		injectApplicationContext(obj);
 		callPostContruct(obj);
-		startScheduledExecutorServices(obj);		
-	}	
-	
+		startScheduledExecutorServices(obj);
+	}
+
 	public void shutdown() throws OXException {
     	stopScheduledExecutorServices();
-        callPreDestroy();		
+        callPreDestroy();
         unregisterServicesFromOsgi();
 	}
-	
+
 	private void unregisterServicesFromOsgi() {
 		serviceRegistrations.forEach(r -> r.unregister());
 	}
-	
+
 	public boolean registerModuleForeignService(Object service) {
 		boolean res = registerService(service, false);
 		classNameToClassInstanceMapping.put(service.getClass().getName(), service.getClass());
 		return res;
 	}
-	
+
 	public boolean registerService(Object service, boolean doInject) {
 		boolean inUnitTestPreparation = Boolean.valueOf(System.getProperty(IN_UNIT_TEST, Boolean.FALSE.toString()));
 		if (inUnitTestPreparation) {
 			if (hasService(service.getClass())) {
 				return false;
-			}			
+			}
 		} else {
 			if (hasService(service.getClass())) {
 				throw new IllegalArgumentException("A service with class " + service.getClass() + " was already registered!, registered services: " + services);
-			}			
+			}
 		}
 		return doRegisterService(service, doInject);
 	}
@@ -420,11 +425,11 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 			injectValues(service);
 			injectDependencies(service);
 			callPostContruct(service);
-			registerServiceToEventServices(service);			
-		}		
+			registerServiceToEventServices(service);
+		}
 		return res;
 	}
-	
+
 	protected <T> boolean hasService(Class<T> clazz) {
 		for (Object obj : services) {
 			if (clazz.isInstance(obj)) {
@@ -435,19 +440,19 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 		return res != null;
 
 	}
-	
+
 	protected void onAfterCreateInstances() throws OXException {}
-	
-	protected void onPreCreateInstances() throws OXException {}	
-	
+
+	protected void onPreCreateInstances() throws OXException {}
+
 	public void createInstances() throws OXException {
 		getLogger().debug("create instances of bundle");
 		onPreCreateInstances();
-		
+
 		Set<String> foundServices = new HashSet<>();
 		Set<Class<?>> classes = getClassesOfBundle();
 
-		for (Class<?> clazz : classes) {			
+		for (Class<?> clazz : classes) {
     		if ((clazz.getAnnotation(RestController.class) != null) || (clazz.getAnnotation(Service.class) != null) || (clazz.getAnnotation(org.springframework.stereotype.Component.class) != null)) {
     			ConditionalOnProperty conditionalOnProperty = clazz.getAnnotation(ConditionalOnProperty.class);
     			boolean create = true;
@@ -459,19 +464,19 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 					} else {
 						create = value.equals(conditionalOnProperty.value()[0]);
 					}
-				}	    				
+				}
 				if (create) {
     				try {
-						Object obj = clazz.newInstance();								
+						Object obj = clazz.newInstance();
 						registerService(obj, false);
 						foundServices.add(clazz.getName());
 					} catch (InstantiationException | IllegalAccessException e) {
 						getLogger().error(e.getMessage(), e);
 						throw new RuntimeException(e);
-					}	    				
+					}
 				}
 			}
-	    }	    
+	    }
 	    if (foundServices.isEmpty() && !bundleContainsNoServices) {
 	    	getLogger().warn("No services in bundle {} found!", getBundleId());
 	    } else {
@@ -480,12 +485,12 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 	    }
 	    onAfterCreateInstances();
 	}
-	
+
 	public void startScheduledExecutorServices() {
 		getLogger().debug("Starting scheduled executer services");
 		startScheduledExecutorServices(services.toArray());
 	}
-	
+
 	public void startScheduledExecutorServices(Object...objects) {
 		Set<String> foundAsyncServices = new HashSet<>();
 		ConfigurationService configurationService = getConfigService();
@@ -505,7 +510,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 					}
 					if (StringUtils.isNoneBlank(asyncAnnotation.configNameInitialPeriod())) {
 						period = configurationService.getIntProperty(asyncAnnotation.configNameInitialPeriod(), (int) period);
-					}									
+					}
 					scheduledExecutorService.scheduleAtFixedRate(runnable, initDelay, period, asyncAnnotation.timeUnit());
 				}
 			}
@@ -515,32 +520,32 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 			getLogger().info("Found async services: {}", Arrays.toString(toLog.toArray()));
 		}
 	}
-	
+
 	public void stopScheduledExecutorServices() {
 		scheduledExecutorServices.forEach(s -> s.shutdown());
 	}
-	
+
 	public void injectApplicationContext() {
 		getLogger().debug("Inject applicationcontext into services");
 		injectApplicationContext(services.toArray());
 	}
-	
-	public void injectApplicationContext(Object...objects) {		
+
+	public void injectApplicationContext(Object...objects) {
 		for (Object obj : objects) {
 			if (obj instanceof OsgiBundleContextAware) {
 				((OsgiBundleContextAware) obj).setApplicationContext(this);
 			}
 		}
 	}
-	
+
 	public void injectValues() {
 		getLogger().debug("Inject values into services");
 		injectValues(services.toArray());
-	}	
-	
-	public void injectValues(Object...objects) {		
+	}
+
+	public void injectValues(Object...objects) {
 		ConfigurationService configurationService = getConfigService();
-		for (Object obj : objects) {			
+		for (Object obj : objects) {
 			Class<?> clazz = obj.getClass();
 			while (!clazz.equals(Object.class)) {
 				Field [] fields = clazz.getDeclaredFields();
@@ -549,9 +554,9 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 					if (valueAnno != null) {
 						field.setAccessible(true);
 						Class<?> fieldClass = field.getType();
-						
+
 				    	String annoValue = valueAnno.value().substring(2, valueAnno.value().length() - 1);
-				    	if (!valueAnno.value().startsWith("${") || !valueAnno.value().endsWith("}")) {				    		
+				    	if (!valueAnno.value().startsWith("${") || !valueAnno.value().endsWith("}")) {
 				    		getLogger().error("Wrong value annotation syntax in class {} and field {}", clazz.getName(), field.getName());
 				    		throw new IllegalArgumentException("Wrong value annotation syntax");
 				    	}
@@ -562,20 +567,20 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 				    		def = annoValue.substring(annoValue.indexOf(":") + 1).trim();
 				    	} else {
 				    		key = annoValue.trim();
-				    	}						
+				    	}
 						Object value = null;
 						switch (fieldClass.getName()) {
 							case "java.lang.String":
-								value = configurationService.getProperty(key, def);							
+								value = configurationService.getProperty(key, def);
 								break;
 							case "int":
 							case "java.lang.Integer":
-							case "java.lang.Long":								
+							case "java.lang.Long":
 								if (def == null) {
 									value = configurationService.getIntProperty(key, Integer.MIN_VALUE);
 								} else {
 									value = configurationService.getIntProperty(key, Integer.parseInt(def));
-								}		
+								}
 								if (value.equals(Integer.MIN_VALUE)) {
 									throw new ValueNotFoundException(key);
 								}
@@ -587,7 +592,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 									tmpBoolValue = configurationService.getProperty(key, "");
 								} else {
 									tmpBoolValue = configurationService.getProperty(key, def);
-								}		
+								}
 								if (tmpBoolValue.equals("")) {
 									throw new ValueNotFoundException(key);
 								}
@@ -595,9 +600,9 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 								break;
 							default: throw new RuntimeException("@Value for type " + fieldClass.getName() + " not implemented yet!");
 						}
-						
+
 						try {
-							field.set(obj, value);							
+							field.set(obj, value);
 						} catch (IllegalArgumentException | IllegalAccessException e) {
 							getLogger().error(e.getMessage(), e);
 							throw new RuntimeException(e);
@@ -606,14 +611,14 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 				}
 				clazz = clazz.getSuperclass();
 			}
-		}		
+		}
 	}
-	
+
 	public void injectDependencies() {
 		getLogger().debug("Inject dependencies...");
 		injectDependencies(services.toArray());
 	}
-	
+
 	public void injectDependencies(Object...objects) {
 		Set<String> optionalServiceListeners = new HashSet<>();
 		for (Object obj : objects) {
@@ -629,9 +634,9 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 							if (service == null) {
 								throw new IllegalArgumentException("No service with class " + fieldClass + " found!");
 							}
-						}	
+						}
 						field.setAccessible(true);
-						if (service != null) {							
+						if (service != null) {
 							try {
 								field.set(obj, service);
 							} catch (IllegalArgumentException | IllegalAccessException e) {
@@ -652,7 +657,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 									throw new RuntimeException(e);
 								}
 							}
-						}						
+						}
 					}
 				}
 				clazz = clazz.getSuperclass();
@@ -661,19 +666,19 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 		for (Object obj : objects) {
 			if (obj instanceof OsgiBundleContextAware) {
 				((OsgiBundleContextAware) obj).setApplicationContext(this);
-			}						
+			}
 		}
 		if (!optionalServiceListeners.isEmpty()) {
 			Collection<String> toLog = reduceLoggingEntriesByMainPackageName(optionalServiceListeners);
 			getLogger().debug("Registered optional service listener: {}", Arrays.toString(toLog.toArray()));
 		}
 	}
-	
+
 	public void callPostContruct() {
 		getLogger().debug("Calling postcontruct on services");
 		callPostContruct(services.toArray());
 	}
-	
+
 	public void callPostContruct(Object...objects) {
 		for (Object obj : objects) {
 			if (obj instanceof InitializingBean) {
@@ -687,14 +692,14 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 			}
 		}
 	}
-	
+
 	public void callPreDestroy() {
 		getLogger().info("Calling predestroy on services");
 		callPreDestroy(services.toArray());
 	}
 
 	public void callPreDestroy(Object...objects) {
-		List<Object> objListToDestroy = new ArrayList<>();		
+		List<Object> objListToDestroy = new ArrayList<>();
 		for (Object obj : objects) {
 			if (obj instanceof DisposableBean) {
 				objListToDestroy.add(obj);
@@ -709,26 +714,26 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 				ShutdownOrder shutdownOrderO2 = o2.getClass().getAnnotation(ShutdownOrder.class);
 				Integer shutdownValueO2 = shutdownOrderO2 == null ? 0 : shutdownOrderO2.value();
 				return shutdownValueO1.compareTo(shutdownValueO2);
-			}			
-		});	
+			}
+		});
 		for (Object obj : objects) {
 			JMXBean jmxBean =  obj.getClass().getAnnotation(JMXBean.class);
 			if (jmxBean != null) {
 				ManagedResource managedResource = obj.getClass().getAnnotation(ManagedResource.class);
 				String objectNameString;
-				if (managedResource != null) {		
+				if (managedResource != null) {
 					objectNameString = managedResource.objectName();
 				} else {
 					String packageName = obj.getClass().getPackage().getName();
 					String className = obj.getClass().getSimpleName();
-					objectNameString = packageName + ":name=" + className;					
+					objectNameString = packageName + ":name=" + className;
 				}
 				try {
 					ObjectName objectName = new ObjectName(objectNameString);
 					getMbeanServer().unregisterMBean(objectName);
 				} catch (JMException e) {
 					getLogger().warn(e.getMessage());
-				}				
+				}
 			}
 		}
 		for (Object obj : objListToDestroy) {
@@ -739,9 +744,9 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 				getLogger().error(e.getMessage(), e);
 				throw new RuntimeException(e);
 			}
-		}			
+		}
 	}
-	
+
 	@SuppressWarnings("unchecked")
 	protected <T> T findService(Class<T> clazz, boolean optional) {
 		for (Object obj : services) {
@@ -752,27 +757,27 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 		T res = getExternalDependency(clazz, null, optional);
 		return res;
 	}
-		
+
 	public void registerManagementObjects() throws OXException {
 		Set<String> foundMngtServices = new HashSet<>();
 		getLogger().debug("Register managment service objects");
-		for (Object service : services) {			
+		for (Object service : services) {
 			JMXBean jmxBeanAnno = service.getClass().getAnnotation(JMXBean.class);
 			if (jmxBeanAnno != null) {
 				getLogger().debug("Found management service: {}", service.getClass().getName());
 				foundMngtServices.add(service.getClass().getName());
 				ManagedResource managedResource = service.getClass().getAnnotation(ManagedResource.class);
 				String objectNameString;
-				if (managedResource != null) {		
+				if (managedResource != null) {
 					objectNameString = managedResource.objectName();
 				} else {
 					String packageName = service.getClass().getPackage().getName();
 					String className = service.getClass().getSimpleName();
-					objectNameString = packageName + ":name=" + className;					
+					objectNameString = packageName + ":name=" + className;
 				}
 				try {
 					ObjectName objectName = new ObjectName(objectNameString);
-					JMXBeanWrapper wrapperBean = new JMXBeanWrapper(service);					
+					JMXBeanWrapper wrapperBean = new JMXBeanWrapper(service);
 					getMbeanServer().registerMBean(wrapperBean, objectName);
 				} catch (Exception ex) {
 					getLogger().warn(ex.getMessage());
@@ -783,7 +788,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 			Collection<String> toLog = reduceLoggingEntriesByMainPackageName(foundMngtServices);
 			log.debug("Found management service object: {}", Arrays.toString(toLog.toArray()));
 		}
-	}	
+	}
 
 	private MBeanServer getMbeanServer() {
 		SpecificPlatform platform = SpecificPlatform.get();
@@ -802,7 +807,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 		services.forEach(s -> {
 			RegisteredService registeredServiceAnno = s.getClass().getAnnotation(RegisteredService.class);
 			if (registeredServiceAnno != null) {
-				
+
 				if (registeredServiceAnno.registeredClass().equals(Object.class)) {
 					registerServiceToOsgi(s, s.getClass());
 					allOsgiServices.add(s.getClass().getName());
@@ -813,30 +818,30 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 			}
 		});
 		if (!allOsgiServices.isEmpty()) {
-			Set<String> logSet = allOsgiServices.stream().map(s -> s.substring(bundleIdentificator.getClass().getPackage().getName().length())).collect(Collectors.toSet());			
+			Set<String> logSet = allOsgiServices.stream().map(s -> s.substring(bundleIdentificator.getClass().getPackage().getName().length())).collect(Collectors.toSet());
 			getLogger().debug("Registered services to OSGI: {}", logSet);
 		}
 	}
-	
-	public void registerServiceToOsgi(Object service, Class<?> clazzToRegister) {		
+
+	public void registerServiceToOsgi(Object service, Class<?> clazzToRegister) {
 	    Bundle bundle = FrameworkUtil.getBundle(service.getClass());
 	    BundleContext bundleContext = bundle.getBundleContext();
 	    String classNameToRegister = Object.class.equals(clazzToRegister) ? service.getClass().getName() : clazzToRegister.getName();
-	    getLogger().debug("ClassnameToRegister: " + classNameToRegister + ", service: " + service.getClass().getName() );	    
+	    getLogger().debug("ClassnameToRegister: " + classNameToRegister + ", service: " + service.getClass().getName() );
 	    bundleContext.registerService(classNameToRegister, service, null);
 	}
-	
+
 	public void registerAjaxActionServiceFactoryToOSGI(AJAXActionServiceFactory ajaxActionServiceFactory, String moduleName, boolean multiple) {
 		final Dictionary< String, Object > dictionary = new Hashtable< >();
         dictionary.put("module"  , moduleName);
         dictionary.put("multiple", multiple ? "true" : "false");
-		
+
 	    Bundle bundle = FrameworkUtil.getBundle(ajaxActionServiceFactory.getClass());
 	    BundleContext bundleContext = bundle.getBundleContext();
 	    serviceRegistrations.add(bundleContext.registerService(AJAXActionServiceFactory.class, ajaxActionServiceFactory, dictionary));
-	    
+
 	}
-	
+
 	public void registerHttpConverter() {
 		HttpModelConverterRegistry httpModelConverterRegistry = null;
 		for (Object service : services) {
@@ -848,7 +853,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 			}
 		}
 	}
-	
+
 	public ConfigurationService getConfigService() {
 		ConfigurationService configurationService = getExternalDependency(ConfigurationService.class, this.getClass(), true);
 		if (configurationService != null) {
@@ -864,9 +869,9 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 			throw new RuntimeException("No configurationService found!!!");
 		}
 		return configurationService;
-		
+
 	}
-	
+
 	@SuppressWarnings("unchecked")
 	public <T> Collection<T> getServicesOfType(Class<T> clazz) {
 		Collection<T> res = new HashSet<>();
@@ -877,7 +882,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 		}
 		return res;
 	}
-	
+
 	@SuppressWarnings("unchecked")
 	protected <T> T getExternalDependency(Class<T> serviceClass, Class<?> owner, boolean optional) {
 		for (Object service : services) {
@@ -893,7 +898,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 		final BundleContext bundleContext = bundle.getBundleContext();
 		if ((bundleContext == null) && optional) {
 			return null;
-		}		
+		}
 		if (bundleContext == null) {
 			getLogger().error("No bundle context found for class {}", serviceClass.getName());
 			throw new RuntimeException("No bundle context found for class " + serviceClass.getName());
@@ -904,7 +909,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 		}
 		if (serviceReference == null) {
 			getLogger().error("No service reference found for class {} in bundle {}", serviceClass.getName(), bundle.getSymbolicName(), new Exception());
-			throw new RuntimeException("No service reference found for class " + serviceClass.getName() + " needed in class " + getOwner(owner));			
+			throw new RuntimeException("No service reference found for class " + serviceClass.getName() + " needed in class " + getOwner(owner));
 		}
 		T res = bundleContext.getService(serviceReference);
 		return res;
@@ -916,7 +921,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 		}
 		return "<unknown>";
 	}
-	
+
 	@Override
 	public <S> S getService(Class<? extends S> clazz) {
 		return findService(clazz, false);
@@ -934,7 +939,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 
 	@Override
 	protected <S> boolean removeService(Class<? extends S> clazz) {
-		Set<Object> toRemove = new HashSet<>(); 
+		Set<Object> toRemove = new HashSet<>();
 		for (Object obj : services) {
 			if (clazz.isAssignableFrom(obj.getClass())) {
 				toRemove.add(obj);
@@ -946,10 +951,10 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 		return !toRemove.isEmpty();
 	}
 
-	//-----------------------------ListableBeanFactory-Methods---------------------------------------------------------	
+	//-----------------------------ListableBeanFactory-Methods---------------------------------------------------------
 	@Override
 	public Object getBean(String name) throws BeansException {
-		if (!classNameToClassInstanceMapping.containsKey(name)) {					
+		if (!classNameToClassInstanceMapping.containsKey(name)) {
 			throw new BeanCreationException("Cannot find class instance of name " + name);
 		}
 		Class<?> clazz = classNameToClassInstanceMapping.get(name);
@@ -1032,7 +1037,7 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 	}
 
 	@Override
-	public String[] getBeanDefinitionNames() {		
+	public String[] getBeanDefinitionNames() {
 		List<String> res = services.stream().map(o -> o.getClass().getName()).collect(Collectors.toList());
 		return res.toArray(new String[0]);
 	}
@@ -1086,27 +1091,44 @@ public abstract class OsgiBundleContextAndActivator extends HousekeepingActivato
 			throws NoSuchBeanDefinitionException {
 		Object bean = getBean(beanName);
 		return bean.getClass().getAnnotation(annotationType);
-	}	
-	
-	public String[] getBeanNamesForType(ResolvableType arg0, boolean arg1, boolean arg2) {
+	}
+
+	@Override
+    public String[] getBeanNamesForType(ResolvableType arg0, boolean arg1, boolean arg2) {
 		throw new NotImplementedException("OsgiBundleContextAndActivator::getBeanNamesForType(ResolvableType arg0, boolean arg1, boolean arg2)");
 	}
 
-	public Class<?> getType(String arg0, boolean arg1) throws NoSuchBeanDefinitionException {
+	@Override
+    public Class<?> getType(String arg0, boolean arg1) throws NoSuchBeanDefinitionException {
 		Object res = getOptionalService(arg0);
 		if (res == null) {
 			throw new NoSuchBeanDefinitionException(arg0);
 		}
 		return res.getClass();
-	}	
-	
+	}
+
+    public <T> ObjectProvider<T> getBeanProvider(Class<T> requiredType, boolean allowEagerInit) {
+        throw new NotImplementedException("OsgiBundleContextAndActivator::getBeanProvider(Class<T> requiredType, boolean allowEagerInit)");
+    }
+
+    public <T> ObjectProvider<T> getBeanProvider(ResolvableType requiredType, boolean allowEagerInit) {
+        throw new NotImplementedException("OsgiBundleContextAndActivator::getBeanProvider(ResolvableType requiredType, boolean allowEagerInit)");
+    }
+
+    public <A extends Annotation> A findAnnotationOnBean(String beanName, Class<A> annotationType, boolean allowFactoryBeanInit) throws NoSuchBeanDefinitionException {
+        if (allowFactoryBeanInit)
+            throw new NotImplementedException("OsgiBundleContextAndActivator::findAnnotationOnBean(String beanName, Class<A> annotationType, boolean allowFactoryBeanInit) with allowFactoryBeanInit = true");
+
+        return findAnnotationOnBean(beanName, annotationType);
+    }
+
 	private Object getOptionalService(String name) {
 		try {
 			Class<?> clazz = Class.forName(name);
 			return getOptionalService(clazz);
-				
+
 		} catch (ClassNotFoundException e) {
 			return null;
-		}		
+		}
 	}
 }
