@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -38,7 +38,8 @@ public class JmsConfigService {
     public static final String KEY_JMS_PASSWORD = "com.openexchange.dcs.client.password";
     public static final String JMS_PASSWORD_DEFAULT = ""; 
     
-    public static final String JMS_KEY_SSL_VERIFY_HOSTNAME = "com.openexchange.dcs.client.ssl.verifyHostname";
+    public static final String KEY_JMS_SSL_ENABLED = "com.openexchange.dcs.client.ssl.enabled";
+    public static final String KEY_JMS_SSL_VERIFY_HOSTNAME = "com.openexchange.dcs.client.ssl.verifyHostname";
 
     public static final String KEY_JMS_SSL_KEYSTORE_PATH = "com.openexchange.dcs.client.ssl.keystore.path";
     public static final String JMS_SSL_KEYSTORE_PATH_DEFAULT = "/opt/open-xchange/etc/security/documents-collaboration-client.ks";
@@ -56,8 +57,25 @@ public class JmsConfigService {
     private ConfigurationService configurationService;    
     
     //-------------------------------------------------------------------------
+    /**
+     * Provides the state of the verify host name feature to check
+     * the host name against a stored certificate when using SSL
+     * connections.
+     * <b>REMARK: The current implementation does not support host names for
+     * DCS instances, therefore setting verifyHostName to true won't make any
+     * sense.</b>
+     * TODO: change this hard-coded solution if we want to support host names, too.
+     *
+     * @return FALSE
+     */
     public boolean isRT2SSLVerifyHostname() {
-        return configurationService.getBoolProperty(JMS_KEY_SSL_VERIFY_HOSTNAME, false);
+        return false;
+        //return configurationService.getBoolProperty(KEY_JMS_SSL_VERIFY_HOSTNAME, false);
+    }
+
+    //-------------------------------------------------------------------------
+    public boolean isRT2SSLEnabled() {
+        return configurationService.getBoolProperty(KEY_JMS_SSL_ENABLED, false);
     }
 
     //-------------------------------------------------------------------------
