@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -29,6 +29,7 @@ import java.util.List;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicReference;
 
 import org.apache.activemq.ActiveMQConnectionFactory;
 import org.apache.activemq.pool.PooledConnectionFactory;
@@ -62,17 +63,23 @@ public class PooledConnectionFactoryCreator implements OsgiBundleContextAware, D
     private final ScheduledExecutorService scheduledExecService = Executors.newScheduledThreadPool(1, new ThreadFactoryBuilder("UrlInSyncWatchDogThread-%d").build());
     
     private LocalDateTime lastErrMsg = null;
-	
-	private PooledConnectionFactory pooledConnectionFactory = null;
-	
+
+	private AtomicReference<PooledConnectionFactory> pooledConnectionFactoryRef = new AtomicReference<>();
+
 	@Override
 	public void setApplicationContext(OsgiBundleContextAndActivator bundleCtx) {
-        log.debug("Creating PooledConnectionFactory for connection to JMS Server...");
-        pooledConnectionFactory = new PooledConnectionFactory();
-        pooledConnectionFactory.setConnectionFactory(getJmsConnectionFactory());
-        bundleCtx.registerServiceToOsgi(new PooledConnectionFactoryProxy(pooledConnectionFactory), PooledConnectionFactoryProxy.class);
-        bundleCtx.registerServiceToOsgi(getJmsTemplateWithoutTtl(), JmsTemplateWithoutTtl.class);
-        bundleCtx.registerServiceToOsgi(getJmsTemplateWithTtl(), JmsTemplateWithTtl.class);
+	    // Prevent a double initialization due to calling setApplicationContext() via
+	    // injectDependencies && by a explicit call of setApplicationContext() in the
+	    // OSGi / spring-boot convenience layer (OsgiBundlesContextAndActivator).
+	    if (pooledConnectionFactoryRef.get() == null) {
+	        if (pooledConnectionFactoryRef.compareAndSet(null, new PooledConnectionFactory())) {
+	            log.debug("Creating PooledConnectionFactory for connection to JMS Server...");
+	            pooledConnectionFactoryRef.get().setConnectionFactory(getJmsConnectionFactory());
+	            bundleCtx.registerServiceToOsgi(new PooledConnectionFactoryProxy(pooledConnectionFactoryRef.get()), PooledConnectionFactoryProxy.class);
+	            bundleCtx.registerServiceToOsgi(getJmsTemplateWithoutTtl(), JmsTemplateWithoutTtl.class);
+	            bundleCtx.registerServiceToOsgi(getJmsTemplateWithTtl(), JmsTemplateWithTtl.class);
+	        }
+	    }
 	}
 	
     @Override
@@ -80,20 +87,21 @@ public class PooledConnectionFactoryCreator implements OsgiBundleContextAware, D
         scheduledExecService.shutdown();
     	//-------------------------------------------------------------------------
         log.info("... deactivate connection factory");
-        if (pooledConnectionFactory != null) {
-        	pooledConnectionFactory.stop();
+        PooledConnectionFactory factory = pooledConnectionFactoryRef.get();
+        if (factory != null) {
+            factory.stop();
         }
     }
 	
     private JmsTemplateWithoutTtl getJmsTemplateWithoutTtl() {
-    	JmsTemplateWithoutTtl res =  new JmsTemplateWithoutTtl(pooledConnectionFactory);
+    	JmsTemplateWithoutTtl res =  new JmsTemplateWithoutTtl(pooledConnectionFactoryRef.get());
     	res.setTimeToLive(0);
     	res.setExplicitQosEnabled(false);
     	return res;
     }
     
     private JmsTemplateWithTtl getJmsTemplateWithTtl() {
-    	JmsTemplateWithTtl res = new JmsTemplateWithTtl(pooledConnectionFactory);
+    	JmsTemplateWithTtl res = new JmsTemplateWithTtl(pooledConnectionFactoryRef.get());
     	res.setTimeToLive(60000);
     	res.setExplicitQosEnabled(true);    	
     	return res;
@@ -139,6 +147,7 @@ public class PooledConnectionFactoryCreator implements OsgiBundleContextAware, D
 
             @Override
             public void transportInterupted() {
+                log.info("Interrupted transport connection to dcs with broker url {}", jmsConnectionFactory.getBrokerURL());
             }
 
             @Override
@@ -187,7 +196,7 @@ public class PooledConnectionFactoryCreator implements OsgiBundleContextAware, D
                 append(item.getJMSPort());
 
             if (useSSL) {
-                res.append("?verifyHostName=" + (jmsConfigService.isRT2SSLVerifyHostname() ? "true" : "false"));
+                res.append("?socket.verifyHostName=" + (jmsConfigService.isRT2SSLVerifyHostname() ? "true" : "false"));
             }
 
             if ((i + 1) < dcsRegistryItems.size()) {
@@ -195,7 +204,21 @@ public class PooledConnectionFactoryCreator implements OsgiBundleContextAware, D
             }
         }
         res.append(")?maxReconnectAttempts=3");
-        ActiveMQConnectionFactory amqFactory = (ActiveMQConnectionFactory)(pooledConnectionFactory.getConnectionFactory());
+
+        // DOCS-3619: We have to disable the updateURIsSupported option if SSL connections are
+        // used between client & broker with failover transport. There is a strange behavior of
+        // ActiveMQ and the JMS client. It receives a ConnectionControl message from a broker and starts
+        // a rebalance process. For this rebalancing the FailoverTransport class prioritize the connected
+        // broker information from ConnectionControl message, where the correct protocol and ip-addresses
+        // are provided, but which lacks the important query parameters. This leads to the fact that
+        // the verifyHostName option get lost on this rebalance process and the client won't be able to
+        // connect to a broker that uses a certificate that does not match to the domain/hostname.
+        // Since ActiveMQ 5.4 the option updateURIsSupported has been implemented and by default is set
+        // to true.
+        if (jmsConfigService.isRT2SSLEnabled() && !jmsConfigService.isRT2SSLVerifyHostname()) {
+            res.append("&updateURIsSupported=false");
+        }
+        ActiveMQConnectionFactory amqFactory = (ActiveMQConnectionFactory)(pooledConnectionFactoryRef.get().getConnectionFactory());
         if ((amqFactory == null) || !amqFactory.getBrokerURL().equals(res.toString())) {
             log.info("Broker Url for the connection to DCS is: {}", res);
         } else {
